/* common.c generated by valac 0.32.1, the Vala compiler
 * generated from common.vala, do not modify */

/* Copyright 2016 Software Freedom Conservancy Inc.
 *
 * This software is licensed under the GNU Lesser General Public License
 * (version 2.1 or later).  See the COPYING file in this distribution.
 */
/* A simple grouping Entry that is only expandable*/

#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <gtk/gtk.h>
#include <gdk/gdk.h>


#define SIDEBAR_TYPE_ENTRY (sidebar_entry_get_type ())
#define SIDEBAR_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_ENTRY, SidebarEntry))
#define SIDEBAR_IS_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_ENTRY))
#define SIDEBAR_ENTRY_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), SIDEBAR_TYPE_ENTRY, SidebarEntryIface))

typedef struct _SidebarEntry SidebarEntry;
typedef struct _SidebarEntryIface SidebarEntryIface;

#define SIDEBAR_TYPE_TREE (sidebar_tree_get_type ())
#define SIDEBAR_TREE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_TREE, SidebarTree))
#define SIDEBAR_TREE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SIDEBAR_TYPE_TREE, SidebarTreeClass))
#define SIDEBAR_IS_TREE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_TREE))
#define SIDEBAR_IS_TREE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SIDEBAR_TYPE_TREE))
#define SIDEBAR_TREE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SIDEBAR_TYPE_TREE, SidebarTreeClass))

typedef struct _SidebarTree SidebarTree;
typedef struct _SidebarTreeClass SidebarTreeClass;

#define SIDEBAR_TYPE_EXPANDABLE_ENTRY (sidebar_expandable_entry_get_type ())
#define SIDEBAR_EXPANDABLE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_EXPANDABLE_ENTRY, SidebarExpandableEntry))
#define SIDEBAR_IS_EXPANDABLE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_EXPANDABLE_ENTRY))
#define SIDEBAR_EXPANDABLE_ENTRY_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), SIDEBAR_TYPE_EXPANDABLE_ENTRY, SidebarExpandableEntryIface))

typedef struct _SidebarExpandableEntry SidebarExpandableEntry;
typedef struct _SidebarExpandableEntryIface SidebarExpandableEntryIface;

#define SIDEBAR_TYPE_RENAMEABLE_ENTRY (sidebar_renameable_entry_get_type ())
#define SIDEBAR_RENAMEABLE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_RENAMEABLE_ENTRY, SidebarRenameableEntry))
#define SIDEBAR_IS_RENAMEABLE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_RENAMEABLE_ENTRY))
#define SIDEBAR_RENAMEABLE_ENTRY_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), SIDEBAR_TYPE_RENAMEABLE_ENTRY, SidebarRenameableEntryIface))

typedef struct _SidebarRenameableEntry SidebarRenameableEntry;
typedef struct _SidebarRenameableEntryIface SidebarRenameableEntryIface;

#define SIDEBAR_TYPE_GROUPING (sidebar_grouping_get_type ())
#define SIDEBAR_GROUPING(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_GROUPING, SidebarGrouping))
#define SIDEBAR_GROUPING_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SIDEBAR_TYPE_GROUPING, SidebarGroupingClass))
#define SIDEBAR_IS_GROUPING(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_GROUPING))
#define SIDEBAR_IS_GROUPING_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SIDEBAR_TYPE_GROUPING))
#define SIDEBAR_GROUPING_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SIDEBAR_TYPE_GROUPING, SidebarGroupingClass))

typedef struct _SidebarGrouping SidebarGrouping;
typedef struct _SidebarGroupingClass SidebarGroupingClass;
typedef struct _SidebarGroupingPrivate SidebarGroupingPrivate;
#define _g_free0(var) (var = (g_free (var), NULL))

#define SIDEBAR_TYPE_SELECTABLE_ENTRY (sidebar_selectable_entry_get_type ())
#define SIDEBAR_SELECTABLE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_SELECTABLE_ENTRY, SidebarSelectableEntry))
#define SIDEBAR_IS_SELECTABLE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_SELECTABLE_ENTRY))
#define SIDEBAR_SELECTABLE_ENTRY_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), SIDEBAR_TYPE_SELECTABLE_ENTRY, SidebarSelectableEntryIface))

typedef struct _SidebarSelectableEntry SidebarSelectableEntry;
typedef struct _SidebarSelectableEntryIface SidebarSelectableEntryIface;

#define SIDEBAR_TYPE_PAGE_REPRESENTATIVE (sidebar_page_representative_get_type ())
#define SIDEBAR_PAGE_REPRESENTATIVE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_PAGE_REPRESENTATIVE, SidebarPageRepresentative))
#define SIDEBAR_IS_PAGE_REPRESENTATIVE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_PAGE_REPRESENTATIVE))
#define SIDEBAR_PAGE_REPRESENTATIVE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), SIDEBAR_TYPE_PAGE_REPRESENTATIVE, SidebarPageRepresentativeIface))

typedef struct _SidebarPageRepresentative SidebarPageRepresentative;
typedef struct _SidebarPageRepresentativeIface SidebarPageRepresentativeIface;

#define TYPE_PAGE (page_get_type ())
#define PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PAGE, Page))
#define PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PAGE, PageClass))
#define IS_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PAGE))
#define IS_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PAGE))
#define PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PAGE, PageClass))

typedef struct _Page Page;
typedef struct _PageClass PageClass;

#define SIDEBAR_TYPE_CONTEXTABLE (sidebar_contextable_get_type ())
#define SIDEBAR_CONTEXTABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_CONTEXTABLE, SidebarContextable))
#define SIDEBAR_IS_CONTEXTABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_CONTEXTABLE))
#define SIDEBAR_CONTEXTABLE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), SIDEBAR_TYPE_CONTEXTABLE, SidebarContextableIface))

typedef struct _SidebarContextable SidebarContextable;
typedef struct _SidebarContextableIface SidebarContextableIface;

#define SIDEBAR_TYPE_SIMPLE_PAGE_ENTRY (sidebar_simple_page_entry_get_type ())
#define SIDEBAR_SIMPLE_PAGE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_SIMPLE_PAGE_ENTRY, SidebarSimplePageEntry))
#define SIDEBAR_SIMPLE_PAGE_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SIDEBAR_TYPE_SIMPLE_PAGE_ENTRY, SidebarSimplePageEntryClass))
#define SIDEBAR_IS_SIMPLE_PAGE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_SIMPLE_PAGE_ENTRY))
#define SIDEBAR_IS_SIMPLE_PAGE_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SIDEBAR_TYPE_SIMPLE_PAGE_ENTRY))
#define SIDEBAR_SIMPLE_PAGE_ENTRY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SIDEBAR_TYPE_SIMPLE_PAGE_ENTRY, SidebarSimplePageEntryClass))

typedef struct _SidebarSimplePageEntry SidebarSimplePageEntry;
typedef struct _SidebarSimplePageEntryClass SidebarSimplePageEntryClass;
typedef struct _SidebarSimplePageEntryPrivate SidebarSimplePageEntryPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define SIDEBAR_TYPE_BRANCH (sidebar_branch_get_type ())
#define SIDEBAR_BRANCH(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_BRANCH, SidebarBranch))
#define SIDEBAR_BRANCH_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SIDEBAR_TYPE_BRANCH, SidebarBranchClass))
#define SIDEBAR_IS_BRANCH(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_BRANCH))
#define SIDEBAR_IS_BRANCH_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SIDEBAR_TYPE_BRANCH))
#define SIDEBAR_BRANCH_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SIDEBAR_TYPE_BRANCH, SidebarBranchClass))

typedef struct _SidebarBranch SidebarBranch;
typedef struct _SidebarBranchClass SidebarBranchClass;
typedef struct _SidebarBranchPrivate SidebarBranchPrivate;

#define SIDEBAR_TYPE_ROOT_ONLY_BRANCH (sidebar_root_only_branch_get_type ())
#define SIDEBAR_ROOT_ONLY_BRANCH(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_ROOT_ONLY_BRANCH, SidebarRootOnlyBranch))
#define SIDEBAR_ROOT_ONLY_BRANCH_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SIDEBAR_TYPE_ROOT_ONLY_BRANCH, SidebarRootOnlyBranchClass))
#define SIDEBAR_IS_ROOT_ONLY_BRANCH(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_ROOT_ONLY_BRANCH))
#define SIDEBAR_IS_ROOT_ONLY_BRANCH_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SIDEBAR_TYPE_ROOT_ONLY_BRANCH))
#define SIDEBAR_ROOT_ONLY_BRANCH_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SIDEBAR_TYPE_ROOT_ONLY_BRANCH, SidebarRootOnlyBranchClass))

typedef struct _SidebarRootOnlyBranch SidebarRootOnlyBranch;
typedef struct _SidebarRootOnlyBranchClass SidebarRootOnlyBranchClass;
typedef struct _SidebarRootOnlyBranchPrivate SidebarRootOnlyBranchPrivate;

#define SIDEBAR_BRANCH_TYPE_OPTIONS (sidebar_branch_options_get_type ())

#define SIDEBAR_TYPE_EMPHASIZABLE_ENTRY (sidebar_emphasizable_entry_get_type ())
#define SIDEBAR_EMPHASIZABLE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_EMPHASIZABLE_ENTRY, SidebarEmphasizableEntry))
#define SIDEBAR_IS_EMPHASIZABLE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_EMPHASIZABLE_ENTRY))
#define SIDEBAR_EMPHASIZABLE_ENTRY_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), SIDEBAR_TYPE_EMPHASIZABLE_ENTRY, SidebarEmphasizableEntryIface))

typedef struct _SidebarEmphasizableEntry SidebarEmphasizableEntry;
typedef struct _SidebarEmphasizableEntryIface SidebarEmphasizableEntryIface;

#define SIDEBAR_TYPE_HEADER (sidebar_header_get_type ())
#define SIDEBAR_HEADER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_HEADER, SidebarHeader))
#define SIDEBAR_HEADER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SIDEBAR_TYPE_HEADER, SidebarHeaderClass))
#define SIDEBAR_IS_HEADER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_HEADER))
#define SIDEBAR_IS_HEADER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SIDEBAR_TYPE_HEADER))
#define SIDEBAR_HEADER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SIDEBAR_TYPE_HEADER, SidebarHeaderClass))

typedef struct _SidebarHeader SidebarHeader;
typedef struct _SidebarHeaderClass SidebarHeaderClass;
typedef struct _SidebarHeaderPrivate SidebarHeaderPrivate;

struct _SidebarEntryIface {
	GTypeInterface parent_iface;
	gchar* (*get_sidebar_name) (SidebarEntry* self);
	gchar* (*get_sidebar_tooltip) (SidebarEntry* self);
	gchar* (*get_sidebar_icon) (SidebarEntry* self);
	gchar* (*to_string) (SidebarEntry* self);
	void (*grafted) (SidebarEntry* self, SidebarTree* tree);
	void (*pruned) (SidebarEntry* self, SidebarTree* tree);
};

struct _SidebarExpandableEntryIface {
	GTypeInterface parent_iface;
	gboolean (*expand_on_select) (SidebarExpandableEntry* self);
};

struct _SidebarRenameableEntryIface {
	GTypeInterface parent_iface;
	void (*rename) (SidebarRenameableEntry* self, const gchar* new_name);
	gboolean (*is_user_renameable) (SidebarRenameableEntry* self);
};

struct _SidebarGrouping {
	GObject parent_instance;
	SidebarGroupingPrivate * priv;
};

struct _SidebarGroupingClass {
	GObjectClass parent_class;
};

struct _SidebarGroupingPrivate {
	gchar* name;
	gchar* tooltip;
	gchar* icon;
};

struct _SidebarSelectableEntryIface {
	GTypeInterface parent_iface;
};

struct _SidebarPageRepresentativeIface {
	GTypeInterface parent_iface;
	gboolean (*has_page) (SidebarPageRepresentative* self);
	Page* (*get_page) (SidebarPageRepresentative* self);
};

struct _SidebarContextableIface {
	GTypeInterface parent_iface;
	GtkMenu* (*get_sidebar_context_menu) (SidebarContextable* self, GdkEventButton* event);
};

struct _SidebarSimplePageEntry {
	GObject parent_instance;
	SidebarSimplePageEntryPrivate * priv;
};

struct _SidebarSimplePageEntryClass {
	GObjectClass parent_class;
	gchar* (*get_sidebar_name) (SidebarSimplePageEntry* self);
	gchar* (*get_sidebar_tooltip) (SidebarSimplePageEntry* self);
	gchar* (*get_sidebar_icon) (SidebarSimplePageEntry* self);
	gchar* (*to_string) (SidebarSimplePageEntry* self);
	Page* (*create_page) (SidebarSimplePageEntry* self);
};

struct _SidebarSimplePageEntryPrivate {
	Page* page;
};

struct _SidebarBranch {
	GObject parent_instance;
	SidebarBranchPrivate * priv;
};

struct _SidebarBranchClass {
	GObjectClass parent_class;
};

struct _SidebarRootOnlyBranch {
	SidebarBranch parent_instance;
	SidebarRootOnlyBranchPrivate * priv;
};

struct _SidebarRootOnlyBranchClass {
	SidebarBranchClass parent_class;
};

typedef enum  {
	SIDEBAR_BRANCH_OPTIONS_NONE = 0,
	SIDEBAR_BRANCH_OPTIONS_HIDE_IF_EMPTY = 1 << 0,
	SIDEBAR_BRANCH_OPTIONS_AUTO_OPEN_ON_NEW_CHILD = 1 << 1,
	SIDEBAR_BRANCH_OPTIONS_STARTUP_EXPAND_TO_FIRST_CHILD = 1 << 2,
	SIDEBAR_BRANCH_OPTIONS_STARTUP_OPEN_GROUPING = 1 << 3
} SidebarBranchOptions;

struct _SidebarEmphasizableEntryIface {
	GTypeInterface parent_iface;
	gboolean (*is_emphasized) (SidebarEmphasizableEntry* self);
};

struct _SidebarHeader {
	SidebarGrouping parent_instance;
	SidebarHeaderPrivate * priv;
};

struct _SidebarHeaderClass {
	SidebarGroupingClass parent_class;
};

struct _SidebarHeaderPrivate {
	gboolean emphasized;
};


static gpointer sidebar_grouping_parent_class = NULL;
static SidebarEntryIface* sidebar_grouping_sidebar_entry_parent_iface = NULL;
static SidebarExpandableEntryIface* sidebar_grouping_sidebar_expandable_entry_parent_iface = NULL;
static SidebarRenameableEntryIface* sidebar_grouping_sidebar_renameable_entry_parent_iface = NULL;
static gpointer sidebar_simple_page_entry_parent_class = NULL;
static SidebarEntryIface* sidebar_simple_page_entry_sidebar_entry_parent_iface = NULL;
static SidebarSelectableEntryIface* sidebar_simple_page_entry_sidebar_selectable_entry_parent_iface = NULL;
static SidebarPageRepresentativeIface* sidebar_simple_page_entry_sidebar_page_representative_parent_iface = NULL;
static SidebarContextableIface* sidebar_simple_page_entry_sidebar_contextable_parent_iface = NULL;
static gpointer sidebar_root_only_branch_parent_class = NULL;
static gpointer sidebar_header_parent_class = NULL;
static SidebarEmphasizableEntryIface* sidebar_header_sidebar_emphasizable_entry_parent_iface = NULL;

GType sidebar_tree_get_type (void) G_GNUC_CONST;
GType sidebar_entry_get_type (void) G_GNUC_CONST;
GType sidebar_expandable_entry_get_type (void) G_GNUC_CONST;
GType sidebar_renameable_entry_get_type (void) G_GNUC_CONST;
GType sidebar_grouping_get_type (void) G_GNUC_CONST;
#define SIDEBAR_GROUPING_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), SIDEBAR_TYPE_GROUPING, SidebarGroupingPrivate))
enum  {
	SIDEBAR_GROUPING_DUMMY_PROPERTY
};
SidebarGrouping* sidebar_grouping_new (const gchar* name, const gchar* icon, const gchar* tooltip);
SidebarGrouping* sidebar_grouping_construct (GType object_type, const gchar* name, const gchar* icon, const gchar* tooltip);
static void sidebar_grouping_real_rename (SidebarRenameableEntry* base, const gchar* name);
static gboolean sidebar_grouping_real_is_user_renameable (SidebarRenameableEntry* base);
static gchar* sidebar_grouping_real_get_sidebar_name (SidebarEntry* base);
static gchar* sidebar_grouping_real_get_sidebar_tooltip (SidebarEntry* base);
static gchar* sidebar_grouping_real_get_sidebar_icon (SidebarEntry* base);
static gchar* sidebar_grouping_real_to_string (SidebarEntry* base);
static gboolean sidebar_grouping_real_expand_on_select (SidebarExpandableEntry* base);
static void sidebar_grouping_finalize (GObject* obj);
GType sidebar_selectable_entry_get_type (void) G_GNUC_CONST;
GType page_get_type (void) G_GNUC_CONST;
GType sidebar_page_representative_get_type (void) G_GNUC_CONST;
GType sidebar_contextable_get_type (void) G_GNUC_CONST;
GType sidebar_simple_page_entry_get_type (void) G_GNUC_CONST;
#define SIDEBAR_SIMPLE_PAGE_ENTRY_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), SIDEBAR_TYPE_SIMPLE_PAGE_ENTRY, SidebarSimplePageEntryPrivate))
enum  {
	SIDEBAR_SIMPLE_PAGE_ENTRY_DUMMY_PROPERTY
};
SidebarSimplePageEntry* sidebar_simple_page_entry_construct (GType object_type);
gchar* sidebar_simple_page_entry_get_sidebar_name (SidebarSimplePageEntry* self);
static gchar* sidebar_simple_page_entry_real_get_sidebar_name (SidebarSimplePageEntry* self);
gchar* sidebar_simple_page_entry_get_sidebar_tooltip (SidebarSimplePageEntry* self);
static gchar* sidebar_simple_page_entry_real_get_sidebar_tooltip (SidebarSimplePageEntry* self);
gchar* sidebar_simple_page_entry_get_sidebar_icon (SidebarSimplePageEntry* self);
static gchar* sidebar_simple_page_entry_real_get_sidebar_icon (SidebarSimplePageEntry* self);
gchar* sidebar_simple_page_entry_to_string (SidebarSimplePageEntry* self);
static gchar* sidebar_simple_page_entry_real_to_string (SidebarSimplePageEntry* self);
Page* sidebar_simple_page_entry_create_page (SidebarSimplePageEntry* self);
static Page* sidebar_simple_page_entry_real_create_page (SidebarSimplePageEntry* self);
static gboolean sidebar_simple_page_entry_real_has_page (SidebarPageRepresentative* base);
static Page* sidebar_simple_page_entry_real_get_page (SidebarPageRepresentative* base);
static void sidebar_simple_page_entry_real_pruned (SidebarEntry* base, SidebarTree* tree);
static GtkMenu* sidebar_simple_page_entry_real_get_sidebar_context_menu (SidebarContextable* base, GdkEventButton* event);
Page* sidebar_page_representative_get_page (SidebarPageRepresentative* self);
GtkMenu* page_get_page_context_menu (Page* self);
static void sidebar_simple_page_entry_finalize (GObject* obj);
GType sidebar_branch_get_type (void) G_GNUC_CONST;
GType sidebar_root_only_branch_get_type (void) G_GNUC_CONST;
enum  {
	SIDEBAR_ROOT_ONLY_BRANCH_DUMMY_PROPERTY
};
SidebarRootOnlyBranch* sidebar_root_only_branch_new (SidebarEntry* root);
SidebarRootOnlyBranch* sidebar_root_only_branch_construct (GType object_type, SidebarEntry* root);
GType sidebar_branch_options_get_type (void) G_GNUC_CONST;
static gint sidebar_root_only_branch_null_comparator (SidebarEntry* a, SidebarEntry* b);
static gint _sidebar_root_only_branch_null_comparator_gcompare_func (gconstpointer a, gconstpointer b);
SidebarBranch* sidebar_branch_new (SidebarEntry* root, SidebarBranchOptions options, GCompareFunc default_comparator, GCompareFunc root_comparator);
SidebarBranch* sidebar_branch_construct (GType object_type, SidebarEntry* root, SidebarBranchOptions options, GCompareFunc default_comparator, GCompareFunc root_comparator);
GType sidebar_emphasizable_entry_get_type (void) G_GNUC_CONST;
GType sidebar_header_get_type (void) G_GNUC_CONST;
#define SIDEBAR_HEADER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), SIDEBAR_TYPE_HEADER, SidebarHeaderPrivate))
enum  {
	SIDEBAR_HEADER_DUMMY_PROPERTY
};
SidebarHeader* sidebar_header_new (const gchar* name, gboolean emphasized);
SidebarHeader* sidebar_header_construct (GType object_type, const gchar* name, gboolean emphasized);
static gboolean sidebar_header_real_is_emphasized (SidebarEmphasizableEntry* base);
static void sidebar_header_finalize (GObject* obj);
GtkMenu* sidebar_contextable_get_sidebar_context_menu (SidebarContextable* self, GdkEventButton* event);


SidebarGrouping* sidebar_grouping_construct (GType object_type, const gchar* name, const gchar* icon, const gchar* tooltip) {
	SidebarGrouping * self = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
#line 15 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	g_return_val_if_fail (name != NULL, NULL);
#line 15 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	self = (SidebarGrouping*) g_object_new (object_type, NULL);
#line 16 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	_tmp0_ = name;
#line 16 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 16 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	_g_free0 (self->priv->name);
#line 16 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	self->priv->name = _tmp1_;
#line 17 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	_tmp2_ = icon;
#line 17 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	_tmp3_ = g_strdup (_tmp2_);
#line 17 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	_g_free0 (self->priv->icon);
#line 17 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	self->priv->icon = _tmp3_;
#line 18 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	_tmp4_ = tooltip;
#line 18 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	_tmp5_ = g_strdup (_tmp4_);
#line 18 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	_g_free0 (self->priv->tooltip);
#line 18 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	self->priv->tooltip = _tmp5_;
#line 15 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	return self;
#line 391 "common.c"
}


SidebarGrouping* sidebar_grouping_new (const gchar* name, const gchar* icon, const gchar* tooltip) {
#line 15 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	return sidebar_grouping_construct (SIDEBAR_TYPE_GROUPING, name, icon, tooltip);
#line 398 "common.c"
}


static void sidebar_grouping_real_rename (SidebarRenameableEntry* base, const gchar* name) {
	SidebarGrouping * self;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
#line 21 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, SIDEBAR_TYPE_GROUPING, SidebarGrouping);
#line 21 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	g_return_if_fail (name != NULL);
#line 22 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	_tmp0_ = name;
#line 22 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 22 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	_g_free0 (self->priv->name);
#line 22 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	self->priv->name = _tmp1_;
#line 23 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	_tmp2_ = name;
#line 23 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	g_signal_emit_by_name (G_TYPE_CHECK_INSTANCE_CAST (self, SIDEBAR_TYPE_RENAMEABLE_ENTRY, SidebarRenameableEntry), "sidebar-name-changed", _tmp2_);
#line 423 "common.c"
}


static gboolean sidebar_grouping_real_is_user_renameable (SidebarRenameableEntry* base) {
	SidebarGrouping * self;
	gboolean result = FALSE;
#line 26 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, SIDEBAR_TYPE_GROUPING, SidebarGrouping);
#line 27 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	result = FALSE;
#line 27 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	return result;
#line 436 "common.c"
}


static gchar* sidebar_grouping_real_get_sidebar_name (SidebarEntry* base) {
	SidebarGrouping * self;
	gchar* result = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 30 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, SIDEBAR_TYPE_GROUPING, SidebarGrouping);
#line 31 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	_tmp0_ = self->priv->name;
#line 31 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 31 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	result = _tmp1_;
#line 31 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	return result;
#line 455 "common.c"
}


static gchar* sidebar_grouping_real_get_sidebar_tooltip (SidebarEntry* base) {
	SidebarGrouping * self;
	gchar* result = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 34 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, SIDEBAR_TYPE_GROUPING, SidebarGrouping);
#line 35 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	_tmp0_ = self->priv->tooltip;
#line 35 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 35 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	result = _tmp1_;
#line 35 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	return result;
#line 474 "common.c"
}


static gchar* sidebar_grouping_real_get_sidebar_icon (SidebarEntry* base) {
	SidebarGrouping * self;
	gchar* result = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 38 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, SIDEBAR_TYPE_GROUPING, SidebarGrouping);
#line 39 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	_tmp0_ = self->priv->icon;
#line 39 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 39 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	result = _tmp1_;
#line 39 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	return result;
#line 493 "common.c"
}


static gchar* sidebar_grouping_real_to_string (SidebarEntry* base) {
	SidebarGrouping * self;
	gchar* result = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 42 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, SIDEBAR_TYPE_GROUPING, SidebarGrouping);
#line 43 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	_tmp0_ = self->priv->name;
#line 43 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 43 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	result = _tmp1_;
#line 43 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	return result;
#line 512 "common.c"
}


static gboolean sidebar_grouping_real_expand_on_select (SidebarExpandableEntry* base) {
	SidebarGrouping * self;
	gboolean result = FALSE;
#line 46 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, SIDEBAR_TYPE_GROUPING, SidebarGrouping);
#line 47 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	result = TRUE;
#line 47 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	return result;
#line 525 "common.c"
}


static void sidebar_grouping_class_init (SidebarGroupingClass * klass) {
#line 8 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	sidebar_grouping_parent_class = g_type_class_peek_parent (klass);
#line 8 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	g_type_class_add_private (klass, sizeof (SidebarGroupingPrivate));
#line 8 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	G_OBJECT_CLASS (klass)->finalize = sidebar_grouping_finalize;
#line 536 "common.c"
}


static void sidebar_grouping_sidebar_entry_interface_init (SidebarEntryIface * iface) {
#line 8 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	sidebar_grouping_sidebar_entry_parent_iface = g_type_interface_peek_parent (iface);
#line 8 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	iface->get_sidebar_name = (gchar* (*)(SidebarEntry*)) sidebar_grouping_real_get_sidebar_name;
#line 8 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	iface->get_sidebar_tooltip = (gchar* (*)(SidebarEntry*)) sidebar_grouping_real_get_sidebar_tooltip;
#line 8 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	iface->get_sidebar_icon = (gchar* (*)(SidebarEntry*)) sidebar_grouping_real_get_sidebar_icon;
#line 8 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	iface->to_string = (gchar* (*)(SidebarEntry*)) sidebar_grouping_real_to_string;
#line 551 "common.c"
}


static void sidebar_grouping_sidebar_expandable_entry_interface_init (SidebarExpandableEntryIface * iface) {
#line 8 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	sidebar_grouping_sidebar_expandable_entry_parent_iface = g_type_interface_peek_parent (iface);
#line 8 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	iface->expand_on_select = (gboolean (*)(SidebarExpandableEntry*)) sidebar_grouping_real_expand_on_select;
#line 560 "common.c"
}


static void sidebar_grouping_sidebar_renameable_entry_interface_init (SidebarRenameableEntryIface * iface) {
#line 8 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	sidebar_grouping_sidebar_renameable_entry_parent_iface = g_type_interface_peek_parent (iface);
#line 8 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	iface->rename = (void (*)(SidebarRenameableEntry*, const gchar*)) sidebar_grouping_real_rename;
#line 8 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	iface->is_user_renameable = (gboolean (*)(SidebarRenameableEntry*)) sidebar_grouping_real_is_user_renameable;
#line 571 "common.c"
}


static void sidebar_grouping_instance_init (SidebarGrouping * self) {
#line 8 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	self->priv = SIDEBAR_GROUPING_GET_PRIVATE (self);
#line 578 "common.c"
}


static void sidebar_grouping_finalize (GObject* obj) {
	SidebarGrouping * self;
#line 8 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SIDEBAR_TYPE_GROUPING, SidebarGrouping);
#line 11 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	_g_free0 (self->priv->name);
#line 12 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	_g_free0 (self->priv->tooltip);
#line 13 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	_g_free0 (self->priv->icon);
#line 8 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	G_OBJECT_CLASS (sidebar_grouping_parent_class)->finalize (obj);
#line 594 "common.c"
}


GType sidebar_grouping_get_type (void) {
	static volatile gsize sidebar_grouping_type_id__volatile = 0;
	if (g_once_init_enter (&sidebar_grouping_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SidebarGroupingClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) sidebar_grouping_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SidebarGrouping), 0, (GInstanceInitFunc) sidebar_grouping_instance_init, NULL };
		static const GInterfaceInfo sidebar_entry_info = { (GInterfaceInitFunc) sidebar_grouping_sidebar_entry_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo sidebar_expandable_entry_info = { (GInterfaceInitFunc) sidebar_grouping_sidebar_expandable_entry_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo sidebar_renameable_entry_info = { (GInterfaceInitFunc) sidebar_grouping_sidebar_renameable_entry_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType sidebar_grouping_type_id;
		sidebar_grouping_type_id = g_type_register_static (G_TYPE_OBJECT, "SidebarGrouping", &g_define_type_info, 0);
		g_type_add_interface_static (sidebar_grouping_type_id, SIDEBAR_TYPE_ENTRY, &sidebar_entry_info);
		g_type_add_interface_static (sidebar_grouping_type_id, SIDEBAR_TYPE_EXPANDABLE_ENTRY, &sidebar_expandable_entry_info);
		g_type_add_interface_static (sidebar_grouping_type_id, SIDEBAR_TYPE_RENAMEABLE_ENTRY, &sidebar_renameable_entry_info);
		g_once_init_leave (&sidebar_grouping_type_id__volatile, sidebar_grouping_type_id);
	}
	return sidebar_grouping_type_id__volatile;
}


SidebarSimplePageEntry* sidebar_simple_page_entry_construct (GType object_type) {
	SidebarSimplePageEntry * self = NULL;
#line 58 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	self = (SidebarSimplePageEntry*) g_object_new (object_type, NULL);
#line 58 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	return self;
#line 622 "common.c"
}


static gchar* sidebar_simple_page_entry_real_get_sidebar_name (SidebarSimplePageEntry* self) {
#line 61 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	g_critical ("Type `%s' does not implement abstract method `sidebar_simple_page_entry_get_sidebar_name'", g_type_name (G_TYPE_FROM_INSTANCE (self)));
#line 61 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	return NULL;
#line 631 "common.c"
}


gchar* sidebar_simple_page_entry_get_sidebar_name (SidebarSimplePageEntry* self) {
#line 61 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	g_return_val_if_fail (SIDEBAR_IS_SIMPLE_PAGE_ENTRY (self), NULL);
#line 61 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	return SIDEBAR_SIMPLE_PAGE_ENTRY_GET_CLASS (self)->get_sidebar_name (self);
#line 640 "common.c"
}


static gchar* sidebar_simple_page_entry_real_get_sidebar_tooltip (SidebarSimplePageEntry* self) {
	gchar* result = NULL;
	gchar* _tmp0_ = NULL;
#line 64 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	_tmp0_ = sidebar_simple_page_entry_get_sidebar_name (self);
#line 64 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	result = _tmp0_;
#line 64 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	return result;
#line 653 "common.c"
}


gchar* sidebar_simple_page_entry_get_sidebar_tooltip (SidebarSimplePageEntry* self) {
#line 63 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	g_return_val_if_fail (SIDEBAR_IS_SIMPLE_PAGE_ENTRY (self), NULL);
#line 63 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	return SIDEBAR_SIMPLE_PAGE_ENTRY_GET_CLASS (self)->get_sidebar_tooltip (self);
#line 662 "common.c"
}


static gchar* sidebar_simple_page_entry_real_get_sidebar_icon (SidebarSimplePageEntry* self) {
#line 67 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	g_critical ("Type `%s' does not implement abstract method `sidebar_simple_page_entry_get_sidebar_icon'", g_type_name (G_TYPE_FROM_INSTANCE (self)));
#line 67 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	return NULL;
#line 671 "common.c"
}


gchar* sidebar_simple_page_entry_get_sidebar_icon (SidebarSimplePageEntry* self) {
#line 67 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	g_return_val_if_fail (SIDEBAR_IS_SIMPLE_PAGE_ENTRY (self), NULL);
#line 67 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	return SIDEBAR_SIMPLE_PAGE_ENTRY_GET_CLASS (self)->get_sidebar_icon (self);
#line 680 "common.c"
}


static gchar* sidebar_simple_page_entry_real_to_string (SidebarSimplePageEntry* self) {
	gchar* result = NULL;
	gchar* _tmp0_ = NULL;
#line 70 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	_tmp0_ = sidebar_simple_page_entry_get_sidebar_name (self);
#line 70 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	result = _tmp0_;
#line 70 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	return result;
#line 693 "common.c"
}


gchar* sidebar_simple_page_entry_to_string (SidebarSimplePageEntry* self) {
#line 69 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	g_return_val_if_fail (SIDEBAR_IS_SIMPLE_PAGE_ENTRY (self), NULL);
#line 69 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	return SIDEBAR_SIMPLE_PAGE_ENTRY_GET_CLASS (self)->to_string (self);
#line 702 "common.c"
}


static Page* sidebar_simple_page_entry_real_create_page (SidebarSimplePageEntry* self) {
#line 73 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	g_critical ("Type `%s' does not implement abstract method `sidebar_simple_page_entry_create_page'", g_type_name (G_TYPE_FROM_INSTANCE (self)));
#line 73 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	return NULL;
#line 711 "common.c"
}


Page* sidebar_simple_page_entry_create_page (SidebarSimplePageEntry* self) {
#line 73 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	g_return_val_if_fail (SIDEBAR_IS_SIMPLE_PAGE_ENTRY (self), NULL);
#line 73 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	return SIDEBAR_SIMPLE_PAGE_ENTRY_GET_CLASS (self)->create_page (self);
#line 720 "common.c"
}


static gboolean sidebar_simple_page_entry_real_has_page (SidebarPageRepresentative* base) {
	SidebarSimplePageEntry * self;
	gboolean result = FALSE;
	Page* _tmp0_ = NULL;
#line 75 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, SIDEBAR_TYPE_SIMPLE_PAGE_ENTRY, SidebarSimplePageEntry);
#line 76 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	_tmp0_ = self->priv->page;
#line 76 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	result = _tmp0_ != NULL;
#line 76 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	return result;
#line 736 "common.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 85 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	return self ? g_object_ref (self) : NULL;
#line 743 "common.c"
}


static Page* sidebar_simple_page_entry_real_get_page (SidebarPageRepresentative* base) {
	SidebarSimplePageEntry * self;
	Page* result = NULL;
	Page* _tmp0_ = NULL;
	Page* _tmp3_ = NULL;
	Page* _tmp4_ = NULL;
#line 79 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, SIDEBAR_TYPE_SIMPLE_PAGE_ENTRY, SidebarSimplePageEntry);
#line 80 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	_tmp0_ = self->priv->page;
#line 80 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	if (_tmp0_ == NULL) {
#line 759 "common.c"
		Page* _tmp1_ = NULL;
		Page* _tmp2_ = NULL;
#line 81 "/home/jens/Source/shotwell/src/sidebar/common.vala"
		_tmp1_ = sidebar_simple_page_entry_create_page (self);
#line 81 "/home/jens/Source/shotwell/src/sidebar/common.vala"
		_g_object_unref0 (self->priv->page);
#line 81 "/home/jens/Source/shotwell/src/sidebar/common.vala"
		self->priv->page = _tmp1_;
#line 82 "/home/jens/Source/shotwell/src/sidebar/common.vala"
		_tmp2_ = self->priv->page;
#line 82 "/home/jens/Source/shotwell/src/sidebar/common.vala"
		g_signal_emit_by_name (G_TYPE_CHECK_INSTANCE_CAST (self, SIDEBAR_TYPE_PAGE_REPRESENTATIVE, SidebarPageRepresentative), "page-created", _tmp2_);
#line 772 "common.c"
	}
#line 85 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	_tmp3_ = self->priv->page;
#line 85 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	_tmp4_ = _g_object_ref0 (_tmp3_);
#line 85 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	result = _tmp4_;
#line 85 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	return result;
#line 782 "common.c"
}


static void sidebar_simple_page_entry_real_pruned (SidebarEntry* base, SidebarTree* tree) {
	SidebarSimplePageEntry * self;
	Page* _tmp0_ = NULL;
	Page* _tmp1_ = NULL;
	Page* _tmp2_ = NULL;
#line 88 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, SIDEBAR_TYPE_SIMPLE_PAGE_ENTRY, SidebarSimplePageEntry);
#line 88 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	g_return_if_fail (SIDEBAR_IS_TREE (tree));
#line 89 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	_tmp0_ = self->priv->page;
#line 89 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	if (_tmp0_ == NULL) {
#line 90 "/home/jens/Source/shotwell/src/sidebar/common.vala"
		return;
#line 801 "common.c"
	}
#line 92 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	_tmp1_ = self->priv->page;
#line 92 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	g_signal_emit_by_name (G_TYPE_CHECK_INSTANCE_CAST (self, SIDEBAR_TYPE_PAGE_REPRESENTATIVE, SidebarPageRepresentative), "destroying-page", _tmp1_);
#line 93 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	_tmp2_ = self->priv->page;
#line 93 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, gtk_widget_get_type (), GtkWidget));
#line 94 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	_g_object_unref0 (self->priv->page);
#line 94 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	self->priv->page = NULL;
#line 815 "common.c"
}


static GtkMenu* sidebar_simple_page_entry_real_get_sidebar_context_menu (SidebarContextable* base, GdkEventButton* event) {
	SidebarSimplePageEntry * self;
	GtkMenu* result = NULL;
	Page* _tmp0_ = NULL;
	Page* _tmp1_ = NULL;
	GtkMenu* _tmp2_ = NULL;
	GtkMenu* _tmp3_ = NULL;
#line 97 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, SIDEBAR_TYPE_SIMPLE_PAGE_ENTRY, SidebarSimplePageEntry);
#line 98 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	_tmp0_ = sidebar_page_representative_get_page (G_TYPE_CHECK_INSTANCE_CAST (self, SIDEBAR_TYPE_PAGE_REPRESENTATIVE, SidebarPageRepresentative));
#line 98 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	_tmp1_ = _tmp0_;
#line 98 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	_tmp2_ = page_get_page_context_menu (_tmp1_);
#line 98 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	_tmp3_ = _tmp2_;
#line 98 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	_g_object_unref0 (_tmp1_);
#line 98 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	result = _tmp3_;
#line 98 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	return result;
#line 842 "common.c"
}


static void sidebar_simple_page_entry_class_init (SidebarSimplePageEntryClass * klass) {
#line 54 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	sidebar_simple_page_entry_parent_class = g_type_class_peek_parent (klass);
#line 54 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	g_type_class_add_private (klass, sizeof (SidebarSimplePageEntryPrivate));
#line 54 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	((SidebarSimplePageEntryClass *) klass)->get_sidebar_name = sidebar_simple_page_entry_real_get_sidebar_name;
#line 54 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	((SidebarSimplePageEntryClass *) klass)->get_sidebar_tooltip = sidebar_simple_page_entry_real_get_sidebar_tooltip;
#line 54 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	((SidebarSimplePageEntryClass *) klass)->get_sidebar_icon = sidebar_simple_page_entry_real_get_sidebar_icon;
#line 54 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	((SidebarSimplePageEntryClass *) klass)->to_string = sidebar_simple_page_entry_real_to_string;
#line 54 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	((SidebarSimplePageEntryClass *) klass)->create_page = sidebar_simple_page_entry_real_create_page;
#line 54 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	G_OBJECT_CLASS (klass)->finalize = sidebar_simple_page_entry_finalize;
#line 863 "common.c"
}


static void sidebar_simple_page_entry_sidebar_entry_interface_init (SidebarEntryIface * iface) {
#line 54 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	sidebar_simple_page_entry_sidebar_entry_parent_iface = g_type_interface_peek_parent (iface);
#line 54 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	iface->get_sidebar_name = (gchar* (*)(SidebarEntry*)) sidebar_simple_page_entry_get_sidebar_name;
#line 54 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	iface->get_sidebar_tooltip = (gchar* (*)(SidebarEntry*)) sidebar_simple_page_entry_get_sidebar_tooltip;
#line 54 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	iface->get_sidebar_icon = (gchar* (*)(SidebarEntry*)) sidebar_simple_page_entry_get_sidebar_icon;
#line 54 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	iface->to_string = (gchar* (*)(SidebarEntry*)) sidebar_simple_page_entry_to_string;
#line 54 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	iface->pruned = (void (*)(SidebarEntry*, SidebarTree*)) sidebar_simple_page_entry_real_pruned;
#line 880 "common.c"
}


static void sidebar_simple_page_entry_sidebar_selectable_entry_interface_init (SidebarSelectableEntryIface * iface) {
#line 54 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	sidebar_simple_page_entry_sidebar_selectable_entry_parent_iface = g_type_interface_peek_parent (iface);
#line 887 "common.c"
}


static void sidebar_simple_page_entry_sidebar_page_representative_interface_init (SidebarPageRepresentativeIface * iface) {
#line 54 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	sidebar_simple_page_entry_sidebar_page_representative_parent_iface = g_type_interface_peek_parent (iface);
#line 54 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	iface->has_page = (gboolean (*)(SidebarPageRepresentative*)) sidebar_simple_page_entry_real_has_page;
#line 54 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	iface->get_page = (Page* (*)(SidebarPageRepresentative*)) sidebar_simple_page_entry_real_get_page;
#line 898 "common.c"
}


static void sidebar_simple_page_entry_sidebar_contextable_interface_init (SidebarContextableIface * iface) {
#line 54 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	sidebar_simple_page_entry_sidebar_contextable_parent_iface = g_type_interface_peek_parent (iface);
#line 54 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	iface->get_sidebar_context_menu = (GtkMenu* (*)(SidebarContextable*, GdkEventButton*)) sidebar_simple_page_entry_real_get_sidebar_context_menu;
#line 907 "common.c"
}


static void sidebar_simple_page_entry_instance_init (SidebarSimplePageEntry * self) {
#line 54 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	self->priv = SIDEBAR_SIMPLE_PAGE_ENTRY_GET_PRIVATE (self);
#line 56 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	self->priv->page = NULL;
#line 916 "common.c"
}


static void sidebar_simple_page_entry_finalize (GObject* obj) {
	SidebarSimplePageEntry * self;
#line 54 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SIDEBAR_TYPE_SIMPLE_PAGE_ENTRY, SidebarSimplePageEntry);
#line 56 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	_g_object_unref0 (self->priv->page);
#line 54 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	G_OBJECT_CLASS (sidebar_simple_page_entry_parent_class)->finalize (obj);
#line 928 "common.c"
}


GType sidebar_simple_page_entry_get_type (void) {
	static volatile gsize sidebar_simple_page_entry_type_id__volatile = 0;
	if (g_once_init_enter (&sidebar_simple_page_entry_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SidebarSimplePageEntryClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) sidebar_simple_page_entry_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SidebarSimplePageEntry), 0, (GInstanceInitFunc) sidebar_simple_page_entry_instance_init, NULL };
		static const GInterfaceInfo sidebar_entry_info = { (GInterfaceInitFunc) sidebar_simple_page_entry_sidebar_entry_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo sidebar_selectable_entry_info = { (GInterfaceInitFunc) sidebar_simple_page_entry_sidebar_selectable_entry_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo sidebar_page_representative_info = { (GInterfaceInitFunc) sidebar_simple_page_entry_sidebar_page_representative_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo sidebar_contextable_info = { (GInterfaceInitFunc) sidebar_simple_page_entry_sidebar_contextable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType sidebar_simple_page_entry_type_id;
		sidebar_simple_page_entry_type_id = g_type_register_static (G_TYPE_OBJECT, "SidebarSimplePageEntry", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
		g_type_add_interface_static (sidebar_simple_page_entry_type_id, SIDEBAR_TYPE_ENTRY, &sidebar_entry_info);
		g_type_add_interface_static (sidebar_simple_page_entry_type_id, SIDEBAR_TYPE_SELECTABLE_ENTRY, &sidebar_selectable_entry_info);
		g_type_add_interface_static (sidebar_simple_page_entry_type_id, SIDEBAR_TYPE_PAGE_REPRESENTATIVE, &sidebar_page_representative_info);
		g_type_add_interface_static (sidebar_simple_page_entry_type_id, SIDEBAR_TYPE_CONTEXTABLE, &sidebar_contextable_info);
		g_once_init_leave (&sidebar_simple_page_entry_type_id__volatile, sidebar_simple_page_entry_type_id);
	}
	return sidebar_simple_page_entry_type_id__volatile;
}


static gint _sidebar_root_only_branch_null_comparator_gcompare_func (gconstpointer a, gconstpointer b) {
	gint result;
	result = sidebar_root_only_branch_null_comparator ((SidebarEntry*) a, (SidebarEntry*) b);
#line 105 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	return result;
#line 957 "common.c"
}


SidebarRootOnlyBranch* sidebar_root_only_branch_construct (GType object_type, SidebarEntry* root) {
	SidebarRootOnlyBranch * self = NULL;
	SidebarEntry* _tmp0_ = NULL;
#line 104 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	g_return_val_if_fail (SIDEBAR_IS_ENTRY (root), NULL);
#line 105 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	_tmp0_ = root;
#line 105 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	self = (SidebarRootOnlyBranch*) sidebar_branch_construct (object_type, _tmp0_, SIDEBAR_BRANCH_OPTIONS_NONE, _sidebar_root_only_branch_null_comparator_gcompare_func, NULL);
#line 104 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	return self;
#line 972 "common.c"
}


SidebarRootOnlyBranch* sidebar_root_only_branch_new (SidebarEntry* root) {
#line 104 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	return sidebar_root_only_branch_construct (SIDEBAR_TYPE_ROOT_ONLY_BRANCH, root);
#line 979 "common.c"
}


static gint sidebar_root_only_branch_null_comparator (SidebarEntry* a, SidebarEntry* b) {
	gint result = 0;
	gint _tmp0_ = 0;
	SidebarEntry* _tmp1_ = NULL;
	SidebarEntry* _tmp2_ = NULL;
#line 108 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	g_return_val_if_fail (SIDEBAR_IS_ENTRY (a), 0);
#line 108 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	g_return_val_if_fail (SIDEBAR_IS_ENTRY (b), 0);
#line 109 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	_tmp1_ = a;
#line 109 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	_tmp2_ = b;
#line 109 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	if (_tmp1_ != _tmp2_) {
#line 109 "/home/jens/Source/shotwell/src/sidebar/common.vala"
		_tmp0_ = -1;
#line 1000 "common.c"
	} else {
#line 109 "/home/jens/Source/shotwell/src/sidebar/common.vala"
		_tmp0_ = 0;
#line 1004 "common.c"
	}
#line 109 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	result = _tmp0_;
#line 109 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	return result;
#line 1010 "common.c"
}


static void sidebar_root_only_branch_class_init (SidebarRootOnlyBranchClass * klass) {
#line 103 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	sidebar_root_only_branch_parent_class = g_type_class_peek_parent (klass);
#line 1017 "common.c"
}


static void sidebar_root_only_branch_instance_init (SidebarRootOnlyBranch * self) {
}


GType sidebar_root_only_branch_get_type (void) {
	static volatile gsize sidebar_root_only_branch_type_id__volatile = 0;
	if (g_once_init_enter (&sidebar_root_only_branch_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SidebarRootOnlyBranchClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) sidebar_root_only_branch_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SidebarRootOnlyBranch), 0, (GInstanceInitFunc) sidebar_root_only_branch_instance_init, NULL };
		GType sidebar_root_only_branch_type_id;
		sidebar_root_only_branch_type_id = g_type_register_static (SIDEBAR_TYPE_BRANCH, "SidebarRootOnlyBranch", &g_define_type_info, 0);
		g_once_init_leave (&sidebar_root_only_branch_type_id__volatile, sidebar_root_only_branch_type_id);
	}
	return sidebar_root_only_branch_type_id__volatile;
}


SidebarHeader* sidebar_header_construct (GType object_type, const gchar* name, gboolean emphasized) {
	SidebarHeader * self = NULL;
	const gchar* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
#line 123 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	g_return_val_if_fail (name != NULL, NULL);
#line 124 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	_tmp0_ = name;
#line 124 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	self = (SidebarHeader*) sidebar_grouping_construct (object_type, _tmp0_, NULL, NULL);
#line 125 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	_tmp1_ = emphasized;
#line 125 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	self->priv->emphasized = _tmp1_;
#line 123 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	return self;
#line 1053 "common.c"
}


SidebarHeader* sidebar_header_new (const gchar* name, gboolean emphasized) {
#line 123 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	return sidebar_header_construct (SIDEBAR_TYPE_HEADER, name, emphasized);
#line 1060 "common.c"
}


static gboolean sidebar_header_real_is_emphasized (SidebarEmphasizableEntry* base) {
	SidebarHeader * self;
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
#line 128 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, SIDEBAR_TYPE_HEADER, SidebarHeader);
#line 129 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	_tmp0_ = self->priv->emphasized;
#line 129 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	result = _tmp0_;
#line 129 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	return result;
#line 1076 "common.c"
}


static void sidebar_header_class_init (SidebarHeaderClass * klass) {
#line 120 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	sidebar_header_parent_class = g_type_class_peek_parent (klass);
#line 120 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	g_type_class_add_private (klass, sizeof (SidebarHeaderPrivate));
#line 120 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	G_OBJECT_CLASS (klass)->finalize = sidebar_header_finalize;
#line 1087 "common.c"
}


static void sidebar_header_sidebar_emphasizable_entry_interface_init (SidebarEmphasizableEntryIface * iface) {
#line 120 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	sidebar_header_sidebar_emphasizable_entry_parent_iface = g_type_interface_peek_parent (iface);
#line 120 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	iface->is_emphasized = (gboolean (*)(SidebarEmphasizableEntry*)) sidebar_header_real_is_emphasized;
#line 1096 "common.c"
}


static void sidebar_header_instance_init (SidebarHeader * self) {
#line 120 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	self->priv = SIDEBAR_HEADER_GET_PRIVATE (self);
#line 1103 "common.c"
}


static void sidebar_header_finalize (GObject* obj) {
	SidebarHeader * self;
#line 120 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SIDEBAR_TYPE_HEADER, SidebarHeader);
#line 120 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	G_OBJECT_CLASS (sidebar_header_parent_class)->finalize (obj);
#line 1113 "common.c"
}


/**
 * A header is an entry that is visually distinguished from its children. Bug 6397 recommends
 * headers to appear bolded and without any icons. To prevent the icons from rendering, we set the
 * icons to null in the base class @see Sidebar.Grouping. But we also go a step further by
 * using a custom cell_data_function (@see Sidebar.Tree::icon_renderer_function) which ensures that
 * header icons won't be rendered. This approach avoids the blank icon spacing issues.
 */
GType sidebar_header_get_type (void) {
	static volatile gsize sidebar_header_type_id__volatile = 0;
	if (g_once_init_enter (&sidebar_header_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SidebarHeaderClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) sidebar_header_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SidebarHeader), 0, (GInstanceInitFunc) sidebar_header_instance_init, NULL };
		static const GInterfaceInfo sidebar_emphasizable_entry_info = { (GInterfaceInitFunc) sidebar_header_sidebar_emphasizable_entry_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType sidebar_header_type_id;
		sidebar_header_type_id = g_type_register_static (SIDEBAR_TYPE_GROUPING, "SidebarHeader", &g_define_type_info, 0);
		g_type_add_interface_static (sidebar_header_type_id, SIDEBAR_TYPE_EMPHASIZABLE_ENTRY, &sidebar_emphasizable_entry_info);
		g_once_init_leave (&sidebar_header_type_id__volatile, sidebar_header_type_id);
	}
	return sidebar_header_type_id__volatile;
}


GtkMenu* sidebar_contextable_get_sidebar_context_menu (SidebarContextable* self, GdkEventButton* event) {
#line 135 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	g_return_val_if_fail (SIDEBAR_IS_CONTEXTABLE (self), NULL);
#line 135 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	return SIDEBAR_CONTEXTABLE_GET_INTERFACE (self)->get_sidebar_context_menu (self, event);
#line 1143 "common.c"
}


static void sidebar_contextable_base_init (SidebarContextableIface * iface) {
#line 133 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	static gboolean initialized = FALSE;
#line 133 "/home/jens/Source/shotwell/src/sidebar/common.vala"
	if (!initialized) {
#line 133 "/home/jens/Source/shotwell/src/sidebar/common.vala"
		initialized = TRUE;
#line 1154 "common.c"
	}
}


GType sidebar_contextable_get_type (void) {
	static volatile gsize sidebar_contextable_type_id__volatile = 0;
	if (g_once_init_enter (&sidebar_contextable_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SidebarContextableIface), (GBaseInitFunc) sidebar_contextable_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
		GType sidebar_contextable_type_id;
		sidebar_contextable_type_id = g_type_register_static (G_TYPE_INTERFACE, "SidebarContextable", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (sidebar_contextable_type_id, G_TYPE_OBJECT);
		g_once_init_leave (&sidebar_contextable_type_id__volatile, sidebar_contextable_type_id);
	}
	return sidebar_contextable_type_id__volatile;
}



