/* Application.c generated by valac 0.32.1, the Vala compiler
 * generated from Application.vala, do not modify */

/* Copyright 2016 Software Freedom Conservancy Inc.
 *
 * This software is licensed under the GNU Lesser General Public License
 * (version 2.1 or later).  See the COPYING file in this distribution.
 */

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <gio/gio.h>
#include <stdlib.h>
#include <string.h>
#include <gobject/gvaluecollector.h>


#define TYPE_APPLICATION (application_get_type ())
#define APPLICATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_APPLICATION, Application))
#define APPLICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_APPLICATION, ApplicationClass))
#define IS_APPLICATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_APPLICATION))
#define IS_APPLICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_APPLICATION))
#define APPLICATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_APPLICATION, ApplicationClass))

typedef struct _Application Application;
typedef struct _ApplicationClass ApplicationClass;
typedef struct _ApplicationPrivate ApplicationPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
#define _application_unref0(var) ((var == NULL) ? NULL : (var = (application_unref (var), NULL)))

#define TYPE_PAGE_WINDOW (page_window_get_type ())
#define PAGE_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PAGE_WINDOW, PageWindow))
#define PAGE_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PAGE_WINDOW, PageWindowClass))
#define IS_PAGE_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PAGE_WINDOW))
#define IS_PAGE_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PAGE_WINDOW))
#define PAGE_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PAGE_WINDOW, PageWindowClass))

typedef struct _PageWindow PageWindow;
typedef struct _PageWindowClass PageWindowClass;

#define TYPE_APP_WINDOW (app_window_get_type ())
#define APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_APP_WINDOW, AppWindow))
#define APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_APP_WINDOW, AppWindowClass))
#define IS_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_APP_WINDOW))
#define IS_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_APP_WINDOW))
#define APP_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_APP_WINDOW, AppWindowClass))

typedef struct _AppWindow AppWindow;
typedef struct _AppWindowClass AppWindowClass;

#define TYPE_LIBRARY_WINDOW (library_window_get_type ())
#define LIBRARY_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_LIBRARY_WINDOW, LibraryWindow))
#define LIBRARY_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_LIBRARY_WINDOW, LibraryWindowClass))
#define IS_LIBRARY_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_LIBRARY_WINDOW))
#define IS_LIBRARY_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_LIBRARY_WINDOW))
#define LIBRARY_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_LIBRARY_WINDOW, LibraryWindowClass))

typedef struct _LibraryWindow LibraryWindow;
typedef struct _LibraryWindowClass LibraryWindowClass;
#define _g_free0(var) (var = (g_free (var), NULL))
typedef struct _ParamSpecApplication ParamSpecApplication;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _Application {
	GTypeInstance parent_instance;
	volatile int ref_count;
	ApplicationPrivate * priv;
};

struct _ApplicationClass {
	GTypeClass parent_class;
	void (*finalize) (Application *self);
	void (*starting) (Application* self);
	void (*exiting) (Application* self, gboolean panicked);
	void (*init_done) (Application* self);
};

struct _ApplicationPrivate {
	GtkApplication* system_app;
	gint system_app_run_retval;
	gboolean direct;
	gboolean fixup_raw_thumbs;
	gboolean running;
	gboolean exiting_fired;
};

struct _ParamSpecApplication {
	GParamSpec parent_instance;
};


static gpointer application_parent_class = NULL;
static Application* application_instance;
static Application* application_instance = NULL;

gpointer application_ref (gpointer instance);
void application_unref (gpointer instance);
GParamSpec* param_spec_application (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_application (GValue* value, gpointer v_object);
void value_take_application (GValue* value, gpointer v_object);
gpointer value_get_application (const GValue* value);
GType application_get_type (void) G_GNUC_CONST;
#define APPLICATION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_APPLICATION, ApplicationPrivate))
enum  {
	APPLICATION_DUMMY_PROPERTY
};
void application_set_raw_thumbs_fix_required (Application* self, gboolean should_fixup);
gboolean application_get_raw_thumbs_fix_required (Application* self);
static Application* application_new (gboolean is_direct);
static Application* application_construct (GType object_type, gboolean is_direct);
void application_panic (Application* self);
gint application_on_command_line (GApplicationCommandLine* acl);
static gint _application_on_command_line_g_application_command_line (GApplication* _sender, GApplicationCommandLine* command_line, gpointer self);
void application_on_activated (void);
static void _application_on_activated_g_application_activate (GApplication* _sender, gpointer self);
static void _application_on_activated_g_application_startup (GApplication* _sender, gpointer self);
void application_send_to_primary_instance (gchar** argv, int argv_length1);
Application* application_get_instance (void);
void application_present_primary_instance (void);
gboolean application_get_is_remote (void);
gboolean application_get_is_direct (void);
GType page_window_get_type (void) G_GNUC_CONST;
GType app_window_get_type (void) G_GNUC_CONST;
GType library_window_get_type (void) G_GNUC_CONST;
AppWindow* app_window_get_instance (void);
LibraryWindow* library_window_get_app (void);
void library_window_mounted_camera_shell_notification (LibraryWindow* self, const gchar* uri, gboolean at_startup);
void application_init (gboolean is_direct);
void application_terminate (void);
void application_exit (Application* self);
void application_start (Application* self, gchar** argv, int argv_length1);
guint application_inhibit (Application* self, GtkApplicationInhibitFlags what, const gchar* reason);
void application_uninhibit (Application* self, guint cookie);
gint application_get_run_return_value (Application* self);
static void application_real_starting (Application* self);
static void application_real_exiting (Application* self, gboolean panicked);
static void application_real_init_done (Application* self);
static void application_finalize (Application* obj);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);


void application_set_raw_thumbs_fix_required (Application* self, gboolean should_fixup) {
	gboolean _tmp0_ = FALSE;
#line 24 "/home/jens/Source/shotwell/src/Application.vala"
	g_return_if_fail (IS_APPLICATION (self));
#line 25 "/home/jens/Source/shotwell/src/Application.vala"
	_tmp0_ = should_fixup;
#line 25 "/home/jens/Source/shotwell/src/Application.vala"
	self->priv->fixup_raw_thumbs = _tmp0_;
#line 157 "Application.c"
}


gboolean application_get_raw_thumbs_fix_required (Application* self) {
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
#line 28 "/home/jens/Source/shotwell/src/Application.vala"
	g_return_val_if_fail (IS_APPLICATION (self), FALSE);
#line 29 "/home/jens/Source/shotwell/src/Application.vala"
	_tmp0_ = self->priv->fixup_raw_thumbs;
#line 29 "/home/jens/Source/shotwell/src/Application.vala"
	result = _tmp0_;
#line 29 "/home/jens/Source/shotwell/src/Application.vala"
	return result;
#line 172 "Application.c"
}


static gint _application_on_command_line_g_application_command_line (GApplication* _sender, GApplicationCommandLine* command_line, gpointer self) {
	gint result;
	result = application_on_command_line (command_line);
#line 61 "/home/jens/Source/shotwell/src/Application.vala"
	return result;
#line 181 "Application.c"
}


static void _application_on_activated_g_application_activate (GApplication* _sender, gpointer self) {
#line 64 "/home/jens/Source/shotwell/src/Application.vala"
	application_on_activated ();
#line 188 "Application.c"
}


static void _application_on_activated_g_application_startup (GApplication* _sender, gpointer self) {
#line 65 "/home/jens/Source/shotwell/src/Application.vala"
	application_on_activated ();
#line 195 "Application.c"
}


static Application* application_construct (GType object_type, gboolean is_direct) {
	Application* self = NULL;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp4_ = FALSE;
	gboolean _tmp5_ = FALSE;
	GtkApplication* _tmp7_ = NULL;
	GtkApplication* _tmp8_ = NULL;
	GError * _inner_error_ = NULL;
#line 35 "/home/jens/Source/shotwell/src/Application.vala"
	self = (Application*) g_type_create_instance (object_type);
#line 36 "/home/jens/Source/shotwell/src/Application.vala"
	_tmp0_ = is_direct;
#line 36 "/home/jens/Source/shotwell/src/Application.vala"
	if (_tmp0_) {
#line 213 "Application.c"
		GtkApplication* _tmp1_ = NULL;
#line 41 "/home/jens/Source/shotwell/src/Application.vala"
		_tmp1_ = gtk_application_new ("org.yorba.shotwell-direct", G_APPLICATION_HANDLES_OPEN | G_APPLICATION_NON_UNIQUE);
#line 41 "/home/jens/Source/shotwell/src/Application.vala"
		_g_object_unref0 (self->priv->system_app);
#line 41 "/home/jens/Source/shotwell/src/Application.vala"
		self->priv->system_app = _tmp1_;
#line 221 "Application.c"
	} else {
		GtkApplication* _tmp2_ = NULL;
#line 47 "/home/jens/Source/shotwell/src/Application.vala"
		_tmp2_ = gtk_application_new ("org.yorba.shotwell", G_APPLICATION_HANDLES_OPEN | G_APPLICATION_HANDLES_COMMAND_LINE);
#line 47 "/home/jens/Source/shotwell/src/Application.vala"
		_g_object_unref0 (self->priv->system_app);
#line 47 "/home/jens/Source/shotwell/src/Application.vala"
		self->priv->system_app = _tmp2_;
#line 230 "Application.c"
	}
	{
		GtkApplication* _tmp3_ = NULL;
#line 53 "/home/jens/Source/shotwell/src/Application.vala"
		_tmp3_ = self->priv->system_app;
#line 53 "/home/jens/Source/shotwell/src/Application.vala"
		g_application_register (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, g_application_get_type (), GApplication), NULL, &_inner_error_);
#line 53 "/home/jens/Source/shotwell/src/Application.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 240 "Application.c"
			goto __catch547_g_error;
		}
	}
	goto __finally547;
	__catch547_g_error:
	{
		GError* e = NULL;
#line 52 "/home/jens/Source/shotwell/src/Application.vala"
		e = _inner_error_;
#line 52 "/home/jens/Source/shotwell/src/Application.vala"
		_inner_error_ = NULL;
#line 55 "/home/jens/Source/shotwell/src/Application.vala"
		application_panic (self);
#line 52 "/home/jens/Source/shotwell/src/Application.vala"
		_g_error_free0 (e);
#line 256 "Application.c"
	}
	__finally547:
#line 52 "/home/jens/Source/shotwell/src/Application.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 52 "/home/jens/Source/shotwell/src/Application.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 52 "/home/jens/Source/shotwell/src/Application.vala"
		g_clear_error (&_inner_error_);
#line 52 "/home/jens/Source/shotwell/src/Application.vala"
		return NULL;
#line 267 "Application.c"
	}
#line 58 "/home/jens/Source/shotwell/src/Application.vala"
	_tmp4_ = is_direct;
#line 58 "/home/jens/Source/shotwell/src/Application.vala"
	self->priv->direct = _tmp4_;
#line 60 "/home/jens/Source/shotwell/src/Application.vala"
	_tmp5_ = self->priv->direct;
#line 60 "/home/jens/Source/shotwell/src/Application.vala"
	if (!_tmp5_) {
#line 277 "Application.c"
		GtkApplication* _tmp6_ = NULL;
#line 61 "/home/jens/Source/shotwell/src/Application.vala"
		_tmp6_ = self->priv->system_app;
#line 61 "/home/jens/Source/shotwell/src/Application.vala"
		g_signal_connect (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, g_application_get_type (), GApplication), "command-line", (GCallback) _application_on_command_line_g_application_command_line, NULL);
#line 283 "Application.c"
	}
#line 64 "/home/jens/Source/shotwell/src/Application.vala"
	_tmp7_ = self->priv->system_app;
#line 64 "/home/jens/Source/shotwell/src/Application.vala"
	g_signal_connect (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, g_application_get_type (), GApplication), "activate", (GCallback) _application_on_activated_g_application_activate, NULL);
#line 65 "/home/jens/Source/shotwell/src/Application.vala"
	_tmp8_ = self->priv->system_app;
#line 65 "/home/jens/Source/shotwell/src/Application.vala"
	g_signal_connect (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, g_application_get_type (), GApplication), "startup", (GCallback) _application_on_activated_g_application_startup, NULL);
#line 35 "/home/jens/Source/shotwell/src/Application.vala"
	return self;
#line 295 "Application.c"
}


static Application* application_new (gboolean is_direct) {
#line 35 "/home/jens/Source/shotwell/src/Application.vala"
	return application_construct (TYPE_APPLICATION, is_direct);
#line 302 "Application.c"
}


/**
     * @brief This is a helper for library mode that should only be
     * called if we've gotten a camera mount and are _not_ the primary
     * instance.
     */
void application_send_to_primary_instance (gchar** argv, int argv_length1) {
	Application* _tmp0_ = NULL;
	Application* _tmp1_ = NULL;
	GtkApplication* _tmp2_ = NULL;
	gchar** _tmp3_ = NULL;
	gint _tmp3__length1 = 0;
#line 74 "/home/jens/Source/shotwell/src/Application.vala"
	_tmp0_ = application_get_instance ();
#line 74 "/home/jens/Source/shotwell/src/Application.vala"
	_tmp1_ = _tmp0_;
#line 74 "/home/jens/Source/shotwell/src/Application.vala"
	_tmp2_ = _tmp1_->priv->system_app;
#line 74 "/home/jens/Source/shotwell/src/Application.vala"
	_tmp3_ = argv;
#line 74 "/home/jens/Source/shotwell/src/Application.vala"
	_tmp3__length1 = argv_length1;
#line 74 "/home/jens/Source/shotwell/src/Application.vala"
	g_application_run (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, g_application_get_type (), GApplication), _tmp3__length1, _tmp3_);
#line 74 "/home/jens/Source/shotwell/src/Application.vala"
	_application_unref0 (_tmp1_);
#line 331 "Application.c"
}


/**
     * @brief A helper for library mode that tells the primary
     * instance to bring its window to the foreground.  This
     * should only be called if we are _not_ the primary instance.
     */
void application_present_primary_instance (void) {
	Application* _tmp0_ = NULL;
	Application* _tmp1_ = NULL;
	GtkApplication* _tmp2_ = NULL;
#line 83 "/home/jens/Source/shotwell/src/Application.vala"
	_tmp0_ = application_get_instance ();
#line 83 "/home/jens/Source/shotwell/src/Application.vala"
	_tmp1_ = _tmp0_;
#line 83 "/home/jens/Source/shotwell/src/Application.vala"
	_tmp2_ = _tmp1_->priv->system_app;
#line 83 "/home/jens/Source/shotwell/src/Application.vala"
	g_application_activate (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, g_application_get_type (), GApplication));
#line 83 "/home/jens/Source/shotwell/src/Application.vala"
	_application_unref0 (_tmp1_);
#line 354 "Application.c"
}


gboolean application_get_is_remote (void) {
	gboolean result = FALSE;
	Application* _tmp0_ = NULL;
	Application* _tmp1_ = NULL;
	GtkApplication* _tmp2_ = NULL;
	gboolean _tmp3_ = FALSE;
	gboolean _tmp4_ = FALSE;
#line 87 "/home/jens/Source/shotwell/src/Application.vala"
	_tmp0_ = application_get_instance ();
#line 87 "/home/jens/Source/shotwell/src/Application.vala"
	_tmp1_ = _tmp0_;
#line 87 "/home/jens/Source/shotwell/src/Application.vala"
	_tmp2_ = _tmp1_->priv->system_app;
#line 87 "/home/jens/Source/shotwell/src/Application.vala"
	_tmp3_ = g_application_get_is_remote (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, g_application_get_type (), GApplication));
#line 87 "/home/jens/Source/shotwell/src/Application.vala"
	_tmp4_ = _tmp3_;
#line 87 "/home/jens/Source/shotwell/src/Application.vala"
	_application_unref0 (_tmp1_);
#line 87 "/home/jens/Source/shotwell/src/Application.vala"
	result = _tmp4_;
#line 87 "/home/jens/Source/shotwell/src/Application.vala"
	return result;
#line 381 "Application.c"
}


gboolean application_get_is_direct (void) {
	gboolean result = FALSE;
	Application* _tmp0_ = NULL;
	Application* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	gboolean _tmp3_ = FALSE;
#line 91 "/home/jens/Source/shotwell/src/Application.vala"
	_tmp0_ = application_get_instance ();
#line 91 "/home/jens/Source/shotwell/src/Application.vala"
	_tmp1_ = _tmp0_;
#line 91 "/home/jens/Source/shotwell/src/Application.vala"
	_tmp2_ = _tmp1_->priv->direct;
#line 91 "/home/jens/Source/shotwell/src/Application.vala"
	_tmp3_ = _tmp2_;
#line 91 "/home/jens/Source/shotwell/src/Application.vala"
	_application_unref0 (_tmp1_);
#line 91 "/home/jens/Source/shotwell/src/Application.vala"
	result = _tmp3_;
#line 91 "/home/jens/Source/shotwell/src/Application.vala"
	return result;
#line 405 "Application.c"
}


/**
     * @brief Signal handler for GApplication's 'command-line' signal.
     *
     * The most likely scenario for this to be fired is if the user
     * either tried to run us twice in library mode, or we've just gotten
     * a camera/removeable-storage mount; in either case, the remote instance
     * will trigger this and exit, and we'll need to bring the window back up...
     */
void application_on_activated (void) {
	Application* _tmp0_ = NULL;
	Application* _tmp1_ = NULL;
	LibraryWindow* lw = NULL;
	AppWindow* _tmp2_ = NULL;
	LibraryWindow* _tmp3_ = NULL;
	gboolean _tmp4_ = FALSE;
	LibraryWindow* _tmp5_ = NULL;
#line 103 "/home/jens/Source/shotwell/src/Application.vala"
	_tmp0_ = application_get_instance ();
#line 103 "/home/jens/Source/shotwell/src/Application.vala"
	_tmp1_ = _tmp0_;
#line 103 "/home/jens/Source/shotwell/src/Application.vala"
	_application_unref0 (_tmp1_);
#line 105 "/home/jens/Source/shotwell/src/Application.vala"
	_tmp2_ = app_window_get_instance ();
#line 105 "/home/jens/Source/shotwell/src/Application.vala"
	_tmp3_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp2_, TYPE_LIBRARY_WINDOW) ? ((LibraryWindow*) _tmp2_) : NULL;
#line 105 "/home/jens/Source/shotwell/src/Application.vala"
	if (_tmp3_ == NULL) {
#line 105 "/home/jens/Source/shotwell/src/Application.vala"
		_g_object_unref0 (_tmp2_);
#line 439 "Application.c"
	}
#line 105 "/home/jens/Source/shotwell/src/Application.vala"
	lw = _tmp3_;
#line 106 "/home/jens/Source/shotwell/src/Application.vala"
	_tmp5_ = lw;
#line 106 "/home/jens/Source/shotwell/src/Application.vala"
	if (_tmp5_ != NULL) {
#line 447 "Application.c"
		gboolean _tmp6_ = FALSE;
#line 106 "/home/jens/Source/shotwell/src/Application.vala"
		_tmp6_ = application_get_is_direct ();
#line 106 "/home/jens/Source/shotwell/src/Application.vala"
		_tmp4_ = !_tmp6_;
#line 453 "Application.c"
	} else {
#line 106 "/home/jens/Source/shotwell/src/Application.vala"
		_tmp4_ = FALSE;
#line 457 "Application.c"
	}
#line 106 "/home/jens/Source/shotwell/src/Application.vala"
	if (_tmp4_) {
#line 461 "Application.c"
		LibraryWindow* _tmp7_ = NULL;
		LibraryWindow* _tmp8_ = NULL;
#line 107 "/home/jens/Source/shotwell/src/Application.vala"
		_tmp7_ = library_window_get_app ();
#line 107 "/home/jens/Source/shotwell/src/Application.vala"
		_tmp8_ = _tmp7_;
#line 107 "/home/jens/Source/shotwell/src/Application.vala"
		gtk_window_present (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, gtk_window_get_type (), GtkWindow));
#line 107 "/home/jens/Source/shotwell/src/Application.vala"
		_g_object_unref0 (_tmp8_);
#line 472 "Application.c"
	}
#line 102 "/home/jens/Source/shotwell/src/Application.vala"
	_g_object_unref0 (lw);
#line 476 "Application.c"
}


/**
     * @brief Signal handler for GApplication's 'command-line' signal.
     *
     * Gets fired whenever a remote instance tries to run, usually
     * with an incoming camera connection.
     *
     * @note This does _not_ get called in direct-edit mode.
     */
gint application_on_command_line (GApplicationCommandLine* acl) {
	gint result = 0;
	gchar** argv = NULL;
	GApplicationCommandLine* _tmp0_ = NULL;
	gint _tmp1_ = 0;
	gchar** _tmp2_ = NULL;
	gint argv_length1 = 0;
	gint _argv_size_ = 0;
	gchar** _tmp3_ = NULL;
	gint _tmp3__length1 = 0;
#line 119 "/home/jens/Source/shotwell/src/Application.vala"
	g_return_val_if_fail (G_IS_APPLICATION_COMMAND_LINE (acl), 0);
#line 120 "/home/jens/Source/shotwell/src/Application.vala"
	_tmp0_ = acl;
#line 120 "/home/jens/Source/shotwell/src/Application.vala"
	_tmp2_ = g_application_command_line_get_arguments (_tmp0_, &_tmp1_);
#line 120 "/home/jens/Source/shotwell/src/Application.vala"
	argv = _tmp2_;
#line 120 "/home/jens/Source/shotwell/src/Application.vala"
	argv_length1 = _tmp1_;
#line 120 "/home/jens/Source/shotwell/src/Application.vala"
	_argv_size_ = argv_length1;
#line 122 "/home/jens/Source/shotwell/src/Application.vala"
	_tmp3_ = argv;
#line 122 "/home/jens/Source/shotwell/src/Application.vala"
	_tmp3__length1 = argv_length1;
#line 122 "/home/jens/Source/shotwell/src/Application.vala"
	if (_tmp3_ != NULL) {
#line 516 "Application.c"
		gchar** _tmp4_ = NULL;
		gint _tmp4__length1 = 0;
#line 123 "/home/jens/Source/shotwell/src/Application.vala"
		_tmp4_ = argv;
#line 123 "/home/jens/Source/shotwell/src/Application.vala"
		_tmp4__length1 = argv_length1;
#line 523 "Application.c"
		{
			gchar** s_collection = NULL;
			gint s_collection_length1 = 0;
			gint _s_collection_size_ = 0;
			gint s_it = 0;
#line 123 "/home/jens/Source/shotwell/src/Application.vala"
			s_collection = _tmp4_;
#line 123 "/home/jens/Source/shotwell/src/Application.vala"
			s_collection_length1 = _tmp4__length1;
#line 123 "/home/jens/Source/shotwell/src/Application.vala"
			for (s_it = 0; s_it < _tmp4__length1; s_it = s_it + 1) {
#line 535 "Application.c"
				gchar* _tmp5_ = NULL;
				gchar* s = NULL;
#line 123 "/home/jens/Source/shotwell/src/Application.vala"
				_tmp5_ = g_strdup (s_collection[s_it]);
#line 123 "/home/jens/Source/shotwell/src/Application.vala"
				s = _tmp5_;
#line 542 "Application.c"
				{
					LibraryWindow* lw = NULL;
					AppWindow* _tmp6_ = NULL;
					LibraryWindow* _tmp7_ = NULL;
					LibraryWindow* _tmp8_ = NULL;
#line 124 "/home/jens/Source/shotwell/src/Application.vala"
					_tmp6_ = app_window_get_instance ();
#line 124 "/home/jens/Source/shotwell/src/Application.vala"
					_tmp7_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp6_, TYPE_LIBRARY_WINDOW) ? ((LibraryWindow*) _tmp6_) : NULL;
#line 124 "/home/jens/Source/shotwell/src/Application.vala"
					if (_tmp7_ == NULL) {
#line 124 "/home/jens/Source/shotwell/src/Application.vala"
						_g_object_unref0 (_tmp6_);
#line 556 "Application.c"
					}
#line 124 "/home/jens/Source/shotwell/src/Application.vala"
					lw = _tmp7_;
#line 125 "/home/jens/Source/shotwell/src/Application.vala"
					_tmp8_ = lw;
#line 125 "/home/jens/Source/shotwell/src/Application.vala"
					if (_tmp8_ != NULL) {
#line 564 "Application.c"
						LibraryWindow* _tmp9_ = NULL;
						const gchar* _tmp10_ = NULL;
#line 126 "/home/jens/Source/shotwell/src/Application.vala"
						_tmp9_ = lw;
#line 126 "/home/jens/Source/shotwell/src/Application.vala"
						_tmp10_ = s;
#line 126 "/home/jens/Source/shotwell/src/Application.vala"
						library_window_mounted_camera_shell_notification (_tmp9_, _tmp10_, FALSE);
#line 573 "Application.c"
					}
#line 123 "/home/jens/Source/shotwell/src/Application.vala"
					_g_object_unref0 (lw);
#line 123 "/home/jens/Source/shotwell/src/Application.vala"
					_g_free0 (s);
#line 579 "Application.c"
				}
			}
		}
	}
#line 130 "/home/jens/Source/shotwell/src/Application.vala"
	application_on_activated ();
#line 131 "/home/jens/Source/shotwell/src/Application.vala"
	result = 0;
#line 131 "/home/jens/Source/shotwell/src/Application.vala"
	argv = (_vala_array_free (argv, argv_length1, (GDestroyNotify) g_free), NULL);
#line 131 "/home/jens/Source/shotwell/src/Application.vala"
	return result;
#line 592 "Application.c"
}


/**
     * @brief Initializes the Shotwell application object and prepares
     * it for use.
     *
     * @param is_direct Whether the application was invoked in direct
     * or in library mode; defaults to FALSE, that is, library mode.
     *
     * @note This MUST be called prior to calling get_instance(), as the
     * application needs to know what mode it was brought up in; failure to
     * call this first will lead to an assertion.
     */
void application_init (gboolean is_direct) {
	Application* _tmp0_ = NULL;
#line 146 "/home/jens/Source/shotwell/src/Application.vala"
	_tmp0_ = application_instance;
#line 146 "/home/jens/Source/shotwell/src/Application.vala"
	if (_tmp0_ == NULL) {
#line 613 "Application.c"
		gboolean _tmp1_ = FALSE;
		Application* _tmp2_ = NULL;
#line 147 "/home/jens/Source/shotwell/src/Application.vala"
		_tmp1_ = is_direct;
#line 147 "/home/jens/Source/shotwell/src/Application.vala"
		_tmp2_ = application_new (_tmp1_);
#line 147 "/home/jens/Source/shotwell/src/Application.vala"
		_application_unref0 (application_instance);
#line 147 "/home/jens/Source/shotwell/src/Application.vala"
		application_instance = _tmp2_;
#line 624 "Application.c"
	}
}


void application_terminate (void) {
	Application* _tmp0_ = NULL;
	Application* _tmp1_ = NULL;
#line 151 "/home/jens/Source/shotwell/src/Application.vala"
	_tmp0_ = application_get_instance ();
#line 151 "/home/jens/Source/shotwell/src/Application.vala"
	_tmp1_ = _tmp0_;
#line 151 "/home/jens/Source/shotwell/src/Application.vala"
	application_exit (_tmp1_);
#line 151 "/home/jens/Source/shotwell/src/Application.vala"
	_application_unref0 (_tmp1_);
#line 640 "Application.c"
}


static gpointer _application_ref0 (gpointer self) {
#line 157 "/home/jens/Source/shotwell/src/Application.vala"
	return self ? application_ref (self) : NULL;
#line 647 "Application.c"
}


Application* application_get_instance (void) {
	Application* result = NULL;
	Application* _tmp0_ = NULL;
	Application* _tmp1_ = NULL;
	Application* _tmp2_ = NULL;
#line 155 "/home/jens/Source/shotwell/src/Application.vala"
	_tmp0_ = application_instance;
#line 155 "/home/jens/Source/shotwell/src/Application.vala"
	_vala_assert (_tmp0_ != NULL, "instance != null");
#line 157 "/home/jens/Source/shotwell/src/Application.vala"
	_tmp1_ = application_instance;
#line 157 "/home/jens/Source/shotwell/src/Application.vala"
	_tmp2_ = _application_ref0 (_tmp1_);
#line 157 "/home/jens/Source/shotwell/src/Application.vala"
	result = _tmp2_;
#line 157 "/home/jens/Source/shotwell/src/Application.vala"
	return result;
#line 668 "Application.c"
}


void application_start (Application* self, gchar** argv, int argv_length1) {
	gboolean _tmp0_ = FALSE;
	AppWindow* _tmp1_ = NULL;
	AppWindow* _tmp2_ = NULL;
	GtkApplication* _tmp3_ = NULL;
	AppWindow* _tmp4_ = NULL;
	AppWindow* _tmp5_ = NULL;
	GtkApplication* _tmp6_ = NULL;
	gchar** _tmp7_ = NULL;
	gint _tmp7__length1 = 0;
	gint _tmp8_ = 0;
	gboolean _tmp9_ = FALSE;
	GtkApplication* _tmp12_ = NULL;
	guint _tmp13_ = 0U;
	GtkApplication* _tmp14_ = NULL;
	guint _tmp15_ = 0U;
#line 160 "/home/jens/Source/shotwell/src/Application.vala"
	g_return_if_fail (IS_APPLICATION (self));
#line 161 "/home/jens/Source/shotwell/src/Application.vala"
	_tmp0_ = self->priv->running;
#line 161 "/home/jens/Source/shotwell/src/Application.vala"
	if (_tmp0_) {
#line 162 "/home/jens/Source/shotwell/src/Application.vala"
		return;
#line 696 "Application.c"
	}
#line 164 "/home/jens/Source/shotwell/src/Application.vala"
	self->priv->running = TRUE;
#line 166 "/home/jens/Source/shotwell/src/Application.vala"
	g_signal_emit_by_name (self, "starting");
#line 168 "/home/jens/Source/shotwell/src/Application.vala"
	_tmp1_ = app_window_get_instance ();
#line 168 "/home/jens/Source/shotwell/src/Application.vala"
	_tmp2_ = _tmp1_;
#line 168 "/home/jens/Source/shotwell/src/Application.vala"
	_vala_assert (_tmp2_ != NULL, "AppWindow.get_instance() != null");
#line 168 "/home/jens/Source/shotwell/src/Application.vala"
	_g_object_unref0 (_tmp2_);
#line 169 "/home/jens/Source/shotwell/src/Application.vala"
	_tmp3_ = self->priv->system_app;
#line 169 "/home/jens/Source/shotwell/src/Application.vala"
	_tmp4_ = app_window_get_instance ();
#line 169 "/home/jens/Source/shotwell/src/Application.vala"
	_tmp5_ = _tmp4_;
#line 169 "/home/jens/Source/shotwell/src/Application.vala"
	gtk_application_add_window (_tmp3_, G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, gtk_window_get_type (), GtkWindow));
#line 169 "/home/jens/Source/shotwell/src/Application.vala"
	_g_object_unref0 (_tmp5_);
#line 170 "/home/jens/Source/shotwell/src/Application.vala"
	_tmp6_ = self->priv->system_app;
#line 170 "/home/jens/Source/shotwell/src/Application.vala"
	_tmp7_ = argv;
#line 170 "/home/jens/Source/shotwell/src/Application.vala"
	_tmp7__length1 = argv_length1;
#line 170 "/home/jens/Source/shotwell/src/Application.vala"
	_tmp8_ = g_application_run (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, g_application_get_type (), GApplication), _tmp7__length1, _tmp7_);
#line 170 "/home/jens/Source/shotwell/src/Application.vala"
	self->priv->system_app_run_retval = _tmp8_;
#line 172 "/home/jens/Source/shotwell/src/Application.vala"
	_tmp9_ = self->priv->direct;
#line 172 "/home/jens/Source/shotwell/src/Application.vala"
	if (!_tmp9_) {
#line 734 "Application.c"
		GtkApplication* _tmp10_ = NULL;
		guint _tmp11_ = 0U;
#line 173 "/home/jens/Source/shotwell/src/Application.vala"
		_tmp10_ = self->priv->system_app;
#line 173 "/home/jens/Source/shotwell/src/Application.vala"
		g_signal_parse_name ("command-line", g_application_get_type (), &_tmp11_, NULL, FALSE);
#line 173 "/home/jens/Source/shotwell/src/Application.vala"
		g_signal_handlers_disconnect_matched (G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, g_application_get_type (), GApplication), G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp11_, 0, NULL, (GCallback) _application_on_command_line_g_application_command_line, NULL);
#line 743 "Application.c"
	}
#line 176 "/home/jens/Source/shotwell/src/Application.vala"
	_tmp12_ = self->priv->system_app;
#line 176 "/home/jens/Source/shotwell/src/Application.vala"
	g_signal_parse_name ("activate", g_application_get_type (), &_tmp13_, NULL, FALSE);
#line 176 "/home/jens/Source/shotwell/src/Application.vala"
	g_signal_handlers_disconnect_matched (G_TYPE_CHECK_INSTANCE_CAST (_tmp12_, g_application_get_type (), GApplication), G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp13_, 0, NULL, (GCallback) _application_on_activated_g_application_activate, NULL);
#line 177 "/home/jens/Source/shotwell/src/Application.vala"
	_tmp14_ = self->priv->system_app;
#line 177 "/home/jens/Source/shotwell/src/Application.vala"
	g_signal_parse_name ("startup", g_application_get_type (), &_tmp15_, NULL, FALSE);
#line 177 "/home/jens/Source/shotwell/src/Application.vala"
	g_signal_handlers_disconnect_matched (G_TYPE_CHECK_INSTANCE_CAST (_tmp14_, g_application_get_type (), GApplication), G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp15_, 0, NULL, (GCallback) _application_on_activated_g_application_startup, NULL);
#line 179 "/home/jens/Source/shotwell/src/Application.vala"
	self->priv->running = FALSE;
#line 759 "Application.c"
}


void application_exit (Application* self) {
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	GtkApplication* _tmp3_ = NULL;
#line 182 "/home/jens/Source/shotwell/src/Application.vala"
	g_return_if_fail (IS_APPLICATION (self));
#line 185 "/home/jens/Source/shotwell/src/Application.vala"
	_tmp1_ = self->priv->exiting_fired;
#line 185 "/home/jens/Source/shotwell/src/Application.vala"
	if (_tmp1_) {
#line 185 "/home/jens/Source/shotwell/src/Application.vala"
		_tmp0_ = TRUE;
#line 775 "Application.c"
	} else {
		gboolean _tmp2_ = FALSE;
#line 185 "/home/jens/Source/shotwell/src/Application.vala"
		_tmp2_ = self->priv->running;
#line 185 "/home/jens/Source/shotwell/src/Application.vala"
		_tmp0_ = !_tmp2_;
#line 782 "Application.c"
	}
#line 185 "/home/jens/Source/shotwell/src/Application.vala"
	if (_tmp0_) {
#line 186 "/home/jens/Source/shotwell/src/Application.vala"
		return;
#line 788 "Application.c"
	}
#line 188 "/home/jens/Source/shotwell/src/Application.vala"
	self->priv->exiting_fired = TRUE;
#line 190 "/home/jens/Source/shotwell/src/Application.vala"
	g_signal_emit_by_name (self, "exiting", FALSE);
#line 192 "/home/jens/Source/shotwell/src/Application.vala"
	_tmp3_ = self->priv->system_app;
#line 192 "/home/jens/Source/shotwell/src/Application.vala"
	g_application_release (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, g_application_get_type (), GApplication));
#line 798 "Application.c"
}


void application_panic (Application* self) {
	gboolean _tmp0_ = FALSE;
#line 197 "/home/jens/Source/shotwell/src/Application.vala"
	g_return_if_fail (IS_APPLICATION (self));
#line 198 "/home/jens/Source/shotwell/src/Application.vala"
	_tmp0_ = self->priv->exiting_fired;
#line 198 "/home/jens/Source/shotwell/src/Application.vala"
	if (!_tmp0_) {
#line 199 "/home/jens/Source/shotwell/src/Application.vala"
		self->priv->exiting_fired = TRUE;
#line 200 "/home/jens/Source/shotwell/src/Application.vala"
		g_signal_emit_by_name (self, "exiting", TRUE);
#line 814 "Application.c"
	}
#line 202 "/home/jens/Source/shotwell/src/Application.vala"
	exit (1);
#line 818 "Application.c"
}


/**
     * @brief Allows the caller to ask for some part of the desktop session's functionality to
     * be prevented from running; wrapper for Gtk.Application.inhibit().
     *
     * @note The return value is a 'cookie' that needs to be passed to 'uninhibit' to turn
     * off a requested inhibition and should be saved by the caller.
     */
guint application_inhibit (Application* self, GtkApplicationInhibitFlags what, const gchar* reason) {
	guint result = 0U;
	GtkApplication* _tmp0_ = NULL;
	AppWindow* _tmp1_ = NULL;
	AppWindow* _tmp2_ = NULL;
	GtkApplicationInhibitFlags _tmp3_ = 0;
	const gchar* _tmp4_ = NULL;
	guint _tmp5_ = 0U;
	guint _tmp6_ = 0U;
#line 212 "/home/jens/Source/shotwell/src/Application.vala"
	g_return_val_if_fail (IS_APPLICATION (self), 0U);
#line 213 "/home/jens/Source/shotwell/src/Application.vala"
	_tmp0_ = self->priv->system_app;
#line 213 "/home/jens/Source/shotwell/src/Application.vala"
	_tmp1_ = app_window_get_instance ();
#line 213 "/home/jens/Source/shotwell/src/Application.vala"
	_tmp2_ = _tmp1_;
#line 213 "/home/jens/Source/shotwell/src/Application.vala"
	_tmp3_ = what;
#line 213 "/home/jens/Source/shotwell/src/Application.vala"
	_tmp4_ = reason;
#line 213 "/home/jens/Source/shotwell/src/Application.vala"
	_tmp5_ = gtk_application_inhibit (_tmp0_, G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, gtk_window_get_type (), GtkWindow), _tmp3_, _tmp4_);
#line 213 "/home/jens/Source/shotwell/src/Application.vala"
	_tmp6_ = _tmp5_;
#line 213 "/home/jens/Source/shotwell/src/Application.vala"
	_g_object_unref0 (_tmp2_);
#line 213 "/home/jens/Source/shotwell/src/Application.vala"
	result = _tmp6_;
#line 213 "/home/jens/Source/shotwell/src/Application.vala"
	return result;
#line 860 "Application.c"
}


/**
     * @brief Turns off a previously-requested inhibition. Wrapper for
     * Gtk.Application.uninhibit().
     */
void application_uninhibit (Application* self, guint cookie) {
	GtkApplication* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
#line 220 "/home/jens/Source/shotwell/src/Application.vala"
	g_return_if_fail (IS_APPLICATION (self));
#line 221 "/home/jens/Source/shotwell/src/Application.vala"
	_tmp0_ = self->priv->system_app;
#line 221 "/home/jens/Source/shotwell/src/Application.vala"
	_tmp1_ = cookie;
#line 221 "/home/jens/Source/shotwell/src/Application.vala"
	gtk_application_uninhibit (_tmp0_, _tmp1_);
#line 879 "Application.c"
}


gint application_get_run_return_value (Application* self) {
	gint result = 0;
	gint _tmp0_ = 0;
#line 224 "/home/jens/Source/shotwell/src/Application.vala"
	g_return_val_if_fail (IS_APPLICATION (self), 0);
#line 225 "/home/jens/Source/shotwell/src/Application.vala"
	_tmp0_ = self->priv->system_app_run_retval;
#line 225 "/home/jens/Source/shotwell/src/Application.vala"
	result = _tmp0_;
#line 225 "/home/jens/Source/shotwell/src/Application.vala"
	return result;
#line 894 "Application.c"
}


static void application_real_starting (Application* self) {
}


static void application_real_exiting (Application* self, gboolean panicked) {
}


static void application_real_init_done (Application* self) {
}


static void value_application_init (GValue* value) {
#line 7 "/home/jens/Source/shotwell/src/Application.vala"
	value->data[0].v_pointer = NULL;
#line 913 "Application.c"
}


static void value_application_free_value (GValue* value) {
#line 7 "/home/jens/Source/shotwell/src/Application.vala"
	if (value->data[0].v_pointer) {
#line 7 "/home/jens/Source/shotwell/src/Application.vala"
		application_unref (value->data[0].v_pointer);
#line 922 "Application.c"
	}
}


static void value_application_copy_value (const GValue* src_value, GValue* dest_value) {
#line 7 "/home/jens/Source/shotwell/src/Application.vala"
	if (src_value->data[0].v_pointer) {
#line 7 "/home/jens/Source/shotwell/src/Application.vala"
		dest_value->data[0].v_pointer = application_ref (src_value->data[0].v_pointer);
#line 932 "Application.c"
	} else {
#line 7 "/home/jens/Source/shotwell/src/Application.vala"
		dest_value->data[0].v_pointer = NULL;
#line 936 "Application.c"
	}
}


static gpointer value_application_peek_pointer (const GValue* value) {
#line 7 "/home/jens/Source/shotwell/src/Application.vala"
	return value->data[0].v_pointer;
#line 944 "Application.c"
}


static gchar* value_application_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
#line 7 "/home/jens/Source/shotwell/src/Application.vala"
	if (collect_values[0].v_pointer) {
#line 951 "Application.c"
		Application* object;
		object = collect_values[0].v_pointer;
#line 7 "/home/jens/Source/shotwell/src/Application.vala"
		if (object->parent_instance.g_class == NULL) {
#line 7 "/home/jens/Source/shotwell/src/Application.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 958 "Application.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 7 "/home/jens/Source/shotwell/src/Application.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 962 "Application.c"
		}
#line 7 "/home/jens/Source/shotwell/src/Application.vala"
		value->data[0].v_pointer = application_ref (object);
#line 966 "Application.c"
	} else {
#line 7 "/home/jens/Source/shotwell/src/Application.vala"
		value->data[0].v_pointer = NULL;
#line 970 "Application.c"
	}
#line 7 "/home/jens/Source/shotwell/src/Application.vala"
	return NULL;
#line 974 "Application.c"
}


static gchar* value_application_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	Application** object_p;
	object_p = collect_values[0].v_pointer;
#line 7 "/home/jens/Source/shotwell/src/Application.vala"
	if (!object_p) {
#line 7 "/home/jens/Source/shotwell/src/Application.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 985 "Application.c"
	}
#line 7 "/home/jens/Source/shotwell/src/Application.vala"
	if (!value->data[0].v_pointer) {
#line 7 "/home/jens/Source/shotwell/src/Application.vala"
		*object_p = NULL;
#line 991 "Application.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 7 "/home/jens/Source/shotwell/src/Application.vala"
		*object_p = value->data[0].v_pointer;
#line 995 "Application.c"
	} else {
#line 7 "/home/jens/Source/shotwell/src/Application.vala"
		*object_p = application_ref (value->data[0].v_pointer);
#line 999 "Application.c"
	}
#line 7 "/home/jens/Source/shotwell/src/Application.vala"
	return NULL;
#line 1003 "Application.c"
}


GParamSpec* param_spec_application (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
	ParamSpecApplication* spec;
#line 7 "/home/jens/Source/shotwell/src/Application.vala"
	g_return_val_if_fail (g_type_is_a (object_type, TYPE_APPLICATION), NULL);
#line 7 "/home/jens/Source/shotwell/src/Application.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 7 "/home/jens/Source/shotwell/src/Application.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 7 "/home/jens/Source/shotwell/src/Application.vala"
	return G_PARAM_SPEC (spec);
#line 1017 "Application.c"
}


gpointer value_get_application (const GValue* value) {
#line 7 "/home/jens/Source/shotwell/src/Application.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_APPLICATION), NULL);
#line 7 "/home/jens/Source/shotwell/src/Application.vala"
	return value->data[0].v_pointer;
#line 1026 "Application.c"
}


void value_set_application (GValue* value, gpointer v_object) {
	Application* old;
#line 7 "/home/jens/Source/shotwell/src/Application.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_APPLICATION));
#line 7 "/home/jens/Source/shotwell/src/Application.vala"
	old = value->data[0].v_pointer;
#line 7 "/home/jens/Source/shotwell/src/Application.vala"
	if (v_object) {
#line 7 "/home/jens/Source/shotwell/src/Application.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, TYPE_APPLICATION));
#line 7 "/home/jens/Source/shotwell/src/Application.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 7 "/home/jens/Source/shotwell/src/Application.vala"
		value->data[0].v_pointer = v_object;
#line 7 "/home/jens/Source/shotwell/src/Application.vala"
		application_ref (value->data[0].v_pointer);
#line 1046 "Application.c"
	} else {
#line 7 "/home/jens/Source/shotwell/src/Application.vala"
		value->data[0].v_pointer = NULL;
#line 1050 "Application.c"
	}
#line 7 "/home/jens/Source/shotwell/src/Application.vala"
	if (old) {
#line 7 "/home/jens/Source/shotwell/src/Application.vala"
		application_unref (old);
#line 1056 "Application.c"
	}
}


void value_take_application (GValue* value, gpointer v_object) {
	Application* old;
#line 7 "/home/jens/Source/shotwell/src/Application.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_APPLICATION));
#line 7 "/home/jens/Source/shotwell/src/Application.vala"
	old = value->data[0].v_pointer;
#line 7 "/home/jens/Source/shotwell/src/Application.vala"
	if (v_object) {
#line 7 "/home/jens/Source/shotwell/src/Application.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, TYPE_APPLICATION));
#line 7 "/home/jens/Source/shotwell/src/Application.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 7 "/home/jens/Source/shotwell/src/Application.vala"
		value->data[0].v_pointer = v_object;
#line 1075 "Application.c"
	} else {
#line 7 "/home/jens/Source/shotwell/src/Application.vala"
		value->data[0].v_pointer = NULL;
#line 1079 "Application.c"
	}
#line 7 "/home/jens/Source/shotwell/src/Application.vala"
	if (old) {
#line 7 "/home/jens/Source/shotwell/src/Application.vala"
		application_unref (old);
#line 1085 "Application.c"
	}
}


static void application_class_init (ApplicationClass * klass) {
#line 7 "/home/jens/Source/shotwell/src/Application.vala"
	application_parent_class = g_type_class_peek_parent (klass);
#line 7 "/home/jens/Source/shotwell/src/Application.vala"
	((ApplicationClass *) klass)->finalize = application_finalize;
#line 7 "/home/jens/Source/shotwell/src/Application.vala"
	g_type_class_add_private (klass, sizeof (ApplicationPrivate));
#line 7 "/home/jens/Source/shotwell/src/Application.vala"
	((ApplicationClass *) klass)->starting = application_real_starting;
#line 7 "/home/jens/Source/shotwell/src/Application.vala"
	((ApplicationClass *) klass)->exiting = application_real_exiting;
#line 7 "/home/jens/Source/shotwell/src/Application.vala"
	((ApplicationClass *) klass)->init_done = application_real_init_done;
#line 7 "/home/jens/Source/shotwell/src/Application.vala"
	g_signal_new ("starting", TYPE_APPLICATION, G_SIGNAL_RUN_LAST, G_STRUCT_OFFSET (ApplicationClass, starting), NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
#line 7 "/home/jens/Source/shotwell/src/Application.vala"
	g_signal_new ("exiting", TYPE_APPLICATION, G_SIGNAL_RUN_LAST, G_STRUCT_OFFSET (ApplicationClass, exiting), NULL, NULL, g_cclosure_marshal_VOID__BOOLEAN, G_TYPE_NONE, 1, G_TYPE_BOOLEAN);
#line 7 "/home/jens/Source/shotwell/src/Application.vala"
	g_signal_new ("init_done", TYPE_APPLICATION, G_SIGNAL_RUN_LAST, G_STRUCT_OFFSET (ApplicationClass, init_done), NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
#line 1109 "Application.c"
}


static void application_instance_init (Application * self) {
#line 7 "/home/jens/Source/shotwell/src/Application.vala"
	self->priv = APPLICATION_GET_PRIVATE (self);
#line 9 "/home/jens/Source/shotwell/src/Application.vala"
	self->priv->system_app = NULL;
#line 10 "/home/jens/Source/shotwell/src/Application.vala"
	self->priv->system_app_run_retval = 0;
#line 22 "/home/jens/Source/shotwell/src/Application.vala"
	self->priv->fixup_raw_thumbs = FALSE;
#line 32 "/home/jens/Source/shotwell/src/Application.vala"
	self->priv->running = FALSE;
#line 33 "/home/jens/Source/shotwell/src/Application.vala"
	self->priv->exiting_fired = FALSE;
#line 7 "/home/jens/Source/shotwell/src/Application.vala"
	self->ref_count = 1;
#line 1128 "Application.c"
}


static void application_finalize (Application* obj) {
	Application * self;
#line 7 "/home/jens/Source/shotwell/src/Application.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_APPLICATION, Application);
#line 7 "/home/jens/Source/shotwell/src/Application.vala"
	g_signal_handlers_destroy (self);
#line 9 "/home/jens/Source/shotwell/src/Application.vala"
	_g_object_unref0 (self->priv->system_app);
#line 1140 "Application.c"
}


GType application_get_type (void) {
	static volatile gsize application_type_id__volatile = 0;
	if (g_once_init_enter (&application_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { value_application_init, value_application_free_value, value_application_copy_value, value_application_peek_pointer, "p", value_application_collect_value, "p", value_application_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (ApplicationClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) application_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (Application), 0, (GInstanceInitFunc) application_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType application_type_id;
		application_type_id = g_type_register_fundamental (g_type_fundamental_next (), "Application", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&application_type_id__volatile, application_type_id);
	}
	return application_type_id__volatile;
}


gpointer application_ref (gpointer instance) {
	Application* self;
	self = instance;
#line 7 "/home/jens/Source/shotwell/src/Application.vala"
	g_atomic_int_inc (&self->ref_count);
#line 7 "/home/jens/Source/shotwell/src/Application.vala"
	return instance;
#line 1165 "Application.c"
}


void application_unref (gpointer instance) {
	Application* self;
	self = instance;
#line 7 "/home/jens/Source/shotwell/src/Application.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 7 "/home/jens/Source/shotwell/src/Application.vala"
		APPLICATION_GET_CLASS (self)->finalize (self);
#line 7 "/home/jens/Source/shotwell/src/Application.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 1178 "Application.c"
	}
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}



