/* Camera.c generated by valac 0.32.1, the Vala compiler
 * generated from Camera.vala, do not modify */

/* Copyright 2016 Software Freedom Conservancy Inc.
 *
 * This software is licensed under the GNU Lesser General Public License
 * (version 2.1 or later).  See the COPYING file in this distribution.
 */

#include <glib.h>
#include <glib-object.h>




void camera_init (GError** error);
void camera_branch_init (void);
void camera_terminate (void);
void camera_branch_terminate (void);


void camera_init (GError** error) {
#line 10 "/home/jens/Source/shotwell/src/camera/Camera.vala"
	camera_branch_init ();
#line 26 "Camera.c"
}


void camera_terminate (void) {
#line 14 "/home/jens/Source/shotwell/src/camera/Camera.vala"
	camera_branch_terminate ();
#line 33 "Camera.c"
}



