/* ImportPage.c generated by valac 0.32.1, the Vala compiler
 * generated from ImportPage.vala, do not modify */

/* Copyright 2016 Software Freedom Conservancy Inc.
 *
 * This software is licensed under the GNU LGPL (version 2.1 or later).
 * See the COPYING file in this distribution.
 */

#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <gee.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <time.h>
#include <gphoto2/gphoto2-camera.h>
#include <gphoto.h>
#include <gphoto2/gphoto2-result.h>
#include <gphoto2/gphoto2-port-result.h>
#include <float.h>
#include <math.h>
#include <gphoto2/gphoto2-context.h>
#include <cairo.h>
#include <gdk/gdk.h>
#include <pango/pango.h>
#include <glib/gi18n-lib.h>
#include <gio/gio.h>
#include <gtk/gtk.h>
#include <gphoto2/gphoto2-abilities-list.h>
#include <gphoto2/gphoto2-list.h>
#include <gphoto2/gphoto2-filesys.h>


#define TYPE_DATA_COLLECTION (data_collection_get_type ())
#define DATA_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATA_COLLECTION, DataCollection))
#define DATA_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATA_COLLECTION, DataCollectionClass))
#define IS_DATA_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATA_COLLECTION))
#define IS_DATA_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATA_COLLECTION))
#define DATA_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATA_COLLECTION, DataCollectionClass))

typedef struct _DataCollection DataCollection;
typedef struct _DataCollectionClass DataCollectionClass;
typedef struct _DataCollectionPrivate DataCollectionPrivate;

#define TYPE_DATA_OBJECT (data_object_get_type ())
#define DATA_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATA_OBJECT, DataObject))
#define DATA_OBJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATA_OBJECT, DataObjectClass))
#define IS_DATA_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATA_OBJECT))
#define IS_DATA_OBJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATA_OBJECT))
#define DATA_OBJECT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATA_OBJECT, DataObjectClass))

typedef struct _DataObject DataObject;
typedef struct _DataObjectClass DataObjectClass;

#define TYPE_ALTERATION (alteration_get_type ())
#define ALTERATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_ALTERATION, Alteration))
#define ALTERATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_ALTERATION, AlterationClass))
#define IS_ALTERATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_ALTERATION))
#define IS_ALTERATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_ALTERATION))
#define ALTERATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_ALTERATION, AlterationClass))

typedef struct _Alteration Alteration;
typedef struct _AlterationClass AlterationClass;

#define TYPE_MARKER (marker_get_type ())
#define MARKER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MARKER, Marker))
#define IS_MARKER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MARKER))
#define MARKER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TYPE_MARKER, MarkerIface))

typedef struct _Marker Marker;
typedef struct _MarkerIface MarkerIface;

#define TYPE_SOURCE_COLLECTION (source_collection_get_type ())
#define SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SOURCE_COLLECTION, SourceCollection))
#define SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SOURCE_COLLECTION, SourceCollectionClass))
#define IS_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SOURCE_COLLECTION))
#define IS_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SOURCE_COLLECTION))
#define SOURCE_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SOURCE_COLLECTION, SourceCollectionClass))

typedef struct _SourceCollection SourceCollection;
typedef struct _SourceCollectionClass SourceCollectionClass;
typedef struct _SourceCollectionPrivate SourceCollectionPrivate;

#define TYPE_DATA_SOURCE (data_source_get_type ())
#define DATA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATA_SOURCE, DataSource))
#define DATA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATA_SOURCE, DataSourceClass))
#define IS_DATA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATA_SOURCE))
#define IS_DATA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATA_SOURCE))
#define DATA_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATA_SOURCE, DataSourceClass))

typedef struct _DataSource DataSource;
typedef struct _DataSourceClass DataSourceClass;

#define TYPE_SOURCE_BACKLINK (source_backlink_get_type ())
#define SOURCE_BACKLINK(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SOURCE_BACKLINK, SourceBacklink))
#define SOURCE_BACKLINK_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SOURCE_BACKLINK, SourceBacklinkClass))
#define IS_SOURCE_BACKLINK(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SOURCE_BACKLINK))
#define IS_SOURCE_BACKLINK_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SOURCE_BACKLINK))
#define SOURCE_BACKLINK_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SOURCE_BACKLINK, SourceBacklinkClass))

typedef struct _SourceBacklink SourceBacklink;
typedef struct _SourceBacklinkClass SourceBacklinkClass;

#define TYPE_IMPORT_SOURCE_COLLECTION (import_source_collection_get_type ())
#define IMPORT_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_IMPORT_SOURCE_COLLECTION, ImportSourceCollection))
#define IMPORT_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_IMPORT_SOURCE_COLLECTION, ImportSourceCollectionClass))
#define IS_IMPORT_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_IMPORT_SOURCE_COLLECTION))
#define IS_IMPORT_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_IMPORT_SOURCE_COLLECTION))
#define IMPORT_SOURCE_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_IMPORT_SOURCE_COLLECTION, ImportSourceCollectionClass))

typedef struct _ImportSourceCollection ImportSourceCollection;
typedef struct _ImportSourceCollectionClass ImportSourceCollectionClass;
typedef struct _ImportSourceCollectionPrivate ImportSourceCollectionPrivate;

#define TYPE_THUMBNAIL_SOURCE (thumbnail_source_get_type ())
#define THUMBNAIL_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_THUMBNAIL_SOURCE, ThumbnailSource))
#define THUMBNAIL_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_THUMBNAIL_SOURCE, ThumbnailSourceClass))
#define IS_THUMBNAIL_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_THUMBNAIL_SOURCE))
#define IS_THUMBNAIL_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_THUMBNAIL_SOURCE))
#define THUMBNAIL_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_THUMBNAIL_SOURCE, ThumbnailSourceClass))

typedef struct _ThumbnailSource ThumbnailSource;
typedef struct _ThumbnailSourceClass ThumbnailSourceClass;

#define TYPE_IMPORT_SOURCE (import_source_get_type ())
#define IMPORT_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_IMPORT_SOURCE, ImportSource))
#define IMPORT_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_IMPORT_SOURCE, ImportSourceClass))
#define IS_IMPORT_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_IMPORT_SOURCE))
#define IS_IMPORT_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_IMPORT_SOURCE))
#define IMPORT_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_IMPORT_SOURCE, ImportSourceClass))

typedef struct _ImportSource ImportSource;
typedef struct _ImportSourceClass ImportSourceClass;
typedef struct _DataObjectPrivate DataObjectPrivate;
typedef struct _DataSourcePrivate DataSourcePrivate;

#define TYPE_SOURCE_HOLDING_TANK (source_holding_tank_get_type ())
#define SOURCE_HOLDING_TANK(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SOURCE_HOLDING_TANK, SourceHoldingTank))
#define SOURCE_HOLDING_TANK_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SOURCE_HOLDING_TANK, SourceHoldingTankClass))
#define IS_SOURCE_HOLDING_TANK(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SOURCE_HOLDING_TANK))
#define IS_SOURCE_HOLDING_TANK_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SOURCE_HOLDING_TANK))
#define SOURCE_HOLDING_TANK_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SOURCE_HOLDING_TANK, SourceHoldingTankClass))

typedef struct _SourceHoldingTank SourceHoldingTank;
typedef struct _SourceHoldingTankClass SourceHoldingTankClass;

#define TYPE_SOURCE_SNAPSHOT (source_snapshot_get_type ())
#define SOURCE_SNAPSHOT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SOURCE_SNAPSHOT, SourceSnapshot))
#define SOURCE_SNAPSHOT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SOURCE_SNAPSHOT, SourceSnapshotClass))
#define IS_SOURCE_SNAPSHOT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SOURCE_SNAPSHOT))
#define IS_SOURCE_SNAPSHOT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SOURCE_SNAPSHOT))
#define SOURCE_SNAPSHOT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SOURCE_SNAPSHOT, SourceSnapshotClass))

typedef struct _SourceSnapshot SourceSnapshot;
typedef struct _SourceSnapshotClass SourceSnapshotClass;
typedef struct _ThumbnailSourcePrivate ThumbnailSourcePrivate;

#define TYPE_PHOTO_FILE_FORMAT (photo_file_format_get_type ())

#define TYPE_INDEXABLE (indexable_get_type ())
#define INDEXABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_INDEXABLE, Indexable))
#define IS_INDEXABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_INDEXABLE))
#define INDEXABLE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TYPE_INDEXABLE, IndexableIface))

typedef struct _Indexable Indexable;
typedef struct _IndexableIface IndexableIface;
typedef struct _ImportSourcePrivate ImportSourcePrivate;
#define _g_free0(var) (var = (g_free (var), NULL))
#define _gp_camera_unref0(var) ((var == NULL) ? NULL : (var = (gp_camera_unref (var), NULL)))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define GP_TYPE_CONTEXT_WRAPPER (gp_context_wrapper_get_type ())
#define GP_CONTEXT_WRAPPER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GP_TYPE_CONTEXT_WRAPPER, GPContextWrapper))
#define GP_CONTEXT_WRAPPER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GP_TYPE_CONTEXT_WRAPPER, GPContextWrapperClass))
#define GP_IS_CONTEXT_WRAPPER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GP_TYPE_CONTEXT_WRAPPER))
#define GP_IS_CONTEXT_WRAPPER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GP_TYPE_CONTEXT_WRAPPER))
#define GP_CONTEXT_WRAPPER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GP_TYPE_CONTEXT_WRAPPER, GPContextWrapperClass))

typedef struct _GPContextWrapper GPContextWrapper;
typedef struct _GPContextWrapperClass GPContextWrapperClass;

#define GP_TYPE_SPIN_IDLE_WRAPPER (gp_spin_idle_wrapper_get_type ())
#define GP_SPIN_IDLE_WRAPPER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GP_TYPE_SPIN_IDLE_WRAPPER, GPSpinIdleWrapper))
#define GP_SPIN_IDLE_WRAPPER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GP_TYPE_SPIN_IDLE_WRAPPER, GPSpinIdleWrapperClass))
#define GP_IS_SPIN_IDLE_WRAPPER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GP_TYPE_SPIN_IDLE_WRAPPER))
#define GP_IS_SPIN_IDLE_WRAPPER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GP_TYPE_SPIN_IDLE_WRAPPER))
#define GP_SPIN_IDLE_WRAPPER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GP_TYPE_SPIN_IDLE_WRAPPER, GPSpinIdleWrapperClass))

typedef struct _GPSpinIdleWrapper GPSpinIdleWrapper;
typedef struct _GPSpinIdleWrapperClass GPSpinIdleWrapperClass;
typedef struct _GPContextWrapperPrivate GPContextWrapperPrivate;

#define TYPE_VIDEO_IMPORT_SOURCE (video_import_source_get_type ())
#define VIDEO_IMPORT_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_VIDEO_IMPORT_SOURCE, VideoImportSource))
#define VIDEO_IMPORT_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_VIDEO_IMPORT_SOURCE, VideoImportSourceClass))
#define IS_VIDEO_IMPORT_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_VIDEO_IMPORT_SOURCE))
#define IS_VIDEO_IMPORT_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_VIDEO_IMPORT_SOURCE))
#define VIDEO_IMPORT_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_VIDEO_IMPORT_SOURCE, VideoImportSourceClass))

typedef struct _VideoImportSource VideoImportSource;
typedef struct _VideoImportSourceClass VideoImportSourceClass;
typedef struct _VideoImportSourcePrivate VideoImportSourcePrivate;

#define TYPE_PHOTO_IMPORT_SOURCE (photo_import_source_get_type ())
#define PHOTO_IMPORT_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PHOTO_IMPORT_SOURCE, PhotoImportSource))
#define PHOTO_IMPORT_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PHOTO_IMPORT_SOURCE, PhotoImportSourceClass))
#define IS_PHOTO_IMPORT_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PHOTO_IMPORT_SOURCE))
#define IS_PHOTO_IMPORT_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PHOTO_IMPORT_SOURCE))
#define PHOTO_IMPORT_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PHOTO_IMPORT_SOURCE, PhotoImportSourceClass))

typedef struct _PhotoImportSource PhotoImportSource;
typedef struct _PhotoImportSourceClass PhotoImportSourceClass;
typedef struct _PhotoImportSourcePrivate PhotoImportSourcePrivate;

#define TYPE_MEDIA_METADATA (media_metadata_get_type ())
#define MEDIA_METADATA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MEDIA_METADATA, MediaMetadata))
#define MEDIA_METADATA_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MEDIA_METADATA, MediaMetadataClass))
#define IS_MEDIA_METADATA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MEDIA_METADATA))
#define IS_MEDIA_METADATA_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MEDIA_METADATA))
#define MEDIA_METADATA_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MEDIA_METADATA, MediaMetadataClass))

typedef struct _MediaMetadata MediaMetadata;
typedef struct _MediaMetadataClass MediaMetadataClass;

#define TYPE_PHOTO_METADATA (photo_metadata_get_type ())
#define PHOTO_METADATA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PHOTO_METADATA, PhotoMetadata))
#define PHOTO_METADATA_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PHOTO_METADATA, PhotoMetadataClass))
#define IS_PHOTO_METADATA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PHOTO_METADATA))
#define IS_PHOTO_METADATA_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PHOTO_METADATA))
#define PHOTO_METADATA_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PHOTO_METADATA, PhotoMetadataClass))

typedef struct _PhotoMetadata PhotoMetadata;
typedef struct _PhotoMetadataClass PhotoMetadataClass;
#define _media_metadata_unref0(var) ((var == NULL) ? NULL : (var = (media_metadata_unref (var), NULL)))

#define TYPE_METADATA_DATE_TIME (metadata_date_time_get_type ())
#define METADATA_DATE_TIME(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_METADATA_DATE_TIME, MetadataDateTime))
#define METADATA_DATE_TIME_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_METADATA_DATE_TIME, MetadataDateTimeClass))
#define IS_METADATA_DATE_TIME(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_METADATA_DATE_TIME))
#define IS_METADATA_DATE_TIME_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_METADATA_DATE_TIME))
#define METADATA_DATE_TIME_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_METADATA_DATE_TIME, MetadataDateTimeClass))

typedef struct _MetadataDateTime MetadataDateTime;
typedef struct _MetadataDateTimeClass MetadataDateTimeClass;
#define _metadata_date_time_unref0(var) ((var == NULL) ? NULL : (var = (metadata_date_time_unref (var), NULL)))

#define TYPE_DATA_VIEW (data_view_get_type ())
#define DATA_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATA_VIEW, DataView))
#define DATA_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATA_VIEW, DataViewClass))
#define IS_DATA_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATA_VIEW))
#define IS_DATA_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATA_VIEW))
#define DATA_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATA_VIEW, DataViewClass))

typedef struct _DataView DataView;
typedef struct _DataViewClass DataViewClass;
typedef struct _DataViewPrivate DataViewPrivate;

#define TYPE_THUMBNAIL_VIEW (thumbnail_view_get_type ())
#define THUMBNAIL_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_THUMBNAIL_VIEW, ThumbnailView))
#define THUMBNAIL_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_THUMBNAIL_VIEW, ThumbnailViewClass))
#define IS_THUMBNAIL_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_THUMBNAIL_VIEW))
#define IS_THUMBNAIL_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_THUMBNAIL_VIEW))
#define THUMBNAIL_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_THUMBNAIL_VIEW, ThumbnailViewClass))

typedef struct _ThumbnailView ThumbnailView;
typedef struct _ThumbnailViewClass ThumbnailViewClass;
typedef struct _ThumbnailViewPrivate ThumbnailViewPrivate;

#define TYPE_CHECKERBOARD_ITEM (checkerboard_item_get_type ())
#define CHECKERBOARD_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_CHECKERBOARD_ITEM, CheckerboardItem))
#define CHECKERBOARD_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_CHECKERBOARD_ITEM, CheckerboardItemClass))
#define IS_CHECKERBOARD_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_CHECKERBOARD_ITEM))
#define IS_CHECKERBOARD_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_CHECKERBOARD_ITEM))
#define CHECKERBOARD_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_CHECKERBOARD_ITEM, CheckerboardItemClass))

typedef struct _CheckerboardItem CheckerboardItem;
typedef struct _CheckerboardItemClass CheckerboardItemClass;
typedef struct _CheckerboardItemPrivate CheckerboardItemPrivate;

#define TYPE_DIMENSIONS (dimensions_get_type ())
typedef struct _Dimensions Dimensions;

#define TYPE_MEDIA_SOURCE_ITEM (media_source_item_get_type ())
#define MEDIA_SOURCE_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MEDIA_SOURCE_ITEM, MediaSourceItem))
#define MEDIA_SOURCE_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MEDIA_SOURCE_ITEM, MediaSourceItemClass))
#define IS_MEDIA_SOURCE_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MEDIA_SOURCE_ITEM))
#define IS_MEDIA_SOURCE_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MEDIA_SOURCE_ITEM))
#define MEDIA_SOURCE_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MEDIA_SOURCE_ITEM, MediaSourceItemClass))

typedef struct _MediaSourceItem MediaSourceItem;
typedef struct _MediaSourceItemClass MediaSourceItemClass;
typedef struct _MediaSourceItemPrivate MediaSourceItemPrivate;

#define TYPE_IMPORT_PREVIEW (import_preview_get_type ())
#define IMPORT_PREVIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_IMPORT_PREVIEW, ImportPreview))
#define IMPORT_PREVIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_IMPORT_PREVIEW, ImportPreviewClass))
#define IS_IMPORT_PREVIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_IMPORT_PREVIEW))
#define IS_IMPORT_PREVIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_IMPORT_PREVIEW))
#define IMPORT_PREVIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_IMPORT_PREVIEW, ImportPreviewClass))

typedef struct _ImportPreview ImportPreview;
typedef struct _ImportPreviewClass ImportPreviewClass;
typedef struct _ImportPreviewPrivate ImportPreviewPrivate;

#define TYPE_DUPLICATED_FILE (duplicated_file_get_type ())
#define DUPLICATED_FILE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DUPLICATED_FILE, DuplicatedFile))
#define DUPLICATED_FILE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DUPLICATED_FILE, DuplicatedFileClass))
#define IS_DUPLICATED_FILE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DUPLICATED_FILE))
#define IS_DUPLICATED_FILE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DUPLICATED_FILE))
#define DUPLICATED_FILE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DUPLICATED_FILE, DuplicatedFileClass))

typedef struct _DuplicatedFile DuplicatedFile;
typedef struct _DuplicatedFileClass DuplicatedFileClass;
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))

#define TYPE_ORIENTATION (orientation_get_type ())

#define TYPE_PHOTO_ID (photo_id_get_type ())
typedef struct _PhotoID PhotoID;

#define TYPE_DATABASE_SOURCE_COLLECTION (database_source_collection_get_type ())
#define DATABASE_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATABASE_SOURCE_COLLECTION, DatabaseSourceCollection))
#define DATABASE_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATABASE_SOURCE_COLLECTION, DatabaseSourceCollectionClass))
#define IS_DATABASE_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATABASE_SOURCE_COLLECTION))
#define IS_DATABASE_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATABASE_SOURCE_COLLECTION))
#define DATABASE_SOURCE_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATABASE_SOURCE_COLLECTION, DatabaseSourceCollectionClass))

typedef struct _DatabaseSourceCollection DatabaseSourceCollection;
typedef struct _DatabaseSourceCollectionClass DatabaseSourceCollectionClass;

#define TYPE_MEDIA_SOURCE_COLLECTION (media_source_collection_get_type ())
#define MEDIA_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollection))
#define MEDIA_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollectionClass))
#define IS_MEDIA_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MEDIA_SOURCE_COLLECTION))
#define IS_MEDIA_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MEDIA_SOURCE_COLLECTION))
#define MEDIA_SOURCE_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollectionClass))

typedef struct _MediaSourceCollection MediaSourceCollection;
typedef struct _MediaSourceCollectionClass MediaSourceCollectionClass;

#define TYPE_LIBRARY_PHOTO_SOURCE_COLLECTION (library_photo_source_collection_get_type ())
#define LIBRARY_PHOTO_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_LIBRARY_PHOTO_SOURCE_COLLECTION, LibraryPhotoSourceCollection))
#define LIBRARY_PHOTO_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_LIBRARY_PHOTO_SOURCE_COLLECTION, LibraryPhotoSourceCollectionClass))
#define IS_LIBRARY_PHOTO_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_LIBRARY_PHOTO_SOURCE_COLLECTION))
#define IS_LIBRARY_PHOTO_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_LIBRARY_PHOTO_SOURCE_COLLECTION))
#define LIBRARY_PHOTO_SOURCE_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_LIBRARY_PHOTO_SOURCE_COLLECTION, LibraryPhotoSourceCollectionClass))

typedef struct _LibraryPhotoSourceCollection LibraryPhotoSourceCollection;
typedef struct _LibraryPhotoSourceCollectionClass LibraryPhotoSourceCollectionClass;

#define TYPE_VIDEO_SOURCE_COLLECTION (video_source_collection_get_type ())
#define VIDEO_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_VIDEO_SOURCE_COLLECTION, VideoSourceCollection))
#define VIDEO_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_VIDEO_SOURCE_COLLECTION, VideoSourceCollectionClass))
#define IS_VIDEO_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_VIDEO_SOURCE_COLLECTION))
#define IS_VIDEO_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_VIDEO_SOURCE_COLLECTION))
#define VIDEO_SOURCE_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_VIDEO_SOURCE_COLLECTION, VideoSourceCollectionClass))

typedef struct _VideoSourceCollection VideoSourceCollection;
typedef struct _VideoSourceCollectionClass VideoSourceCollectionClass;

#define TYPE_VIDEO_ID (video_id_get_type ())
typedef struct _VideoID VideoID;

#define CORE_TYPE_TRACKER (core_tracker_get_type ())
#define CORE_TRACKER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CORE_TYPE_TRACKER, CoreTracker))
#define CORE_TRACKER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), CORE_TYPE_TRACKER, CoreTrackerClass))
#define CORE_IS_TRACKER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CORE_TYPE_TRACKER))
#define CORE_IS_TRACKER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CORE_TYPE_TRACKER))
#define CORE_TRACKER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), CORE_TYPE_TRACKER, CoreTrackerClass))

typedef struct _CoreTracker CoreTracker;
typedef struct _CoreTrackerClass CoreTrackerClass;
typedef struct _CoreTrackerPrivate CoreTrackerPrivate;

#define CORE_TYPE_VIEW_TRACKER (core_view_tracker_get_type ())
#define CORE_VIEW_TRACKER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CORE_TYPE_VIEW_TRACKER, CoreViewTracker))
#define CORE_VIEW_TRACKER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), CORE_TYPE_VIEW_TRACKER, CoreViewTrackerClass))
#define CORE_IS_VIEW_TRACKER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CORE_TYPE_VIEW_TRACKER))
#define CORE_IS_VIEW_TRACKER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CORE_TYPE_VIEW_TRACKER))
#define CORE_VIEW_TRACKER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), CORE_TYPE_VIEW_TRACKER, CoreViewTrackerClass))

typedef struct _CoreViewTracker CoreViewTracker;
typedef struct _CoreViewTrackerClass CoreViewTrackerClass;
typedef struct _CoreViewTrackerPrivate CoreViewTrackerPrivate;

#define TYPE_CAMERA_VIEW_TRACKER (camera_view_tracker_get_type ())
#define CAMERA_VIEW_TRACKER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_CAMERA_VIEW_TRACKER, CameraViewTracker))
#define CAMERA_VIEW_TRACKER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_CAMERA_VIEW_TRACKER, CameraViewTrackerClass))
#define IS_CAMERA_VIEW_TRACKER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_CAMERA_VIEW_TRACKER))
#define IS_CAMERA_VIEW_TRACKER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_CAMERA_VIEW_TRACKER))
#define CAMERA_VIEW_TRACKER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_CAMERA_VIEW_TRACKER, CameraViewTrackerClass))

typedef struct _CameraViewTracker CameraViewTracker;
typedef struct _CameraViewTrackerClass CameraViewTrackerClass;
typedef struct _CameraViewTrackerPrivate CameraViewTrackerPrivate;

#define TYPE_CAMERA_ACCUMULATOR (camera_accumulator_get_type ())
#define CAMERA_ACCUMULATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_CAMERA_ACCUMULATOR, CameraAccumulator))
#define CAMERA_ACCUMULATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_CAMERA_ACCUMULATOR, CameraAccumulatorClass))
#define IS_CAMERA_ACCUMULATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_CAMERA_ACCUMULATOR))
#define IS_CAMERA_ACCUMULATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_CAMERA_ACCUMULATOR))
#define CAMERA_ACCUMULATOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_CAMERA_ACCUMULATOR, CameraAccumulatorClass))

typedef struct _CameraAccumulator CameraAccumulator;
typedef struct _CameraAccumulatorClass CameraAccumulatorClass;

#define TYPE_VIEW_COLLECTION (view_collection_get_type ())
#define VIEW_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_VIEW_COLLECTION, ViewCollection))
#define VIEW_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_VIEW_COLLECTION, ViewCollectionClass))
#define IS_VIEW_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_VIEW_COLLECTION))
#define IS_VIEW_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_VIEW_COLLECTION))
#define VIEW_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_VIEW_COLLECTION, ViewCollectionClass))

typedef struct _ViewCollection ViewCollection;
typedef struct _ViewCollectionClass ViewCollectionClass;

#define CORE_TYPE_TRACKER_ACCUMULATOR (core_tracker_accumulator_get_type ())
#define CORE_TRACKER_ACCUMULATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CORE_TYPE_TRACKER_ACCUMULATOR, CoreTrackerAccumulator))
#define CORE_IS_TRACKER_ACCUMULATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CORE_TYPE_TRACKER_ACCUMULATOR))
#define CORE_TRACKER_ACCUMULATOR_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), CORE_TYPE_TRACKER_ACCUMULATOR, CoreTrackerAccumulatorIface))

typedef struct _CoreTrackerAccumulator CoreTrackerAccumulator;
typedef struct _CoreTrackerAccumulatorIface CoreTrackerAccumulatorIface;
typedef struct _CameraAccumulatorPrivate CameraAccumulatorPrivate;

#define TYPE_PAGE (page_get_type ())
#define PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PAGE, Page))
#define PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PAGE, PageClass))
#define IS_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PAGE))
#define IS_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PAGE))
#define PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PAGE, PageClass))

typedef struct _Page Page;
typedef struct _PageClass PageClass;
typedef struct _PagePrivate PagePrivate;

#define TYPE_PAGE_WINDOW (page_window_get_type ())
#define PAGE_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PAGE_WINDOW, PageWindow))
#define PAGE_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PAGE_WINDOW, PageWindowClass))
#define IS_PAGE_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PAGE_WINDOW))
#define IS_PAGE_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PAGE_WINDOW))
#define PAGE_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PAGE_WINDOW, PageWindowClass))

typedef struct _PageWindow PageWindow;
typedef struct _PageWindowClass PageWindowClass;

#define TYPE_FULLSCREEN_WINDOW (fullscreen_window_get_type ())
#define FULLSCREEN_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_FULLSCREEN_WINDOW, FullscreenWindow))
#define FULLSCREEN_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_FULLSCREEN_WINDOW, FullscreenWindowClass))
#define IS_FULLSCREEN_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_FULLSCREEN_WINDOW))
#define IS_FULLSCREEN_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_FULLSCREEN_WINDOW))
#define FULLSCREEN_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_FULLSCREEN_WINDOW, FullscreenWindowClass))

typedef struct _FullscreenWindow FullscreenWindow;
typedef struct _FullscreenWindowClass FullscreenWindowClass;

#define TYPE_INJECTION_GROUP (injection_group_get_type ())
#define INJECTION_GROUP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_INJECTION_GROUP, InjectionGroup))
#define INJECTION_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_INJECTION_GROUP, InjectionGroupClass))
#define IS_INJECTION_GROUP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_INJECTION_GROUP))
#define IS_INJECTION_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_INJECTION_GROUP))
#define INJECTION_GROUP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_INJECTION_GROUP, InjectionGroupClass))

typedef struct _InjectionGroup InjectionGroup;
typedef struct _InjectionGroupClass InjectionGroupClass;

#define TYPE_CHECKERBOARD_PAGE (checkerboard_page_get_type ())
#define CHECKERBOARD_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_CHECKERBOARD_PAGE, CheckerboardPage))
#define CHECKERBOARD_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_CHECKERBOARD_PAGE, CheckerboardPageClass))
#define IS_CHECKERBOARD_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_CHECKERBOARD_PAGE))
#define IS_CHECKERBOARD_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_CHECKERBOARD_PAGE))
#define CHECKERBOARD_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_CHECKERBOARD_PAGE, CheckerboardPageClass))

typedef struct _CheckerboardPage CheckerboardPage;
typedef struct _CheckerboardPageClass CheckerboardPageClass;
typedef struct _CheckerboardPagePrivate CheckerboardPagePrivate;

#define CHECKERBOARD_PAGE_TYPE_ACTIVATOR (checkerboard_page_activator_get_type ())

#define CHECKERBOARD_PAGE_TYPE_KEYBOARD_MODIFIERS (checkerboard_page_keyboard_modifiers_get_type ())
typedef struct _CheckerboardPageKeyboardModifiers CheckerboardPageKeyboardModifiers;

#define TYPE_VIEW_FILTER (view_filter_get_type ())
#define VIEW_FILTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_VIEW_FILTER, ViewFilter))
#define VIEW_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_VIEW_FILTER, ViewFilterClass))
#define IS_VIEW_FILTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_VIEW_FILTER))
#define IS_VIEW_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_VIEW_FILTER))
#define VIEW_FILTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_VIEW_FILTER, ViewFilterClass))

typedef struct _ViewFilter ViewFilter;
typedef struct _ViewFilterClass ViewFilterClass;

#define TYPE_SEARCH_VIEW_FILTER (search_view_filter_get_type ())
#define SEARCH_VIEW_FILTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SEARCH_VIEW_FILTER, SearchViewFilter))
#define SEARCH_VIEW_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SEARCH_VIEW_FILTER, SearchViewFilterClass))
#define IS_SEARCH_VIEW_FILTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SEARCH_VIEW_FILTER))
#define IS_SEARCH_VIEW_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SEARCH_VIEW_FILTER))
#define SEARCH_VIEW_FILTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SEARCH_VIEW_FILTER, SearchViewFilterClass))

typedef struct _SearchViewFilter SearchViewFilter;
typedef struct _SearchViewFilterClass SearchViewFilterClass;

#define TYPE_IMPORT_PAGE (import_page_get_type ())
#define IMPORT_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_IMPORT_PAGE, ImportPage))
#define IMPORT_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_IMPORT_PAGE, ImportPageClass))
#define IS_IMPORT_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_IMPORT_PAGE))
#define IS_IMPORT_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_IMPORT_PAGE))
#define IMPORT_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_IMPORT_PAGE, ImportPageClass))

typedef struct _ImportPage ImportPage;
typedef struct _ImportPageClass ImportPageClass;
typedef struct _ImportPagePrivate ImportPagePrivate;

#define IMPORT_PAGE_TYPE_IMPORT_PAGE_SEARCH_VIEW_FILTER (import_page_import_page_search_view_filter_get_type ())
#define IMPORT_PAGE_IMPORT_PAGE_SEARCH_VIEW_FILTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), IMPORT_PAGE_TYPE_IMPORT_PAGE_SEARCH_VIEW_FILTER, ImportPageImportPageSearchViewFilter))
#define IMPORT_PAGE_IMPORT_PAGE_SEARCH_VIEW_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), IMPORT_PAGE_TYPE_IMPORT_PAGE_SEARCH_VIEW_FILTER, ImportPageImportPageSearchViewFilterClass))
#define IMPORT_PAGE_IS_IMPORT_PAGE_SEARCH_VIEW_FILTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), IMPORT_PAGE_TYPE_IMPORT_PAGE_SEARCH_VIEW_FILTER))
#define IMPORT_PAGE_IS_IMPORT_PAGE_SEARCH_VIEW_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), IMPORT_PAGE_TYPE_IMPORT_PAGE_SEARCH_VIEW_FILTER))
#define IMPORT_PAGE_IMPORT_PAGE_SEARCH_VIEW_FILTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), IMPORT_PAGE_TYPE_IMPORT_PAGE_SEARCH_VIEW_FILTER, ImportPageImportPageSearchViewFilterClass))

typedef struct _ImportPageImportPageSearchViewFilter ImportPageImportPageSearchViewFilter;
typedef struct _ImportPageImportPageSearchViewFilterClass ImportPageImportPageSearchViewFilterClass;

#define IMPORT_PAGE_TYPE_HIDE_IMPORTED_VIEW_FILTER (import_page_hide_imported_view_filter_get_type ())
#define IMPORT_PAGE_HIDE_IMPORTED_VIEW_FILTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), IMPORT_PAGE_TYPE_HIDE_IMPORTED_VIEW_FILTER, ImportPageHideImportedViewFilter))
#define IMPORT_PAGE_HIDE_IMPORTED_VIEW_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), IMPORT_PAGE_TYPE_HIDE_IMPORTED_VIEW_FILTER, ImportPageHideImportedViewFilterClass))
#define IMPORT_PAGE_IS_HIDE_IMPORTED_VIEW_FILTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), IMPORT_PAGE_TYPE_HIDE_IMPORTED_VIEW_FILTER))
#define IMPORT_PAGE_IS_HIDE_IMPORTED_VIEW_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), IMPORT_PAGE_TYPE_HIDE_IMPORTED_VIEW_FILTER))
#define IMPORT_PAGE_HIDE_IMPORTED_VIEW_FILTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), IMPORT_PAGE_TYPE_HIDE_IMPORTED_VIEW_FILTER, ImportPageHideImportedViewFilterClass))

typedef struct _ImportPageHideImportedViewFilter ImportPageHideImportedViewFilter;
typedef struct _ImportPageHideImportedViewFilterClass ImportPageHideImportedViewFilterClass;

#define IMPORT_PAGE_TYPE_REFRESH_RESULT (import_page_refresh_result_get_type ())
#define _data_collection_unref0(var) ((var == NULL) ? NULL : (var = (data_collection_unref (var), NULL)))
#define _view_filter_unref0(var) ((var == NULL) ? NULL : (var = (view_filter_unref (var), NULL)))
#define _core_tracker_unref0(var) ((var == NULL) ? NULL : (var = (core_tracker_unref (var), NULL)))
#define _gp_context_wrapper_unref0(var) ((var == NULL) ? NULL : (var = (gp_context_wrapper_unref (var), NULL)))

#define TYPE_VIEW_MANAGER (view_manager_get_type ())
#define VIEW_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_VIEW_MANAGER, ViewManager))
#define VIEW_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_VIEW_MANAGER, ViewManagerClass))
#define IS_VIEW_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_VIEW_MANAGER))
#define IS_VIEW_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_VIEW_MANAGER))
#define VIEW_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_VIEW_MANAGER, ViewManagerClass))

typedef struct _ViewManager ViewManager;
typedef struct _ViewManagerClass ViewManagerClass;

#define VIEW_COLLECTION_TYPE_MONITOR (view_collection_monitor_get_type ())
#define VIEW_COLLECTION_MONITOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VIEW_COLLECTION_TYPE_MONITOR, ViewCollectionMonitor))
#define VIEW_COLLECTION_MONITOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VIEW_COLLECTION_TYPE_MONITOR, ViewCollectionMonitorClass))
#define VIEW_COLLECTION_IS_MONITOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VIEW_COLLECTION_TYPE_MONITOR))
#define VIEW_COLLECTION_IS_MONITOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VIEW_COLLECTION_TYPE_MONITOR))
#define VIEW_COLLECTION_MONITOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VIEW_COLLECTION_TYPE_MONITOR, ViewCollectionMonitorClass))

typedef struct _ViewCollectionMonitor ViewCollectionMonitor;
typedef struct _ViewCollectionMonitorClass ViewCollectionMonitorClass;

#define IMPORT_PAGE_TYPE_IMPORT_VIEW_MANAGER (import_page_import_view_manager_get_type ())
#define IMPORT_PAGE_IMPORT_VIEW_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), IMPORT_PAGE_TYPE_IMPORT_VIEW_MANAGER, ImportPageImportViewManager))
#define IMPORT_PAGE_IMPORT_VIEW_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), IMPORT_PAGE_TYPE_IMPORT_VIEW_MANAGER, ImportPageImportViewManagerClass))
#define IMPORT_PAGE_IS_IMPORT_VIEW_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), IMPORT_PAGE_TYPE_IMPORT_VIEW_MANAGER))
#define IMPORT_PAGE_IS_IMPORT_VIEW_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), IMPORT_PAGE_TYPE_IMPORT_VIEW_MANAGER))
#define IMPORT_PAGE_IMPORT_VIEW_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), IMPORT_PAGE_TYPE_IMPORT_VIEW_MANAGER, ImportPageImportViewManagerClass))

typedef struct _ImportPageImportViewManager ImportPageImportViewManager;
typedef struct _ImportPageImportViewManagerClass ImportPageImportViewManagerClass;
#define _view_collection_monitor_unref0(var) ((var == NULL) ? NULL : (var = (view_collection_monitor_unref (var), NULL)))
#define _view_manager_unref0(var) ((var == NULL) ? NULL : (var = (view_manager_unref (var), NULL)))

#define TYPE_CONFIGURATION_FACADE (configuration_facade_get_type ())
#define CONFIGURATION_FACADE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_CONFIGURATION_FACADE, ConfigurationFacade))
#define CONFIGURATION_FACADE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_CONFIGURATION_FACADE, ConfigurationFacadeClass))
#define IS_CONFIGURATION_FACADE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_CONFIGURATION_FACADE))
#define IS_CONFIGURATION_FACADE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_CONFIGURATION_FACADE))
#define CONFIGURATION_FACADE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_CONFIGURATION_FACADE, ConfigurationFacadeClass))

typedef struct _ConfigurationFacade ConfigurationFacade;
typedef struct _ConfigurationFacadeClass ConfigurationFacadeClass;

#define CONFIG_TYPE_FACADE (config_facade_get_type ())
#define CONFIG_FACADE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CONFIG_TYPE_FACADE, ConfigFacade))
#define CONFIG_FACADE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), CONFIG_TYPE_FACADE, ConfigFacadeClass))
#define CONFIG_IS_FACADE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CONFIG_TYPE_FACADE))
#define CONFIG_IS_FACADE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CONFIG_TYPE_FACADE))
#define CONFIG_FACADE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), CONFIG_TYPE_FACADE, ConfigFacadeClass))

typedef struct _ConfigFacade ConfigFacade;
typedef struct _ConfigFacadeClass ConfigFacadeClass;

#define TYPE_BATCH_IMPORT_JOB (batch_import_job_get_type ())
#define BATCH_IMPORT_JOB(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_BATCH_IMPORT_JOB, BatchImportJob))
#define BATCH_IMPORT_JOB_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_BATCH_IMPORT_JOB, BatchImportJobClass))
#define IS_BATCH_IMPORT_JOB(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_BATCH_IMPORT_JOB))
#define IS_BATCH_IMPORT_JOB_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_BATCH_IMPORT_JOB))
#define BATCH_IMPORT_JOB_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_BATCH_IMPORT_JOB, BatchImportJobClass))

typedef struct _BatchImportJob BatchImportJob;
typedef struct _BatchImportJobClass BatchImportJobClass;

#define IMPORT_PAGE_TYPE_CAMERA_IMPORT_JOB (import_page_camera_import_job_get_type ())
#define IMPORT_PAGE_CAMERA_IMPORT_JOB(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), IMPORT_PAGE_TYPE_CAMERA_IMPORT_JOB, ImportPageCameraImportJob))
#define IMPORT_PAGE_CAMERA_IMPORT_JOB_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), IMPORT_PAGE_TYPE_CAMERA_IMPORT_JOB, ImportPageCameraImportJobClass))
#define IMPORT_PAGE_IS_CAMERA_IMPORT_JOB(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), IMPORT_PAGE_TYPE_CAMERA_IMPORT_JOB))
#define IMPORT_PAGE_IS_CAMERA_IMPORT_JOB_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), IMPORT_PAGE_TYPE_CAMERA_IMPORT_JOB))
#define IMPORT_PAGE_CAMERA_IMPORT_JOB_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), IMPORT_PAGE_TYPE_CAMERA_IMPORT_JOB, ImportPageCameraImportJobClass))

typedef struct _ImportPageCameraImportJob ImportPageCameraImportJob;
typedef struct _ImportPageCameraImportJobClass ImportPageCameraImportJobClass;

#define TYPE_APP_WINDOW (app_window_get_type ())
#define APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_APP_WINDOW, AppWindow))
#define APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_APP_WINDOW, AppWindowClass))
#define IS_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_APP_WINDOW))
#define IS_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_APP_WINDOW))
#define APP_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_APP_WINDOW, AppWindowClass))

typedef struct _AppWindow AppWindow;
typedef struct _AppWindowClass AppWindowClass;

#define TYPE_MEDIA_SOURCE (media_source_get_type ())
#define MEDIA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MEDIA_SOURCE, MediaSource))
#define MEDIA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MEDIA_SOURCE, MediaSourceClass))
#define IS_MEDIA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MEDIA_SOURCE))
#define IS_MEDIA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MEDIA_SOURCE))
#define MEDIA_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MEDIA_SOURCE, MediaSourceClass))

typedef struct _MediaSource MediaSource;
typedef struct _MediaSourceClass MediaSourceClass;
#define _gp_list_unref0(var) ((var == NULL) ? NULL : (var = (gp_list_unref (var), NULL)))

#define TYPE_SORTED_LIST (sorted_list_get_type ())
#define SORTED_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SORTED_LIST, SortedList))
#define SORTED_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SORTED_LIST, SortedListClass))
#define IS_SORTED_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SORTED_LIST))
#define IS_SORTED_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SORTED_LIST))
#define SORTED_LIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SORTED_LIST, SortedListClass))

typedef struct _SortedList SortedList;
typedef struct _SortedListClass SortedListClass;
#define _batch_import_job_unref0(var) ((var == NULL) ? NULL : (var = (batch_import_job_unref (var), NULL)))

#define TYPE_BATCH_IMPORT (batch_import_get_type ())
#define BATCH_IMPORT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_BATCH_IMPORT, BatchImport))
#define BATCH_IMPORT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_BATCH_IMPORT, BatchImportClass))
#define IS_BATCH_IMPORT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_BATCH_IMPORT))
#define IS_BATCH_IMPORT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_BATCH_IMPORT))
#define BATCH_IMPORT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_BATCH_IMPORT, BatchImportClass))

typedef struct _BatchImport BatchImport;
typedef struct _BatchImportClass BatchImportClass;

#define TYPE_IMPORT_MANIFEST (import_manifest_get_type ())
#define IMPORT_MANIFEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_IMPORT_MANIFEST, ImportManifest))
#define IMPORT_MANIFEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_IMPORT_MANIFEST, ImportManifestClass))
#define IS_IMPORT_MANIFEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_IMPORT_MANIFEST))
#define IS_IMPORT_MANIFEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_IMPORT_MANIFEST))
#define IMPORT_MANIFEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_IMPORT_MANIFEST, ImportManifestClass))

typedef struct _ImportManifest ImportManifest;
typedef struct _ImportManifestClass ImportManifestClass;

#define TYPE_BATCH_IMPORT_ROLL (batch_import_roll_get_type ())
#define BATCH_IMPORT_ROLL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_BATCH_IMPORT_ROLL, BatchImportRoll))
#define BATCH_IMPORT_ROLL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_BATCH_IMPORT_ROLL, BatchImportRollClass))
#define IS_BATCH_IMPORT_ROLL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_BATCH_IMPORT_ROLL))
#define IS_BATCH_IMPORT_ROLL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_BATCH_IMPORT_ROLL))
#define BATCH_IMPORT_ROLL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_BATCH_IMPORT_ROLL, BatchImportRollClass))

typedef struct _BatchImportRoll BatchImportRoll;
typedef struct _BatchImportRollClass BatchImportRollClass;

#define TYPE_BATCH_IMPORT_RESULT (batch_import_result_get_type ())
#define BATCH_IMPORT_RESULT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_BATCH_IMPORT_RESULT, BatchImportResult))
#define BATCH_IMPORT_RESULT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_BATCH_IMPORT_RESULT, BatchImportResultClass))
#define IS_BATCH_IMPORT_RESULT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_BATCH_IMPORT_RESULT))
#define IS_BATCH_IMPORT_RESULT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_BATCH_IMPORT_RESULT))
#define BATCH_IMPORT_RESULT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_BATCH_IMPORT_RESULT, BatchImportResultClass))

typedef struct _BatchImportResult BatchImportResult;
typedef struct _BatchImportResultClass BatchImportResultClass;

#define TYPE_LIBRARY_WINDOW (library_window_get_type ())
#define LIBRARY_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_LIBRARY_WINDOW, LibraryWindow))
#define LIBRARY_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_LIBRARY_WINDOW, LibraryWindowClass))
#define IS_LIBRARY_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_LIBRARY_WINDOW))
#define IS_LIBRARY_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_LIBRARY_WINDOW))
#define LIBRARY_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_LIBRARY_WINDOW, LibraryWindowClass))

typedef struct _LibraryWindow LibraryWindow;
typedef struct _LibraryWindowClass LibraryWindowClass;
#define _import_manifest_unref0(var) ((var == NULL) ? NULL : (var = (import_manifest_unref (var), NULL)))
typedef struct _BatchImportResultPrivate BatchImportResultPrivate;

#define TYPE_IMPORT_RESULT (import_result_get_type ())
typedef struct _ImportManifestPrivate ImportManifestPrivate;

#define IMPORT_UI_TYPE_QUESTION_PARAMS (import_ui_question_params_get_type ())
#define IMPORT_UI_QUESTION_PARAMS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), IMPORT_UI_TYPE_QUESTION_PARAMS, ImportUIQuestionParams))
#define IMPORT_UI_QUESTION_PARAMS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), IMPORT_UI_TYPE_QUESTION_PARAMS, ImportUIQuestionParamsClass))
#define IMPORT_UI_IS_QUESTION_PARAMS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), IMPORT_UI_TYPE_QUESTION_PARAMS))
#define IMPORT_UI_IS_QUESTION_PARAMS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), IMPORT_UI_TYPE_QUESTION_PARAMS))
#define IMPORT_UI_QUESTION_PARAMS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), IMPORT_UI_TYPE_QUESTION_PARAMS, ImportUIQuestionParamsClass))

typedef struct _ImportUIQuestionParams ImportUIQuestionParams;
typedef struct _ImportUIQuestionParamsClass ImportUIQuestionParamsClass;
#define _import_ui_question_params_unref0(var) ((var == NULL) ? NULL : (var = (import_ui_question_params_unref (var), NULL)))
#define _batch_import_result_unref0(var) ((var == NULL) ? NULL : (var = (batch_import_result_unref (var), NULL)))

#define TYPE_PROGRESS_DIALOG (progress_dialog_get_type ())
#define PROGRESS_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PROGRESS_DIALOG, ProgressDialog))
#define PROGRESS_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PROGRESS_DIALOG, ProgressDialogClass))
#define IS_PROGRESS_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PROGRESS_DIALOG))
#define IS_PROGRESS_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PROGRESS_DIALOG))
#define PROGRESS_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PROGRESS_DIALOG, ProgressDialogClass))

typedef struct _ProgressDialog ProgressDialog;
typedef struct _ProgressDialogClass ProgressDialogClass;
typedef struct _ViewManagerPrivate ViewManagerPrivate;
typedef struct _ImportPageImportViewManagerPrivate ImportPageImportViewManagerPrivate;
typedef struct _BatchImportJobPrivate BatchImportJobPrivate;
typedef struct _ImportPageCameraImportJobPrivate ImportPageCameraImportJobPrivate;

#define TYPE_BACKING_PHOTO_ROW (backing_photo_row_get_type ())
#define BACKING_PHOTO_ROW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_BACKING_PHOTO_ROW, BackingPhotoRow))
#define BACKING_PHOTO_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_BACKING_PHOTO_ROW, BackingPhotoRowClass))
#define IS_BACKING_PHOTO_ROW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_BACKING_PHOTO_ROW))
#define IS_BACKING_PHOTO_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_BACKING_PHOTO_ROW))
#define BACKING_PHOTO_ROW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_BACKING_PHOTO_ROW, BackingPhotoRowClass))

typedef struct _BackingPhotoRow BackingPhotoRow;
typedef struct _BackingPhotoRowClass BackingPhotoRowClass;
#define _backing_photo_row_unref0(var) ((var == NULL) ? NULL : (var = (backing_photo_row_unref (var), NULL)))

#define TYPE_RAW_DEVELOPER (raw_developer_get_type ())
typedef struct _BackingPhotoRowPrivate BackingPhotoRowPrivate;

#define TYPE_BACKING_PHOTO_ID (backing_photo_id_get_type ())
typedef struct _BackingPhotoID BackingPhotoID;

#define TYPE_PHOTO_SOURCE (photo_source_get_type ())
#define PHOTO_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PHOTO_SOURCE, PhotoSource))
#define PHOTO_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PHOTO_SOURCE, PhotoSourceClass))
#define IS_PHOTO_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PHOTO_SOURCE))
#define IS_PHOTO_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PHOTO_SOURCE))
#define PHOTO_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PHOTO_SOURCE, PhotoSourceClass))

typedef struct _PhotoSource PhotoSource;
typedef struct _PhotoSourceClass PhotoSourceClass;

#define TYPE_PHOTO (photo_get_type ())
#define PHOTO(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PHOTO, Photo))
#define PHOTO_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PHOTO, PhotoClass))
#define IS_PHOTO(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PHOTO))
#define IS_PHOTO_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PHOTO))
#define PHOTO_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PHOTO, PhotoClass))

typedef struct _Photo Photo;
typedef struct _PhotoClass PhotoClass;
typedef struct _ViewFilterPrivate ViewFilterPrivate;
typedef struct _SearchViewFilterPrivate SearchViewFilterPrivate;
typedef struct _ImportPageImportPageSearchViewFilterPrivate ImportPageImportPageSearchViewFilterPrivate;

#define TYPE_SEARCH_FILTER_CRITERIA (search_filter_criteria_get_type ())
typedef struct _ImportPageHideImportedViewFilterPrivate ImportPageHideImportedViewFilterPrivate;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

typedef gint64 (*Comparator) (void* a, void* b, void* user_data);
typedef gboolean (*ComparatorPredicate) (DataObject* object, Alteration* alteration, void* user_data);
typedef gboolean (*ProgressMonitor) (guint64 current, guint64 total, gboolean do_event_loop, void* user_data);
struct _MarkerIface {
	GTypeInterface parent_iface;
	void (*mark) (Marker* self, DataObject* object);
	void (*unmark) (Marker* self, DataObject* object);
	gboolean (*toggle) (Marker* self, DataObject* object);
	void (*mark_many) (Marker* self, GeeCollection* list);
	void (*unmark_many) (Marker* self, GeeCollection* list);
	void (*mark_all) (Marker* self);
	gint (*get_count) (Marker* self);
	GeeCollection* (*get_all) (Marker* self);
};

struct _DataCollection {
	GTypeInstance parent_instance;
	volatile int ref_count;
	DataCollectionPrivate * priv;
};

struct _DataCollectionClass {
	GTypeClass parent_class;
	void (*finalize) (DataCollection *self);
	gchar* (*to_string) (DataCollection* self);
	void (*notify_items_added) (DataCollection* self, GeeIterable* added);
	void (*notify_items_removed) (DataCollection* self, GeeIterable* removed);
	void (*notify_contents_altered) (DataCollection* self, GeeIterable* added, GeeIterable* removed);
	void (*notify_items_altered) (DataCollection* self, GeeMap* items);
	void (*notify_ordering_changed) (DataCollection* self);
	void (*notify_property_set) (DataCollection* self, const gchar* name, GValue* old, GValue* val);
	void (*notify_property_cleared) (DataCollection* self, const gchar* name);
	gboolean (*valid_type) (DataCollection* self, DataObject* object);
	void (*set_comparator) (DataCollection* self, Comparator comparator, void* comparator_target, ComparatorPredicate predicate, void* predicate_target);
	void (*reset_comparator) (DataCollection* self);
	GeeCollection* (*get_all) (DataCollection* self);
	gint (*get_count) (DataCollection* self);
	DataObject* (*get_at) (DataCollection* self, gint index);
	gint (*index_of) (DataCollection* self, DataObject* object);
	gboolean (*contains) (DataCollection* self, DataObject* object);
	gboolean (*add) (DataCollection* self, DataObject* object);
	GeeCollection* (*add_many) (DataCollection* self, GeeCollection* objects, ProgressMonitor monitor, void* monitor_target);
	void (*remove_marked) (DataCollection* self, Marker* m);
	void (*clear) (DataCollection* self);
	void (*close) (DataCollection* self);
	void (*notify_frozen) (DataCollection* self);
	void (*notify_thawed) (DataCollection* self);
	void (*items_added) (DataCollection* self, GeeIterable* added);
	void (*items_removed) (DataCollection* self, GeeIterable* removed);
	void (*contents_altered) (DataCollection* self, GeeIterable* added, GeeIterable* removed);
	void (*items_altered) (DataCollection* self, GeeMap* items);
	void (*ordering_changed) (DataCollection* self);
	void (*property_set) (DataCollection* self, const gchar* name, GValue* old, GValue* val);
	void (*property_cleared) (DataCollection* self, const gchar* name);
	void (*frozen) (DataCollection* self);
	void (*thawed) (DataCollection* self);
};

struct _SourceCollection {
	DataCollection parent_instance;
	SourceCollectionPrivate * priv;
};

struct _SourceCollectionClass {
	DataCollectionClass parent_class;
	gboolean (*holds_type_of_source) (SourceCollection* self, DataSource* source);
	void (*notify_items_unlinking) (SourceCollection* self, GeeCollection* unlinking);
	void (*notify_items_relinked) (SourceCollection* self, GeeCollection* relinked);
	void (*notify_item_destroyed) (SourceCollection* self, DataSource* source);
	void (*notify_items_destroyed) (SourceCollection* self, GeeCollection* destroyed);
	void (*notify_unlinked_destroyed) (SourceCollection* self, DataSource* unlinked);
	void (*notify_backlink_removed) (SourceCollection* self, SourceBacklink* backlink, GeeCollection* sources);
	gboolean (*has_backlink) (SourceCollection* self, SourceBacklink* backlink);
	void (*remove_backlink) (SourceCollection* self, SourceBacklink* backlink);
	void (*items_unlinking) (SourceCollection* self, GeeCollection* unlinking);
	void (*items_relinked) (SourceCollection* self, GeeCollection* relinked);
	void (*item_destroyed) (SourceCollection* self, DataSource* source);
	void (*items_destroyed) (SourceCollection* self, GeeCollection* destroyed);
	void (*unlinked_destroyed) (SourceCollection* self, DataSource* source);
	void (*backlink_removed) (SourceCollection* self, SourceBacklink* backlink, GeeCollection* sources);
};

struct _ImportSourceCollection {
	SourceCollection parent_instance;
	ImportSourceCollectionPrivate * priv;
};

struct _ImportSourceCollectionClass {
	SourceCollectionClass parent_class;
};

struct _DataObject {
	GObject parent_instance;
	DataObjectPrivate * priv;
};

struct _DataObjectClass {
	GObjectClass parent_class;
	void (*notify_altered) (DataObject* self, Alteration* alteration);
	void (*notify_membership_changed) (DataObject* self, DataCollection* collection);
	void (*notify_collection_property_set) (DataObject* self, const gchar* name, GValue* old, GValue* val);
	void (*notify_collection_property_cleared) (DataObject* self, const gchar* name);
	gchar* (*get_name) (DataObject* self);
	gchar* (*to_string) (DataObject* self);
};

struct _DataSource {
	DataObject parent_instance;
	DataSourcePrivate * priv;
};

struct _DataSourceClass {
	DataObjectClass parent_class;
	void (*notify_held_in_tank) (DataSource* self, SourceHoldingTank* holding_tank);
	void (*notify_unlinking) (DataSource* self, SourceCollection* collection);
	void (*notify_unlinked) (DataSource* self);
	void (*notify_relinking) (DataSource* self, SourceCollection* collection);
	void (*notify_relinked) (DataSource* self);
	gchar* (*get_typename) (DataSource* self);
	gint64 (*get_instance_id) (DataSource* self);
	gchar* (*get_source_id) (DataSource* self);
	void (*commit_backlinks) (DataSource* self, SourceCollection* sources, const gchar* dehydrated);
	SourceSnapshot* (*save_snapshot) (DataSource* self);
	gboolean (*internal_delete_backing) (DataSource* self, GError** error);
	gboolean (*equals) (DataSource* self, DataSource* source);
	void (*destroy) (DataSource* self);
	void (*unlinked) (DataSource* self, SourceCollection* sources);
	void (*relinked) (DataSource* self, SourceCollection* sources);
	void (*destroyed) (DataSource* self);
};

typedef enum  {
	PHOTO_FILE_FORMAT_JFIF,
	PHOTO_FILE_FORMAT_RAW,
	PHOTO_FILE_FORMAT_PNG,
	PHOTO_FILE_FORMAT_TIFF,
	PHOTO_FILE_FORMAT_BMP,
	PHOTO_FILE_FORMAT_UNKNOWN
} PhotoFileFormat;

struct _ThumbnailSource {
	DataSource parent_instance;
	ThumbnailSourcePrivate * priv;
};

struct _ThumbnailSourceClass {
	DataSourceClass parent_class;
	void (*notify_thumbnail_altered) (ThumbnailSource* self);
	GdkPixbuf* (*get_thumbnail) (ThumbnailSource* self, gint scale, GError** error);
	GdkPixbuf* (*create_thumbnail) (ThumbnailSource* self, gint scale, GError** error);
	gchar* (*get_representative_id) (ThumbnailSource* self);
	PhotoFileFormat (*get_preferred_thumbnail_format) (ThumbnailSource* self);
	void (*thumbnail_altered) (ThumbnailSource* self);
};

struct _IndexableIface {
	GTypeInterface parent_iface;
	const gchar* (*get_indexable_keywords) (Indexable* self);
};

struct _ImportSource {
	ThumbnailSource parent_instance;
	ImportSourcePrivate * priv;
};

struct _ImportSourceClass {
	ThumbnailSourceClass parent_class;
	GdkPixbuf* (*get_preview) (ImportSource* self);
	time_t (*get_exposure_time) (ImportSource* self);
};

struct _ImportSourcePrivate {
	gchar* camera_name;
	Camera* camera;
	gint fsid;
	gchar* folder;
	gchar* filename;
	gulong file_size;
	time_t modification_time;
	GdkPixbuf* preview;
	gchar* indexable_keywords;
};

struct _GPContextWrapper {
	GTypeInstance parent_instance;
	volatile int ref_count;
	GPContextWrapperPrivate * priv;
	GPContext* context;
};

struct _GPContextWrapperClass {
	GTypeClass parent_class;
	void (*finalize) (GPContextWrapper *self);
	void (*idle) (GPContextWrapper* self);
	void (*error) (GPContextWrapper* self, const gchar* text, void* data);
	void (*status) (GPContextWrapper* self, const gchar* text, void* data);
	void (*message) (GPContextWrapper* self, const gchar* text, void* data);
	void (*progress_start) (GPContextWrapper* self, gfloat current, const gchar* text, void* data);
	void (*progress_update) (GPContextWrapper* self, gfloat current, void* data);
	void (*progress_stop) (GPContextWrapper* self);
};

struct _VideoImportSource {
	ImportSource parent_instance;
	VideoImportSourcePrivate * priv;
};

struct _VideoImportSourceClass {
	ImportSourceClass parent_class;
};

struct _PhotoImportSource {
	ImportSource parent_instance;
	PhotoImportSourcePrivate * priv;
};

struct _PhotoImportSourceClass {
	ImportSourceClass parent_class;
};

struct _PhotoImportSourcePrivate {
	PhotoFileFormat file_format;
	gchar* preview_md5;
	PhotoMetadata* metadata;
	gchar* exif_md5;
	PhotoImportSource* associated;
};

struct _DataView {
	DataObject parent_instance;
	DataViewPrivate * priv;
};

struct _DataViewClass {
	DataObjectClass parent_class;
	void (*notify_view_altered) (DataView* self);
	void (*notify_geometry_altered) (DataView* self);
	void (*notify_unsubscribed) (DataView* self, DataSource* source);
	void (*state_changed) (DataView* self, gboolean selected);
	void (*visibility_changed) (DataView* self, gboolean visible);
	void (*view_altered) (DataView* self);
	void (*geometry_altered) (DataView* self);
	void (*unsubscribed) (DataView* self, DataSource* source);
};

struct _ThumbnailView {
	DataView parent_instance;
	ThumbnailViewPrivate * priv;
};

struct _ThumbnailViewClass {
	DataViewClass parent_class;
	void (*notify_thumbnail_altered) (ThumbnailView* self);
	void (*thumbnail_altered) (ThumbnailView* self);
};

struct _Dimensions {
	gint width;
	gint height;
};

struct _CheckerboardItem {
	ThumbnailView parent_instance;
	CheckerboardItemPrivate * priv;
	Dimensions requisition;
	GdkRectangle allocation;
};

struct _CheckerboardItemClass {
	ThumbnailViewClass parent_class;
	void (*exposed) (CheckerboardItem* self);
	void (*unexposed) (CheckerboardItem* self);
	gboolean (*is_exposed) (CheckerboardItem* self);
	void (*paint_shadow) (CheckerboardItem* self, cairo_t* ctx, Dimensions* dimensions, GdkPoint* origin, gint radius, gfloat initial_alpha);
	void (*paint_border) (CheckerboardItem* self, cairo_t* ctx, Dimensions* object_dimensions, GdkPoint* object_origin, gint border_width);
	void (*paint_image) (CheckerboardItem* self, cairo_t* ctx, GdkPixbuf* pixbuf, GdkPoint* origin);
	GdkPixbuf* (*get_top_left_trinket) (CheckerboardItem* self, gint scale);
	GdkPixbuf* (*get_top_right_trinket) (CheckerboardItem* self, gint scale);
	GdkPixbuf* (*get_bottom_left_trinket) (CheckerboardItem* self, gint scale);
	GdkPixbuf* (*get_bottom_right_trinket) (CheckerboardItem* self, gint scale);
};

struct _MediaSourceItem {
	CheckerboardItem parent_instance;
	MediaSourceItemPrivate * priv;
};

struct _MediaSourceItemClass {
	CheckerboardItemClass parent_class;
};

struct _ImportPreview {
	MediaSourceItem parent_instance;
	ImportPreviewPrivate * priv;
};

struct _ImportPreviewClass {
	MediaSourceItemClass parent_class;
};

struct _ImportPreviewPrivate {
	DuplicatedFile* duplicated_file;
};

typedef enum  {
	ORIENTATION_MIN = 1,
	ORIENTATION_TOP_LEFT = 1,
	ORIENTATION_TOP_RIGHT = 2,
	ORIENTATION_BOTTOM_RIGHT = 3,
	ORIENTATION_BOTTOM_LEFT = 4,
	ORIENTATION_LEFT_TOP = 5,
	ORIENTATION_RIGHT_TOP = 6,
	ORIENTATION_RIGHT_BOTTOM = 7,
	ORIENTATION_LEFT_BOTTOM = 8,
	ORIENTATION_MAX = 8
} Orientation;

struct _PhotoID {
	gint64 id;
};

struct _VideoID {
	gint64 id;
};

struct _CoreTracker {
	GTypeInstance parent_instance;
	volatile int ref_count;
	CoreTrackerPrivate * priv;
};

struct _CoreTrackerClass {
	GTypeClass parent_class;
	void (*finalize) (CoreTracker *self);
	void (*updated) (CoreTracker* self);
};

struct _CoreViewTracker {
	CoreTracker parent_instance;
	CoreViewTrackerPrivate * priv;
};

struct _CoreViewTrackerClass {
	CoreTrackerClass parent_class;
};

struct _CameraViewTracker {
	CoreViewTracker parent_instance;
	CameraViewTrackerPrivate * priv;
	CameraAccumulator* all;
	CameraAccumulator* visible;
	CameraAccumulator* selected;
};

struct _CameraViewTrackerClass {
	CoreViewTrackerClass parent_class;
};

struct _CoreTrackerAccumulatorIface {
	GTypeInterface parent_iface;
	gboolean (*include) (CoreTrackerAccumulator* self, DataObject* object);
	gboolean (*uninclude) (CoreTrackerAccumulator* self, DataObject* object);
	gboolean (*altered) (CoreTrackerAccumulator* self, DataObject* object, Alteration* alteration);
};

struct _CameraAccumulator {
	GObject parent_instance;
	CameraAccumulatorPrivate * priv;
};

struct _CameraAccumulatorClass {
	GObjectClass parent_class;
};

struct _CameraAccumulatorPrivate {
	gint _total;
	gint _photos;
	gint _videos;
	gint _raw;
};

struct _Page {
	GtkScrolledWindow parent_instance;
	PagePrivate * priv;
	GtkUIManager* ui;
	GtkToolbar* toolbar;
	gboolean in_view;
};

struct _PageClass {
	GtkScrolledWindowClass parent_class;
	void (*set_page_name) (Page* self, const gchar* page_name);
	void (*set_container) (Page* self, GtkWindow* container);
	void (*clear_container) (Page* self);
	GtkMenuBar* (*get_menubar) (Page* self);
	GtkWidget* (*get_page_ui_widget) (Page* self, const gchar* path);
	GtkToolbar* (*get_toolbar) (Page* self);
	GtkMenu* (*get_page_context_menu) (Page* self);
	void (*switching_from) (Page* self);
	void (*switched_to) (Page* self);
	void (*ready) (Page* self);
	void (*switching_to_fullscreen) (Page* self, FullscreenWindow* fsw);
	void (*returning_from_fullscreen) (Page* self, FullscreenWindow* fsw);
	void (*init_collect_ui_filenames) (Page* self, GeeList* ui_filenames);
	GtkActionEntry* (*init_collect_action_entries) (Page* self, int* result_length1);
	GtkToggleActionEntry* (*init_collect_toggle_action_entries) (Page* self, int* result_length1);
	void (*register_radio_actions) (Page* self, GtkActionGroup* action_group);
	InjectionGroup** (*init_collect_injection_groups) (Page* self, int* result_length1);
	void (*init_actions) (Page* self, gint selected_count, gint count);
	void (*update_actions) (Page* self, gint selected_count, gint count);
	gboolean (*source_drag_failed) (Page* self, GdkDragContext* context, GtkDragResult drag_result);
	gboolean (*on_left_click) (Page* self, GdkEventButton* event);
	gboolean (*on_middle_click) (Page* self, GdkEventButton* event);
	gboolean (*on_right_click) (Page* self, GdkEventButton* event);
	gboolean (*on_left_released) (Page* self, GdkEventButton* event);
	gboolean (*on_middle_released) (Page* self, GdkEventButton* event);
	gboolean (*on_right_released) (Page* self, GdkEventButton* event);
	gboolean (*on_ctrl_pressed) (Page* self, GdkEventKey* event);
	gboolean (*on_ctrl_released) (Page* self, GdkEventKey* event);
	gboolean (*on_alt_pressed) (Page* self, GdkEventKey* event);
	gboolean (*on_alt_released) (Page* self, GdkEventKey* event);
	gboolean (*on_shift_pressed) (Page* self, GdkEventKey* event);
	gboolean (*on_shift_released) (Page* self, GdkEventKey* event);
	gboolean (*on_super_pressed) (Page* self, GdkEventKey* event);
	gboolean (*on_super_released) (Page* self, GdkEventKey* event);
	gboolean (*on_app_key_pressed) (Page* self, GdkEventKey* event);
	gboolean (*on_app_key_released) (Page* self, GdkEventKey* event);
	void (*on_move) (Page* self, GdkRectangle* rect);
	void (*on_move_start) (Page* self, GdkRectangle* rect);
	void (*on_move_finished) (Page* self, GdkRectangle* rect);
	void (*on_resize) (Page* self, GdkRectangle* rect);
	void (*on_resize_start) (Page* self, GdkRectangle* rect);
	void (*on_resize_finished) (Page* self, GdkRectangle* rect);
	gboolean (*on_configure) (Page* self, GdkEventConfigure* event, GdkRectangle* rect);
	gboolean (*on_motion) (Page* self, GdkEventMotion* event, gint x, gint y, GdkModifierType mask);
	gboolean (*on_leave_notify_event) (Page* self);
	gboolean (*on_mousewheel_up) (Page* self, GdkEventScroll* event);
	gboolean (*on_mousewheel_down) (Page* self, GdkEventScroll* event);
	gboolean (*on_mousewheel_left) (Page* self, GdkEventScroll* event);
	gboolean (*on_mousewheel_right) (Page* self, GdkEventScroll* event);
	gboolean (*on_context_keypress) (Page* self);
	gboolean (*on_context_buttonpress) (Page* self, GdkEventButton* event);
	gboolean (*on_context_invoked) (Page* self);
	void (*set_page_cursor) (Page* self, GdkCursorType cursor_type);
};

typedef enum  {
	CHECKERBOARD_PAGE_ACTIVATOR_KEYBOARD,
	CHECKERBOARD_PAGE_ACTIVATOR_MOUSE
} CheckerboardPageActivator;

struct _CheckerboardPageKeyboardModifiers {
	gboolean ctrl_pressed;
	gboolean alt_pressed;
	gboolean shift_pressed;
	gboolean super_pressed;
};

struct _CheckerboardPage {
	Page parent_instance;
	CheckerboardPagePrivate * priv;
	CheckerboardItem* anchor;
	CheckerboardItem* cursor;
};

struct _CheckerboardPageClass {
	PageClass parent_class;
	GtkMenu* (*get_item_context_menu) (CheckerboardPage* self);
	gchar* (*get_view_empty_message) (CheckerboardPage* self);
	gchar* (*get_filter_no_match_message) (CheckerboardPage* self);
	void (*on_item_activated) (CheckerboardPage* self, CheckerboardItem* item, CheckerboardPageActivator activator, CheckerboardPageKeyboardModifiers* modifiers);
	SearchViewFilter* (*get_search_view_filter) (CheckerboardPage* self);
	CoreViewTracker* (*get_view_tracker) (CheckerboardPage* self);
	gboolean (*on_mouse_over) (CheckerboardPage* self, CheckerboardItem* item, gint x, gint y, GdkModifierType mask);
	void (*set_display_titles) (CheckerboardPage* self, gboolean display);
	void (*set_display_comments) (CheckerboardPage* self, gboolean display);
};

struct _ImportPage {
	CheckerboardPage parent_instance;
	ImportPagePrivate * priv;
};

struct _ImportPageClass {
	CheckerboardPageClass parent_class;
};

struct _ImportPagePrivate {
	SourceCollection* import_sources;
	GtkLabel* camera_label;
	GtkCheckButton* hide_imported;
	GtkProgressBar* progress_bar;
	Camera* camera;
	gchar* uri;
	gboolean busy;
	gboolean refreshed;
	int refresh_result;
	gchar* refresh_error;
	gchar* camera_name;
	GVolumeMonitor* volume_monitor;
	ImportPage* local_ref;
	gchar* icon;
	ImportPageImportPageSearchViewFilter* search_filter;
	ImportPageHideImportedViewFilter* hide_imported_filter;
	CameraViewTracker* tracker;
};

typedef enum  {
	IMPORT_PAGE_REFRESH_RESULT_OK,
	IMPORT_PAGE_REFRESH_RESULT_BUSY,
	IMPORT_PAGE_REFRESH_RESULT_LOCKED,
	IMPORT_PAGE_REFRESH_RESULT_LIBRARY_ERROR
} ImportPageRefreshResult;

typedef gboolean (*ValueEqualFunc) (GValue* a, GValue* b, void* user_data);
typedef void (*BatchImportImportReporter) (ImportManifest* manifest, BatchImportRoll* import_roll, void* user_data);
typedef enum  {
	IMPORT_RESULT_SUCCESS,
	IMPORT_RESULT_FILE_ERROR,
	IMPORT_RESULT_DECODE_ERROR,
	IMPORT_RESULT_DATABASE_ERROR,
	IMPORT_RESULT_USER_ABORT,
	IMPORT_RESULT_NOT_A_FILE,
	IMPORT_RESULT_PHOTO_EXISTS,
	IMPORT_RESULT_UNSUPPORTED_FORMAT,
	IMPORT_RESULT_NOT_AN_IMAGE,
	IMPORT_RESULT_DISK_FAILURE,
	IMPORT_RESULT_DISK_FULL,
	IMPORT_RESULT_CAMERA_ERROR,
	IMPORT_RESULT_FILE_WRITE_ERROR,
	IMPORT_RESULT_PIXBUF_CORRUPT_IMAGE
} ImportResult;

struct _BatchImportResult {
	GTypeInstance parent_instance;
	volatile int ref_count;
	BatchImportResultPrivate * priv;
	BatchImportJob* job;
	GFile* file;
	gchar* src_identifier;
	gchar* dest_identifier;
	ImportResult result;
	gchar* errmsg;
	DuplicatedFile* duplicate_of;
};

struct _BatchImportResultClass {
	GTypeClass parent_class;
	void (*finalize) (BatchImportResult *self);
};

struct _ImportManifest {
	GTypeInstance parent_instance;
	volatile int ref_count;
	ImportManifestPrivate * priv;
	GeeList* imported;
	GeeList* success;
	GeeList* camera_failed;
	GeeList* failed;
	GeeList* write_failed;
	GeeList* skipped_photos;
	GeeList* skipped_files;
	GeeList* aborted;
	GeeList* already_imported;
	GeeList* corrupt_files;
	GeeList* all;
};

struct _ImportManifestClass {
	GTypeClass parent_class;
	void (*finalize) (ImportManifest *self);
};

struct _ViewManager {
	GTypeInstance parent_instance;
	volatile int ref_count;
	ViewManagerPrivate * priv;
};

struct _ViewManagerClass {
	GTypeClass parent_class;
	void (*finalize) (ViewManager *self);
	gboolean (*include_in_view) (ViewManager* self, DataSource* source);
	DataView* (*create_view) (ViewManager* self, DataSource* source);
};

struct _ImportPageImportViewManager {
	ViewManager parent_instance;
	ImportPageImportViewManagerPrivate * priv;
};

struct _ImportPageImportViewManagerClass {
	ViewManagerClass parent_class;
};

struct _ImportPageImportViewManagerPrivate {
	ImportPage* owner;
};

struct _BatchImportJob {
	GTypeInstance parent_instance;
	volatile int ref_count;
	BatchImportJobPrivate * priv;
};

struct _BatchImportJobClass {
	GTypeClass parent_class;
	void (*finalize) (BatchImportJob *self);
	gchar* (*get_dest_identifier) (BatchImportJob* self);
	gchar* (*get_source_identifier) (BatchImportJob* self);
	gboolean (*is_directory) (BatchImportJob* self);
	gchar* (*get_basename) (BatchImportJob* self);
	gchar* (*get_path) (BatchImportJob* self);
	DuplicatedFile* (*get_duplicated_file) (BatchImportJob* self);
	void (*set_associated) (BatchImportJob* self, BatchImportJob* associated);
	gboolean (*determine_file_size) (BatchImportJob* self, guint64* filesize, GFile** file_or_dir);
	gboolean (*prepare) (BatchImportJob* self, GFile** file_to_import, gboolean* copy_to_library, GError** error);
	gboolean (*complete) (BatchImportJob* self, MediaSource* source, BatchImportRoll* import_roll, GError** error);
	time_t (*get_exposure_time_override) (BatchImportJob* self);
};

struct _ImportPageCameraImportJob {
	BatchImportJob parent_instance;
	ImportPageCameraImportJobPrivate * priv;
};

struct _ImportPageCameraImportJobClass {
	BatchImportJobClass parent_class;
};

struct _ImportPageCameraImportJobPrivate {
	GPContextWrapper* context;
	ImportSource* import_file;
	Camera* camera;
	gchar* fulldir;
	gchar* filename;
	guint64 filesize;
	PhotoMetadata* metadata;
	time_t exposure_time;
	ImportPageCameraImportJob* associated;
	BackingPhotoRow* associated_file;
	DuplicatedFile* duplicated_file;
};

typedef enum  {
	RAW_DEVELOPER_SHOTWELL = 0,
	RAW_DEVELOPER_CAMERA,
	RAW_DEVELOPER_EMBEDDED
} RawDeveloper;

struct _BackingPhotoID {
	gint64 id;
};

struct _BackingPhotoRow {
	GTypeInstance parent_instance;
	volatile int ref_count;
	BackingPhotoRowPrivate * priv;
	BackingPhotoID id;
	time_t time_created;
	gchar* filepath;
	gint64 filesize;
	time_t timestamp;
	PhotoFileFormat file_format;
	Dimensions dim;
	Orientation original_orientation;
};

struct _BackingPhotoRowClass {
	GTypeClass parent_class;
	void (*finalize) (BackingPhotoRow *self);
};

struct _ViewFilter {
	GTypeInstance parent_instance;
	volatile int ref_count;
	ViewFilterPrivate * priv;
};

struct _ViewFilterClass {
	GTypeClass parent_class;
	void (*finalize) (ViewFilter *self);
	gboolean (*predicate) (ViewFilter* self, DataView* view);
	void (*refresh) (ViewFilter* self);
};

struct _SearchViewFilter {
	ViewFilter parent_instance;
	SearchViewFilterPrivate * priv;
};

struct _SearchViewFilterClass {
	ViewFilterClass parent_class;
	guint (*get_criteria) (SearchViewFilter* self);
};

struct _ImportPageImportPageSearchViewFilter {
	SearchViewFilter parent_instance;
	ImportPageImportPageSearchViewFilterPrivate * priv;
};

struct _ImportPageImportPageSearchViewFilterClass {
	SearchViewFilterClass parent_class;
};

typedef enum  {
	SEARCH_FILTER_CRITERIA_NONE = 0,
	SEARCH_FILTER_CRITERIA_RECURSIVE = 1 << 0,
	SEARCH_FILTER_CRITERIA_TEXT = 1 << 1,
	SEARCH_FILTER_CRITERIA_FLAG = 1 << 2,
	SEARCH_FILTER_CRITERIA_MEDIA = 1 << 3,
	SEARCH_FILTER_CRITERIA_RATING = 1 << 4,
	SEARCH_FILTER_CRITERIA_SAVEDSEARCH = 1 << 5,
	SEARCH_FILTER_CRITERIA_ALL = 0xFFFFFFFFLL
} SearchFilterCriteria;

struct _ImportPageHideImportedViewFilter {
	ViewFilter parent_instance;
	ImportPageHideImportedViewFilterPrivate * priv;
};

struct _ImportPageHideImportedViewFilterClass {
	ViewFilterClass parent_class;
};


static gpointer import_source_collection_parent_class = NULL;
static gpointer import_source_parent_class = NULL;
extern GPSpinIdleWrapper* import_page_spin_idle_context;
static IndexableIface* import_source_indexable_parent_iface = NULL;
static gpointer video_import_source_parent_class = NULL;
static gpointer photo_import_source_parent_class = NULL;
static gpointer import_preview_parent_class = NULL;
static GdkPixbuf* import_preview_placeholder_preview;
static GdkPixbuf* import_preview_placeholder_preview = NULL;
extern LibraryPhotoSourceCollection* library_photo_global;
extern VideoSourceCollection* video_global;
static gpointer camera_view_tracker_parent_class = NULL;
static gpointer camera_accumulator_parent_class = NULL;
static CoreTrackerAccumulatorIface* camera_accumulator_core_tracker_accumulator_parent_iface = NULL;
static gpointer import_page_parent_class = NULL;
extern GPContextWrapper* import_page_null_context;
GPContextWrapper* import_page_null_context = NULL;
GPSpinIdleWrapper* import_page_spin_idle_context = NULL;
static gpointer import_page_import_view_manager_parent_class = NULL;
static gpointer import_page_camera_import_job_parent_class = NULL;
static gpointer import_page_import_page_search_view_filter_parent_class = NULL;
static gpointer import_page_hide_imported_view_filter_parent_class = NULL;

gpointer data_collection_ref (gpointer instance);
void data_collection_unref (gpointer instance);
GParamSpec* param_spec_data_collection (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_data_collection (GValue* value, gpointer v_object);
void value_take_data_collection (GValue* value, gpointer v_object);
gpointer value_get_data_collection (const GValue* value);
GType data_collection_get_type (void) G_GNUC_CONST;
GType data_object_get_type (void) G_GNUC_CONST;
gpointer alteration_ref (gpointer instance);
void alteration_unref (gpointer instance);
GParamSpec* param_spec_alteration (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_alteration (GValue* value, gpointer v_object);
void value_take_alteration (GValue* value, gpointer v_object);
gpointer value_get_alteration (const GValue* value);
GType alteration_get_type (void) G_GNUC_CONST;
GType marker_get_type (void) G_GNUC_CONST;
GType source_collection_get_type (void) G_GNUC_CONST;
GType data_source_get_type (void) G_GNUC_CONST;
gpointer source_backlink_ref (gpointer instance);
void source_backlink_unref (gpointer instance);
GParamSpec* param_spec_source_backlink (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_source_backlink (GValue* value, gpointer v_object);
void value_take_source_backlink (GValue* value, gpointer v_object);
gpointer value_get_source_backlink (const GValue* value);
GType source_backlink_get_type (void) G_GNUC_CONST;
GType import_source_collection_get_type (void) G_GNUC_CONST;
enum  {
	IMPORT_SOURCE_COLLECTION_DUMMY_PROPERTY
};
ImportSourceCollection* import_source_collection_new (const gchar* name);
ImportSourceCollection* import_source_collection_construct (GType object_type, const gchar* name);
SourceCollection* source_collection_construct (GType object_type, const gchar* name);
static gboolean import_source_collection_real_holds_type_of_source (SourceCollection* base, DataSource* source);
GType thumbnail_source_get_type (void) G_GNUC_CONST;
GType import_source_get_type (void) G_GNUC_CONST;
gpointer source_holding_tank_ref (gpointer instance);
void source_holding_tank_unref (gpointer instance);
GParamSpec* param_spec_source_holding_tank (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_source_holding_tank (GValue* value, gpointer v_object);
void value_take_source_holding_tank (GValue* value, gpointer v_object);
gpointer value_get_source_holding_tank (const GValue* value);
GType source_holding_tank_get_type (void) G_GNUC_CONST;
gpointer source_snapshot_ref (gpointer instance);
void source_snapshot_unref (gpointer instance);
GParamSpec* param_spec_source_snapshot (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_source_snapshot (GValue* value, gpointer v_object);
void value_take_source_snapshot (GValue* value, gpointer v_object);
gpointer value_get_source_snapshot (const GValue* value);
GType source_snapshot_get_type (void) G_GNUC_CONST;
GType photo_file_format_get_type (void) G_GNUC_CONST;
GType indexable_get_type (void) G_GNUC_CONST;
#define IMPORT_SOURCE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_IMPORT_SOURCE, ImportSourcePrivate))
enum  {
	IMPORT_SOURCE_DUMMY_PROPERTY
};
ImportSource* import_source_construct (GType object_type, const gchar* camera_name, Camera* camera, gint fsid, const gchar* folder, const gchar* filename, gulong file_size, time_t modification_time);
#define DATA_OBJECT_INVALID_OBJECT_ID ((gint64) -1)
ThumbnailSource* thumbnail_source_construct (GType object_type, gint64 object_id);
gchar* indexable_prepare_indexable_string (const gchar* str);
void import_source_set_preview (ImportSource* self, GdkPixbuf* preview);
gchar* import_source_get_camera_name (ImportSource* self);
Camera* import_source_get_camera (ImportSource* self);
gint import_source_get_fsid (ImportSource* self);
gchar* import_source_get_folder (ImportSource* self);
gchar* import_source_get_filename (ImportSource* self);
gulong import_source_get_filesize (ImportSource* self);
time_t import_source_get_modification_time (ImportSource* self);
GdkPixbuf* import_source_get_preview (ImportSource* self);
static GdkPixbuf* import_source_real_get_preview (ImportSource* self);
time_t import_source_get_exposure_time (ImportSource* self);
static time_t import_source_real_get_exposure_time (ImportSource* self);
gchar* import_source_get_fulldir (ImportSource* self);
gchar* import_page_get_fulldir (Camera* camera, const gchar* camera_name, gint fsid, const gchar* folder);
static gchar* import_source_real_to_string (DataObject* base);
static gboolean import_source_real_internal_delete_backing (DataSource* base, GError** error);
gchar* data_object_to_string (DataObject* self);
gboolean data_source_internal_delete_backing (DataSource* self, GError** error);
gpointer gp_context_wrapper_ref (gpointer instance);
void gp_context_wrapper_unref (gpointer instance);
GParamSpec* gp_param_spec_context_wrapper (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void gp_value_set_context_wrapper (GValue* value, gpointer v_object);
void gp_value_take_context_wrapper (GValue* value, gpointer v_object);
gpointer gp_value_get_context_wrapper (const GValue* value);
GType gp_context_wrapper_get_type (void) G_GNUC_CONST;
GType gp_spin_idle_wrapper_get_type (void) G_GNUC_CONST;
static const gchar* import_source_real_get_indexable_keywords (Indexable* base);
static void import_source_finalize (GObject* obj);
GType video_import_source_get_type (void) G_GNUC_CONST;
enum  {
	VIDEO_IMPORT_SOURCE_DUMMY_PROPERTY
};
VideoImportSource* video_import_source_new (const gchar* camera_name, Camera* camera, gint fsid, const gchar* folder, const gchar* filename, gulong file_size, time_t modification_time);
VideoImportSource* video_import_source_construct (GType object_type, const gchar* camera_name, Camera* camera, gint fsid, const gchar* folder, const gchar* filename, gulong file_size, time_t modification_time);
static GdkPixbuf* video_import_source_real_get_thumbnail (ThumbnailSource* base, gint scale, GError** error);
GdkPixbuf* thumbnail_source_create_thumbnail (ThumbnailSource* self, gint scale, GError** error);
static GdkPixbuf* video_import_source_real_create_thumbnail (ThumbnailSource* base, gint scale, GError** error);
GdkPixbuf* scale_pixbuf (GdkPixbuf* pixbuf, gint scale, GdkInterpType interp, gboolean scale_up);
static gchar* video_import_source_real_get_typename (DataSource* base);
static gint64 video_import_source_real_get_instance_id (DataSource* base);
gint64 data_object_get_object_id (DataObject* self);
static PhotoFileFormat video_import_source_real_get_preferred_thumbnail_format (ThumbnailSource* base);
PhotoFileFormat photo_file_format_get_system_default_format (void);
static gchar* video_import_source_real_get_name (DataObject* base);
void video_import_source_update (VideoImportSource* self, GdkPixbuf* preview);
GdkPixbuf* resources_get_noninterpretable_badge_pixbuf (void);
GType photo_import_source_get_type (void) G_GNUC_CONST;
gpointer media_metadata_ref (gpointer instance);
void media_metadata_unref (gpointer instance);
GParamSpec* param_spec_media_metadata (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_media_metadata (GValue* value, gpointer v_object);
void value_take_media_metadata (GValue* value, gpointer v_object);
gpointer value_get_media_metadata (const GValue* value);
GType media_metadata_get_type (void) G_GNUC_CONST;
GType photo_metadata_get_type (void) G_GNUC_CONST;
#define PHOTO_IMPORT_SOURCE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_PHOTO_IMPORT_SOURCE, PhotoImportSourcePrivate))
enum  {
	PHOTO_IMPORT_SOURCE_DUMMY_PROPERTY
};
#define PHOTO_IMPORT_SOURCE_INTERP GDK_INTERP_BILINEAR
PhotoImportSource* photo_import_source_new (const gchar* camera_name, Camera* camera, gint fsid, const gchar* folder, const gchar* filename, gulong file_size, time_t modification_time, PhotoFileFormat file_format);
PhotoImportSource* photo_import_source_construct (GType object_type, const gchar* camera_name, Camera* camera, gint fsid, const gchar* folder, const gchar* filename, gulong file_size, time_t modification_time, PhotoFileFormat file_format);
static gchar* photo_import_source_real_get_name (DataObject* base);
gchar* photo_import_source_get_title (PhotoImportSource* self);
gboolean is_string_empty (const gchar* s);
static gchar* photo_import_source_real_get_typename (DataSource* base);
static gint64 photo_import_source_real_get_instance_id (DataSource* base);
static PhotoFileFormat photo_import_source_real_get_preferred_thumbnail_format (ThumbnailSource* base);
gboolean photo_file_format_can_write (PhotoFileFormat self);
static GdkPixbuf* photo_import_source_real_create_thumbnail (ThumbnailSource* base, gint scale, GError** error);
void photo_import_source_update (PhotoImportSource* self, GdkPixbuf* preview, const gchar* preview_md5, PhotoMetadata* metadata, const gchar* exif_md5);
static time_t photo_import_source_real_get_exposure_time (ImportSource* base);
gpointer metadata_date_time_ref (gpointer instance);
void metadata_date_time_unref (gpointer instance);
GParamSpec* param_spec_metadata_date_time (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_metadata_date_time (GValue* value, gpointer v_object);
void value_take_metadata_date_time (GValue* value, gpointer v_object);
gpointer value_get_metadata_date_time (const GValue* value);
GType metadata_date_time_get_type (void) G_GNUC_CONST;
MetadataDateTime* photo_metadata_get_exposure_date_time (PhotoMetadata* self);
time_t metadata_date_time_get_timestamp (MetadataDateTime* self);
gchar* media_metadata_get_title (MediaMetadata* self);
PhotoMetadata* photo_import_source_get_metadata (PhotoImportSource* self);
static GdkPixbuf* photo_import_source_real_get_preview (ImportSource* base);
static GdkPixbuf* photo_import_source_real_get_thumbnail (ThumbnailSource* base, gint scale, GError** error);
PhotoFileFormat photo_import_source_get_file_format (PhotoImportSource* self);
gchar* photo_import_source_get_preview_md5 (PhotoImportSource* self);
void photo_import_source_set_associated (PhotoImportSource* self, PhotoImportSource* associated);
PhotoImportSource* photo_import_source_get_associated (PhotoImportSource* self);
static gboolean photo_import_source_real_internal_delete_backing (DataSource* base, GError** error);
static void photo_import_source_finalize (GObject* obj);
GType data_view_get_type (void) G_GNUC_CONST;
GType thumbnail_view_get_type (void) G_GNUC_CONST;
GType checkerboard_item_get_type (void) G_GNUC_CONST;
GType dimensions_get_type (void) G_GNUC_CONST;
Dimensions* dimensions_dup (const Dimensions* self);
void dimensions_free (Dimensions* self);
GType media_source_item_get_type (void) G_GNUC_CONST;
GType import_preview_get_type (void) G_GNUC_CONST;
GType duplicated_file_get_type (void) G_GNUC_CONST;
#define IMPORT_PREVIEW_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_IMPORT_PREVIEW, ImportPreviewPrivate))
enum  {
	IMPORT_PREVIEW_DUMMY_PROPERTY
};
#define IMPORT_PREVIEW_MAX_SCALE 128
ImportPreview* import_preview_new (ImportSource* source);
ImportPreview* import_preview_construct (GType object_type, ImportSource* source);
void dimensions_init (Dimensions *self, gint width, gint height);
gchar* data_object_get_name (DataObject* self);
MediaSourceItem* media_source_item_new (ThumbnailSource* source, Dimensions* initial_pixbuf_dim, const gchar* title, const gchar* comment, gboolean marked_up, PangoAlignment alignment);
MediaSourceItem* media_source_item_construct (GType object_type, ThumbnailSource* source, Dimensions* initial_pixbuf_dim, const gchar* title, const gchar* comment, gboolean marked_up, PangoAlignment alignment);
void media_source_item_set_enable_sprockets (MediaSourceItem* self, gboolean enable_sprockets);
GdkPixbuf* thumbnail_source_get_thumbnail (ThumbnailSource* self, gint scale, GError** error);
GdkPixbuf* get_placeholder_pixbuf (void);
GType orientation_get_type (void) G_GNUC_CONST;
Orientation photo_metadata_get_orientation (PhotoMetadata* self);
GdkPixbuf* orientation_rotate_pixbuf (Orientation self, GdkPixbuf* pixbuf);
void checkerboard_item_set_subtitle (CheckerboardItem* self, const gchar* text, gboolean marked_up, PangoAlignment alignment);
void checkerboard_item_set_image (CheckerboardItem* self, GdkPixbuf* pixbuf);
gboolean import_preview_is_already_imported (ImportPreview* self);
ImportSource* import_preview_get_import_source (ImportPreview* self);
gboolean library_photo_has_nontrash_duplicate (GFile* file, const gchar* thumbnail_md5, const gchar* full_md5, PhotoFileFormat file_format);
GType photo_id_get_type (void) G_GNUC_CONST;
PhotoID* photo_id_dup (const PhotoID* self);
void photo_id_free (PhotoID* self);
DuplicatedFile* duplicated_file_create_from_photo_id (PhotoID* photo_id);
void library_photo_get_nontrash_duplicate (GFile* file, const gchar* thumbnail_md5, const gchar* full_md5, PhotoFileFormat file_format, PhotoID* result);
GType database_source_collection_get_type (void) G_GNUC_CONST;
GType media_source_collection_get_type (void) G_GNUC_CONST;
GType library_photo_source_collection_get_type (void) G_GNUC_CONST;
gboolean library_photo_source_collection_has_basename_filesize_duplicate (LibraryPhotoSourceCollection* self, const gchar* basename, gint64 filesize);
void library_photo_source_collection_get_basename_filesize_duplicate (LibraryPhotoSourceCollection* self, const gchar* basename, gint64 filesize, PhotoID* result);
GType video_source_collection_get_type (void) G_GNUC_CONST;
gboolean video_source_collection_has_basename_filesize_duplicate (VideoSourceCollection* self, const gchar* basename, guint64 filesize);
GType video_id_get_type (void) G_GNUC_CONST;
VideoID* video_id_dup (const VideoID* self);
void video_id_free (VideoID* self);
DuplicatedFile* duplicated_file_create_from_video_id (VideoID* video_id);
void video_source_collection_get_basename_filesize_duplicate (VideoSourceCollection* self, const gchar* basename, guint64 filesize, VideoID* result);
DuplicatedFile* import_preview_get_duplicated_file (ImportPreview* self);
DataSource* data_view_get_source (DataView* self);
static void import_preview_finalize (GObject* obj);
gpointer core_tracker_ref (gpointer instance);
void core_tracker_unref (gpointer instance);
GParamSpec* core_param_spec_tracker (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void core_value_set_tracker (GValue* value, gpointer v_object);
void core_value_take_tracker (GValue* value, gpointer v_object);
gpointer core_value_get_tracker (const GValue* value);
GType core_tracker_get_type (void) G_GNUC_CONST;
GType core_view_tracker_get_type (void) G_GNUC_CONST;
GType camera_view_tracker_get_type (void) G_GNUC_CONST;
GType camera_accumulator_get_type (void) G_GNUC_CONST;
enum  {
	CAMERA_VIEW_TRACKER_DUMMY_PROPERTY
};
CameraAccumulator* camera_accumulator_new (void);
CameraAccumulator* camera_accumulator_construct (GType object_type);
GType view_collection_get_type (void) G_GNUC_CONST;
CameraViewTracker* camera_view_tracker_new (ViewCollection* collection);
CameraViewTracker* camera_view_tracker_construct (GType object_type, ViewCollection* collection);
CoreViewTracker* core_view_tracker_new (ViewCollection* collection);
CoreViewTracker* core_view_tracker_construct (GType object_type, ViewCollection* collection);
GType core_tracker_accumulator_get_type (void) G_GNUC_CONST;
void core_view_tracker_start (CoreViewTracker* self, CoreTrackerAccumulator* all, CoreTrackerAccumulator* visible, CoreTrackerAccumulator* selected);
static void camera_view_tracker_finalize (CoreTracker* obj);
#define CAMERA_ACCUMULATOR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_CAMERA_ACCUMULATOR, CameraAccumulatorPrivate))
enum  {
	CAMERA_ACCUMULATOR_DUMMY_PROPERTY,
	CAMERA_ACCUMULATOR_TOTAL,
	CAMERA_ACCUMULATOR_PHOTOS,
	CAMERA_ACCUMULATOR_VIDEOS,
	CAMERA_ACCUMULATOR_RAW
};
static gboolean camera_accumulator_real_include (CoreTrackerAccumulator* base, DataObject* object);
gint camera_accumulator_get_total (CameraAccumulator* self);
static void camera_accumulator_set_total (CameraAccumulator* self, gint value);
gint camera_accumulator_get_photos (CameraAccumulator* self);
static void camera_accumulator_set_photos (CameraAccumulator* self, gint value);
gint camera_accumulator_get_raw (CameraAccumulator* self);
static void camera_accumulator_set_raw (CameraAccumulator* self, gint value);
gint camera_accumulator_get_videos (CameraAccumulator* self);
static void camera_accumulator_set_videos (CameraAccumulator* self, gint value);
static gboolean camera_accumulator_real_uninclude (CoreTrackerAccumulator* base, DataObject* object);
static gboolean camera_accumulator_real_altered (CoreTrackerAccumulator* base, DataObject* object, Alteration* alteration);
gchar* camera_accumulator_to_string (CameraAccumulator* self);
static void camera_accumulator_finalize (GObject* obj);
static void _vala_camera_accumulator_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_camera_accumulator_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
GType page_get_type (void) G_GNUC_CONST;
GType page_window_get_type (void) G_GNUC_CONST;
GType fullscreen_window_get_type (void) G_GNUC_CONST;
gpointer injection_group_ref (gpointer instance);
void injection_group_unref (gpointer instance);
GParamSpec* param_spec_injection_group (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_injection_group (GValue* value, gpointer v_object);
void value_take_injection_group (GValue* value, gpointer v_object);
gpointer value_get_injection_group (const GValue* value);
GType injection_group_get_type (void) G_GNUC_CONST;
GType checkerboard_page_get_type (void) G_GNUC_CONST;
GType checkerboard_page_activator_get_type (void) G_GNUC_CONST;
GType checkerboard_page_keyboard_modifiers_get_type (void) G_GNUC_CONST;
CheckerboardPageKeyboardModifiers* checkerboard_page_keyboard_modifiers_dup (const CheckerboardPageKeyboardModifiers* self);
void checkerboard_page_keyboard_modifiers_free (CheckerboardPageKeyboardModifiers* self);
gpointer view_filter_ref (gpointer instance);
void view_filter_unref (gpointer instance);
GParamSpec* param_spec_view_filter (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_view_filter (GValue* value, gpointer v_object);
void value_take_view_filter (GValue* value, gpointer v_object);
gpointer value_get_view_filter (const GValue* value);
GType view_filter_get_type (void) G_GNUC_CONST;
GType search_view_filter_get_type (void) G_GNUC_CONST;
GType import_page_get_type (void) G_GNUC_CONST;
static GType import_page_import_page_search_view_filter_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
static GType import_page_hide_imported_view_filter_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
#define IMPORT_PAGE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_IMPORT_PAGE, ImportPagePrivate))
enum  {
	IMPORT_PAGE_DUMMY_PROPERTY
};
static void import_page_on_media_added_removed (ImportPage* self);
static void _import_page_on_media_added_removed_data_collection_contents_altered (DataCollection* _sender, GeeIterable* added, GeeIterable* removed, gpointer self);
GType import_page_refresh_result_get_type (void) G_GNUC_CONST;
static ImportPageImportPageSearchViewFilter* import_page_import_page_search_view_filter_new (void);
static ImportPageImportPageSearchViewFilter* import_page_import_page_search_view_filter_construct (GType object_type);
static ImportPageHideImportedViewFilter* import_page_hide_imported_view_filter_new (void);
static ImportPageHideImportedViewFilter* import_page_hide_imported_view_filter_construct (GType object_type);
#define IMPORT_PAGE_UNMOUNT_FAILED_MSG _ ("Unable to unmount camera.  Try unmounting the camera from the file man" \
"ager.")
ImportPage* import_page_new (Camera* camera, const gchar* uri, const gchar* display_name, const gchar* icon);
ImportPage* import_page_construct (GType object_type, Camera* camera, const gchar* uri, const gchar* display_name, const gchar* icon);
CheckerboardPage* checkerboard_page_construct (GType object_type, const gchar* page_name);
ViewCollection* page_get_view (Page* self);
void page_set_page_name (Page* self, const gchar* page_name);
GPContextWrapper* gp_context_wrapper_new (void);
GPContextWrapper* gp_context_wrapper_construct (GType object_type);
GPSpinIdleWrapper* gp_spin_idle_wrapper_new (void);
GPSpinIdleWrapper* gp_spin_idle_wrapper_construct (GType object_type);
gpointer view_manager_ref (gpointer instance);
void view_manager_unref (gpointer instance);
GParamSpec* param_spec_view_manager (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_view_manager (GValue* value, gpointer v_object);
void value_take_view_manager (GValue* value, gpointer v_object);
gpointer value_get_view_manager (const GValue* value);
GType view_manager_get_type (void) G_GNUC_CONST;
gpointer view_collection_monitor_ref (gpointer instance);
void view_collection_monitor_unref (gpointer instance);
GParamSpec* view_collection_param_spec_monitor (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void view_collection_value_set_monitor (GValue* value, gpointer v_object);
void view_collection_value_take_monitor (GValue* value, gpointer v_object);
gpointer view_collection_value_get_monitor (const GValue* value);
GType view_collection_monitor_get_type (void) G_GNUC_CONST;
ViewCollectionMonitor* view_collection_monitor_source_collection (ViewCollection* self, SourceCollection* sources, ViewManager* manager, Alteration* prereq, GeeCollection* initial, ProgressMonitor progress_monitor, void* progress_monitor_target);
static ImportPageImportViewManager* import_page_import_view_manager_new (ImportPage* owner);
static ImportPageImportViewManager* import_page_import_view_manager_construct (GType object_type, ImportPage* owner);
static GType import_page_import_view_manager_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
void data_collection_set_comparator (DataCollection* self, Comparator comparator, void* comparator_target, ComparatorPredicate predicate, void* predicate_target);
static gint64 import_page_preview_comparator (void* a, void* b);
static gint64 _import_page_preview_comparator_comparator (void* a, void* b, gpointer self);
static gboolean import_page_preview_comparator_predicate (DataObject* object, Alteration* alteration);
static gboolean _import_page_preview_comparator_predicate_comparator_predicate (DataObject* object, Alteration* alteration, gpointer self);
static void import_page_on_view_changed (ImportPage* self);
static void _import_page_on_view_changed_view_collection_items_state_changed (ViewCollection* _sender, GeeIterable* changed, gpointer self);
static void _import_page_on_view_changed_data_collection_contents_altered (DataCollection* _sender, GeeIterable* added, GeeIterable* removed, gpointer self);
static void _import_page_on_view_changed_view_collection_items_visibility_changed (ViewCollection* _sender, GeeCollection* changed, gpointer self);
void data_collection_set_property (DataCollection* self, const gchar* name, GValue* val, ValueEqualFunc value_equals, void* value_equals_target);
#define CHECKERBOARD_ITEM_PROP_SHOW_SUBTITLES "show-subtitles"
void checkerboard_page_init_item_context_menu (CheckerboardPage* self, const gchar* path);
void checkerboard_page_init_page_context_menu (CheckerboardPage* self, const gchar* path);
static GtkToolbar* import_page_real_get_toolbar (Page* base);
GtkToolbar* page_get_toolbar (Page* self);
static void import_page_on_hide_imported (ImportPage* self);
static void _import_page_on_hide_imported_gtk_button_clicked (GtkButton* _sender, gpointer self);
GType configuration_facade_get_type (void) G_GNUC_CONST;
GType config_facade_get_type (void) G_GNUC_CONST;
ConfigFacade* config_facade_get_instance (void);
gboolean configuration_facade_get_hide_photos_already_imported (ConfigurationFacade* self);
GtkAction* page_get_action (Page* self, const gchar* name);
#define RESOURCES_IMPORT "shotwell-import"
#define RESOURCES_IMPORT_ALL "shotwell-import-all"
static void import_page_update_toolbar_state (ImportPage* self);
static CoreViewTracker* import_page_real_get_view_tracker (CheckerboardPage* base);
static gchar* import_page_real_get_view_empty_message (CheckerboardPage* base);
static gchar* import_page_real_get_filter_no_match_message (CheckerboardPage* base);
gboolean alteration_has_detail (Alteration* self, const gchar* subject, const gchar* detail);
static gint64 import_page_import_job_comparator (ImportPage* self, void* a, void* b);
gpointer batch_import_job_ref (gpointer instance);
void batch_import_job_unref (gpointer instance);
GParamSpec* param_spec_batch_import_job (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_batch_import_job (GValue* value, gpointer v_object);
void value_take_batch_import_job (GValue* value, gpointer v_object);
gpointer value_get_batch_import_job (const GValue* value);
GType batch_import_job_get_type (void) G_GNUC_CONST;
static GType import_page_camera_import_job_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
static time_t import_page_camera_import_job_get_exposure_time (ImportPageCameraImportJob* self);
static void import_page_real_init_collect_ui_filenames (Page* base, GeeList* ui_filenames);
void page_init_collect_ui_filenames (Page* self, GeeList* ui_filenames);
static GtkToggleActionEntry* import_page_real_init_collect_toggle_action_entries (Page* base, int* result_length1);
GtkToggleActionEntry* page_init_collect_toggle_action_entries (Page* self, int* result_length1);
#define TRANSLATABLE "translatable"
static void import_page_on_display_titles (ImportPage* self, GtkAction* action);
static void _import_page_on_display_titles_gtk_action_callback (GtkAction* action, gpointer self);
gboolean configuration_facade_get_display_photo_titles (ConfigurationFacade* self);
static void _vala_array_add143 (GtkToggleActionEntry** array, int* length, int* size, const GtkToggleActionEntry* value);
static GtkActionEntry* import_page_real_init_collect_action_entries (Page* base, int* result_length1);
GtkActionEntry* page_init_collect_action_entries (Page* self, int* result_length1);
static void import_page_on_import_selected (ImportPage* self);
static void _import_page_on_import_selected_gtk_action_callback (GtkAction* action, gpointer self);
static void _vala_array_add144 (GtkActionEntry** array, int* length, int* size, const GtkActionEntry* value);
static void import_page_on_import_all (ImportPage* self);
static void _import_page_on_import_all_gtk_action_callback (GtkAction* action, gpointer self);
static void _vala_array_add145 (GtkActionEntry** array, int* length, int* size, const GtkActionEntry* value);
Camera* import_page_get_camera (ImportPage* self);
gchar* import_page_get_uri (ImportPage* self);
gboolean import_page_is_busy (ImportPage* self);
static void import_page_real_init_actions (Page* base, gint selected_count, gint count);
void page_set_action_important (Page* self, const gchar* name, gboolean important);
void page_init_actions (Page* self, gint selected_count, gint count);
gboolean import_page_is_refreshed (ImportPage* self);
gchar* import_page_get_refresh_message (ImportPage* self);
static void import_page_update_status (ImportPage* self, gboolean busy, gboolean refreshed);
gint view_collection_get_unfiltered_count (ViewCollection* self);
gint view_collection_get_selected_count (ViewCollection* self);
void page_set_action_sensitive (Page* self, const gchar* name, gboolean sensitive);
gint data_collection_get_count (DataCollection* self);
GType app_window_get_type (void) G_GNUC_CONST;
AppWindow* app_window_get_instance (void);
void app_window_set_common_action_sensitive (AppWindow* self, const gchar* name, gboolean sensitive);
void checkerboard_page_set_display_titles (CheckerboardPage* self, gboolean display);
void configuration_facade_set_display_photo_titles (ConfigurationFacade* self, gboolean display);
static void import_page_real_switched_to (Page* base);
void page_switched_to (Page* self);
static void import_page_real_ready (Page* base);
static void import_page_try_refreshing_camera (ImportPage* self, gboolean fail_on_locked);
static ImportPageRefreshResult import_page_refresh_camera (ImportPage* self);
void app_window_error_message (const gchar* message, GtkWindow* parent);
#define RESOURCES_APP_TITLE "Shotwell"
void checkerboard_page_set_page_message (CheckerboardPage* self, const gchar* message);
gboolean import_page_unmount_camera (ImportPage* self, GMount* mount);
static void import_page_on_unmounted (ImportPage* self, GMount* mount);
static void _import_page_on_unmounted_g_mount_unmounted (GMount* _sender, gpointer self);
static void import_page_on_unmount_finished (ImportPage* self, GObject* source, GAsyncResult* aresult);
static void _import_page_on_unmount_finished_gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static void import_page_clear_all_import_sources (ImportPage* self);
Marker* data_collection_start_marking (DataCollection* self);
void marker_mark_all (Marker* self);
GType media_source_get_type (void) G_GNUC_CONST;
gint source_collection_destroy_marked (SourceCollection* self, Marker* marker, gboolean delete_backing, ProgressMonitor monitor, void* monitor_target, GeeList* not_removed);
static gboolean import_page_check_directory_exists (ImportPage* self, gint fsid, const gchar* dir, const gchar* search_target);
static gboolean import_page_enumerate_files (ImportPage* self, gint fsid, const gchar* dir, GeeArrayList* import_list);
static void import_page_auto_match_raw_jpeg (ImportPage* self, GeeArrayList* import_list);
static void import_page_load_previews_and_metadata (ImportPage* self, GeeList* import_list);
gchar* checkerboard_page_get_view_empty_message (CheckerboardPage* self);
static gchar* import_page_chomp_ch (const gchar* str, gchar ch);
gchar* import_page_append_path (const gchar* basepath, const gchar* addition);
gchar* import_page_get_fs_basedir (Camera* camera, gint fsid);
#define GP_MAX_BASEDIR_LENGTH 255
gboolean gp_get_info (GPContext* context, Camera* camera, const gchar* folder, const gchar* filename, CameraFileInfo* info, GError** error);
gboolean video_reader_is_supported_video_filename (const gchar* filename);
PhotoFileFormat photo_file_format_from_gphoto_type (const gchar* type);
PhotoFileFormat photo_file_format_get_by_basename_extension (const gchar* basename);
void spin_event_loop (void);
void disassemble_filename (const gchar* basename, gchar** name, gchar** ext);
PhotoMetadata* gp_load_metadata (GPContext* context, Camera* camera, const gchar* folder, const gchar* filename, GError** error);
guint8* photo_metadata_flatten_exif (PhotoMetadata* self, gboolean include_preview, int* result_length1);
gchar* md5_binary (guint8* buffer, gsize length);
GdkPixbuf* gp_load_preview (GPContext* context, Camera* camera, const gchar* folder, const gchar* filename, guint8** raw, int* raw_length1, gsize* raw_length, GError** error);
gboolean data_collection_add (DataCollection* self, DataObject* object);
void view_collection_install_view_filter (ViewCollection* self, ViewFilter* f);
void view_collection_remove_view_filter (ViewCollection* self, ViewFilter* f);
void configuration_facade_set_hide_photos_already_imported (ConfigurationFacade* self, gboolean hide_imported);
static void import_page_import (ImportPage* self, GeeIterable* items);
GeeList* view_collection_get_selected (ViewCollection* self);
GeeCollection* data_collection_get_all (DataCollection* self);
GType sorted_list_get_type (void) G_GNUC_CONST;
static gint64 _import_page_import_job_comparator_comparator (void* a, void* b, gpointer self);
SortedList* sorted_list_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, Comparator cmp, void* cmp_target);
SortedList* sorted_list_construct (GType object_type, GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, Comparator cmp, void* cmp_target);
static ImportPageCameraImportJob* import_page_camera_import_job_new (GPContextWrapper* context, ImportSource* import_file, DuplicatedFile* duplicated_file);
static ImportPageCameraImportJob* import_page_camera_import_job_construct (GType object_type, GPContextWrapper* context, ImportSource* import_file, DuplicatedFile* duplicated_file);
void batch_import_job_set_associated (BatchImportJob* self, BatchImportJob* associated);
GType batch_import_get_type (void) G_GNUC_CONST;
gpointer import_manifest_ref (gpointer instance);
void import_manifest_unref (gpointer instance);
GParamSpec* param_spec_import_manifest (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_import_manifest (GValue* value, gpointer v_object);
void value_take_import_manifest (GValue* value, gpointer v_object);
gpointer value_get_import_manifest (const GValue* value);
GType import_manifest_get_type (void) G_GNUC_CONST;
static void import_page_import_reporter (ImportPage* self, ImportManifest* manifest);
gpointer batch_import_roll_ref (gpointer instance);
void batch_import_roll_unref (gpointer instance);
GParamSpec* param_spec_batch_import_roll (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_batch_import_roll (GValue* value, gpointer v_object);
void value_take_batch_import_roll (GValue* value, gpointer v_object);
gpointer value_get_batch_import_roll (const GValue* value);
GType batch_import_roll_get_type (void) G_GNUC_CONST;
static void _import_page_import_reporter_batch_import_import_reporter (ImportManifest* manifest, BatchImportRoll* import_roll, gpointer self);
BatchImport* batch_import_new (GeeIterable* jobs, const gchar* name, BatchImportImportReporter reporter, void* reporter_target, GeeArrayList* prefailed, GeeArrayList* pre_already_imported, GCancellable* cancellable, BatchImportRoll* import_roll, ImportManifest* skip_manifest);
BatchImport* batch_import_construct (GType object_type, GeeIterable* jobs, const gchar* name, BatchImportImportReporter reporter, void* reporter_target, GeeArrayList* prefailed, GeeArrayList* pre_already_imported, GCancellable* cancellable, BatchImportRoll* import_roll, ImportManifest* skip_manifest);
gpointer batch_import_result_ref (gpointer instance);
void batch_import_result_unref (gpointer instance);
GParamSpec* param_spec_batch_import_result (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_batch_import_result (GValue* value, gpointer v_object);
void value_take_batch_import_result (GValue* value, gpointer v_object);
gpointer value_get_batch_import_result (const GValue* value);
GType batch_import_result_get_type (void) G_GNUC_CONST;
static void import_page_on_import_job_failed (ImportPage* self, BatchImportResult* _result_);
static void _import_page_on_import_job_failed_batch_import_import_job_failed (BatchImport* _sender, BatchImportResult* _result_, gpointer self);
static void import_page_close_import (ImportPage* self);
static void _import_page_close_import_batch_import_import_complete (BatchImport* _sender, ImportManifest* manifest, BatchImportRoll* import_roll, gpointer self);
GType library_window_get_type (void) G_GNUC_CONST;
LibraryWindow* library_window_get_app (void);
void library_window_enqueue_batch_import (LibraryWindow* self, BatchImport* batch_import, gboolean allow_user_cancel);
void library_window_switch_to_import_queue_page (LibraryWindow* self);
ImportManifest* import_manifest_new (GeeList* prefailed, GeeList* pre_already_imported);
ImportManifest* import_manifest_construct (GType object_type, GeeList* prefailed, GeeList* pre_already_imported);
GType import_result_get_type (void) G_GNUC_CONST;
gchar* import_ui_get_media_specific_string (GeeCollection* import_collection, const gchar* photos_msg, const gchar* videos_msg, const gchar* both_msg, const gchar* neither_msg);
gpointer import_ui_question_params_ref (gpointer instance);
void import_ui_question_params_unref (gpointer instance);
GParamSpec* import_ui_param_spec_question_params (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void import_ui_value_set_question_params (GValue* value, gpointer v_object);
void import_ui_value_take_question_params (GValue* value, gpointer v_object);
gpointer import_ui_value_get_question_params (const GValue* value);
GType import_ui_question_params_get_type (void) G_GNUC_CONST;
#define RESOURCES_DELETE_LABEL _ ("_Delete")
ImportUIQuestionParams* import_ui_question_params_new (const gchar* question, const gchar* yes_button, const gchar* no_button);
ImportUIQuestionParams* import_ui_question_params_construct (GType object_type, const gchar* question, const gchar* yes_button, const gchar* no_button);
gboolean import_ui_report_manifest (ImportManifest* manifest, gboolean show_dest_id, ImportUIQuestionParams* question);
void marker_mark (Marker* self, DataObject* object);
static ImportSource* import_page_camera_import_job_get_source (ImportPageCameraImportJob* self);
GType progress_dialog_get_type (void) G_GNUC_CONST;
ProgressDialog* progress_dialog_new (GtkWindow* owner, const gchar* text, GCancellable* cancellable);
ProgressDialog* progress_dialog_construct (GType object_type, GtkWindow* owner, const gchar* text, GCancellable* cancellable);
gboolean progress_dialog_monitor (ProgressDialog* self, guint64 count, guint64 total, gboolean do_event_loop);
static gboolean _progress_dialog_monitor_progress_monitor (guint64 current, guint64 total, gboolean do_event_loop, gpointer self);
void progress_dialog_close (ProgressDialog* self);
static void import_page_real_set_display_titles (CheckerboardPage* base, gboolean display);
static SearchViewFilter* import_page_real_get_search_view_filter (CheckerboardPage* base);
#define IMPORT_PAGE_IMPORT_VIEW_MANAGER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), IMPORT_PAGE_TYPE_IMPORT_VIEW_MANAGER, ImportPageImportViewManagerPrivate))
enum  {
	IMPORT_PAGE_IMPORT_VIEW_MANAGER_DUMMY_PROPERTY
};
ViewManager* view_manager_construct (GType object_type);
static DataView* import_page_import_view_manager_real_create_view (ViewManager* base, DataSource* source);
static void import_page_import_view_manager_finalize (ViewManager* obj);
gpointer backing_photo_row_ref (gpointer instance);
void backing_photo_row_unref (gpointer instance);
GParamSpec* param_spec_backing_photo_row (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_backing_photo_row (GValue* value, gpointer v_object);
void value_take_backing_photo_row (GValue* value, gpointer v_object);
gpointer value_get_backing_photo_row (const GValue* value);
GType backing_photo_row_get_type (void) G_GNUC_CONST;
#define IMPORT_PAGE_CAMERA_IMPORT_JOB_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), IMPORT_PAGE_TYPE_CAMERA_IMPORT_JOB, ImportPageCameraImportJobPrivate))
enum  {
	IMPORT_PAGE_CAMERA_IMPORT_JOB_DUMMY_PROPERTY
};
BatchImportJob* batch_import_job_construct (GType object_type);
static DuplicatedFile* import_page_camera_import_job_real_get_duplicated_file (BatchImportJob* base);
static time_t import_page_camera_import_job_real_get_exposure_time_override (BatchImportJob* base);
static gchar* import_page_camera_import_job_real_get_dest_identifier (BatchImportJob* base);
static gchar* import_page_camera_import_job_real_get_source_identifier (BatchImportJob* base);
static gchar* import_page_camera_import_job_real_get_basename (BatchImportJob* base);
static gchar* import_page_camera_import_job_real_get_path (BatchImportJob* base);
static void import_page_camera_import_job_real_set_associated (BatchImportJob* base, BatchImportJob* associated);
static gboolean import_page_camera_import_job_real_is_directory (BatchImportJob* base);
static gboolean import_page_camera_import_job_real_determine_file_size (BatchImportJob* base, guint64* filesize, GFile** file);
static gboolean import_page_camera_import_job_real_prepare (BatchImportJob* base, GFile** file_to_import, gboolean* copy_to_library, GError** error);
GFile* library_files_generate_unique_file (const gchar* basename, MediaMetadata* metadata, time_t ts, gboolean* collision, GError** error);
void library_monitor_blacklist_file (GFile* file, const gchar* reason);
void gp_save_image (GPContext* context, Camera* camera, const gchar* folder, const gchar* filename, GFile* dest_file, GError** error);
void library_monitor_unblacklist_file (GFile* file);
GType raw_developer_get_type (void) G_GNUC_CONST;
BackingPhotoRow* raw_developer_create_backing_row_for_development (RawDeveloper self, const gchar* raw_filepath, const gchar* camera_development_filename, GError** error);
gchar* batch_import_job_get_basename (BatchImportJob* self);
GType backing_photo_id_get_type (void) G_GNUC_CONST;
BackingPhotoID* backing_photo_id_dup (const BackingPhotoID* self);
void backing_photo_id_free (BackingPhotoID* self);
static gboolean import_page_camera_import_job_real_complete (BatchImportJob* base, MediaSource* source, BatchImportRoll* import_roll, GError** error);
GType photo_source_get_type (void) G_GNUC_CONST;
GType photo_get_type (void) G_GNUC_CONST;
void photo_add_backing_photo_for_development (Photo* self, RawDeveloper d, BackingPhotoRow* bpr, GError** error);
void photo_set_raw_developer (Photo* self, RawDeveloper d);
RawDeveloper configuration_facade_get_default_raw_developer (ConfigurationFacade* self);
static void import_page_camera_import_job_finalize (BatchImportJob* obj);
enum  {
	IMPORT_PAGE_IMPORT_PAGE_SEARCH_VIEW_FILTER_DUMMY_PROPERTY
};
static guint import_page_import_page_search_view_filter_real_get_criteria (SearchViewFilter* base);
GType search_filter_criteria_get_type (void) G_GNUC_CONST;
static gboolean import_page_import_page_search_view_filter_real_predicate (ViewFilter* base, DataView* view);
guint search_view_filter_get_criteria (SearchViewFilter* self);
gboolean search_view_filter_filter_by_media_type (SearchViewFilter* self);
gboolean search_view_filter_get_show_media_video (SearchViewFilter* self);
gboolean search_view_filter_get_show_media_photos (SearchViewFilter* self);
gboolean search_view_filter_get_show_media_raw (SearchViewFilter* self);
const gchar* indexable_get_indexable_keywords (Indexable* self);
gchar** search_view_filter_get_search_filter_words (SearchViewFilter* self, int* result_length1);
SearchViewFilter* search_view_filter_construct (GType object_type);
enum  {
	IMPORT_PAGE_HIDE_IMPORTED_VIEW_FILTER_DUMMY_PROPERTY
};
static gboolean import_page_hide_imported_view_filter_real_predicate (ViewFilter* base, DataView* view);
ViewFilter* view_filter_construct (GType object_type);
static void import_page_finalize (GObject* obj);


ImportSourceCollection* import_source_collection_construct (GType object_type, const gchar* name) {
	ImportSourceCollection* self = NULL;
	const gchar* _tmp0_ = NULL;
#line 8 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail (name != NULL, NULL);
#line 9 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = name;
#line 9 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self = (ImportSourceCollection*) source_collection_construct (object_type, _tmp0_);
#line 8 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return self;
#line 2098 "ImportPage.c"
}


ImportSourceCollection* import_source_collection_new (const gchar* name) {
#line 8 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return import_source_collection_construct (TYPE_IMPORT_SOURCE_COLLECTION, name);
#line 2105 "ImportPage.c"
}


static gboolean import_source_collection_real_holds_type_of_source (SourceCollection* base, DataSource* source) {
	ImportSourceCollection * self;
	gboolean result = FALSE;
	DataSource* _tmp0_ = NULL;
#line 12 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_IMPORT_SOURCE_COLLECTION, ImportSourceCollection);
#line 12 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail (IS_DATA_SOURCE (source), FALSE);
#line 13 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = source;
#line 13 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, TYPE_IMPORT_SOURCE);
#line 13 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 2123 "ImportPage.c"
}


static void import_source_collection_class_init (ImportSourceCollectionClass * klass) {
#line 7 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	import_source_collection_parent_class = g_type_class_peek_parent (klass);
#line 7 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	((SourceCollectionClass *) klass)->holds_type_of_source = import_source_collection_real_holds_type_of_source;
#line 2132 "ImportPage.c"
}


static void import_source_collection_instance_init (ImportSourceCollection * self) {
}


GType import_source_collection_get_type (void) {
	static volatile gsize import_source_collection_type_id__volatile = 0;
	if (g_once_init_enter (&import_source_collection_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (ImportSourceCollectionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) import_source_collection_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ImportSourceCollection), 0, (GInstanceInitFunc) import_source_collection_instance_init, NULL };
		GType import_source_collection_type_id;
		import_source_collection_type_id = g_type_register_static (TYPE_SOURCE_COLLECTION, "ImportSourceCollection", &g_define_type_info, 0);
		g_once_init_leave (&import_source_collection_type_id__volatile, import_source_collection_type_id);
	}
	return import_source_collection_type_id__volatile;
}


static gpointer _GPHOTO_REF_CAMERA0 (gpointer self) {
#line 31 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return self ? GPHOTO_REF_CAMERA (self) : NULL;
#line 2155 "ImportPage.c"
}


ImportSource* import_source_construct (GType object_type, const gchar* camera_name, Camera* camera, gint fsid, const gchar* folder, const gchar* filename, gulong file_size, time_t modification_time) {
	ImportSource * self = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	Camera* _tmp2_ = NULL;
	Camera* _tmp3_ = NULL;
	gint _tmp4_ = 0;
	const gchar* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	const gchar* _tmp7_ = NULL;
	gchar* _tmp8_ = NULL;
	gulong _tmp9_ = 0UL;
	time_t _tmp10_ = 0;
	const gchar* _tmp11_ = NULL;
	gchar* _tmp12_ = NULL;
#line 28 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail (camera_name != NULL, NULL);
#line 28 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail (camera != NULL, NULL);
#line 28 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail (folder != NULL, NULL);
#line 28 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail (filename != NULL, NULL);
#line 28 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self = (ImportSource*) thumbnail_source_construct (object_type, DATA_OBJECT_INVALID_OBJECT_ID);
#line 30 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = camera_name;
#line 30 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 30 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_free0 (self->priv->camera_name);
#line 30 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self->priv->camera_name = _tmp1_;
#line 31 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp2_ = camera;
#line 31 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp3_ = _GPHOTO_REF_CAMERA0 (_tmp2_);
#line 31 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_gp_camera_unref0 (self->priv->camera);
#line 31 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self->priv->camera = _tmp3_;
#line 32 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp4_ = fsid;
#line 32 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self->priv->fsid = _tmp4_;
#line 33 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp5_ = folder;
#line 33 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp6_ = g_strdup (_tmp5_);
#line 33 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_free0 (self->priv->folder);
#line 33 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self->priv->folder = _tmp6_;
#line 34 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp7_ = filename;
#line 34 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp8_ = g_strdup (_tmp7_);
#line 34 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_free0 (self->priv->filename);
#line 34 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self->priv->filename = _tmp8_;
#line 35 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp9_ = file_size;
#line 35 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self->priv->file_size = _tmp9_;
#line 36 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp10_ = modification_time;
#line 36 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self->priv->modification_time = _tmp10_;
#line 37 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp11_ = filename;
#line 37 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp12_ = indexable_prepare_indexable_string (_tmp11_);
#line 37 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_free0 (self->priv->indexable_keywords);
#line 37 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self->priv->indexable_keywords = _tmp12_;
#line 28 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return self;
#line 2238 "ImportPage.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 41 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return self ? g_object_ref (self) : NULL;
#line 2245 "ImportPage.c"
}


void import_source_set_preview (ImportSource* self, GdkPixbuf* preview) {
	GdkPixbuf* _tmp0_ = NULL;
	GdkPixbuf* _tmp1_ = NULL;
#line 40 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_if_fail (IS_IMPORT_SOURCE (self));
#line 40 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_if_fail ((preview == NULL) || GDK_IS_PIXBUF (preview));
#line 41 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = preview;
#line 41 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 41 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_object_unref0 (self->priv->preview);
#line 41 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self->priv->preview = _tmp1_;
#line 2264 "ImportPage.c"
}


gchar* import_source_get_camera_name (ImportSource* self) {
	gchar* result = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 44 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail (IS_IMPORT_SOURCE (self), NULL);
#line 45 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = self->priv->camera_name;
#line 45 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 45 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = _tmp1_;
#line 45 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 2282 "ImportPage.c"
}


Camera* import_source_get_camera (ImportSource* self) {
	Camera* result = NULL;
	Camera* _tmp0_ = NULL;
	Camera* _tmp1_ = NULL;
#line 48 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail (IS_IMPORT_SOURCE (self), NULL);
#line 49 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = self->priv->camera;
#line 49 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = _GPHOTO_REF_CAMERA0 (_tmp0_);
#line 49 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = _tmp1_;
#line 49 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 2300 "ImportPage.c"
}


gint import_source_get_fsid (ImportSource* self) {
	gint result = 0;
	gint _tmp0_ = 0;
#line 52 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail (IS_IMPORT_SOURCE (self), 0);
#line 53 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = self->priv->fsid;
#line 53 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = _tmp0_;
#line 53 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 2315 "ImportPage.c"
}


gchar* import_source_get_folder (ImportSource* self) {
	gchar* result = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 56 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail (IS_IMPORT_SOURCE (self), NULL);
#line 57 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = self->priv->folder;
#line 57 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 57 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = _tmp1_;
#line 57 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 2333 "ImportPage.c"
}


gchar* import_source_get_filename (ImportSource* self) {
	gchar* result = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 60 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail (IS_IMPORT_SOURCE (self), NULL);
#line 61 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = self->priv->filename;
#line 61 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 61 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = _tmp1_;
#line 61 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 2351 "ImportPage.c"
}


gulong import_source_get_filesize (ImportSource* self) {
	gulong result = 0UL;
	gulong _tmp0_ = 0UL;
#line 64 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail (IS_IMPORT_SOURCE (self), 0UL);
#line 65 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = self->priv->file_size;
#line 65 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = _tmp0_;
#line 65 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 2366 "ImportPage.c"
}


time_t import_source_get_modification_time (ImportSource* self) {
	time_t result = 0;
	time_t _tmp0_ = 0;
#line 68 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail (IS_IMPORT_SOURCE (self), 0);
#line 69 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = self->priv->modification_time;
#line 69 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = _tmp0_;
#line 69 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 2381 "ImportPage.c"
}


static GdkPixbuf* import_source_real_get_preview (ImportSource* self) {
	GdkPixbuf* result = NULL;
	GdkPixbuf* _tmp0_ = NULL;
	GdkPixbuf* _tmp1_ = NULL;
#line 73 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = self->priv->preview;
#line 73 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 73 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = _tmp1_;
#line 73 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 2397 "ImportPage.c"
}


GdkPixbuf* import_source_get_preview (ImportSource* self) {
#line 72 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail (IS_IMPORT_SOURCE (self), NULL);
#line 72 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return IMPORT_SOURCE_GET_CLASS (self)->get_preview (self);
#line 2406 "ImportPage.c"
}


static time_t import_source_real_get_exposure_time (ImportSource* self) {
	time_t result = 0;
	time_t _tmp0_ = 0;
#line 77 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = import_source_get_modification_time (self);
#line 77 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = _tmp0_;
#line 77 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 2419 "ImportPage.c"
}


time_t import_source_get_exposure_time (ImportSource* self) {
#line 76 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail (IS_IMPORT_SOURCE (self), 0);
#line 76 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return IMPORT_SOURCE_GET_CLASS (self)->get_exposure_time (self);
#line 2428 "ImportPage.c"
}


gchar* import_source_get_fulldir (ImportSource* self) {
	gchar* result = NULL;
	Camera* _tmp0_ = NULL;
	Camera* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gint _tmp4_ = 0;
	gchar* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
	gchar* _tmp8_ = NULL;
#line 80 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail (IS_IMPORT_SOURCE (self), NULL);
#line 81 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = import_source_get_camera (self);
#line 81 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = _tmp0_;
#line 81 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp2_ = import_source_get_camera_name (self);
#line 81 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp3_ = _tmp2_;
#line 81 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp4_ = import_source_get_fsid (self);
#line 81 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp5_ = import_source_get_folder (self);
#line 81 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp6_ = _tmp5_;
#line 81 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp7_ = import_page_get_fulldir (_tmp1_, _tmp3_, _tmp4_, _tmp6_);
#line 81 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp8_ = _tmp7_;
#line 81 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_free0 (_tmp6_);
#line 81 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_free0 (_tmp3_);
#line 81 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_gp_camera_unref0 (_tmp1_);
#line 81 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = _tmp8_;
#line 81 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 2473 "ImportPage.c"
}


static gchar* import_source_real_to_string (DataObject* base) {
	ImportSource * self;
	gchar* result = NULL;
	gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
#line 84 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_IMPORT_SOURCE, ImportSource);
#line 85 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = import_source_get_camera_name (self);
#line 85 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = _tmp0_;
#line 85 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp2_ = import_source_get_folder (self);
#line 85 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp3_ = _tmp2_;
#line 85 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp4_ = import_source_get_filename (self);
#line 85 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp5_ = _tmp4_;
#line 85 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp6_ = g_strdup_printf ("%s %s/%s", _tmp1_, _tmp3_, _tmp5_);
#line 85 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp7_ = _tmp6_;
#line 85 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_free0 (_tmp5_);
#line 85 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_free0 (_tmp3_);
#line 85 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_free0 (_tmp1_);
#line 85 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = _tmp7_;
#line 85 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 2516 "ImportPage.c"
}


static gchar* gp_result_to_full_string (int self) {
	gchar* result = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 480 "/home/jens/Source/shotwell/vapi/libgphoto2.vapi"
	_tmp0_ = gp_port_result_as_string (self);
#line 480 "/home/jens/Source/shotwell/vapi/libgphoto2.vapi"
	_tmp1_ = g_strdup_printf ("%s (%d)", _tmp0_, (gint) self);
#line 480 "/home/jens/Source/shotwell/vapi/libgphoto2.vapi"
	result = _tmp1_;
#line 480 "/home/jens/Source/shotwell/vapi/libgphoto2.vapi"
	return result;
#line 2532 "ImportPage.c"
}


static gboolean import_source_real_internal_delete_backing (DataSource* base, GError** error) {
	ImportSource * self;
	gboolean result = FALSE;
	gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	gchar* fulldir = NULL;
	gchar* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	int _result_ = 0;
	Camera* _tmp10_ = NULL;
	Camera* _tmp11_ = NULL;
	const gchar* _tmp12_ = NULL;
	gchar* _tmp13_ = NULL;
	gchar* _tmp14_ = NULL;
	GPSpinIdleWrapper* _tmp15_ = NULL;
	GPContext* _tmp16_ = NULL;
	int _tmp17_ = 0;
	int _tmp18_ = 0;
	int _tmp19_ = 0;
	gboolean _tmp26_ = FALSE;
	gboolean _tmp27_ = FALSE;
	gboolean _tmp28_ = FALSE;
	GError * _inner_error_ = NULL;
#line 88 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_IMPORT_SOURCE, ImportSource);
#line 89 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = data_object_to_string (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATA_OBJECT, DataObject));
#line 89 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = _tmp0_;
#line 89 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp2_ = self->priv->camera_name;
#line 89 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_debug ("ImportPage.vala:89: Deleting %s from %s", _tmp1_, _tmp2_);
#line 89 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_free0 (_tmp1_);
#line 91 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp3_ = import_source_get_fulldir (self);
#line 91 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	fulldir = _tmp3_;
#line 92 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp4_ = fulldir;
#line 92 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (_tmp4_ == NULL) {
#line 2580 "ImportPage.c"
		gchar* _tmp5_ = NULL;
		gchar* _tmp6_ = NULL;
		const gchar* _tmp7_ = NULL;
		gboolean _tmp8_ = FALSE;
		gboolean _tmp9_ = FALSE;
#line 93 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp5_ = data_object_to_string (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATA_OBJECT, DataObject));
#line 93 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp6_ = _tmp5_;
#line 93 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp7_ = self->priv->camera_name;
#line 93 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		g_warning ("ImportPage.vala:93: Skipping deleting %s from %s: invalid folder name", _tmp6_, _tmp7_);
#line 93 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_free0 (_tmp6_);
#line 95 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp9_ = DATA_SOURCE_CLASS (import_source_parent_class)->internal_delete_backing (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_THUMBNAIL_SOURCE, ThumbnailSource), TYPE_DATA_SOURCE, DataSource), &_inner_error_);
#line 95 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp8_ = _tmp9_;
#line 95 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 95 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			g_propagate_error (error, _inner_error_);
#line 95 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_g_free0 (fulldir);
#line 95 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			return FALSE;
#line 2608 "ImportPage.c"
		}
#line 95 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		result = _tmp8_;
#line 95 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_free0 (fulldir);
#line 95 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		return result;
#line 2616 "ImportPage.c"
	}
#line 98 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp10_ = import_source_get_camera (self);
#line 98 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp11_ = _tmp10_;
#line 98 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp12_ = fulldir;
#line 98 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp13_ = import_source_get_filename (self);
#line 98 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp14_ = _tmp13_;
#line 98 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp15_ = import_page_spin_idle_context;
#line 98 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp16_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp15_, GP_TYPE_CONTEXT_WRAPPER, GPContextWrapper)->context;
#line 98 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp17_ = gp_camera_file_delete (_tmp11_, _tmp12_, _tmp14_, _tmp16_);
#line 98 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp18_ = _tmp17_;
#line 98 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_free0 (_tmp14_);
#line 98 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_gp_camera_unref0 (_tmp11_);
#line 98 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_result_ = _tmp18_;
#line 100 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp19_ = _result_;
#line 100 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (_tmp19_ != GP_OK) {
#line 2646 "ImportPage.c"
		gchar* _tmp20_ = NULL;
		gchar* _tmp21_ = NULL;
		const gchar* _tmp22_ = NULL;
		int _tmp23_ = 0;
		gchar* _tmp24_ = NULL;
		gchar* _tmp25_ = NULL;
#line 101 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp20_ = data_object_to_string (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATA_OBJECT, DataObject));
#line 101 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp21_ = _tmp20_;
#line 101 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp22_ = self->priv->camera_name;
#line 101 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp23_ = _result_;
#line 101 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp24_ = gp_result_to_full_string (_tmp23_);
#line 101 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp25_ = _tmp24_;
#line 101 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		g_warning ("ImportPage.vala:101: Error deleting %s from %s: %s", _tmp21_, _tmp22_, _tmp25_);
#line 101 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_free0 (_tmp25_);
#line 101 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_free0 (_tmp21_);
#line 2671 "ImportPage.c"
	}
#line 103 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp28_ = DATA_SOURCE_CLASS (import_source_parent_class)->internal_delete_backing (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_THUMBNAIL_SOURCE, ThumbnailSource), TYPE_DATA_SOURCE, DataSource), &_inner_error_);
#line 103 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp27_ = _tmp28_;
#line 103 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 103 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		g_propagate_error (error, _inner_error_);
#line 103 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_free0 (fulldir);
#line 103 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		return FALSE;
#line 2685 "ImportPage.c"
	}
#line 103 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (_tmp27_) {
#line 2689 "ImportPage.c"
		int _tmp29_ = 0;
#line 103 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp29_ = _result_;
#line 103 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp26_ = _tmp29_ == GP_OK;
#line 2695 "ImportPage.c"
	} else {
#line 103 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp26_ = FALSE;
#line 2699 "ImportPage.c"
	}
#line 103 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = _tmp26_;
#line 103 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_free0 (fulldir);
#line 103 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 2707 "ImportPage.c"
}


static const gchar* import_source_real_get_indexable_keywords (Indexable* base) {
	ImportSource * self;
	const gchar* result = NULL;
	const gchar* _tmp0_ = NULL;
#line 106 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_IMPORT_SOURCE, ImportSource);
#line 107 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = self->priv->indexable_keywords;
#line 107 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = _tmp0_;
#line 107 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 2723 "ImportPage.c"
}


static void import_source_class_init (ImportSourceClass * klass) {
#line 17 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	import_source_parent_class = g_type_class_peek_parent (klass);
#line 17 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_type_class_add_private (klass, sizeof (ImportSourcePrivate));
#line 17 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	((ImportSourceClass *) klass)->get_preview = import_source_real_get_preview;
#line 17 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	((ImportSourceClass *) klass)->get_exposure_time = import_source_real_get_exposure_time;
#line 17 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	((DataObjectClass *) klass)->to_string = import_source_real_to_string;
#line 17 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	((DataSourceClass *) klass)->internal_delete_backing = import_source_real_internal_delete_backing;
#line 17 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	G_OBJECT_CLASS (klass)->finalize = import_source_finalize;
#line 2742 "ImportPage.c"
}


static void import_source_indexable_interface_init (IndexableIface * iface) {
#line 17 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	import_source_indexable_parent_iface = g_type_interface_peek_parent (iface);
#line 17 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	iface->get_indexable_keywords = (const gchar* (*)(Indexable*)) import_source_real_get_indexable_keywords;
#line 2751 "ImportPage.c"
}


static void import_source_instance_init (ImportSource * self) {
#line 17 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self->priv = IMPORT_SOURCE_GET_PRIVATE (self);
#line 25 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self->priv->preview = NULL;
#line 26 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self->priv->indexable_keywords = NULL;
#line 2762 "ImportPage.c"
}


static void import_source_finalize (GObject* obj) {
	ImportSource * self;
#line 17 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_IMPORT_SOURCE, ImportSource);
#line 18 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_free0 (self->priv->camera_name);
#line 19 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_gp_camera_unref0 (self->priv->camera);
#line 21 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_free0 (self->priv->folder);
#line 22 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_free0 (self->priv->filename);
#line 25 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_object_unref0 (self->priv->preview);
#line 26 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_free0 (self->priv->indexable_keywords);
#line 17 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	G_OBJECT_CLASS (import_source_parent_class)->finalize (obj);
#line 2784 "ImportPage.c"
}


GType import_source_get_type (void) {
	static volatile gsize import_source_type_id__volatile = 0;
	if (g_once_init_enter (&import_source_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (ImportSourceClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) import_source_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ImportSource), 0, (GInstanceInitFunc) import_source_instance_init, NULL };
		static const GInterfaceInfo indexable_info = { (GInterfaceInitFunc) import_source_indexable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType import_source_type_id;
		import_source_type_id = g_type_register_static (TYPE_THUMBNAIL_SOURCE, "ImportSource", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
		g_type_add_interface_static (import_source_type_id, TYPE_INDEXABLE, &indexable_info);
		g_once_init_leave (&import_source_type_id__volatile, import_source_type_id);
	}
	return import_source_type_id__volatile;
}


VideoImportSource* video_import_source_construct (GType object_type, const gchar* camera_name, Camera* camera, gint fsid, const gchar* folder, const gchar* filename, gulong file_size, time_t modification_time) {
	VideoImportSource * self = NULL;
	const gchar* _tmp0_ = NULL;
	Camera* _tmp1_ = NULL;
	gint _tmp2_ = 0;
	const gchar* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	gulong _tmp5_ = 0UL;
	time_t _tmp6_ = 0;
#line 112 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail (camera_name != NULL, NULL);
#line 112 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail (camera != NULL, NULL);
#line 112 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail (folder != NULL, NULL);
#line 112 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail (filename != NULL, NULL);
#line 114 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = camera_name;
#line 114 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = camera;
#line 114 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp2_ = fsid;
#line 114 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp3_ = folder;
#line 114 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp4_ = filename;
#line 114 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp5_ = file_size;
#line 114 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp6_ = modification_time;
#line 114 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self = (VideoImportSource*) import_source_construct (object_type, _tmp0_, _tmp1_, _tmp2_, _tmp3_, _tmp4_, _tmp5_, _tmp6_);
#line 112 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return self;
#line 2837 "ImportPage.c"
}


VideoImportSource* video_import_source_new (const gchar* camera_name, Camera* camera, gint fsid, const gchar* folder, const gchar* filename, gulong file_size, time_t modification_time) {
#line 112 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return video_import_source_construct (TYPE_VIDEO_IMPORT_SOURCE, camera_name, camera, fsid, folder, filename, file_size, modification_time);
#line 2844 "ImportPage.c"
}


static GdkPixbuf* video_import_source_real_get_thumbnail (ThumbnailSource* base, gint scale, GError** error) {
	VideoImportSource * self;
	GdkPixbuf* result = NULL;
	GdkPixbuf* _tmp0_ = NULL;
	gint _tmp1_ = 0;
	GdkPixbuf* _tmp2_ = NULL;
	GdkPixbuf* _tmp3_ = NULL;
	GError * _inner_error_ = NULL;
#line 117 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_VIDEO_IMPORT_SOURCE, VideoImportSource);
#line 118 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = scale;
#line 118 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp2_ = thumbnail_source_create_thumbnail (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_THUMBNAIL_SOURCE, ThumbnailSource), _tmp1_, &_inner_error_);
#line 118 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = _tmp2_;
#line 118 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 118 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		g_propagate_error (error, _inner_error_);
#line 118 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		return NULL;
#line 2870 "ImportPage.c"
	}
#line 118 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp3_ = _tmp0_;
#line 118 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = NULL;
#line 118 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = _tmp3_;
#line 118 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_object_unref0 (_tmp0_);
#line 118 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 2882 "ImportPage.c"
}


static GdkPixbuf* video_import_source_real_create_thumbnail (ThumbnailSource* base, gint scale, GError** error) {
	VideoImportSource * self;
	GdkPixbuf* result = NULL;
	GdkPixbuf* _tmp0_ = NULL;
	GdkPixbuf* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	GdkPixbuf* _tmp3_ = NULL;
	gint _tmp4_ = 0;
#line 121 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_VIDEO_IMPORT_SOURCE, VideoImportSource);
#line 122 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = import_source_get_preview (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_IMPORT_SOURCE, ImportSource));
#line 122 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = _tmp0_;
#line 122 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp2_ = _tmp1_ == NULL;
#line 122 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_object_unref0 (_tmp1_);
#line 122 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (_tmp2_) {
#line 123 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		result = NULL;
#line 123 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		return result;
#line 2910 "ImportPage.c"
	}
#line 127 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp4_ = scale;
#line 127 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (_tmp4_ > 0) {
#line 2916 "ImportPage.c"
		GdkPixbuf* _tmp5_ = NULL;
		GdkPixbuf* _tmp6_ = NULL;
		gint _tmp7_ = 0;
		GdkPixbuf* _tmp8_ = NULL;
#line 127 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp5_ = import_source_get_preview (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_IMPORT_SOURCE, ImportSource));
#line 127 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp6_ = _tmp5_;
#line 127 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp7_ = scale;
#line 127 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp8_ = scale_pixbuf (_tmp6_, _tmp7_, GDK_INTERP_BILINEAR, TRUE);
#line 127 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_object_unref0 (_tmp3_);
#line 127 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp3_ = _tmp8_;
#line 127 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_object_unref0 (_tmp6_);
#line 2935 "ImportPage.c"
	} else {
		GdkPixbuf* _tmp9_ = NULL;
#line 128 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp9_ = import_source_get_preview (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_IMPORT_SOURCE, ImportSource));
#line 128 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_object_unref0 (_tmp3_);
#line 128 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp3_ = _tmp9_;
#line 2944 "ImportPage.c"
	}
#line 127 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = _tmp3_;
#line 127 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 2950 "ImportPage.c"
}


static gchar* video_import_source_real_get_typename (DataSource* base) {
	VideoImportSource * self;
	gchar* result = NULL;
	gchar* _tmp0_ = NULL;
#line 131 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_VIDEO_IMPORT_SOURCE, VideoImportSource);
#line 132 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = g_strdup ("videoimport");
#line 132 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = _tmp0_;
#line 132 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 2966 "ImportPage.c"
}


static gint64 video_import_source_real_get_instance_id (DataSource* base) {
	VideoImportSource * self;
	gint64 result = 0LL;
	gint64 _tmp0_ = 0LL;
#line 135 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_VIDEO_IMPORT_SOURCE, VideoImportSource);
#line 136 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = data_object_get_object_id (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATA_OBJECT, DataObject));
#line 136 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = _tmp0_;
#line 136 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 2982 "ImportPage.c"
}


static PhotoFileFormat video_import_source_real_get_preferred_thumbnail_format (ThumbnailSource* base) {
	VideoImportSource * self;
	PhotoFileFormat result = 0;
	PhotoFileFormat _tmp0_ = 0;
#line 139 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_VIDEO_IMPORT_SOURCE, VideoImportSource);
#line 140 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = photo_file_format_get_system_default_format ();
#line 140 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = _tmp0_;
#line 140 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 2998 "ImportPage.c"
}


static gchar* video_import_source_real_get_name (DataObject* base) {
	VideoImportSource * self;
	gchar* result = NULL;
	gchar* _tmp0_ = NULL;
#line 143 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_VIDEO_IMPORT_SOURCE, VideoImportSource);
#line 144 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = import_source_get_filename (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_IMPORT_SOURCE, ImportSource));
#line 144 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = _tmp0_;
#line 144 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 3014 "ImportPage.c"
}


void video_import_source_update (VideoImportSource* self, GdkPixbuf* preview) {
	GdkPixbuf* _tmp0_ = NULL;
	GdkPixbuf* _tmp1_ = NULL;
#line 147 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_if_fail (IS_VIDEO_IMPORT_SOURCE (self));
#line 147 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_if_fail ((preview == NULL) || GDK_IS_PIXBUF (preview));
#line 148 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = preview;
#line 148 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (_tmp1_ != NULL) {
#line 3029 "ImportPage.c"
		GdkPixbuf* _tmp2_ = NULL;
		GdkPixbuf* _tmp3_ = NULL;
#line 148 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp2_ = preview;
#line 148 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp3_ = _g_object_ref0 (_tmp2_);
#line 148 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_object_unref0 (_tmp0_);
#line 148 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp0_ = _tmp3_;
#line 3040 "ImportPage.c"
	} else {
		GdkPixbuf* _tmp4_ = NULL;
#line 148 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp4_ = resources_get_noninterpretable_badge_pixbuf ();
#line 148 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_object_unref0 (_tmp0_);
#line 148 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp0_ = _tmp4_;
#line 3049 "ImportPage.c"
	}
#line 148 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	import_source_set_preview (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_IMPORT_SOURCE, ImportSource), _tmp0_);
#line 147 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_object_unref0 (_tmp0_);
#line 3055 "ImportPage.c"
}


static void video_import_source_class_init (VideoImportSourceClass * klass) {
#line 111 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	video_import_source_parent_class = g_type_class_peek_parent (klass);
#line 111 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	((ThumbnailSourceClass *) klass)->get_thumbnail = video_import_source_real_get_thumbnail;
#line 111 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	((ThumbnailSourceClass *) klass)->create_thumbnail = video_import_source_real_create_thumbnail;
#line 111 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	((DataSourceClass *) klass)->get_typename = video_import_source_real_get_typename;
#line 111 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	((DataSourceClass *) klass)->get_instance_id = video_import_source_real_get_instance_id;
#line 111 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	((ThumbnailSourceClass *) klass)->get_preferred_thumbnail_format = video_import_source_real_get_preferred_thumbnail_format;
#line 111 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	((DataObjectClass *) klass)->get_name = video_import_source_real_get_name;
#line 3074 "ImportPage.c"
}


static void video_import_source_instance_init (VideoImportSource * self) {
}


GType video_import_source_get_type (void) {
	static volatile gsize video_import_source_type_id__volatile = 0;
	if (g_once_init_enter (&video_import_source_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (VideoImportSourceClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) video_import_source_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (VideoImportSource), 0, (GInstanceInitFunc) video_import_source_instance_init, NULL };
		GType video_import_source_type_id;
		video_import_source_type_id = g_type_register_static (TYPE_IMPORT_SOURCE, "VideoImportSource", &g_define_type_info, 0);
		g_once_init_leave (&video_import_source_type_id__volatile, video_import_source_type_id);
	}
	return video_import_source_type_id__volatile;
}


PhotoImportSource* photo_import_source_construct (GType object_type, const gchar* camera_name, Camera* camera, gint fsid, const gchar* folder, const gchar* filename, gulong file_size, time_t modification_time, PhotoFileFormat file_format) {
	PhotoImportSource * self = NULL;
	const gchar* _tmp0_ = NULL;
	Camera* _tmp1_ = NULL;
	gint _tmp2_ = 0;
	const gchar* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	gulong _tmp5_ = 0UL;
	time_t _tmp6_ = 0;
	PhotoFileFormat _tmp7_ = 0;
#line 161 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail (camera_name != NULL, NULL);
#line 161 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail (camera != NULL, NULL);
#line 161 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail (folder != NULL, NULL);
#line 161 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail (filename != NULL, NULL);
#line 163 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = camera_name;
#line 163 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = camera;
#line 163 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp2_ = fsid;
#line 163 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp3_ = folder;
#line 163 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp4_ = filename;
#line 163 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp5_ = file_size;
#line 163 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp6_ = modification_time;
#line 163 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self = (PhotoImportSource*) import_source_construct (object_type, _tmp0_, _tmp1_, _tmp2_, _tmp3_, _tmp4_, _tmp5_, _tmp6_);
#line 164 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp7_ = file_format;
#line 164 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self->priv->file_format = _tmp7_;
#line 161 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return self;
#line 3134 "ImportPage.c"
}


PhotoImportSource* photo_import_source_new (const gchar* camera_name, Camera* camera, gint fsid, const gchar* folder, const gchar* filename, gulong file_size, time_t modification_time, PhotoFileFormat file_format) {
#line 161 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return photo_import_source_construct (TYPE_PHOTO_IMPORT_SOURCE, camera_name, camera, fsid, folder, filename, file_size, modification_time, file_format);
#line 3141 "ImportPage.c"
}


static gchar* photo_import_source_real_get_name (DataObject* base) {
	PhotoImportSource * self;
	gchar* result = NULL;
	gchar* title = NULL;
	gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	gboolean _tmp3_ = FALSE;
#line 167 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_PHOTO_IMPORT_SOURCE, PhotoImportSource);
#line 168 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = photo_import_source_get_title (self);
#line 168 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	title = _tmp0_;
#line 170 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp2_ = title;
#line 170 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp3_ = is_string_empty (_tmp2_);
#line 170 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (!_tmp3_) {
#line 3165 "ImportPage.c"
		const gchar* _tmp4_ = NULL;
		gchar* _tmp5_ = NULL;
#line 170 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp4_ = title;
#line 170 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp5_ = g_strdup (_tmp4_);
#line 170 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_free0 (_tmp1_);
#line 170 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp1_ = _tmp5_;
#line 3176 "ImportPage.c"
	} else {
		gchar* _tmp6_ = NULL;
#line 170 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp6_ = import_source_get_filename (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_IMPORT_SOURCE, ImportSource));
#line 170 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_free0 (_tmp1_);
#line 170 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp1_ = _tmp6_;
#line 3185 "ImportPage.c"
	}
#line 170 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = _tmp1_;
#line 170 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_free0 (title);
#line 170 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 3193 "ImportPage.c"
}


static gchar* photo_import_source_real_get_typename (DataSource* base) {
	PhotoImportSource * self;
	gchar* result = NULL;
	gchar* _tmp0_ = NULL;
#line 173 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_PHOTO_IMPORT_SOURCE, PhotoImportSource);
#line 174 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = g_strdup ("photoimport");
#line 174 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = _tmp0_;
#line 174 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 3209 "ImportPage.c"
}


static gint64 photo_import_source_real_get_instance_id (DataSource* base) {
	PhotoImportSource * self;
	gint64 result = 0LL;
	gint64 _tmp0_ = 0LL;
#line 177 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_PHOTO_IMPORT_SOURCE, PhotoImportSource);
#line 178 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = data_object_get_object_id (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATA_OBJECT, DataObject));
#line 178 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = _tmp0_;
#line 178 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 3225 "ImportPage.c"
}


static PhotoFileFormat photo_import_source_real_get_preferred_thumbnail_format (ThumbnailSource* base) {
	PhotoImportSource * self;
	PhotoFileFormat result = 0;
	PhotoFileFormat _tmp0_ = 0;
	PhotoFileFormat _tmp1_ = 0;
	gboolean _tmp2_ = FALSE;
#line 181 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_PHOTO_IMPORT_SOURCE, PhotoImportSource);
#line 182 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = self->priv->file_format;
#line 182 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp2_ = photo_file_format_can_write (_tmp1_);
#line 182 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (_tmp2_) {
#line 3243 "ImportPage.c"
		PhotoFileFormat _tmp3_ = 0;
#line 182 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp3_ = self->priv->file_format;
#line 182 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp0_ = _tmp3_;
#line 3249 "ImportPage.c"
	} else {
		PhotoFileFormat _tmp4_ = 0;
#line 183 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp4_ = photo_file_format_get_system_default_format ();
#line 183 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp0_ = _tmp4_;
#line 3256 "ImportPage.c"
	}
#line 182 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = _tmp0_;
#line 182 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 3262 "ImportPage.c"
}


static GdkPixbuf* photo_import_source_real_create_thumbnail (ThumbnailSource* base, gint scale, GError** error) {
	PhotoImportSource * self;
	GdkPixbuf* result = NULL;
	GdkPixbuf* _tmp0_ = NULL;
	GdkPixbuf* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	GdkPixbuf* _tmp3_ = NULL;
	gint _tmp4_ = 0;
#line 186 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_PHOTO_IMPORT_SOURCE, PhotoImportSource);
#line 187 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = import_source_get_preview (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_IMPORT_SOURCE, ImportSource));
#line 187 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = _tmp0_;
#line 187 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp2_ = _tmp1_ == NULL;
#line 187 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_object_unref0 (_tmp1_);
#line 187 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (_tmp2_) {
#line 188 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		result = NULL;
#line 188 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		return result;
#line 3290 "ImportPage.c"
	}
#line 192 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp4_ = scale;
#line 192 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (_tmp4_ > 0) {
#line 3296 "ImportPage.c"
		GdkPixbuf* _tmp5_ = NULL;
		GdkPixbuf* _tmp6_ = NULL;
		gint _tmp7_ = 0;
		GdkPixbuf* _tmp8_ = NULL;
#line 192 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp5_ = import_source_get_preview (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_IMPORT_SOURCE, ImportSource));
#line 192 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp6_ = _tmp5_;
#line 192 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp7_ = scale;
#line 192 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp8_ = scale_pixbuf (_tmp6_, _tmp7_, PHOTO_IMPORT_SOURCE_INTERP, TRUE);
#line 192 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_object_unref0 (_tmp3_);
#line 192 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp3_ = _tmp8_;
#line 192 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_object_unref0 (_tmp6_);
#line 3315 "ImportPage.c"
	} else {
		GdkPixbuf* _tmp9_ = NULL;
#line 192 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp9_ = import_source_get_preview (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_IMPORT_SOURCE, ImportSource));
#line 192 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_object_unref0 (_tmp3_);
#line 192 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp3_ = _tmp9_;
#line 3324 "ImportPage.c"
	}
#line 192 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = _tmp3_;
#line 192 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 3330 "ImportPage.c"
}


static gpointer _media_metadata_ref0 (gpointer self) {
#line 199 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return self ? media_metadata_ref (self) : NULL;
#line 3337 "ImportPage.c"
}


void photo_import_source_update (PhotoImportSource* self, GdkPixbuf* preview, const gchar* preview_md5, PhotoMetadata* metadata, const gchar* exif_md5) {
	GdkPixbuf* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	PhotoMetadata* _tmp3_ = NULL;
	PhotoMetadata* _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
#line 196 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_if_fail (IS_PHOTO_IMPORT_SOURCE (self));
#line 196 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_if_fail ((preview == NULL) || GDK_IS_PIXBUF (preview));
#line 196 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_if_fail ((metadata == NULL) || IS_PHOTO_METADATA (metadata));
#line 197 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = preview;
#line 197 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	import_source_set_preview (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_IMPORT_SOURCE, ImportSource), _tmp0_);
#line 198 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = preview_md5;
#line 198 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp2_ = g_strdup (_tmp1_);
#line 198 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_free0 (self->priv->preview_md5);
#line 198 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self->priv->preview_md5 = _tmp2_;
#line 199 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp3_ = metadata;
#line 199 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp4_ = _media_metadata_ref0 (_tmp3_);
#line 199 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_media_metadata_unref0 (self->priv->metadata);
#line 199 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self->priv->metadata = _tmp4_;
#line 200 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp5_ = exif_md5;
#line 200 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp6_ = g_strdup (_tmp5_);
#line 200 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_free0 (self->priv->exif_md5);
#line 200 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self->priv->exif_md5 = _tmp6_;
#line 3383 "ImportPage.c"
}


static time_t photo_import_source_real_get_exposure_time (ImportSource* base) {
	PhotoImportSource * self;
	time_t result = 0;
	PhotoMetadata* _tmp0_ = NULL;
	MetadataDateTime* date_time = NULL;
	PhotoMetadata* _tmp2_ = NULL;
	MetadataDateTime* _tmp3_ = NULL;
	time_t _tmp4_ = 0;
	MetadataDateTime* _tmp5_ = NULL;
#line 203 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_PHOTO_IMPORT_SOURCE, PhotoImportSource);
#line 204 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = self->priv->metadata;
#line 204 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (_tmp0_ == NULL) {
#line 3402 "ImportPage.c"
		time_t _tmp1_ = 0;
#line 205 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp1_ = import_source_get_modification_time (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_IMPORT_SOURCE, ImportSource));
#line 205 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		result = _tmp1_;
#line 205 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		return result;
#line 3410 "ImportPage.c"
	}
#line 207 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp2_ = self->priv->metadata;
#line 207 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp3_ = photo_metadata_get_exposure_date_time (_tmp2_);
#line 207 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	date_time = _tmp3_;
#line 209 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp5_ = date_time;
#line 209 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (_tmp5_ != NULL) {
#line 3422 "ImportPage.c"
		MetadataDateTime* _tmp6_ = NULL;
		time_t _tmp7_ = 0;
#line 209 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp6_ = date_time;
#line 209 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp7_ = metadata_date_time_get_timestamp (_tmp6_);
#line 209 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp4_ = _tmp7_;
#line 3431 "ImportPage.c"
	} else {
		time_t _tmp8_ = 0;
#line 209 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp8_ = import_source_get_modification_time (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_IMPORT_SOURCE, ImportSource));
#line 209 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp4_ = _tmp8_;
#line 3438 "ImportPage.c"
	}
#line 209 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = _tmp4_;
#line 209 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_metadata_date_time_unref0 (date_time);
#line 209 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 3446 "ImportPage.c"
}


gchar* photo_import_source_get_title (PhotoImportSource* self) {
	gchar* result = NULL;
	gchar* _tmp0_ = NULL;
	PhotoMetadata* _tmp1_ = NULL;
#line 212 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail (IS_PHOTO_IMPORT_SOURCE (self), NULL);
#line 213 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = self->priv->metadata;
#line 213 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (_tmp1_ != NULL) {
#line 3460 "ImportPage.c"
		PhotoMetadata* _tmp2_ = NULL;
		gchar* _tmp3_ = NULL;
#line 213 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp2_ = self->priv->metadata;
#line 213 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp3_ = media_metadata_get_title (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, TYPE_MEDIA_METADATA, MediaMetadata));
#line 213 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_free0 (_tmp0_);
#line 213 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp0_ = _tmp3_;
#line 3471 "ImportPage.c"
	} else {
#line 213 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_free0 (_tmp0_);
#line 213 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp0_ = NULL;
#line 3477 "ImportPage.c"
	}
#line 213 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = _tmp0_;
#line 213 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 3483 "ImportPage.c"
}


PhotoMetadata* photo_import_source_get_metadata (PhotoImportSource* self) {
	PhotoMetadata* result = NULL;
	PhotoImportSource* _tmp0_ = NULL;
	PhotoMetadata* _tmp3_ = NULL;
	PhotoMetadata* _tmp4_ = NULL;
#line 216 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail (IS_PHOTO_IMPORT_SOURCE (self), NULL);
#line 217 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = self->priv->associated;
#line 217 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (_tmp0_ != NULL) {
#line 3498 "ImportPage.c"
		PhotoImportSource* _tmp1_ = NULL;
		PhotoMetadata* _tmp2_ = NULL;
#line 218 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp1_ = self->priv->associated;
#line 218 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp2_ = photo_import_source_get_metadata (_tmp1_);
#line 218 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		result = _tmp2_;
#line 218 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		return result;
#line 3509 "ImportPage.c"
	}
#line 220 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp3_ = self->priv->metadata;
#line 220 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp4_ = _media_metadata_ref0 (_tmp3_);
#line 220 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = _tmp4_;
#line 220 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 3519 "ImportPage.c"
}


static GdkPixbuf* photo_import_source_real_get_preview (ImportSource* base) {
	PhotoImportSource * self;
	GdkPixbuf* result = NULL;
	PhotoImportSource* _tmp0_ = NULL;
	GdkPixbuf* _tmp3_ = NULL;
	GdkPixbuf* _tmp4_ = NULL;
	gboolean _tmp5_ = FALSE;
#line 223 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_PHOTO_IMPORT_SOURCE, PhotoImportSource);
#line 224 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = self->priv->associated;
#line 224 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (_tmp0_ != NULL) {
#line 3536 "ImportPage.c"
		PhotoImportSource* _tmp1_ = NULL;
		GdkPixbuf* _tmp2_ = NULL;
#line 225 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp1_ = self->priv->associated;
#line 225 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp2_ = import_source_get_preview (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, TYPE_IMPORT_SOURCE, ImportSource));
#line 225 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		result = _tmp2_;
#line 225 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		return result;
#line 3547 "ImportPage.c"
	}
#line 227 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp3_ = IMPORT_SOURCE_CLASS (photo_import_source_parent_class)->get_preview (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_IMPORT_SOURCE, ImportSource));
#line 227 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp4_ = _tmp3_;
#line 227 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp5_ = _tmp4_ != NULL;
#line 227 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_object_unref0 (_tmp4_);
#line 227 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (_tmp5_) {
#line 3559 "ImportPage.c"
		GdkPixbuf* _tmp6_ = NULL;
#line 228 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp6_ = IMPORT_SOURCE_CLASS (photo_import_source_parent_class)->get_preview (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_IMPORT_SOURCE, ImportSource));
#line 228 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		result = _tmp6_;
#line 228 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		return result;
#line 3567 "ImportPage.c"
	}
#line 230 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = NULL;
#line 230 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 3573 "ImportPage.c"
}


static GdkPixbuf* photo_import_source_real_get_thumbnail (ThumbnailSource* base, gint scale, GError** error) {
	PhotoImportSource * self;
	GdkPixbuf* result = NULL;
	GdkPixbuf* _tmp0_ = NULL;
	GdkPixbuf* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	GdkPixbuf* _tmp3_ = NULL;
	gint _tmp4_ = 0;
#line 233 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_PHOTO_IMPORT_SOURCE, PhotoImportSource);
#line 234 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = import_source_get_preview (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_IMPORT_SOURCE, ImportSource));
#line 234 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = _tmp0_;
#line 234 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp2_ = _tmp1_ == NULL;
#line 234 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_object_unref0 (_tmp1_);
#line 234 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (_tmp2_) {
#line 235 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		result = NULL;
#line 235 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		return result;
#line 3601 "ImportPage.c"
	}
#line 237 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp4_ = scale;
#line 237 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (_tmp4_ > 0) {
#line 3607 "ImportPage.c"
		GdkPixbuf* _tmp5_ = NULL;
		GdkPixbuf* _tmp6_ = NULL;
		gint _tmp7_ = 0;
		GdkPixbuf* _tmp8_ = NULL;
#line 237 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp5_ = import_source_get_preview (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_IMPORT_SOURCE, ImportSource));
#line 237 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp6_ = _tmp5_;
#line 237 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp7_ = scale;
#line 237 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp8_ = scale_pixbuf (_tmp6_, _tmp7_, PHOTO_IMPORT_SOURCE_INTERP, TRUE);
#line 237 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_object_unref0 (_tmp3_);
#line 237 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp3_ = _tmp8_;
#line 237 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_object_unref0 (_tmp6_);
#line 3626 "ImportPage.c"
	} else {
		GdkPixbuf* _tmp9_ = NULL;
#line 237 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp9_ = import_source_get_preview (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_IMPORT_SOURCE, ImportSource));
#line 237 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_object_unref0 (_tmp3_);
#line 237 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp3_ = _tmp9_;
#line 3635 "ImportPage.c"
	}
#line 237 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = _tmp3_;
#line 237 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 3641 "ImportPage.c"
}


PhotoFileFormat photo_import_source_get_file_format (PhotoImportSource* self) {
	PhotoFileFormat result = 0;
	PhotoFileFormat _tmp0_ = 0;
#line 240 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail (IS_PHOTO_IMPORT_SOURCE (self), 0);
#line 241 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = self->priv->file_format;
#line 241 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = _tmp0_;
#line 241 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 3656 "ImportPage.c"
}


gchar* photo_import_source_get_preview_md5 (PhotoImportSource* self) {
	gchar* result = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 244 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail (IS_PHOTO_IMPORT_SOURCE (self), NULL);
#line 245 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = self->priv->preview_md5;
#line 245 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 245 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = _tmp1_;
#line 245 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 3674 "ImportPage.c"
}


void photo_import_source_set_associated (PhotoImportSource* self, PhotoImportSource* associated) {
	PhotoImportSource* _tmp0_ = NULL;
	PhotoImportSource* _tmp1_ = NULL;
#line 248 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_if_fail (IS_PHOTO_IMPORT_SOURCE (self));
#line 248 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_if_fail ((associated == NULL) || IS_PHOTO_IMPORT_SOURCE (associated));
#line 249 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = associated;
#line 249 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 249 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_object_unref0 (self->priv->associated);
#line 249 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self->priv->associated = _tmp1_;
#line 3693 "ImportPage.c"
}


PhotoImportSource* photo_import_source_get_associated (PhotoImportSource* self) {
	PhotoImportSource* result = NULL;
	PhotoImportSource* _tmp0_ = NULL;
	PhotoImportSource* _tmp1_ = NULL;
#line 252 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail (IS_PHOTO_IMPORT_SOURCE (self), NULL);
#line 253 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = self->priv->associated;
#line 253 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 253 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = _tmp1_;
#line 253 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 3711 "ImportPage.c"
}


static gboolean photo_import_source_real_internal_delete_backing (DataSource* base, GError** error) {
	PhotoImportSource * self;
	gboolean result = FALSE;
	gboolean ret = FALSE;
	gboolean _tmp0_ = FALSE;
	PhotoImportSource* _tmp1_ = NULL;
	GError * _inner_error_ = NULL;
#line 256 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_PHOTO_IMPORT_SOURCE, PhotoImportSource);
#line 257 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = DATA_SOURCE_CLASS (photo_import_source_parent_class)->internal_delete_backing (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_IMPORT_SOURCE, ImportSource), TYPE_DATA_SOURCE, DataSource), &_inner_error_);
#line 257 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	ret = _tmp0_;
#line 257 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 257 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		g_propagate_error (error, _inner_error_);
#line 257 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		return FALSE;
#line 3734 "ImportPage.c"
	}
#line 258 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = self->priv->associated;
#line 258 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (_tmp1_ != NULL) {
#line 3740 "ImportPage.c"
		gboolean _tmp2_ = FALSE;
		PhotoImportSource* _tmp3_ = NULL;
		gboolean _tmp4_ = FALSE;
		gboolean _tmp5_ = FALSE;
#line 259 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp3_ = self->priv->associated;
#line 259 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp4_ = data_source_internal_delete_backing (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, TYPE_DATA_SOURCE, DataSource), &_inner_error_);
#line 259 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp2_ = _tmp4_;
#line 259 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 259 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			g_propagate_error (error, _inner_error_);
#line 259 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			return FALSE;
#line 3757 "ImportPage.c"
		}
#line 259 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp5_ = ret;
#line 259 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		ret = _tmp5_ & _tmp2_;
#line 3763 "ImportPage.c"
	}
#line 260 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = ret;
#line 260 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 3769 "ImportPage.c"
}


static void photo_import_source_class_init (PhotoImportSourceClass * klass) {
#line 152 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	photo_import_source_parent_class = g_type_class_peek_parent (klass);
#line 152 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_type_class_add_private (klass, sizeof (PhotoImportSourcePrivate));
#line 152 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	((DataObjectClass *) klass)->get_name = photo_import_source_real_get_name;
#line 152 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	((DataSourceClass *) klass)->get_typename = photo_import_source_real_get_typename;
#line 152 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	((DataSourceClass *) klass)->get_instance_id = photo_import_source_real_get_instance_id;
#line 152 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	((ThumbnailSourceClass *) klass)->get_preferred_thumbnail_format = photo_import_source_real_get_preferred_thumbnail_format;
#line 152 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	((ThumbnailSourceClass *) klass)->create_thumbnail = photo_import_source_real_create_thumbnail;
#line 152 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	((ImportSourceClass *) klass)->get_exposure_time = photo_import_source_real_get_exposure_time;
#line 152 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	((ImportSourceClass *) klass)->get_preview = photo_import_source_real_get_preview;
#line 152 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	((ThumbnailSourceClass *) klass)->get_thumbnail = photo_import_source_real_get_thumbnail;
#line 152 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	((DataSourceClass *) klass)->internal_delete_backing = photo_import_source_real_internal_delete_backing;
#line 152 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	G_OBJECT_CLASS (klass)->finalize = photo_import_source_finalize;
#line 3798 "ImportPage.c"
}


static void photo_import_source_instance_init (PhotoImportSource * self) {
#line 152 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self->priv = PHOTO_IMPORT_SOURCE_GET_PRIVATE (self);
#line 156 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self->priv->preview_md5 = NULL;
#line 157 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self->priv->metadata = NULL;
#line 158 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self->priv->exif_md5 = NULL;
#line 159 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self->priv->associated = NULL;
#line 3813 "ImportPage.c"
}


static void photo_import_source_finalize (GObject* obj) {
	PhotoImportSource * self;
#line 152 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_PHOTO_IMPORT_SOURCE, PhotoImportSource);
#line 156 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_free0 (self->priv->preview_md5);
#line 157 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_media_metadata_unref0 (self->priv->metadata);
#line 158 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_free0 (self->priv->exif_md5);
#line 159 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_object_unref0 (self->priv->associated);
#line 152 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	G_OBJECT_CLASS (photo_import_source_parent_class)->finalize (obj);
#line 3831 "ImportPage.c"
}


GType photo_import_source_get_type (void) {
	static volatile gsize photo_import_source_type_id__volatile = 0;
	if (g_once_init_enter (&photo_import_source_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PhotoImportSourceClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) photo_import_source_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PhotoImportSource), 0, (GInstanceInitFunc) photo_import_source_instance_init, NULL };
		GType photo_import_source_type_id;
		photo_import_source_type_id = g_type_register_static (TYPE_IMPORT_SOURCE, "PhotoImportSource", &g_define_type_info, 0);
		g_once_init_leave (&photo_import_source_type_id__volatile, photo_import_source_type_id);
	}
	return photo_import_source_type_id__volatile;
}


ImportPreview* import_preview_construct (GType object_type, ImportSource* source) {
	ImportPreview * self = NULL;
	ImportSource* _tmp0_ = NULL;
	Dimensions _tmp1_ = {0};
	ImportSource* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	ImportSource* _tmp5_ = NULL;
	GdkPixbuf* pixbuf = NULL;
	gboolean using_placeholder = FALSE;
	GdkPixbuf* _tmp14_ = NULL;
	GdkPixbuf* _tmp15_ = NULL;
	gboolean _tmp22_ = FALSE;
	GdkPixbuf* _tmp23_ = NULL;
	gint _tmp24_ = 0;
	ImportSource* _tmp29_ = NULL;
	GdkPixbuf* _tmp50_ = NULL;
	GError * _inner_error_ = NULL;
#line 271 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail (IS_IMPORT_SOURCE (source), NULL);
#line 272 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = source;
#line 272 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	dimensions_init (&_tmp1_, 0, 0);
#line 272 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp2_ = source;
#line 272 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp3_ = data_object_get_name (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, TYPE_DATA_OBJECT, DataObject));
#line 272 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp4_ = _tmp3_;
#line 272 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self = (ImportPreview*) media_source_item_construct (object_type, G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, TYPE_THUMBNAIL_SOURCE, ThumbnailSource), &_tmp1_, _tmp4_, NULL, FALSE, PANGO_ALIGN_LEFT);
#line 272 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_free0 (_tmp4_);
#line 274 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_object_unref0 (self->priv->duplicated_file);
#line 274 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self->priv->duplicated_file = NULL;
#line 277 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp5_ = source;
#line 277 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp5_, TYPE_VIDEO_IMPORT_SOURCE)) {
#line 278 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		media_source_item_set_enable_sprockets (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MEDIA_SOURCE_ITEM, MediaSourceItem), TRUE);
#line 3891 "ImportPage.c"
	}
#line 281 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	pixbuf = NULL;
#line 3895 "ImportPage.c"
	{
		GdkPixbuf* _tmp6_ = NULL;
		ImportSource* _tmp7_ = NULL;
		GdkPixbuf* _tmp8_ = NULL;
		GdkPixbuf* _tmp9_ = NULL;
#line 283 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp7_ = source;
#line 283 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp8_ = thumbnail_source_get_thumbnail (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, TYPE_THUMBNAIL_SOURCE, ThumbnailSource), 0, &_inner_error_);
#line 283 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp6_ = _tmp8_;
#line 283 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3909 "ImportPage.c"
			goto __catch61_g_error;
		}
#line 283 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp9_ = _tmp6_;
#line 283 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp6_ = NULL;
#line 283 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_object_unref0 (pixbuf);
#line 283 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		pixbuf = _tmp9_;
#line 282 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_object_unref0 (_tmp6_);
#line 3922 "ImportPage.c"
	}
	goto __finally61;
	__catch61_g_error:
	{
		GError* err = NULL;
		gchar* _tmp10_ = NULL;
		gchar* _tmp11_ = NULL;
		GError* _tmp12_ = NULL;
		const gchar* _tmp13_ = NULL;
#line 282 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		err = _inner_error_;
#line 282 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_inner_error_ = NULL;
#line 285 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp10_ = data_object_to_string (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATA_OBJECT, DataObject));
#line 285 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp11_ = _tmp10_;
#line 285 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp12_ = err;
#line 285 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp13_ = _tmp12_->message;
#line 285 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		g_warning ("ImportPage.vala:285: Unable to fetch loaded import preview for %s: %s", _tmp11_, _tmp13_);
#line 285 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_free0 (_tmp11_);
#line 282 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_error_free0 (err);
#line 3950 "ImportPage.c"
	}
	__finally61:
#line 282 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 282 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_object_unref0 (pixbuf);
#line 282 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 282 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		g_clear_error (&_inner_error_);
#line 282 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		return NULL;
#line 3963 "ImportPage.c"
	}
#line 289 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp14_ = pixbuf;
#line 289 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	using_placeholder = _tmp14_ == NULL;
#line 290 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp15_ = pixbuf;
#line 290 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (_tmp15_ == NULL) {
#line 3973 "ImportPage.c"
		GdkPixbuf* _tmp16_ = NULL;
		GdkPixbuf* _tmp20_ = NULL;
		GdkPixbuf* _tmp21_ = NULL;
#line 291 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp16_ = import_preview_placeholder_preview;
#line 291 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		if (_tmp16_ == NULL) {
#line 3981 "ImportPage.c"
			GdkPixbuf* _tmp17_ = NULL;
			GdkPixbuf* _tmp18_ = NULL;
			GdkPixbuf* _tmp19_ = NULL;
#line 292 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp17_ = get_placeholder_pixbuf ();
#line 292 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_g_object_unref0 (import_preview_placeholder_preview);
#line 292 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			import_preview_placeholder_preview = _tmp17_;
#line 293 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp18_ = import_preview_placeholder_preview;
#line 293 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp19_ = scale_pixbuf (_tmp18_, IMPORT_PREVIEW_MAX_SCALE, GDK_INTERP_BILINEAR, TRUE);
#line 293 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_g_object_unref0 (import_preview_placeholder_preview);
#line 293 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			import_preview_placeholder_preview = _tmp19_;
#line 3999 "ImportPage.c"
		}
#line 297 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp20_ = import_preview_placeholder_preview;
#line 297 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp21_ = _g_object_ref0 (_tmp20_);
#line 297 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_object_unref0 (pixbuf);
#line 297 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		pixbuf = _tmp21_;
#line 4009 "ImportPage.c"
	}
#line 301 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp23_ = pixbuf;
#line 301 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp24_ = gdk_pixbuf_get_width (_tmp23_);
#line 301 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (_tmp24_ > IMPORT_PREVIEW_MAX_SCALE) {
#line 301 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp22_ = TRUE;
#line 4019 "ImportPage.c"
	} else {
		GdkPixbuf* _tmp25_ = NULL;
		gint _tmp26_ = 0;
#line 301 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp25_ = pixbuf;
#line 301 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp26_ = gdk_pixbuf_get_height (_tmp25_);
#line 301 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp22_ = _tmp26_ > IMPORT_PREVIEW_MAX_SCALE;
#line 4029 "ImportPage.c"
	}
#line 301 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (_tmp22_) {
#line 4033 "ImportPage.c"
		GdkPixbuf* _tmp27_ = NULL;
		GdkPixbuf* _tmp28_ = NULL;
#line 302 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp27_ = pixbuf;
#line 302 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp28_ = scale_pixbuf (_tmp27_, IMPORT_PREVIEW_MAX_SCALE, PHOTO_IMPORT_SOURCE_INTERP, FALSE);
#line 302 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_object_unref0 (pixbuf);
#line 302 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		pixbuf = _tmp28_;
#line 4044 "ImportPage.c"
	}
#line 304 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp29_ = source;
#line 304 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp29_, TYPE_PHOTO_IMPORT_SOURCE)) {
#line 4050 "ImportPage.c"
		PhotoImportSource* photo_import_source = NULL;
		ImportSource* _tmp30_ = NULL;
		PhotoImportSource* _tmp31_ = NULL;
		gboolean _tmp32_ = FALSE;
		gboolean _tmp33_ = FALSE;
		PhotoImportSource* _tmp43_ = NULL;
		PhotoImportSource* _tmp44_ = NULL;
		PhotoImportSource* _tmp45_ = NULL;
		gboolean _tmp46_ = FALSE;
#line 306 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp30_ = source;
#line 306 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp31_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp30_, TYPE_PHOTO_IMPORT_SOURCE) ? ((PhotoImportSource*) _tmp30_) : NULL);
#line 306 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		photo_import_source = _tmp31_;
#line 307 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp33_ = using_placeholder;
#line 307 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		if (!_tmp33_) {
#line 4070 "ImportPage.c"
			PhotoImportSource* _tmp34_ = NULL;
			PhotoMetadata* _tmp35_ = NULL;
			PhotoMetadata* _tmp36_ = NULL;
#line 307 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp34_ = photo_import_source;
#line 307 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp35_ = photo_import_source_get_metadata (_tmp34_);
#line 307 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp36_ = _tmp35_;
#line 307 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp32_ = _tmp36_ != NULL;
#line 307 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_media_metadata_unref0 (_tmp36_);
#line 4084 "ImportPage.c"
		} else {
#line 307 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp32_ = FALSE;
#line 4088 "ImportPage.c"
		}
#line 307 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		if (_tmp32_) {
#line 4092 "ImportPage.c"
			PhotoImportSource* _tmp37_ = NULL;
			PhotoMetadata* _tmp38_ = NULL;
			PhotoMetadata* _tmp39_ = NULL;
			Orientation _tmp40_ = 0;
			GdkPixbuf* _tmp41_ = NULL;
			GdkPixbuf* _tmp42_ = NULL;
#line 308 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp37_ = photo_import_source;
#line 308 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp38_ = photo_import_source_get_metadata (_tmp37_);
#line 308 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp39_ = _tmp38_;
#line 308 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp40_ = photo_metadata_get_orientation (_tmp39_);
#line 308 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp41_ = pixbuf;
#line 308 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp42_ = orientation_rotate_pixbuf (_tmp40_, _tmp41_);
#line 308 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_g_object_unref0 (pixbuf);
#line 308 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			pixbuf = _tmp42_;
#line 308 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_media_metadata_unref0 (_tmp39_);
#line 4117 "ImportPage.c"
		}
#line 310 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp43_ = photo_import_source;
#line 310 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp44_ = photo_import_source_get_associated (_tmp43_);
#line 310 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp45_ = _tmp44_;
#line 310 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp46_ = _tmp45_ != NULL;
#line 310 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_object_unref0 (_tmp45_);
#line 310 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		if (_tmp46_) {
#line 4131 "ImportPage.c"
			const gchar* _tmp47_ = NULL;
			gchar* _tmp48_ = NULL;
			gchar* _tmp49_ = NULL;
#line 311 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp47_ = _ ("RAW+JPEG");
#line 311 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp48_ = g_strdup_printf ("<small>%s</small>", _tmp47_);
#line 311 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp49_ = _tmp48_;
#line 311 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			checkerboard_item_set_subtitle (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_CHECKERBOARD_ITEM, CheckerboardItem), _tmp49_, TRUE, PANGO_ALIGN_LEFT);
#line 311 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_g_free0 (_tmp49_);
#line 4145 "ImportPage.c"
		}
#line 304 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_object_unref0 (photo_import_source);
#line 4149 "ImportPage.c"
	}
#line 315 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp50_ = pixbuf;
#line 315 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	checkerboard_item_set_image (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_CHECKERBOARD_ITEM, CheckerboardItem), _tmp50_);
#line 271 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_object_unref0 (pixbuf);
#line 271 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return self;
#line 4159 "ImportPage.c"
}


ImportPreview* import_preview_new (ImportSource* source) {
#line 271 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return import_preview_construct (TYPE_IMPORT_PREVIEW, source);
#line 4166 "ImportPage.c"
}


gboolean import_preview_is_already_imported (ImportPreview* self) {
	gboolean result = FALSE;
	PhotoImportSource* photo_import_source = NULL;
	ImportSource* _tmp0_ = NULL;
	PhotoImportSource* _tmp1_ = NULL;
	PhotoImportSource* _tmp2_ = NULL;
	VideoImportSource* video_import_source = NULL;
	ImportSource* _tmp39_ = NULL;
	VideoImportSource* _tmp40_ = NULL;
	VideoImportSource* _tmp41_ = NULL;
#line 318 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail (IS_IMPORT_PREVIEW (self), FALSE);
#line 319 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = import_preview_get_import_source (self);
#line 319 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, TYPE_PHOTO_IMPORT_SOURCE) ? ((PhotoImportSource*) _tmp0_) : NULL;
#line 319 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (_tmp1_ == NULL) {
#line 319 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_object_unref0 (_tmp0_);
#line 4190 "ImportPage.c"
	}
#line 319 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	photo_import_source = _tmp1_;
#line 320 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp2_ = photo_import_source;
#line 320 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (_tmp2_ != NULL) {
#line 4198 "ImportPage.c"
		gchar* preview_md5 = NULL;
		PhotoImportSource* _tmp3_ = NULL;
		gchar* _tmp4_ = NULL;
		PhotoFileFormat file_format = 0;
		PhotoImportSource* _tmp5_ = NULL;
		PhotoFileFormat _tmp6_ = 0;
		gboolean _tmp7_ = FALSE;
		const gchar* _tmp8_ = NULL;
		gboolean _tmp9_ = FALSE;
		PhotoFileFormat _tmp17_ = 0;
#line 321 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp3_ = photo_import_source;
#line 321 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp4_ = photo_import_source_get_preview_md5 (_tmp3_);
#line 321 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		preview_md5 = _tmp4_;
#line 322 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp5_ = photo_import_source;
#line 322 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp6_ = photo_import_source_get_file_format (_tmp5_);
#line 322 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		file_format = _tmp6_;
#line 325 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp8_ = preview_md5;
#line 325 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp9_ = is_string_empty (_tmp8_);
#line 325 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		if (!_tmp9_) {
#line 4227 "ImportPage.c"
			const gchar* _tmp10_ = NULL;
			PhotoFileFormat _tmp11_ = 0;
			gboolean _tmp12_ = FALSE;
#line 326 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp10_ = preview_md5;
#line 326 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp11_ = file_format;
#line 326 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp12_ = library_photo_has_nontrash_duplicate (NULL, _tmp10_, NULL, _tmp11_);
#line 326 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp7_ = _tmp12_;
#line 4239 "ImportPage.c"
		} else {
#line 325 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp7_ = FALSE;
#line 4243 "ImportPage.c"
		}
#line 325 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		if (_tmp7_) {
#line 4247 "ImportPage.c"
			const gchar* _tmp13_ = NULL;
			PhotoFileFormat _tmp14_ = 0;
			PhotoID _tmp15_ = {0};
			DuplicatedFile* _tmp16_ = NULL;
#line 328 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp13_ = preview_md5;
#line 328 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp14_ = file_format;
#line 328 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			library_photo_get_nontrash_duplicate (NULL, _tmp13_, NULL, _tmp14_, &_tmp15_);
#line 328 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp16_ = duplicated_file_create_from_photo_id (&_tmp15_);
#line 328 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_g_object_unref0 (self->priv->duplicated_file);
#line 328 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			self->priv->duplicated_file = _tmp16_;
#line 331 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			result = TRUE;
#line 331 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_g_free0 (preview_md5);
#line 331 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_g_object_unref0 (photo_import_source);
#line 331 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			return result;
#line 4272 "ImportPage.c"
		}
#line 337 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp17_ = file_format;
#line 337 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		if (_tmp17_ == PHOTO_FILE_FORMAT_RAW) {
#line 4278 "ImportPage.c"
			guint64 filesize = 0ULL;
			ImportSource* _tmp18_ = NULL;
			ImportSource* _tmp19_ = NULL;
			gulong _tmp20_ = 0UL;
			guint64 _tmp21_ = 0ULL;
			guint64 _tmp22_ = 0ULL;
#line 338 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp18_ = import_preview_get_import_source (self);
#line 338 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp19_ = _tmp18_;
#line 338 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp20_ = import_source_get_filesize (_tmp19_);
#line 338 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp21_ = (guint64) _tmp20_;
#line 338 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_g_object_unref0 (_tmp19_);
#line 338 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			filesize = _tmp21_;
#line 340 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp22_ = filesize;
#line 340 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			if (_tmp22_ <= ((guint64) G_MAXINT64)) {
#line 4301 "ImportPage.c"
				LibraryPhotoSourceCollection* _tmp23_ = NULL;
				ImportSource* _tmp24_ = NULL;
				ImportSource* _tmp25_ = NULL;
				gchar* _tmp26_ = NULL;
				gchar* _tmp27_ = NULL;
				guint64 _tmp28_ = 0ULL;
				gboolean _tmp29_ = FALSE;
				gboolean _tmp30_ = FALSE;
#line 341 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp23_ = library_photo_global;
#line 341 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp24_ = import_preview_get_import_source (self);
#line 341 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp25_ = _tmp24_;
#line 341 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp26_ = import_source_get_filename (_tmp25_);
#line 341 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp27_ = _tmp26_;
#line 341 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp28_ = filesize;
#line 341 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp29_ = library_photo_source_collection_has_basename_filesize_duplicate (_tmp23_, _tmp27_, (gint64) _tmp28_);
#line 341 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp30_ = _tmp29_;
#line 341 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_g_free0 (_tmp27_);
#line 341 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_g_object_unref0 (_tmp25_);
#line 341 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				if (_tmp30_) {
#line 4332 "ImportPage.c"
					LibraryPhotoSourceCollection* _tmp31_ = NULL;
					ImportSource* _tmp32_ = NULL;
					ImportSource* _tmp33_ = NULL;
					gchar* _tmp34_ = NULL;
					gchar* _tmp35_ = NULL;
					guint64 _tmp36_ = 0ULL;
					PhotoID _tmp37_ = {0};
					DuplicatedFile* _tmp38_ = NULL;
#line 344 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp31_ = library_photo_global;
#line 344 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp32_ = import_preview_get_import_source (self);
#line 344 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp33_ = _tmp32_;
#line 344 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp34_ = import_source_get_filename (_tmp33_);
#line 344 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp35_ = _tmp34_;
#line 344 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp36_ = filesize;
#line 344 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					library_photo_source_collection_get_basename_filesize_duplicate (_tmp31_, _tmp35_, (gint64) _tmp36_, &_tmp37_);
#line 344 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp38_ = duplicated_file_create_from_photo_id (&_tmp37_);
#line 344 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_g_object_unref0 (self->priv->duplicated_file);
#line 344 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					self->priv->duplicated_file = _tmp38_;
#line 344 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_g_free0 (_tmp35_);
#line 344 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_g_object_unref0 (_tmp33_);
#line 348 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					result = TRUE;
#line 348 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_g_free0 (preview_md5);
#line 348 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_g_object_unref0 (photo_import_source);
#line 348 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					return result;
#line 4373 "ImportPage.c"
				}
			}
		}
#line 353 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		result = FALSE;
#line 353 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_free0 (preview_md5);
#line 353 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_object_unref0 (photo_import_source);
#line 353 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		return result;
#line 4385 "ImportPage.c"
	}
#line 356 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp39_ = import_preview_get_import_source (self);
#line 356 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp40_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp39_, TYPE_VIDEO_IMPORT_SOURCE) ? ((VideoImportSource*) _tmp39_) : NULL;
#line 356 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (_tmp40_ == NULL) {
#line 356 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_object_unref0 (_tmp39_);
#line 4395 "ImportPage.c"
	}
#line 356 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	video_import_source = _tmp40_;
#line 357 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp41_ = video_import_source;
#line 357 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (_tmp41_ != NULL) {
#line 4403 "ImportPage.c"
		VideoSourceCollection* _tmp42_ = NULL;
		VideoImportSource* _tmp43_ = NULL;
		gchar* _tmp44_ = NULL;
		gchar* _tmp45_ = NULL;
		VideoImportSource* _tmp46_ = NULL;
		gulong _tmp47_ = 0UL;
		gboolean _tmp48_ = FALSE;
		gboolean _tmp49_ = FALSE;
#line 362 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp42_ = video_global;
#line 362 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp43_ = video_import_source;
#line 362 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp44_ = import_source_get_filename (G_TYPE_CHECK_INSTANCE_CAST (_tmp43_, TYPE_IMPORT_SOURCE, ImportSource));
#line 362 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp45_ = _tmp44_;
#line 362 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp46_ = video_import_source;
#line 362 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp47_ = import_source_get_filesize (G_TYPE_CHECK_INSTANCE_CAST (_tmp46_, TYPE_IMPORT_SOURCE, ImportSource));
#line 362 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp48_ = video_source_collection_has_basename_filesize_duplicate (_tmp42_, _tmp45_, (guint64) _tmp47_);
#line 362 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp49_ = _tmp48_;
#line 362 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_free0 (_tmp45_);
#line 362 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		if (_tmp49_) {
#line 4432 "ImportPage.c"
			VideoSourceCollection* _tmp50_ = NULL;
			VideoImportSource* _tmp51_ = NULL;
			gchar* _tmp52_ = NULL;
			gchar* _tmp53_ = NULL;
			VideoImportSource* _tmp54_ = NULL;
			gulong _tmp55_ = 0UL;
			VideoID _tmp56_ = {0};
			DuplicatedFile* _tmp57_ = NULL;
#line 365 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp50_ = video_global;
#line 365 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp51_ = video_import_source;
#line 365 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp52_ = import_source_get_filename (G_TYPE_CHECK_INSTANCE_CAST (_tmp51_, TYPE_IMPORT_SOURCE, ImportSource));
#line 365 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp53_ = _tmp52_;
#line 365 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp54_ = video_import_source;
#line 365 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp55_ = import_source_get_filesize (G_TYPE_CHECK_INSTANCE_CAST (_tmp54_, TYPE_IMPORT_SOURCE, ImportSource));
#line 365 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			video_source_collection_get_basename_filesize_duplicate (_tmp50_, _tmp53_, (guint64) _tmp55_, &_tmp56_);
#line 365 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp57_ = duplicated_file_create_from_video_id (&_tmp56_);
#line 365 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_g_object_unref0 (self->priv->duplicated_file);
#line 365 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			self->priv->duplicated_file = _tmp57_;
#line 365 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_g_free0 (_tmp53_);
#line 370 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			result = TRUE;
#line 370 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_g_object_unref0 (video_import_source);
#line 370 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_g_object_unref0 (photo_import_source);
#line 370 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			return result;
#line 4471 "ImportPage.c"
		}
#line 373 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		result = FALSE;
#line 373 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_object_unref0 (video_import_source);
#line 373 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_object_unref0 (photo_import_source);
#line 373 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		return result;
#line 4481 "ImportPage.c"
	}
#line 376 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = FALSE;
#line 376 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_object_unref0 (video_import_source);
#line 376 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_object_unref0 (photo_import_source);
#line 376 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 4491 "ImportPage.c"
}


DuplicatedFile* import_preview_get_duplicated_file (ImportPreview* self) {
	DuplicatedFile* result = NULL;
	gboolean _tmp0_ = FALSE;
	DuplicatedFile* _tmp1_ = NULL;
	DuplicatedFile* _tmp2_ = NULL;
#line 379 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail (IS_IMPORT_PREVIEW (self), NULL);
#line 380 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = import_preview_is_already_imported (self);
#line 380 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (!_tmp0_) {
#line 381 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		result = NULL;
#line 381 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		return result;
#line 4510 "ImportPage.c"
	}
#line 383 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = self->priv->duplicated_file;
#line 383 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 383 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = _tmp2_;
#line 383 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 4520 "ImportPage.c"
}


ImportSource* import_preview_get_import_source (ImportPreview* self) {
	ImportSource* result = NULL;
	DataSource* _tmp0_ = NULL;
#line 386 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail (IS_IMPORT_PREVIEW (self), NULL);
#line 387 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = data_view_get_source (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATA_VIEW, DataView));
#line 387 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, TYPE_IMPORT_SOURCE, ImportSource);
#line 387 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 4535 "ImportPage.c"
}


static void import_preview_class_init (ImportPreviewClass * klass) {
#line 264 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	import_preview_parent_class = g_type_class_peek_parent (klass);
#line 264 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_type_class_add_private (klass, sizeof (ImportPreviewPrivate));
#line 264 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	G_OBJECT_CLASS (klass)->finalize = import_preview_finalize;
#line 4546 "ImportPage.c"
}


static void import_preview_instance_init (ImportPreview * self) {
#line 264 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self->priv = IMPORT_PREVIEW_GET_PRIVATE (self);
#line 4553 "ImportPage.c"
}


static void import_preview_finalize (GObject* obj) {
	ImportPreview * self;
#line 264 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_IMPORT_PREVIEW, ImportPreview);
#line 269 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_object_unref0 (self->priv->duplicated_file);
#line 264 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	G_OBJECT_CLASS (import_preview_parent_class)->finalize (obj);
#line 4565 "ImportPage.c"
}


GType import_preview_get_type (void) {
	static volatile gsize import_preview_type_id__volatile = 0;
	if (g_once_init_enter (&import_preview_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (ImportPreviewClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) import_preview_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ImportPreview), 0, (GInstanceInitFunc) import_preview_instance_init, NULL };
		GType import_preview_type_id;
		import_preview_type_id = g_type_register_static (TYPE_MEDIA_SOURCE_ITEM, "ImportPreview", &g_define_type_info, 0);
		g_once_init_leave (&import_preview_type_id__volatile, import_preview_type_id);
	}
	return import_preview_type_id__volatile;
}


CameraViewTracker* camera_view_tracker_construct (GType object_type, ViewCollection* collection) {
	CameraViewTracker* self = NULL;
	ViewCollection* _tmp0_ = NULL;
	CameraAccumulator* _tmp1_ = NULL;
	CameraAccumulator* _tmp2_ = NULL;
	CameraAccumulator* _tmp3_ = NULL;
#line 396 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail (IS_VIEW_COLLECTION (collection), NULL);
#line 397 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = collection;
#line 397 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self = (CameraViewTracker*) core_view_tracker_construct (object_type, _tmp0_);
#line 399 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = self->all;
#line 399 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp2_ = self->visible;
#line 399 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp3_ = self->selected;
#line 399 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	core_view_tracker_start (G_TYPE_CHECK_INSTANCE_CAST (self, CORE_TYPE_VIEW_TRACKER, CoreViewTracker), G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, CORE_TYPE_TRACKER_ACCUMULATOR, CoreTrackerAccumulator), G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, CORE_TYPE_TRACKER_ACCUMULATOR, CoreTrackerAccumulator), G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, CORE_TYPE_TRACKER_ACCUMULATOR, CoreTrackerAccumulator));
#line 396 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return self;
#line 4603 "ImportPage.c"
}


CameraViewTracker* camera_view_tracker_new (ViewCollection* collection) {
#line 396 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return camera_view_tracker_construct (TYPE_CAMERA_VIEW_TRACKER, collection);
#line 4610 "ImportPage.c"
}


static void camera_view_tracker_class_init (CameraViewTrackerClass * klass) {
#line 391 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	camera_view_tracker_parent_class = g_type_class_peek_parent (klass);
#line 391 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	((CoreTrackerClass *) klass)->finalize = camera_view_tracker_finalize;
#line 4619 "ImportPage.c"
}


static void camera_view_tracker_instance_init (CameraViewTracker * self) {
	CameraAccumulator* _tmp0_ = NULL;
	CameraAccumulator* _tmp1_ = NULL;
	CameraAccumulator* _tmp2_ = NULL;
#line 392 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = camera_accumulator_new ();
#line 392 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self->all = _tmp0_;
#line 393 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = camera_accumulator_new ();
#line 393 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self->visible = _tmp1_;
#line 394 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp2_ = camera_accumulator_new ();
#line 394 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self->selected = _tmp2_;
#line 4639 "ImportPage.c"
}


static void camera_view_tracker_finalize (CoreTracker* obj) {
	CameraViewTracker * self;
#line 391 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_CAMERA_VIEW_TRACKER, CameraViewTracker);
#line 392 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_object_unref0 (self->all);
#line 393 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_object_unref0 (self->visible);
#line 394 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_object_unref0 (self->selected);
#line 391 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	CORE_TRACKER_CLASS (camera_view_tracker_parent_class)->finalize (obj);
#line 4655 "ImportPage.c"
}


GType camera_view_tracker_get_type (void) {
	static volatile gsize camera_view_tracker_type_id__volatile = 0;
	if (g_once_init_enter (&camera_view_tracker_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (CameraViewTrackerClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) camera_view_tracker_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (CameraViewTracker), 0, (GInstanceInitFunc) camera_view_tracker_instance_init, NULL };
		GType camera_view_tracker_type_id;
		camera_view_tracker_type_id = g_type_register_static (CORE_TYPE_VIEW_TRACKER, "CameraViewTracker", &g_define_type_info, 0);
		g_once_init_leave (&camera_view_tracker_type_id__volatile, camera_view_tracker_type_id);
	}
	return camera_view_tracker_type_id__volatile;
}


static gboolean camera_accumulator_real_include (CoreTrackerAccumulator* base, DataObject* object) {
	CameraAccumulator * self;
	gboolean result = FALSE;
	ImportSource* source = NULL;
	DataObject* _tmp0_ = NULL;
	DataSource* _tmp1_ = NULL;
	gint _tmp2_ = 0;
	PhotoImportSource* photo = NULL;
	ImportSource* _tmp3_ = NULL;
	PhotoImportSource* _tmp4_ = NULL;
	gboolean _tmp5_ = FALSE;
	PhotoImportSource* _tmp6_ = NULL;
#line 409 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_CAMERA_ACCUMULATOR, CameraAccumulator);
#line 409 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail (IS_DATA_OBJECT (object), FALSE);
#line 410 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = object;
#line 410 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = data_view_get_source (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, TYPE_DATA_VIEW, DataView));
#line 410 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	source = G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, TYPE_IMPORT_SOURCE, ImportSource);
#line 412 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp2_ = self->priv->_total;
#line 412 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	camera_accumulator_set_total (self, _tmp2_ + 1);
#line 414 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp3_ = source;
#line 414 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp4_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, TYPE_PHOTO_IMPORT_SOURCE) ? ((PhotoImportSource*) _tmp3_) : NULL);
#line 414 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	photo = _tmp4_;
#line 415 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp6_ = photo;
#line 415 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (_tmp6_ != NULL) {
#line 4707 "ImportPage.c"
		PhotoImportSource* _tmp7_ = NULL;
		PhotoFileFormat _tmp8_ = 0;
#line 415 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp7_ = photo;
#line 415 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp8_ = photo_import_source_get_file_format (_tmp7_);
#line 415 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp5_ = _tmp8_ != PHOTO_FILE_FORMAT_RAW;
#line 4716 "ImportPage.c"
	} else {
#line 415 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp5_ = FALSE;
#line 4720 "ImportPage.c"
	}
#line 415 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (_tmp5_) {
#line 4724 "ImportPage.c"
		gint _tmp9_ = 0;
#line 416 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp9_ = self->priv->_photos;
#line 416 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		camera_accumulator_set_photos (self, _tmp9_ + 1);
#line 4730 "ImportPage.c"
	} else {
		gboolean _tmp10_ = FALSE;
		PhotoImportSource* _tmp11_ = NULL;
#line 417 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp11_ = photo;
#line 417 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		if (_tmp11_ != NULL) {
#line 4738 "ImportPage.c"
			PhotoImportSource* _tmp12_ = NULL;
			PhotoFileFormat _tmp13_ = 0;
#line 417 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp12_ = photo;
#line 417 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp13_ = photo_import_source_get_file_format (_tmp12_);
#line 417 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp10_ = _tmp13_ == PHOTO_FILE_FORMAT_RAW;
#line 4747 "ImportPage.c"
		} else {
#line 417 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp10_ = FALSE;
#line 4751 "ImportPage.c"
		}
#line 417 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		if (_tmp10_) {
#line 4755 "ImportPage.c"
			gint _tmp14_ = 0;
#line 418 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp14_ = self->priv->_raw;
#line 418 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			camera_accumulator_set_raw (self, _tmp14_ + 1);
#line 4761 "ImportPage.c"
		} else {
			ImportSource* _tmp15_ = NULL;
#line 419 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp15_ = source;
#line 419 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp15_, TYPE_VIDEO_IMPORT_SOURCE)) {
#line 4768 "ImportPage.c"
				gint _tmp16_ = 0;
#line 420 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp16_ = self->priv->_videos;
#line 420 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				camera_accumulator_set_videos (self, _tmp16_ + 1);
#line 4774 "ImportPage.c"
			}
		}
	}
#line 423 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = TRUE;
#line 423 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_object_unref0 (photo);
#line 423 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_object_unref0 (source);
#line 423 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 4786 "ImportPage.c"
}


static gboolean camera_accumulator_real_uninclude (CoreTrackerAccumulator* base, DataObject* object) {
	CameraAccumulator * self;
	gboolean result = FALSE;
	ImportSource* source = NULL;
	DataObject* _tmp0_ = NULL;
	DataSource* _tmp1_ = NULL;
	gint _tmp2_ = 0;
	PhotoImportSource* photo = NULL;
	ImportSource* _tmp3_ = NULL;
	PhotoImportSource* _tmp4_ = NULL;
	gboolean _tmp5_ = FALSE;
	PhotoImportSource* _tmp6_ = NULL;
#line 426 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_CAMERA_ACCUMULATOR, CameraAccumulator);
#line 426 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail (IS_DATA_OBJECT (object), FALSE);
#line 427 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = object;
#line 427 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = data_view_get_source (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, TYPE_DATA_VIEW, DataView));
#line 427 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	source = G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, TYPE_IMPORT_SOURCE, ImportSource);
#line 429 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp2_ = self->priv->_total;
#line 429 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	camera_accumulator_set_total (self, _tmp2_ + 1);
#line 431 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp3_ = source;
#line 431 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp4_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, TYPE_PHOTO_IMPORT_SOURCE) ? ((PhotoImportSource*) _tmp3_) : NULL);
#line 431 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	photo = _tmp4_;
#line 432 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp6_ = photo;
#line 432 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (_tmp6_ != NULL) {
#line 4826 "ImportPage.c"
		PhotoImportSource* _tmp7_ = NULL;
		PhotoFileFormat _tmp8_ = 0;
#line 432 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp7_ = photo;
#line 432 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp8_ = photo_import_source_get_file_format (_tmp7_);
#line 432 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp5_ = _tmp8_ != PHOTO_FILE_FORMAT_RAW;
#line 4835 "ImportPage.c"
	} else {
#line 432 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp5_ = FALSE;
#line 4839 "ImportPage.c"
	}
#line 432 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (_tmp5_) {
#line 4843 "ImportPage.c"
		gint _tmp9_ = 0;
		gint _tmp10_ = 0;
#line 433 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp9_ = self->priv->_photos;
#line 433 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_vala_assert (_tmp9_ > 0, "photos > 0");
#line 434 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp10_ = self->priv->_photos;
#line 434 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		camera_accumulator_set_photos (self, _tmp10_ - 1);
#line 4854 "ImportPage.c"
	} else {
		gboolean _tmp11_ = FALSE;
		PhotoImportSource* _tmp12_ = NULL;
#line 435 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp12_ = photo;
#line 435 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		if (_tmp12_ != NULL) {
#line 4862 "ImportPage.c"
			PhotoImportSource* _tmp13_ = NULL;
			PhotoFileFormat _tmp14_ = 0;
#line 435 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp13_ = photo;
#line 435 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp14_ = photo_import_source_get_file_format (_tmp13_);
#line 435 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp11_ = _tmp14_ == PHOTO_FILE_FORMAT_RAW;
#line 4871 "ImportPage.c"
		} else {
#line 435 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp11_ = FALSE;
#line 4875 "ImportPage.c"
		}
#line 435 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		if (_tmp11_) {
#line 4879 "ImportPage.c"
			gint _tmp15_ = 0;
			gint _tmp16_ = 0;
#line 436 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp15_ = self->priv->_raw;
#line 436 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_vala_assert (_tmp15_ > 0, "raw > 0");
#line 437 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp16_ = self->priv->_raw;
#line 437 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			camera_accumulator_set_raw (self, _tmp16_ - 1);
#line 4890 "ImportPage.c"
		} else {
			ImportSource* _tmp17_ = NULL;
#line 438 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp17_ = source;
#line 438 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp17_, TYPE_VIDEO_IMPORT_SOURCE)) {
#line 4897 "ImportPage.c"
				gint _tmp18_ = 0;
				gint _tmp19_ = 0;
#line 439 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp18_ = self->priv->_videos;
#line 439 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_vala_assert (_tmp18_ > 0, "videos > 0");
#line 440 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp19_ = self->priv->_videos;
#line 440 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				camera_accumulator_set_videos (self, _tmp19_ - 1);
#line 4908 "ImportPage.c"
			}
		}
	}
#line 444 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = TRUE;
#line 444 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_object_unref0 (photo);
#line 444 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_object_unref0 (source);
#line 444 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 4920 "ImportPage.c"
}


static gboolean camera_accumulator_real_altered (CoreTrackerAccumulator* base, DataObject* object, Alteration* alteration) {
	CameraAccumulator * self;
	gboolean result = FALSE;
#line 447 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_CAMERA_ACCUMULATOR, CameraAccumulator);
#line 447 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail (IS_DATA_OBJECT (object), FALSE);
#line 447 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail (IS_ALTERATION (alteration), FALSE);
#line 449 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = FALSE;
#line 449 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 4937 "ImportPage.c"
}


gchar* camera_accumulator_to_string (CameraAccumulator* self) {
	gchar* result = NULL;
	gint _tmp0_ = 0;
	gint _tmp1_ = 0;
	gint _tmp2_ = 0;
	gint _tmp3_ = 0;
	gchar* _tmp4_ = NULL;
#line 452 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail (IS_CAMERA_ACCUMULATOR (self), NULL);
#line 453 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = self->priv->_total;
#line 453 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = self->priv->_photos;
#line 453 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp2_ = self->priv->_videos;
#line 453 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp3_ = self->priv->_raw;
#line 453 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp4_ = g_strdup_printf ("%d total/%d photos/%d videos/%d raw", _tmp0_, _tmp1_, _tmp2_, _tmp3_);
#line 453 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = _tmp4_;
#line 453 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 4964 "ImportPage.c"
}


CameraAccumulator* camera_accumulator_construct (GType object_type) {
	CameraAccumulator * self = NULL;
#line 403 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self = (CameraAccumulator*) g_object_new (object_type, NULL);
#line 403 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return self;
#line 4974 "ImportPage.c"
}


CameraAccumulator* camera_accumulator_new (void) {
#line 403 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return camera_accumulator_construct (TYPE_CAMERA_ACCUMULATOR);
#line 4981 "ImportPage.c"
}


gint camera_accumulator_get_total (CameraAccumulator* self) {
	gint result;
	gint _tmp0_ = 0;
#line 404 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail (IS_CAMERA_ACCUMULATOR (self), 0);
#line 404 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = self->priv->_total;
#line 404 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = _tmp0_;
#line 404 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 4996 "ImportPage.c"
}


static void camera_accumulator_set_total (CameraAccumulator* self, gint value) {
	gint _tmp0_ = 0;
#line 404 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_if_fail (IS_CAMERA_ACCUMULATOR (self));
#line 404 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = value;
#line 404 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self->priv->_total = _tmp0_;
#line 404 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_object_notify ((GObject *) self, "total");
#line 5010 "ImportPage.c"
}


gint camera_accumulator_get_photos (CameraAccumulator* self) {
	gint result;
	gint _tmp0_ = 0;
#line 405 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail (IS_CAMERA_ACCUMULATOR (self), 0);
#line 405 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = self->priv->_photos;
#line 405 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = _tmp0_;
#line 405 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 5025 "ImportPage.c"
}


static void camera_accumulator_set_photos (CameraAccumulator* self, gint value) {
	gint _tmp0_ = 0;
#line 405 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_if_fail (IS_CAMERA_ACCUMULATOR (self));
#line 405 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = value;
#line 405 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self->priv->_photos = _tmp0_;
#line 405 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_object_notify ((GObject *) self, "photos");
#line 5039 "ImportPage.c"
}


gint camera_accumulator_get_videos (CameraAccumulator* self) {
	gint result;
	gint _tmp0_ = 0;
#line 406 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail (IS_CAMERA_ACCUMULATOR (self), 0);
#line 406 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = self->priv->_videos;
#line 406 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = _tmp0_;
#line 406 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 5054 "ImportPage.c"
}


static void camera_accumulator_set_videos (CameraAccumulator* self, gint value) {
	gint _tmp0_ = 0;
#line 406 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_if_fail (IS_CAMERA_ACCUMULATOR (self));
#line 406 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = value;
#line 406 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self->priv->_videos = _tmp0_;
#line 406 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_object_notify ((GObject *) self, "videos");
#line 5068 "ImportPage.c"
}


gint camera_accumulator_get_raw (CameraAccumulator* self) {
	gint result;
	gint _tmp0_ = 0;
#line 407 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail (IS_CAMERA_ACCUMULATOR (self), 0);
#line 407 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = self->priv->_raw;
#line 407 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = _tmp0_;
#line 407 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 5083 "ImportPage.c"
}


static void camera_accumulator_set_raw (CameraAccumulator* self, gint value) {
	gint _tmp0_ = 0;
#line 407 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_if_fail (IS_CAMERA_ACCUMULATOR (self));
#line 407 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = value;
#line 407 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self->priv->_raw = _tmp0_;
#line 407 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_object_notify ((GObject *) self, "raw");
#line 5097 "ImportPage.c"
}


static void camera_accumulator_class_init (CameraAccumulatorClass * klass) {
#line 403 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	camera_accumulator_parent_class = g_type_class_peek_parent (klass);
#line 403 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_type_class_add_private (klass, sizeof (CameraAccumulatorPrivate));
#line 403 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_camera_accumulator_get_property;
#line 403 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_camera_accumulator_set_property;
#line 403 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	G_OBJECT_CLASS (klass)->finalize = camera_accumulator_finalize;
#line 403 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), CAMERA_ACCUMULATOR_TOTAL, g_param_spec_int ("total", "total", "total", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 403 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), CAMERA_ACCUMULATOR_PHOTOS, g_param_spec_int ("photos", "photos", "photos", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 403 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), CAMERA_ACCUMULATOR_VIDEOS, g_param_spec_int ("videos", "videos", "videos", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 403 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), CAMERA_ACCUMULATOR_RAW, g_param_spec_int ("raw", "raw", "raw", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 5120 "ImportPage.c"
}


static void camera_accumulator_core_tracker_accumulator_interface_init (CoreTrackerAccumulatorIface * iface) {
#line 403 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	camera_accumulator_core_tracker_accumulator_parent_iface = g_type_interface_peek_parent (iface);
#line 403 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	iface->include = (gboolean (*)(CoreTrackerAccumulator*, DataObject*)) camera_accumulator_real_include;
#line 403 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	iface->uninclude = (gboolean (*)(CoreTrackerAccumulator*, DataObject*)) camera_accumulator_real_uninclude;
#line 403 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	iface->altered = (gboolean (*)(CoreTrackerAccumulator*, DataObject*, Alteration*)) camera_accumulator_real_altered;
#line 5133 "ImportPage.c"
}


static void camera_accumulator_instance_init (CameraAccumulator * self) {
#line 403 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self->priv = CAMERA_ACCUMULATOR_GET_PRIVATE (self);
#line 404 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self->priv->_total = 0;
#line 405 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self->priv->_photos = 0;
#line 406 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self->priv->_videos = 0;
#line 407 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self->priv->_raw = 0;
#line 5148 "ImportPage.c"
}


static void camera_accumulator_finalize (GObject* obj) {
	CameraAccumulator * self;
#line 403 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_CAMERA_ACCUMULATOR, CameraAccumulator);
#line 403 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	G_OBJECT_CLASS (camera_accumulator_parent_class)->finalize (obj);
#line 5158 "ImportPage.c"
}


GType camera_accumulator_get_type (void) {
	static volatile gsize camera_accumulator_type_id__volatile = 0;
	if (g_once_init_enter (&camera_accumulator_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (CameraAccumulatorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) camera_accumulator_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (CameraAccumulator), 0, (GInstanceInitFunc) camera_accumulator_instance_init, NULL };
		static const GInterfaceInfo core_tracker_accumulator_info = { (GInterfaceInitFunc) camera_accumulator_core_tracker_accumulator_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType camera_accumulator_type_id;
		camera_accumulator_type_id = g_type_register_static (G_TYPE_OBJECT, "CameraAccumulator", &g_define_type_info, 0);
		g_type_add_interface_static (camera_accumulator_type_id, CORE_TYPE_TRACKER_ACCUMULATOR, &core_tracker_accumulator_info);
		g_once_init_leave (&camera_accumulator_type_id__volatile, camera_accumulator_type_id);
	}
	return camera_accumulator_type_id__volatile;
}


static void _vala_camera_accumulator_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	CameraAccumulator * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_CAMERA_ACCUMULATOR, CameraAccumulator);
#line 403 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	switch (property_id) {
#line 403 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		case CAMERA_ACCUMULATOR_TOTAL:
#line 403 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		g_value_set_int (value, camera_accumulator_get_total (self));
#line 403 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		break;
#line 403 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		case CAMERA_ACCUMULATOR_PHOTOS:
#line 403 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		g_value_set_int (value, camera_accumulator_get_photos (self));
#line 403 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		break;
#line 403 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		case CAMERA_ACCUMULATOR_VIDEOS:
#line 403 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		g_value_set_int (value, camera_accumulator_get_videos (self));
#line 403 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		break;
#line 403 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		case CAMERA_ACCUMULATOR_RAW:
#line 403 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		g_value_set_int (value, camera_accumulator_get_raw (self));
#line 403 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		break;
#line 5205 "ImportPage.c"
		default:
#line 403 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 403 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		break;
#line 5211 "ImportPage.c"
	}
}


static void _vala_camera_accumulator_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	CameraAccumulator * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_CAMERA_ACCUMULATOR, CameraAccumulator);
#line 403 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	switch (property_id) {
#line 403 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		case CAMERA_ACCUMULATOR_TOTAL:
#line 403 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		camera_accumulator_set_total (self, g_value_get_int (value));
#line 403 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		break;
#line 403 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		case CAMERA_ACCUMULATOR_PHOTOS:
#line 403 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		camera_accumulator_set_photos (self, g_value_get_int (value));
#line 403 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		break;
#line 403 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		case CAMERA_ACCUMULATOR_VIDEOS:
#line 403 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		camera_accumulator_set_videos (self, g_value_get_int (value));
#line 403 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		break;
#line 403 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		case CAMERA_ACCUMULATOR_RAW:
#line 403 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		camera_accumulator_set_raw (self, g_value_get_int (value));
#line 403 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		break;
#line 5245 "ImportPage.c"
		default:
#line 403 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 403 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		break;
#line 5251 "ImportPage.c"
	}
}


static void _import_page_on_media_added_removed_data_collection_contents_altered (DataCollection* _sender, GeeIterable* added, GeeIterable* removed, gpointer self) {
#line 766 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	import_page_on_media_added_removed ((ImportPage*) self);
#line 5259 "ImportPage.c"
}


GType import_page_refresh_result_get_type (void) {
	static volatile gsize import_page_refresh_result_type_id__volatile = 0;
	if (g_once_init_enter (&import_page_refresh_result_type_id__volatile)) {
		static const GEnumValue values[] = {{IMPORT_PAGE_REFRESH_RESULT_OK, "IMPORT_PAGE_REFRESH_RESULT_OK", "ok"}, {IMPORT_PAGE_REFRESH_RESULT_BUSY, "IMPORT_PAGE_REFRESH_RESULT_BUSY", "busy"}, {IMPORT_PAGE_REFRESH_RESULT_LOCKED, "IMPORT_PAGE_REFRESH_RESULT_LOCKED", "locked"}, {IMPORT_PAGE_REFRESH_RESULT_LIBRARY_ERROR, "IMPORT_PAGE_REFRESH_RESULT_LIBRARY_ERROR", "library-error"}, {0, NULL, NULL}};
		GType import_page_refresh_result_type_id;
		import_page_refresh_result_type_id = g_enum_register_static ("ImportPageRefreshResult", values);
		g_once_init_leave (&import_page_refresh_result_type_id__volatile, import_page_refresh_result_type_id);
	}
	return import_page_refresh_result_type_id__volatile;
}


static gint64 _import_page_preview_comparator_comparator (void* a, void* b, gpointer self) {
	gint64 result;
	result = import_page_preview_comparator (a, b);
#line 747 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 5280 "ImportPage.c"
}


static gboolean _import_page_preview_comparator_predicate_comparator_predicate (DataObject* object, Alteration* alteration, gpointer self) {
	gboolean result;
	result = import_page_preview_comparator_predicate (object, alteration);
#line 747 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 5289 "ImportPage.c"
}


static void _import_page_on_view_changed_view_collection_items_state_changed (ViewCollection* _sender, GeeIterable* changed, gpointer self) {
#line 750 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	import_page_on_view_changed ((ImportPage*) self);
#line 5296 "ImportPage.c"
}


static void _import_page_on_view_changed_data_collection_contents_altered (DataCollection* _sender, GeeIterable* added, GeeIterable* removed, gpointer self) {
#line 751 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	import_page_on_view_changed ((ImportPage*) self);
#line 5303 "ImportPage.c"
}


static void _import_page_on_view_changed_view_collection_items_visibility_changed (ViewCollection* _sender, GeeCollection* changed, gpointer self) {
#line 752 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	import_page_on_view_changed ((ImportPage*) self);
#line 5310 "ImportPage.c"
}


ImportPage* import_page_construct (GType object_type, Camera* camera, const gchar* uri, const gchar* display_name, const gchar* icon) {
	ImportPage * self = NULL;
	const gchar* _tmp0_ = NULL;
	Camera* _tmp1_ = NULL;
	Camera* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
	ImportSourceCollection* _tmp8_ = NULL;
	const gchar* _tmp9_ = NULL;
	gchar* _tmp10_ = NULL;
	ViewCollection* _tmp11_ = NULL;
	ViewCollection* _tmp12_ = NULL;
	CameraViewTracker* _tmp13_ = NULL;
	const gchar* _tmp14_ = NULL;
	GtkLabel* _tmp26_ = NULL;
	const gchar* _tmp27_ = NULL;
	const gchar* _tmp28_ = NULL;
	GVolumeMonitor* _tmp29_ = NULL;
	GPContextWrapper* _tmp30_ = NULL;
	GPSpinIdleWrapper* _tmp32_ = NULL;
	ViewCollection* _tmp34_ = NULL;
	ViewCollection* _tmp35_ = NULL;
	SourceCollection* _tmp36_ = NULL;
	ImportPageImportViewManager* _tmp37_ = NULL;
	ImportPageImportViewManager* _tmp38_ = NULL;
	ViewCollectionMonitor* _tmp39_ = NULL;
	ViewCollectionMonitor* _tmp40_ = NULL;
	ViewCollection* _tmp41_ = NULL;
	ViewCollection* _tmp42_ = NULL;
	ViewCollection* _tmp43_ = NULL;
	ViewCollection* _tmp44_ = NULL;
	ViewCollection* _tmp45_ = NULL;
	ViewCollection* _tmp46_ = NULL;
	ViewCollection* _tmp47_ = NULL;
	ViewCollection* _tmp48_ = NULL;
	ViewCollection* _tmp49_ = NULL;
	ViewCollection* _tmp50_ = NULL;
	GValue _tmp51_ = {0};
	LibraryPhotoSourceCollection* _tmp52_ = NULL;
	VideoSourceCollection* _tmp53_ = NULL;
#line 709 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail (camera != NULL, NULL);
#line 709 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail (uri != NULL, NULL);
#line 710 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = _ ("Camera");
#line 710 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self = (ImportPage*) checkerboard_page_construct (object_type, _tmp0_);
#line 711 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = camera;
#line 711 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp2_ = _GPHOTO_REF_CAMERA0 (_tmp1_);
#line 711 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_gp_camera_unref0 (self->priv->camera);
#line 711 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self->priv->camera = _tmp2_;
#line 712 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp3_ = uri;
#line 712 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp4_ = g_strdup (_tmp3_);
#line 712 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_free0 (self->priv->uri);
#line 712 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self->priv->uri = _tmp4_;
#line 713 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp5_ = uri;
#line 713 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp6_ = g_strdup_printf ("ImportSources for %s", _tmp5_);
#line 713 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp7_ = _tmp6_;
#line 713 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp8_ = import_source_collection_new (_tmp7_);
#line 713 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_data_collection_unref0 (self->priv->import_sources);
#line 713 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self->priv->import_sources = G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, TYPE_SOURCE_COLLECTION, SourceCollection);
#line 713 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_free0 (_tmp7_);
#line 714 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp9_ = icon;
#line 714 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp10_ = g_strdup (_tmp9_);
#line 714 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_free0 (self->priv->icon);
#line 714 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self->priv->icon = _tmp10_;
#line 716 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp11_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 716 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp12_ = _tmp11_;
#line 716 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp13_ = camera_view_tracker_new (_tmp12_);
#line 716 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_core_tracker_unref0 (self->priv->tracker);
#line 716 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self->priv->tracker = _tmp13_;
#line 716 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_data_collection_unref0 (_tmp12_);
#line 719 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp14_ = display_name;
#line 719 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (NULL != _tmp14_) {
#line 5419 "ImportPage.c"
		const gchar* _tmp15_ = NULL;
		gchar* _tmp16_ = NULL;
#line 720 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp15_ = display_name;
#line 720 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp16_ = g_strdup (_tmp15_);
#line 720 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_free0 (self->priv->camera_name);
#line 720 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		self->priv->camera_name = _tmp16_;
#line 5430 "ImportPage.c"
	} else {
		CameraAbilities abilities = {0};
		int res = 0;
		Camera* _tmp17_ = NULL;
		CameraAbilities _tmp18_ = {0};
		int _tmp19_ = 0;
		int _tmp20_ = 0;
#line 723 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp17_ = camera;
#line 723 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp19_ = gp_camera_get_abilities (_tmp17_, &_tmp18_);
#line 723 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		 (abilities);
#line 723 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		abilities = _tmp18_;
#line 723 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		res = _tmp19_;
#line 724 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp20_ = res;
#line 724 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		if (_tmp20_ != GP_OK) {
#line 5452 "ImportPage.c"
			int _tmp21_ = 0;
			gchar* _tmp22_ = NULL;
			gchar* _tmp23_ = NULL;
			const gchar* _tmp24_ = NULL;
			gchar* _tmp25_ = NULL;
#line 725 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp21_ = res;
#line 725 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp22_ = gp_result_to_full_string (_tmp21_);
#line 725 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp23_ = _tmp22_;
#line 725 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			g_debug ("ImportPage.vala:725: Unable to get camera abilities: %s", _tmp23_);
#line 725 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_g_free0 (_tmp23_);
#line 726 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp24_ = _ ("Camera");
#line 726 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp25_ = g_strdup (_tmp24_);
#line 726 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_g_free0 (self->priv->camera_name);
#line 726 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			self->priv->camera_name = _tmp25_;
#line 5476 "ImportPage.c"
		}
#line 719 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		 (abilities);
#line 5480 "ImportPage.c"
	}
#line 729 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp26_ = self->priv->camera_label;
#line 729 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp27_ = self->priv->camera_name;
#line 729 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	gtk_label_set_text (_tmp26_, _tmp27_);
#line 730 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp28_ = self->priv->camera_name;
#line 730 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	page_set_page_name (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page), _tmp28_);
#line 733 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp29_ = g_volume_monitor_get ();
#line 733 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_object_unref0 (self->priv->volume_monitor);
#line 733 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self->priv->volume_monitor = _tmp29_;
#line 736 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp30_ = import_page_null_context;
#line 736 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (_tmp30_ == NULL) {
#line 5502 "ImportPage.c"
		GPContextWrapper* _tmp31_ = NULL;
#line 737 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp31_ = gp_context_wrapper_new ();
#line 737 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_gp_context_wrapper_unref0 (import_page_null_context);
#line 737 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		import_page_null_context = _tmp31_;
#line 5510 "ImportPage.c"
	}
#line 740 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp32_ = import_page_spin_idle_context;
#line 740 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (_tmp32_ == NULL) {
#line 5516 "ImportPage.c"
		GPSpinIdleWrapper* _tmp33_ = NULL;
#line 741 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp33_ = gp_spin_idle_wrapper_new ();
#line 741 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_gp_context_wrapper_unref0 (import_page_spin_idle_context);
#line 741 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		import_page_spin_idle_context = _tmp33_;
#line 5524 "ImportPage.c"
	}
#line 744 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp34_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 744 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp35_ = _tmp34_;
#line 744 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp36_ = self->priv->import_sources;
#line 744 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp37_ = import_page_import_view_manager_new (self);
#line 744 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp38_ = _tmp37_;
#line 744 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp39_ = view_collection_monitor_source_collection (_tmp35_, _tmp36_, G_TYPE_CHECK_INSTANCE_CAST (_tmp38_, TYPE_VIEW_MANAGER, ViewManager), NULL, NULL, NULL, NULL);
#line 744 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp40_ = _tmp39_;
#line 744 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_view_collection_monitor_unref0 (_tmp40_);
#line 744 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_view_manager_unref0 (_tmp38_);
#line 744 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_data_collection_unref0 (_tmp35_);
#line 747 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp41_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 747 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp42_ = _tmp41_;
#line 747 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	data_collection_set_comparator (G_TYPE_CHECK_INSTANCE_CAST (_tmp42_, TYPE_DATA_COLLECTION, DataCollection), _import_page_preview_comparator_comparator, NULL, _import_page_preview_comparator_predicate_comparator_predicate, NULL);
#line 747 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_data_collection_unref0 (_tmp42_);
#line 750 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp43_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 750 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp44_ = _tmp43_;
#line 750 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_signal_connect_object (_tmp44_, "items-state-changed", (GCallback) _import_page_on_view_changed_view_collection_items_state_changed, self, 0);
#line 750 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_data_collection_unref0 (_tmp44_);
#line 751 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp45_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 751 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp46_ = _tmp45_;
#line 751 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp46_, TYPE_DATA_COLLECTION, DataCollection), "contents-altered", (GCallback) _import_page_on_view_changed_data_collection_contents_altered, self, 0);
#line 751 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_data_collection_unref0 (_tmp46_);
#line 752 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp47_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 752 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp48_ = _tmp47_;
#line 752 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_signal_connect_object (_tmp48_, "items-visibility-changed", (GCallback) _import_page_on_view_changed_view_collection_items_visibility_changed, self, 0);
#line 752 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_data_collection_unref0 (_tmp48_);
#line 755 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp49_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 755 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp50_ = _tmp49_;
#line 755 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_value_init (&_tmp51_, G_TYPE_BOOLEAN);
#line 755 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_value_set_boolean (&_tmp51_, TRUE);
#line 755 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	data_collection_set_property (G_TYPE_CHECK_INSTANCE_CAST (_tmp50_, TYPE_DATA_COLLECTION, DataCollection), CHECKERBOARD_ITEM_PROP_SHOW_SUBTITLES, &_tmp51_, NULL, NULL);
#line 755 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	G_IS_VALUE (&_tmp51_) ? (g_value_unset (&_tmp51_), NULL) : NULL;
#line 755 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_data_collection_unref0 (_tmp50_);
#line 758 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp52_ = library_photo_global;
#line 758 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp52_, TYPE_DATA_COLLECTION, DataCollection), "contents-altered", (GCallback) _import_page_on_media_added_removed_data_collection_contents_altered, self, 0);
#line 759 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp53_ = video_global;
#line 759 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp53_, TYPE_DATA_COLLECTION, DataCollection), "contents-altered", (GCallback) _import_page_on_media_added_removed_data_collection_contents_altered, self, 0);
#line 761 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	checkerboard_page_init_item_context_menu (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_CHECKERBOARD_PAGE, CheckerboardPage), "/ImportContextMenu");
#line 762 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	checkerboard_page_init_page_context_menu (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_CHECKERBOARD_PAGE, CheckerboardPage), "/ImportContextMenu");
#line 709 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return self;
#line 5606 "ImportPage.c"
}


ImportPage* import_page_new (Camera* camera, const gchar* uri, const gchar* display_name, const gchar* icon) {
#line 709 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return import_page_construct (TYPE_IMPORT_PAGE, camera, uri, display_name, icon);
#line 5613 "ImportPage.c"
}


static void _import_page_on_hide_imported_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 777 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	import_page_on_hide_imported ((ImportPage*) self);
#line 5620 "ImportPage.c"
}


static GtkToolbar* import_page_real_get_toolbar (Page* base) {
	ImportPage * self;
	GtkToolbar* result = NULL;
	GtkToolbar* _tmp0_ = NULL;
	GtkToolbar* _tmp56_ = NULL;
	GtkToolbar* _tmp57_ = NULL;
#line 770 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_IMPORT_PAGE, ImportPage);
#line 771 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page)->toolbar;
#line 771 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (_tmp0_ == NULL) {
#line 5636 "ImportPage.c"
		GtkToolbar* _tmp1_ = NULL;
		GtkToolbar* _tmp2_ = NULL;
		const gchar* _tmp3_ = NULL;
		GtkCheckButton* _tmp4_ = NULL;
		GtkCheckButton* _tmp5_ = NULL;
		const gchar* _tmp6_ = NULL;
		GtkCheckButton* _tmp7_ = NULL;
		GtkCheckButton* _tmp8_ = NULL;
		GtkCheckButton* _tmp9_ = NULL;
		ConfigFacade* _tmp10_ = NULL;
		ConfigFacade* _tmp11_ = NULL;
		gboolean _tmp12_ = FALSE;
		GtkToolItem* hide_item = NULL;
		GtkToolItem* _tmp13_ = NULL;
		GtkToolItem* _tmp14_ = NULL;
		GtkToolItem* _tmp15_ = NULL;
		GtkCheckButton* _tmp16_ = NULL;
		GtkToolbar* _tmp17_ = NULL;
		GtkToolItem* _tmp18_ = NULL;
		GtkSeparatorToolItem* separator = NULL;
		GtkSeparatorToolItem* _tmp19_ = NULL;
		GtkSeparatorToolItem* _tmp20_ = NULL;
		GtkToolbar* _tmp21_ = NULL;
		GtkSeparatorToolItem* _tmp22_ = NULL;
		GtkProgressBar* _tmp23_ = NULL;
		GtkProgressBar* _tmp24_ = NULL;
		GtkToolItem* progress_item = NULL;
		GtkToolItem* _tmp25_ = NULL;
		GtkToolItem* _tmp26_ = NULL;
		GtkToolItem* _tmp27_ = NULL;
		GtkProgressBar* _tmp28_ = NULL;
		GtkProgressBar* _tmp29_ = NULL;
		GtkToolbar* _tmp30_ = NULL;
		GtkToolItem* _tmp31_ = NULL;
		GtkToggleToolButton* find_button = NULL;
		GtkToggleToolButton* _tmp32_ = NULL;
		GtkToggleToolButton* _tmp33_ = NULL;
		GtkAction* _tmp34_ = NULL;
		GtkAction* _tmp35_ = NULL;
		GtkToolbar* _tmp36_ = NULL;
		GtkToggleToolButton* _tmp37_ = NULL;
		GtkToolbar* _tmp38_ = NULL;
		GtkSeparatorToolItem* _tmp39_ = NULL;
		GtkSeparatorToolItem* _tmp40_ = NULL;
		GtkToolButton* import_selected_button = NULL;
		GtkToolButton* _tmp41_ = NULL;
		GtkToolButton* _tmp42_ = NULL;
		GtkToolButton* _tmp43_ = NULL;
		GtkAction* _tmp44_ = NULL;
		GtkAction* _tmp45_ = NULL;
		GtkToolbar* _tmp46_ = NULL;
		GtkToolButton* _tmp47_ = NULL;
		GtkToolButton* import_all_button = NULL;
		GtkToolButton* _tmp48_ = NULL;
		GtkToolButton* _tmp49_ = NULL;
		GtkToolButton* _tmp50_ = NULL;
		GtkAction* _tmp51_ = NULL;
		GtkAction* _tmp52_ = NULL;
		GtkToolbar* _tmp53_ = NULL;
		GtkToolButton* _tmp54_ = NULL;
		GtkProgressBar* _tmp55_ = NULL;
#line 772 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp1_ = PAGE_CLASS (import_page_parent_class)->get_toolbar (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_CHECKERBOARD_PAGE, CheckerboardPage), TYPE_PAGE, Page));
#line 772 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp2_ = _tmp1_;
#line 772 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_object_unref0 (_tmp2_);
#line 775 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp3_ = _ ("Hide photos already imported");
#line 775 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp4_ = (GtkCheckButton*) gtk_check_button_new_with_label (_tmp3_);
#line 775 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		g_object_ref_sink (_tmp4_);
#line 775 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_object_unref0 (self->priv->hide_imported);
#line 775 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		self->priv->hide_imported = _tmp4_;
#line 776 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp5_ = self->priv->hide_imported;
#line 776 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp6_ = _ ("Only display photos that have not been imported");
#line 776 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		gtk_widget_set_tooltip_text (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, gtk_widget_get_type (), GtkWidget), _tmp6_);
#line 777 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp7_ = self->priv->hide_imported;
#line 777 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, gtk_button_get_type (), GtkButton), "clicked", (GCallback) _import_page_on_hide_imported_gtk_button_clicked, self, 0);
#line 778 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp8_ = self->priv->hide_imported;
#line 778 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 779 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp9_ = self->priv->hide_imported;
#line 779 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp10_ = config_facade_get_instance ();
#line 779 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp11_ = _tmp10_;
#line 779 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp12_ = configuration_facade_get_hide_photos_already_imported (G_TYPE_CHECK_INSTANCE_CAST (_tmp11_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade));
#line 779 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		gtk_toggle_button_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, gtk_toggle_button_get_type (), GtkToggleButton), _tmp12_);
#line 779 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_object_unref0 (_tmp11_);
#line 780 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp13_ = gtk_tool_item_new ();
#line 780 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		g_object_ref_sink (_tmp13_);
#line 780 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		hide_item = _tmp13_;
#line 781 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp14_ = hide_item;
#line 781 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		gtk_tool_item_set_is_important (_tmp14_, TRUE);
#line 782 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp15_ = hide_item;
#line 782 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp16_ = self->priv->hide_imported;
#line 782 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		gtk_container_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp15_, gtk_container_get_type (), GtkContainer), G_TYPE_CHECK_INSTANCE_CAST (_tmp16_, gtk_widget_get_type (), GtkWidget));
#line 784 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp17_ = G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page)->toolbar;
#line 784 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp18_ = hide_item;
#line 784 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		gtk_toolbar_insert (_tmp17_, _tmp18_, -1);
#line 787 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp19_ = (GtkSeparatorToolItem*) gtk_separator_tool_item_new ();
#line 787 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		g_object_ref_sink (_tmp19_);
#line 787 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		separator = _tmp19_;
#line 788 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp20_ = separator;
#line 788 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		gtk_separator_tool_item_set_draw (_tmp20_, FALSE);
#line 790 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp21_ = G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page)->toolbar;
#line 790 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp22_ = separator;
#line 790 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		gtk_toolbar_insert (_tmp21_, G_TYPE_CHECK_INSTANCE_CAST (_tmp22_, gtk_tool_item_get_type (), GtkToolItem), -1);
#line 793 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp23_ = self->priv->progress_bar;
#line 793 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		gtk_orientable_set_orientation (G_TYPE_CHECK_INSTANCE_CAST (_tmp23_, GTK_TYPE_ORIENTABLE, GtkOrientable), GTK_ORIENTATION_HORIZONTAL);
#line 794 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp24_ = self->priv->progress_bar;
#line 794 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		gtk_widget_set_visible (G_TYPE_CHECK_INSTANCE_CAST (_tmp24_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 795 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp25_ = gtk_tool_item_new ();
#line 795 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		g_object_ref_sink (_tmp25_);
#line 795 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		progress_item = _tmp25_;
#line 796 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp26_ = progress_item;
#line 796 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		gtk_tool_item_set_expand (_tmp26_, TRUE);
#line 797 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp27_ = progress_item;
#line 797 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp28_ = self->priv->progress_bar;
#line 797 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		gtk_container_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp27_, gtk_container_get_type (), GtkContainer), G_TYPE_CHECK_INSTANCE_CAST (_tmp28_, gtk_widget_get_type (), GtkWidget));
#line 798 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp29_ = self->priv->progress_bar;
#line 798 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		gtk_progress_bar_set_show_text (_tmp29_, TRUE);
#line 800 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp30_ = G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page)->toolbar;
#line 800 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp31_ = progress_item;
#line 800 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		gtk_toolbar_insert (_tmp30_, _tmp31_, -1);
#line 803 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp32_ = (GtkToggleToolButton*) gtk_toggle_tool_button_new ();
#line 803 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		g_object_ref_sink (_tmp32_);
#line 803 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		find_button = _tmp32_;
#line 804 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp33_ = find_button;
#line 804 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp34_ = page_get_action (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page), "CommonDisplaySearchbar");
#line 804 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp35_ = _tmp34_;
#line 804 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		gtk_activatable_set_related_action (G_TYPE_CHECK_INSTANCE_CAST (_tmp33_, GTK_TYPE_ACTIVATABLE, GtkActivatable), _tmp35_);
#line 804 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_object_unref0 (_tmp35_);
#line 806 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp36_ = G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page)->toolbar;
#line 806 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp37_ = find_button;
#line 806 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		gtk_toolbar_insert (_tmp36_, G_TYPE_CHECK_INSTANCE_CAST (_tmp37_, gtk_tool_item_get_type (), GtkToolItem), -1);
#line 809 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp38_ = G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page)->toolbar;
#line 809 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp39_ = (GtkSeparatorToolItem*) gtk_separator_tool_item_new ();
#line 809 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		g_object_ref_sink (_tmp39_);
#line 809 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp40_ = _tmp39_;
#line 809 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		gtk_toolbar_insert (_tmp38_, G_TYPE_CHECK_INSTANCE_CAST (_tmp40_, gtk_tool_item_get_type (), GtkToolItem), -1);
#line 809 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_object_unref0 (_tmp40_);
#line 812 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp41_ = (GtkToolButton*) gtk_tool_button_new (NULL, NULL);
#line 812 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		g_object_ref_sink (_tmp41_);
#line 812 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		import_selected_button = _tmp41_;
#line 813 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp42_ = import_selected_button;
#line 813 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		gtk_tool_button_set_icon_name (_tmp42_, RESOURCES_IMPORT);
#line 814 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp43_ = import_selected_button;
#line 814 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp44_ = page_get_action (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page), "ImportSelected");
#line 814 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp45_ = _tmp44_;
#line 814 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		gtk_activatable_set_related_action (G_TYPE_CHECK_INSTANCE_CAST (_tmp43_, GTK_TYPE_ACTIVATABLE, GtkActivatable), _tmp45_);
#line 814 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_object_unref0 (_tmp45_);
#line 816 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp46_ = G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page)->toolbar;
#line 816 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp47_ = import_selected_button;
#line 816 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		gtk_toolbar_insert (_tmp46_, G_TYPE_CHECK_INSTANCE_CAST (_tmp47_, gtk_tool_item_get_type (), GtkToolItem), -1);
#line 819 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp48_ = (GtkToolButton*) gtk_tool_button_new (NULL, NULL);
#line 819 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		g_object_ref_sink (_tmp48_);
#line 819 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		import_all_button = _tmp48_;
#line 820 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp49_ = import_all_button;
#line 820 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		gtk_tool_button_set_icon_name (_tmp49_, RESOURCES_IMPORT_ALL);
#line 821 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp50_ = import_all_button;
#line 821 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp51_ = page_get_action (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page), "ImportAll");
#line 821 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp52_ = _tmp51_;
#line 821 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		gtk_activatable_set_related_action (G_TYPE_CHECK_INSTANCE_CAST (_tmp50_, GTK_TYPE_ACTIVATABLE, GtkActivatable), _tmp52_);
#line 821 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_object_unref0 (_tmp52_);
#line 823 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp53_ = G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page)->toolbar;
#line 823 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp54_ = import_all_button;
#line 823 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		gtk_toolbar_insert (_tmp53_, G_TYPE_CHECK_INSTANCE_CAST (_tmp54_, gtk_tool_item_get_type (), GtkToolItem), -1);
#line 827 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp55_ = self->priv->progress_bar;
#line 827 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		gtk_widget_set_no_show_all (G_TYPE_CHECK_INSTANCE_CAST (_tmp55_, gtk_widget_get_type (), GtkWidget), TRUE);
#line 829 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		import_page_update_toolbar_state (self);
#line 831 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		gtk_widget_show_all (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 771 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_object_unref0 (import_all_button);
#line 771 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_object_unref0 (import_selected_button);
#line 771 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_object_unref0 (find_button);
#line 771 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_object_unref0 (progress_item);
#line 771 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_object_unref0 (separator);
#line 771 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_object_unref0 (hide_item);
#line 5918 "ImportPage.c"
	}
#line 834 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp56_ = G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page)->toolbar;
#line 834 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp57_ = _g_object_ref0 (_tmp56_);
#line 834 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = _tmp57_;
#line 834 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 5928 "ImportPage.c"
}


static gpointer _core_tracker_ref0 (gpointer self) {
#line 838 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return self ? core_tracker_ref (self) : NULL;
#line 5935 "ImportPage.c"
}


static CoreViewTracker* import_page_real_get_view_tracker (CheckerboardPage* base) {
	ImportPage * self;
	CoreViewTracker* result = NULL;
	CameraViewTracker* _tmp0_ = NULL;
	CoreViewTracker* _tmp1_ = NULL;
#line 837 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_IMPORT_PAGE, ImportPage);
#line 838 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = self->priv->tracker;
#line 838 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = _core_tracker_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, CORE_TYPE_VIEW_TRACKER, CoreViewTracker));
#line 838 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = _tmp1_;
#line 838 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 5954 "ImportPage.c"
}


static gchar* import_page_real_get_view_empty_message (CheckerboardPage* base) {
	ImportPage * self;
	gchar* result = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 841 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_IMPORT_PAGE, ImportPage);
#line 842 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = _ ("The camera seems to be empty. No photos/videos found to import");
#line 842 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 842 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = _tmp1_;
#line 842 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 5973 "ImportPage.c"
}


static gchar* import_page_real_get_filter_no_match_message (CheckerboardPage* base) {
	ImportPage * self;
	gchar* result = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 845 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_IMPORT_PAGE, ImportPage);
#line 846 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = _ ("No new photos/videos found on camera");
#line 846 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 846 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = _tmp1_;
#line 846 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 5992 "ImportPage.c"
}


static gint64 import_page_preview_comparator (void* a, void* b) {
	gint64 result = 0LL;
	void* _tmp0_ = NULL;
	ImportSource* _tmp1_ = NULL;
	ImportSource* _tmp2_ = NULL;
	time_t _tmp3_ = 0;
	void* _tmp4_ = NULL;
	ImportSource* _tmp5_ = NULL;
	ImportSource* _tmp6_ = NULL;
	time_t _tmp7_ = 0;
	gint64 _tmp8_ = 0LL;
#line 850 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = a;
#line 850 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = import_preview_get_import_source (G_TYPE_CHECK_INSTANCE_CAST ((ImportPreview*) _tmp0_, TYPE_IMPORT_PREVIEW, ImportPreview));
#line 850 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp2_ = _tmp1_;
#line 850 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp3_ = import_source_get_exposure_time (_tmp2_);
#line 850 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp4_ = b;
#line 850 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp5_ = import_preview_get_import_source (G_TYPE_CHECK_INSTANCE_CAST ((ImportPreview*) _tmp4_, TYPE_IMPORT_PREVIEW, ImportPreview));
#line 850 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp6_ = _tmp5_;
#line 850 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp7_ = import_source_get_exposure_time (_tmp6_);
#line 850 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp8_ = (gint64) (_tmp3_ - _tmp7_);
#line 850 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_object_unref0 (_tmp6_);
#line 850 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_object_unref0 (_tmp2_);
#line 850 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = _tmp8_;
#line 850 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 6033 "ImportPage.c"
}


static gboolean import_page_preview_comparator_predicate (DataObject* object, Alteration* alteration) {
	gboolean result = FALSE;
	Alteration* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
#line 854 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail (IS_DATA_OBJECT (object), FALSE);
#line 854 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail (IS_ALTERATION (alteration), FALSE);
#line 855 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = alteration;
#line 855 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = alteration_has_detail (_tmp0_, "metadata", "exposure-time");
#line 855 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = _tmp1_;
#line 855 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 6053 "ImportPage.c"
}


static gint64 import_page_import_job_comparator (ImportPage* self, void* a, void* b) {
	gint64 result = 0LL;
	void* _tmp0_ = NULL;
	time_t _tmp1_ = 0;
	void* _tmp2_ = NULL;
	time_t _tmp3_ = 0;
#line 858 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail (IS_IMPORT_PAGE (self), 0LL);
#line 859 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = a;
#line 859 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = import_page_camera_import_job_get_exposure_time (G_TYPE_CHECK_INSTANCE_CAST ((ImportPageCameraImportJob*) _tmp0_, IMPORT_PAGE_TYPE_CAMERA_IMPORT_JOB, ImportPageCameraImportJob));
#line 859 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp2_ = b;
#line 859 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp3_ = import_page_camera_import_job_get_exposure_time (G_TYPE_CHECK_INSTANCE_CAST ((ImportPageCameraImportJob*) _tmp2_, IMPORT_PAGE_TYPE_CAMERA_IMPORT_JOB, ImportPageCameraImportJob));
#line 859 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = (gint64) (_tmp1_ - _tmp3_);
#line 859 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 6077 "ImportPage.c"
}


static void import_page_real_init_collect_ui_filenames (Page* base, GeeList* ui_filenames) {
	ImportPage * self;
	GeeList* _tmp0_ = NULL;
	GeeList* _tmp1_ = NULL;
#line 862 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_IMPORT_PAGE, ImportPage);
#line 862 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_if_fail (GEE_IS_LIST (ui_filenames));
#line 863 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = ui_filenames;
#line 863 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	PAGE_CLASS (import_page_parent_class)->init_collect_ui_filenames (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_CHECKERBOARD_PAGE, CheckerboardPage), TYPE_PAGE, Page), _tmp0_);
#line 865 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = ui_filenames;
#line 865 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	gee_collection_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, GEE_TYPE_COLLECTION, GeeCollection), "import.ui");
#line 6097 "ImportPage.c"
}


static void _import_page_on_display_titles_gtk_action_callback (GtkAction* action, gpointer self) {
#line 871 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	import_page_on_display_titles ((ImportPage*) self, action);
#line 6104 "ImportPage.c"
}


static void _vala_array_add143 (GtkToggleActionEntry** array, int* length, int* size, const GtkToggleActionEntry* value) {
#line 875 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if ((*length) == (*size)) {
#line 875 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 875 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		*array = g_renew (GtkToggleActionEntry, *array, *size);
#line 6115 "ImportPage.c"
	}
#line 875 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	(*array)[(*length)++] = *value;
#line 6119 "ImportPage.c"
}


static GtkToggleActionEntry* import_page_real_init_collect_toggle_action_entries (Page* base, int* result_length1) {
	ImportPage * self;
	GtkToggleActionEntry* result = NULL;
	GtkToggleActionEntry* toggle_actions = NULL;
	gint _tmp0_ = 0;
	GtkToggleActionEntry* _tmp1_ = NULL;
	gint toggle_actions_length1 = 0;
	gint _toggle_actions_size_ = 0;
	GtkToggleActionEntry titles = {0};
	ConfigFacade* _tmp2_ = NULL;
	ConfigFacade* _tmp3_ = NULL;
	gboolean _tmp4_ = FALSE;
	GtkToggleActionEntry _tmp5_ = {0};
	GtkToggleActionEntry _tmp6_ = {0};
	const gchar* _tmp7_ = NULL;
	const gchar* _tmp8_ = NULL;
	GtkToggleActionEntry* _tmp9_ = NULL;
	gint _tmp9__length1 = 0;
	GtkToggleActionEntry _tmp10_ = {0};
	GtkToggleActionEntry* _tmp11_ = NULL;
	gint _tmp11__length1 = 0;
#line 868 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_IMPORT_PAGE, ImportPage);
#line 869 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = PAGE_CLASS (import_page_parent_class)->init_collect_toggle_action_entries (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_CHECKERBOARD_PAGE, CheckerboardPage), TYPE_PAGE, Page), &_tmp0_);
#line 869 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	toggle_actions = _tmp1_;
#line 869 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	toggle_actions_length1 = _tmp0_;
#line 869 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_toggle_actions_size_ = toggle_actions_length1;
#line 871 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp2_ = config_facade_get_instance ();
#line 871 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp3_ = _tmp2_;
#line 871 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp4_ = configuration_facade_get_display_photo_titles (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade));
#line 871 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp5_.name = "ViewTitle";
#line 871 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp5_.stock_id = NULL;
#line 871 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp5_.label = TRANSLATABLE;
#line 871 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp5_.accelerator = "<Ctrl><Shift>T";
#line 871 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp5_.tooltip = TRANSLATABLE;
#line 871 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp5_.callback = (GCallback) _import_page_on_display_titles_gtk_action_callback;
#line 871 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp5_.is_active = _tmp4_;
#line 871 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp6_ = _tmp5_;
#line 871 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_object_unref0 (_tmp3_);
#line 871 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	titles = _tmp6_;
#line 873 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp7_ = _ ("_Titles");
#line 873 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	titles.label = _tmp7_;
#line 874 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp8_ = _ ("Display the title of each photo");
#line 874 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	titles.tooltip = _tmp8_;
#line 875 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp9_ = toggle_actions;
#line 875 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp9__length1 = toggle_actions_length1;
#line 875 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp10_ = titles;
#line 875 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_vala_array_add143 (&toggle_actions, &toggle_actions_length1, &_toggle_actions_size_, &_tmp10_);
#line 877 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp11_ = toggle_actions;
#line 877 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp11__length1 = toggle_actions_length1;
#line 877 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (result_length1) {
#line 877 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		*result_length1 = _tmp11__length1;
#line 6204 "ImportPage.c"
	}
#line 877 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = _tmp11_;
#line 877 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 6210 "ImportPage.c"
}


static void _import_page_on_import_selected_gtk_action_callback (GtkAction* action, gpointer self) {
#line 883 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	import_page_on_import_selected ((ImportPage*) self);
#line 6217 "ImportPage.c"
}


static void _vala_array_add144 (GtkActionEntry** array, int* length, int* size, const GtkActionEntry* value) {
#line 887 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if ((*length) == (*size)) {
#line 887 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 887 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		*array = g_renew (GtkActionEntry, *array, *size);
#line 6228 "ImportPage.c"
	}
#line 887 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	(*array)[(*length)++] = *value;
#line 6232 "ImportPage.c"
}


static void _import_page_on_import_all_gtk_action_callback (GtkAction* action, gpointer self) {
#line 889 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	import_page_on_import_all ((ImportPage*) self);
#line 6239 "ImportPage.c"
}


static void _vala_array_add145 (GtkActionEntry** array, int* length, int* size, const GtkActionEntry* value) {
#line 893 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if ((*length) == (*size)) {
#line 893 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 893 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		*array = g_renew (GtkActionEntry, *array, *size);
#line 6250 "ImportPage.c"
	}
#line 893 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	(*array)[(*length)++] = *value;
#line 6254 "ImportPage.c"
}


static GtkActionEntry* import_page_real_init_collect_action_entries (Page* base, int* result_length1) {
	ImportPage * self;
	GtkActionEntry* result = NULL;
	GtkActionEntry* actions = NULL;
	gint _tmp0_ = 0;
	GtkActionEntry* _tmp1_ = NULL;
	gint actions_length1 = 0;
	gint _actions_size_ = 0;
	GtkActionEntry import_selected = {0};
	GtkActionEntry _tmp2_ = {0};
	const gchar* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	GtkActionEntry* _tmp5_ = NULL;
	gint _tmp5__length1 = 0;
	GtkActionEntry _tmp6_ = {0};
	GtkActionEntry import_all = {0};
	GtkActionEntry _tmp7_ = {0};
	const gchar* _tmp8_ = NULL;
	const gchar* _tmp9_ = NULL;
	GtkActionEntry* _tmp10_ = NULL;
	gint _tmp10__length1 = 0;
	GtkActionEntry _tmp11_ = {0};
	GtkActionEntry* _tmp12_ = NULL;
	gint _tmp12__length1 = 0;
#line 880 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_IMPORT_PAGE, ImportPage);
#line 881 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = PAGE_CLASS (import_page_parent_class)->init_collect_action_entries (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_CHECKERBOARD_PAGE, CheckerboardPage), TYPE_PAGE, Page), &_tmp0_);
#line 881 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	actions = _tmp1_;
#line 881 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	actions_length1 = _tmp0_;
#line 881 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_actions_size_ = actions_length1;
#line 883 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp2_.name = "ImportSelected";
#line 883 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp2_.stock_id = RESOURCES_IMPORT;
#line 883 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp2_.label = TRANSLATABLE;
#line 883 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp2_.accelerator = NULL;
#line 883 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp2_.tooltip = NULL;
#line 883 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp2_.callback = (GCallback) _import_page_on_import_selected_gtk_action_callback;
#line 883 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	import_selected = _tmp2_;
#line 885 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp3_ = _ ("Import _Selected");
#line 885 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	import_selected.label = _tmp3_;
#line 886 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp4_ = _ ("Import the selected photos into your library");
#line 886 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	import_selected.tooltip = _tmp4_;
#line 887 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp5_ = actions;
#line 887 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp5__length1 = actions_length1;
#line 887 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp6_ = import_selected;
#line 887 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_vala_array_add144 (&actions, &actions_length1, &_actions_size_, &_tmp6_);
#line 889 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp7_.name = "ImportAll";
#line 889 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp7_.stock_id = RESOURCES_IMPORT_ALL;
#line 889 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp7_.label = TRANSLATABLE;
#line 889 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp7_.accelerator = NULL;
#line 889 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp7_.tooltip = NULL;
#line 889 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp7_.callback = (GCallback) _import_page_on_import_all_gtk_action_callback;
#line 889 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	import_all = _tmp7_;
#line 891 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp8_ = _ ("Import _All");
#line 891 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	import_all.label = _tmp8_;
#line 892 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp9_ = _ ("Import all the photos into your library");
#line 892 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	import_all.tooltip = _tmp9_;
#line 893 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp10_ = actions;
#line 893 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp10__length1 = actions_length1;
#line 893 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp11_ = import_all;
#line 893 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_vala_array_add145 (&actions, &actions_length1, &_actions_size_, &_tmp11_);
#line 895 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp12_ = actions;
#line 895 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp12__length1 = actions_length1;
#line 895 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (result_length1) {
#line 895 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		*result_length1 = _tmp12__length1;
#line 6360 "ImportPage.c"
	}
#line 895 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = _tmp12_;
#line 895 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 6366 "ImportPage.c"
}


Camera* import_page_get_camera (ImportPage* self) {
	Camera* result = NULL;
	Camera* _tmp0_ = NULL;
	Camera* _tmp1_ = NULL;
#line 898 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail (IS_IMPORT_PAGE (self), NULL);
#line 899 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = self->priv->camera;
#line 899 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = _GPHOTO_REF_CAMERA0 (_tmp0_);
#line 899 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = _tmp1_;
#line 899 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 6384 "ImportPage.c"
}


gchar* import_page_get_uri (ImportPage* self) {
	gchar* result = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 902 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail (IS_IMPORT_PAGE (self), NULL);
#line 903 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = self->priv->uri;
#line 903 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 903 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = _tmp1_;
#line 903 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 6402 "ImportPage.c"
}


gboolean import_page_is_busy (ImportPage* self) {
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
#line 906 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail (IS_IMPORT_PAGE (self), FALSE);
#line 907 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = self->priv->busy;
#line 907 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = _tmp0_;
#line 907 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 6417 "ImportPage.c"
}


static void import_page_real_init_actions (Page* base, gint selected_count, gint count) {
	ImportPage * self;
	gint _tmp0_ = 0;
	gint _tmp1_ = 0;
#line 910 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_IMPORT_PAGE, ImportPage);
#line 911 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	import_page_on_view_changed (self);
#line 913 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	page_set_action_important (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page), "ImportSelected", TRUE);
#line 914 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	page_set_action_important (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page), "ImportAll", TRUE);
#line 916 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = selected_count;
#line 916 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = count;
#line 916 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	PAGE_CLASS (import_page_parent_class)->init_actions (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_CHECKERBOARD_PAGE, CheckerboardPage), TYPE_PAGE, Page), _tmp0_, _tmp1_);
#line 6439 "ImportPage.c"
}


gboolean import_page_is_refreshed (ImportPage* self) {
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
#line 919 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail (IS_IMPORT_PAGE (self), FALSE);
#line 920 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = self->priv->refreshed;
#line 920 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (_tmp1_) {
#line 6453 "ImportPage.c"
		gboolean _tmp2_ = FALSE;
#line 920 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp2_ = self->priv->busy;
#line 920 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp0_ = !_tmp2_;
#line 6459 "ImportPage.c"
	} else {
#line 920 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp0_ = FALSE;
#line 6463 "ImportPage.c"
	}
#line 920 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = _tmp0_;
#line 920 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 6469 "ImportPage.c"
}


gchar* import_page_get_refresh_message (ImportPage* self) {
	gchar* result = NULL;
	gchar* msg = NULL;
	const gchar* _tmp0_ = NULL;
#line 923 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail (IS_IMPORT_PAGE (self), NULL);
#line 924 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	msg = NULL;
#line 925 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = self->priv->refresh_error;
#line 925 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (_tmp0_ != NULL) {
#line 6485 "ImportPage.c"
		const gchar* _tmp1_ = NULL;
		gchar* _tmp2_ = NULL;
#line 926 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp1_ = self->priv->refresh_error;
#line 926 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp2_ = g_strdup (_tmp1_);
#line 926 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_free0 (msg);
#line 926 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		msg = _tmp2_;
#line 6496 "ImportPage.c"
	} else {
		int _tmp3_ = 0;
#line 927 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp3_ = self->priv->refresh_result;
#line 927 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		if (_tmp3_ == GP_OK) {
#line 6503 "ImportPage.c"
		} else {
			int _tmp4_ = 0;
			gchar* _tmp5_ = NULL;
#line 930 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp4_ = self->priv->refresh_result;
#line 930 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp5_ = gp_result_to_full_string (_tmp4_);
#line 930 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_g_free0 (msg);
#line 930 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			msg = _tmp5_;
#line 6515 "ImportPage.c"
		}
	}
#line 933 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = msg;
#line 933 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 6522 "ImportPage.c"
}


static void import_page_update_status (ImportPage* self, gboolean busy, gboolean refreshed) {
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
#line 936 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_if_fail (IS_IMPORT_PAGE (self));
#line 937 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = busy;
#line 937 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self->priv->busy = _tmp0_;
#line 938 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = refreshed;
#line 938 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self->priv->refreshed = _tmp1_;
#line 940 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	import_page_on_view_changed (self);
#line 6541 "ImportPage.c"
}


static void import_page_update_toolbar_state (ImportPage* self) {
	GtkCheckButton* _tmp0_ = NULL;
#line 943 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_if_fail (IS_IMPORT_PAGE (self));
#line 944 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = self->priv->hide_imported;
#line 944 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (_tmp0_ != NULL) {
#line 6553 "ImportPage.c"
		gboolean _tmp1_ = FALSE;
		gboolean _tmp2_ = FALSE;
		gboolean _tmp3_ = FALSE;
		GtkCheckButton* _tmp8_ = NULL;
#line 945 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp3_ = self->priv->busy;
#line 945 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		if (!_tmp3_) {
#line 6562 "ImportPage.c"
			gboolean _tmp4_ = FALSE;
#line 945 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp4_ = self->priv->refreshed;
#line 945 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp2_ = _tmp4_;
#line 6568 "ImportPage.c"
		} else {
#line 945 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp2_ = FALSE;
#line 6572 "ImportPage.c"
		}
#line 945 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		if (_tmp2_) {
#line 6576 "ImportPage.c"
			ViewCollection* _tmp5_ = NULL;
			ViewCollection* _tmp6_ = NULL;
			gint _tmp7_ = 0;
#line 945 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp5_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 945 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp6_ = _tmp5_;
#line 945 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp7_ = view_collection_get_unfiltered_count (_tmp6_);
#line 945 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp1_ = _tmp7_ > 0;
#line 945 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_data_collection_unref0 (_tmp6_);
#line 6590 "ImportPage.c"
		} else {
#line 945 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp1_ = FALSE;
#line 6594 "ImportPage.c"
		}
#line 945 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp8_ = self->priv->hide_imported;
#line 945 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, gtk_widget_get_type (), GtkWidget), _tmp1_);
#line 6600 "ImportPage.c"
	}
}


static void import_page_on_view_changed (ImportPage* self) {
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_ = FALSE;
	gboolean _tmp7_ = FALSE;
	gboolean _tmp8_ = FALSE;
	gboolean _tmp9_ = FALSE;
	gboolean _tmp14_ = FALSE;
	gboolean _tmp15_ = FALSE;
	AppWindow* _tmp19_ = NULL;
	AppWindow* _tmp20_ = NULL;
#line 948 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_if_fail (IS_IMPORT_PAGE (self));
#line 949 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp2_ = self->priv->busy;
#line 949 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (!_tmp2_) {
#line 6622 "ImportPage.c"
		gboolean _tmp3_ = FALSE;
#line 949 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp3_ = self->priv->refreshed;
#line 949 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp1_ = _tmp3_;
#line 6628 "ImportPage.c"
	} else {
#line 949 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp1_ = FALSE;
#line 6632 "ImportPage.c"
	}
#line 949 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (_tmp1_) {
#line 6636 "ImportPage.c"
		ViewCollection* _tmp4_ = NULL;
		ViewCollection* _tmp5_ = NULL;
		gint _tmp6_ = 0;
#line 949 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp4_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 949 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp5_ = _tmp4_;
#line 949 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp6_ = view_collection_get_selected_count (_tmp5_);
#line 949 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp0_ = _tmp6_ > 0;
#line 949 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_data_collection_unref0 (_tmp5_);
#line 6650 "ImportPage.c"
	} else {
#line 949 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp0_ = FALSE;
#line 6654 "ImportPage.c"
	}
#line 949 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	page_set_action_sensitive (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page), "ImportSelected", _tmp0_);
#line 950 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp9_ = self->priv->busy;
#line 950 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (!_tmp9_) {
#line 6662 "ImportPage.c"
		gboolean _tmp10_ = FALSE;
#line 950 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp10_ = self->priv->refreshed;
#line 950 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp8_ = _tmp10_;
#line 6668 "ImportPage.c"
	} else {
#line 950 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp8_ = FALSE;
#line 6672 "ImportPage.c"
	}
#line 950 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (_tmp8_) {
#line 6676 "ImportPage.c"
		ViewCollection* _tmp11_ = NULL;
		ViewCollection* _tmp12_ = NULL;
		gint _tmp13_ = 0;
#line 950 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp11_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 950 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp12_ = _tmp11_;
#line 950 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp13_ = data_collection_get_count (G_TYPE_CHECK_INSTANCE_CAST (_tmp12_, TYPE_DATA_COLLECTION, DataCollection));
#line 950 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp7_ = _tmp13_ > 0;
#line 950 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_data_collection_unref0 (_tmp12_);
#line 6690 "ImportPage.c"
	} else {
#line 950 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp7_ = FALSE;
#line 6694 "ImportPage.c"
	}
#line 950 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	page_set_action_sensitive (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page), "ImportAll", _tmp7_);
#line 952 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp15_ = self->priv->busy;
#line 952 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (!_tmp15_) {
#line 6702 "ImportPage.c"
		ViewCollection* _tmp16_ = NULL;
		ViewCollection* _tmp17_ = NULL;
		gint _tmp18_ = 0;
#line 952 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp16_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 952 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp17_ = _tmp16_;
#line 952 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp18_ = data_collection_get_count (G_TYPE_CHECK_INSTANCE_CAST (_tmp17_, TYPE_DATA_COLLECTION, DataCollection));
#line 952 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp14_ = _tmp18_ > 0;
#line 952 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_data_collection_unref0 (_tmp17_);
#line 6716 "ImportPage.c"
	} else {
#line 952 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp14_ = FALSE;
#line 6720 "ImportPage.c"
	}
#line 951 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp19_ = app_window_get_instance ();
#line 951 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp20_ = _tmp19_;
#line 951 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	app_window_set_common_action_sensitive (_tmp20_, "CommonSelectAll", _tmp14_);
#line 951 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_object_unref0 (_tmp20_);
#line 954 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	import_page_update_toolbar_state (self);
#line 6732 "ImportPage.c"
}


static void import_page_on_media_added_removed (ImportPage* self) {
	ImportPageImportPageSearchViewFilter* _tmp0_ = NULL;
#line 957 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_if_fail (IS_IMPORT_PAGE (self));
#line 958 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = self->priv->search_filter;
#line 958 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_signal_emit_by_name (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, TYPE_VIEW_FILTER, ViewFilter), "refresh");
#line 6744 "ImportPage.c"
}


static void import_page_on_display_titles (ImportPage* self, GtkAction* action) {
	gboolean display = FALSE;
	GtkAction* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	ConfigFacade* _tmp2_ = NULL;
	ConfigFacade* _tmp3_ = NULL;
#line 961 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_if_fail (IS_IMPORT_PAGE (self));
#line 961 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_if_fail (GTK_IS_ACTION (action));
#line 962 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = action;
#line 962 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = gtk_toggle_action_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_toggle_action_get_type (), GtkToggleAction));
#line 962 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	display = _tmp1_;
#line 964 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	checkerboard_page_set_display_titles (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_CHECKERBOARD_PAGE, CheckerboardPage), display);
#line 965 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp2_ = config_facade_get_instance ();
#line 965 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp3_ = _tmp2_;
#line 965 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	configuration_facade_set_display_photo_titles (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade), display);
#line 965 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_object_unref0 (_tmp3_);
#line 6774 "ImportPage.c"
}


static void import_page_real_switched_to (Page* base) {
	ImportPage * self;
	ConfigFacade* _tmp0_ = NULL;
	ConfigFacade* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
#line 968 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_IMPORT_PAGE, ImportPage);
#line 969 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = config_facade_get_instance ();
#line 969 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = _tmp0_;
#line 969 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp2_ = configuration_facade_get_display_photo_titles (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade));
#line 969 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	checkerboard_page_set_display_titles (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_CHECKERBOARD_PAGE, CheckerboardPage), _tmp2_);
#line 969 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_object_unref0 (_tmp1_);
#line 971 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	PAGE_CLASS (import_page_parent_class)->switched_to (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_CHECKERBOARD_PAGE, CheckerboardPage), TYPE_PAGE, Page));
#line 6797 "ImportPage.c"
}


static void import_page_real_ready (Page* base) {
	ImportPage * self;
	ImportPageHideImportedViewFilter* _tmp0_ = NULL;
#line 974 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_IMPORT_PAGE, ImportPage);
#line 975 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	import_page_try_refreshing_camera (self, FALSE);
#line 976 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = self->priv->hide_imported_filter;
#line 976 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_signal_emit_by_name (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, TYPE_VIEW_FILTER, ViewFilter), "refresh");
#line 6812 "ImportPage.c"
}


static void import_page_try_refreshing_camera (ImportPage* self, gboolean fail_on_locked) {
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	ImportPageRefreshResult res = 0;
	ImportPageRefreshResult _tmp3_ = 0;
	ImportPageRefreshResult _tmp4_ = 0;
	GError * _inner_error_ = NULL;
#line 979 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_if_fail (IS_IMPORT_PAGE (self));
#line 981 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = self->priv->refreshed;
#line 981 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (_tmp1_) {
#line 981 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp0_ = TRUE;
#line 6831 "ImportPage.c"
	} else {
		gboolean _tmp2_ = FALSE;
#line 981 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp2_ = self->priv->busy;
#line 981 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp0_ = _tmp2_;
#line 6838 "ImportPage.c"
	}
#line 981 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (_tmp0_) {
#line 982 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		return;
#line 6844 "ImportPage.c"
	}
#line 984 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp3_ = import_page_refresh_camera (self);
#line 984 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	res = _tmp3_;
#line 985 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp4_ = res;
#line 985 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	switch (_tmp4_) {
#line 985 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		case IMPORT_PAGE_REFRESH_RESULT_OK:
#line 985 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		case IMPORT_PAGE_REFRESH_RESULT_BUSY:
#line 6858 "ImportPage.c"
		{
#line 990 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			break;
#line 6862 "ImportPage.c"
		}
#line 985 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		case IMPORT_PAGE_REFRESH_RESULT_LOCKED:
#line 6866 "ImportPage.c"
		{
			gboolean _tmp5_ = FALSE;
			const gchar* _tmp6_ = NULL;
			GFile* uri = NULL;
			const gchar* _tmp7_ = NULL;
			GFile* _tmp8_ = NULL;
			GMount* mount = NULL;
			GMount* _tmp13_ = NULL;
#line 993 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp5_ = fail_on_locked;
#line 993 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			if (_tmp5_) {
#line 994 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				app_window_error_message (IMPORT_PAGE_UNMOUNT_FAILED_MSG, NULL);
#line 996 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				break;
#line 6883 "ImportPage.c"
			}
#line 1000 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp6_ = self->priv->uri;
#line 1000 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			g_debug ("ImportPage.vala:1000: Checking if %s is mounted ...", _tmp6_);
#line 1002 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp7_ = self->priv->uri;
#line 1002 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp8_ = g_file_new_for_uri (_tmp7_);
#line 1002 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			uri = _tmp8_;
#line 1004 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			mount = NULL;
#line 6897 "ImportPage.c"
			{
				GMount* _tmp9_ = NULL;
				GFile* _tmp10_ = NULL;
				GMount* _tmp11_ = NULL;
				GMount* _tmp12_ = NULL;
#line 1006 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp10_ = uri;
#line 1006 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp11_ = g_file_find_enclosing_mount (_tmp10_, NULL, &_inner_error_);
#line 1006 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp9_ = _tmp11_;
#line 1006 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 6911 "ImportPage.c"
					goto __catch62_g_error;
				}
#line 1006 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp12_ = _tmp9_;
#line 1006 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp9_ = NULL;
#line 1006 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_g_object_unref0 (mount);
#line 1006 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				mount = _tmp12_;
#line 1005 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_g_object_unref0 (_tmp9_);
#line 6924 "ImportPage.c"
			}
			goto __finally62;
			__catch62_g_error:
			{
				GError* err = NULL;
#line 1005 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				err = _inner_error_;
#line 1005 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_inner_error_ = NULL;
#line 1005 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_g_error_free0 (err);
#line 6936 "ImportPage.c"
			}
			__finally62:
#line 1005 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1005 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_g_object_unref0 (mount);
#line 1005 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_g_object_unref0 (uri);
#line 1005 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1005 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				g_clear_error (&_inner_error_);
#line 1005 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				return;
#line 6951 "ImportPage.c"
			}
#line 1011 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp13_ = mount;
#line 1011 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			if (_tmp13_ != NULL) {
#line 6957 "ImportPage.c"
				gchar* mounted_message = NULL;
				const gchar* _tmp14_ = NULL;
				gchar* _tmp15_ = NULL;
				GtkMessageDialog* dialog = NULL;
				AppWindow* _tmp16_ = NULL;
				AppWindow* _tmp17_ = NULL;
				const gchar* _tmp18_ = NULL;
				GtkMessageDialog* _tmp19_ = NULL;
				GtkMessageDialog* _tmp20_ = NULL;
				GtkMessageDialog* _tmp21_ = NULL;
				GtkMessageDialog* _tmp22_ = NULL;
				const gchar* _tmp23_ = NULL;
				gint dialog_res = 0;
				GtkMessageDialog* _tmp24_ = NULL;
				gint _tmp25_ = 0;
				GtkMessageDialog* _tmp26_ = NULL;
				gint _tmp27_ = 0;
#line 1013 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp14_ = _ ("Shotwell needs to unmount the camera from the filesystem in order to a" \
"ccess it.  Continue?");
#line 1013 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp15_ = g_strdup (_tmp14_);
#line 1013 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				mounted_message = _tmp15_;
#line 1015 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp16_ = app_window_get_instance ();
#line 1015 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp17_ = _tmp16_;
#line 1015 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp18_ = mounted_message;
#line 1015 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp19_ = (GtkMessageDialog*) gtk_message_dialog_new (G_TYPE_CHECK_INSTANCE_CAST (_tmp17_, gtk_window_get_type (), GtkWindow), GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_CANCEL, "%s", _tmp18_);
#line 1015 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				g_object_ref_sink (_tmp19_);
#line 1015 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp20_ = _tmp19_;
#line 1015 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_g_object_unref0 (_tmp17_);
#line 1015 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				dialog = _tmp20_;
#line 1018 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp21_ = dialog;
#line 1018 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				gtk_window_set_title (G_TYPE_CHECK_INSTANCE_CAST (_tmp21_, gtk_window_get_type (), GtkWindow), RESOURCES_APP_TITLE);
#line 1019 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp22_ = dialog;
#line 1019 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp23_ = _ ("_Unmount");
#line 1019 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				gtk_dialog_add_button (G_TYPE_CHECK_INSTANCE_CAST (_tmp22_, gtk_dialog_get_type (), GtkDialog), _tmp23_, (gint) GTK_RESPONSE_YES);
#line 1020 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp24_ = dialog;
#line 1020 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp25_ = gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (_tmp24_, gtk_dialog_get_type (), GtkDialog));
#line 1020 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				dialog_res = _tmp25_;
#line 1021 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp26_ = dialog;
#line 1021 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (_tmp26_, gtk_widget_get_type (), GtkWidget));
#line 1023 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp27_ = dialog_res;
#line 1023 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				if (_tmp27_ != ((gint) GTK_RESPONSE_YES)) {
#line 7021 "ImportPage.c"
					const gchar* _tmp28_ = NULL;
#line 1024 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp28_ = _ ("Please unmount the camera.");
#line 1024 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					checkerboard_page_set_page_message (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_CHECKERBOARD_PAGE, CheckerboardPage), _tmp28_);
#line 7027 "ImportPage.c"
				} else {
					GMount* _tmp29_ = NULL;
#line 1026 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp29_ = mount;
#line 1026 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					import_page_unmount_camera (self, _tmp29_);
#line 7034 "ImportPage.c"
				}
#line 1011 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_g_object_unref0 (dialog);
#line 1011 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_g_free0 (mounted_message);
#line 7040 "ImportPage.c"
			} else {
				gchar* locked_message = NULL;
				const gchar* _tmp30_ = NULL;
				gchar* _tmp31_ = NULL;
				GtkMessageDialog* dialog = NULL;
				AppWindow* _tmp32_ = NULL;
				AppWindow* _tmp33_ = NULL;
				const gchar* _tmp34_ = NULL;
				GtkMessageDialog* _tmp35_ = NULL;
				GtkMessageDialog* _tmp36_ = NULL;
				GtkMessageDialog* _tmp37_ = NULL;
				GtkMessageDialog* _tmp38_ = NULL;
				GtkMessageDialog* _tmp39_ = NULL;
				const gchar* _tmp40_ = NULL;
#line 1029 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp30_ = _ ("The camera is locked by another application.  Shotwell can only access" \
" the camera when it's unlocked.  Please close any other application us" \
"ing the camera and try again.");
#line 1029 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp31_ = g_strdup (_tmp30_);
#line 1029 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				locked_message = _tmp31_;
#line 1032 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp32_ = app_window_get_instance ();
#line 1032 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp33_ = _tmp32_;
#line 1032 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp34_ = locked_message;
#line 1032 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp35_ = (GtkMessageDialog*) gtk_message_dialog_new (G_TYPE_CHECK_INSTANCE_CAST (_tmp33_, gtk_window_get_type (), GtkWindow), GTK_DIALOG_MODAL, GTK_MESSAGE_WARNING, GTK_BUTTONS_OK, "%s", _tmp34_);
#line 1032 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				g_object_ref_sink (_tmp35_);
#line 1032 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp36_ = _tmp35_;
#line 1032 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_g_object_unref0 (_tmp33_);
#line 1032 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				dialog = _tmp36_;
#line 1035 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp37_ = dialog;
#line 1035 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				gtk_window_set_title (G_TYPE_CHECK_INSTANCE_CAST (_tmp37_, gtk_window_get_type (), GtkWindow), RESOURCES_APP_TITLE);
#line 1036 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp38_ = dialog;
#line 1036 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (_tmp38_, gtk_dialog_get_type (), GtkDialog));
#line 1037 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp39_ = dialog;
#line 1037 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (_tmp39_, gtk_widget_get_type (), GtkWidget));
#line 1039 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp40_ = _ ("Please close any other application using the camera.");
#line 1039 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				checkerboard_page_set_page_message (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_CHECKERBOARD_PAGE, CheckerboardPage), _tmp40_);
#line 1011 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_g_object_unref0 (dialog);
#line 1011 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_g_free0 (locked_message);
#line 7097 "ImportPage.c"
			}
#line 1041 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_g_object_unref0 (mount);
#line 1041 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_g_object_unref0 (uri);
#line 1041 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			break;
#line 7105 "ImportPage.c"
		}
#line 985 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		case IMPORT_PAGE_REFRESH_RESULT_LIBRARY_ERROR:
#line 7109 "ImportPage.c"
		{
			const gchar* _tmp41_ = NULL;
			gchar* _tmp42_ = NULL;
			gchar* _tmp43_ = NULL;
			gchar* _tmp44_ = NULL;
			gchar* _tmp45_ = NULL;
#line 1044 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp41_ = _ ("Unable to fetch previews from the camera:\n%s");
#line 1044 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp42_ = import_page_get_refresh_message (self);
#line 1044 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp43_ = _tmp42_;
#line 1044 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp44_ = g_strdup_printf (_tmp41_, _tmp43_);
#line 1044 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp45_ = _tmp44_;
#line 1044 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			app_window_error_message (_tmp45_, NULL);
#line 1044 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_g_free0 (_tmp45_);
#line 1044 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_g_free0 (_tmp43_);
#line 1046 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			break;
#line 7134 "ImportPage.c"
		}
		default:
		{
			ImportPageRefreshResult _tmp46_ = 0;
#line 1049 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp46_ = res;
#line 1049 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			g_error ("ImportPage.vala:1049: Unknown result type %d", (gint) _tmp46_);
#line 7143 "ImportPage.c"
		}
	}
}


static void _import_page_on_unmounted_g_mount_unmounted (GMount* _sender, gpointer self) {
#line 1066 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	import_page_on_unmounted ((ImportPage*) self, _sender);
#line 7152 "ImportPage.c"
}


static void _import_page_on_unmount_finished_gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 1069 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	import_page_on_unmount_finished ((ImportPage*) self, source_object, res);
#line 1069 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_object_unref (self);
#line 7161 "ImportPage.c"
}


gboolean import_page_unmount_camera (ImportPage* self, GMount* mount) {
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
	GtkProgressBar* _tmp1_ = NULL;
	GtkProgressBar* _tmp2_ = NULL;
	GtkProgressBar* _tmp3_ = NULL;
	GtkProgressBar* _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
	GMount* _tmp6_ = NULL;
	GMount* _tmp7_ = NULL;
	AppWindow* _tmp8_ = NULL;
	AppWindow* _tmp9_ = NULL;
	GtkMountOperation* _tmp10_ = NULL;
	GtkMountOperation* _tmp11_ = NULL;
#line 1053 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail (IS_IMPORT_PAGE (self), FALSE);
#line 1053 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail (G_IS_MOUNT (mount), FALSE);
#line 1054 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = self->priv->busy;
#line 1054 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (_tmp0_) {
#line 1055 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		result = FALSE;
#line 1055 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		return result;
#line 7191 "ImportPage.c"
	}
#line 1057 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	import_page_update_status (self, TRUE, FALSE);
#line 1058 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = self->priv->progress_bar;
#line 1058 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	gtk_widget_set_visible (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, gtk_widget_get_type (), GtkWidget), TRUE);
#line 1059 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp2_ = self->priv->progress_bar;
#line 1059 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	gtk_progress_bar_set_fraction (_tmp2_, 0.0);
#line 1060 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp3_ = self->priv->progress_bar;
#line 1060 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	gtk_progress_bar_set_ellipsize (_tmp3_, PANGO_ELLIPSIZE_NONE);
#line 1061 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp4_ = self->priv->progress_bar;
#line 1061 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp5_ = _ ("Unmounting...");
#line 1061 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	gtk_progress_bar_set_text (_tmp4_, _tmp5_);
#line 1066 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp6_ = mount;
#line 1066 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_signal_connect_object (_tmp6_, "unmounted", (GCallback) _import_page_on_unmounted_g_mount_unmounted, self, 0);
#line 1068 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_debug ("ImportPage.vala:1068: Unmounting camera ...");
#line 1069 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp7_ = mount;
#line 1069 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp8_ = app_window_get_instance ();
#line 1069 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp9_ = _tmp8_;
#line 1069 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp10_ = (GtkMountOperation*) gtk_mount_operation_new (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, gtk_window_get_type (), GtkWindow));
#line 1069 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp11_ = _tmp10_;
#line 1069 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_mount_unmount_with_operation (_tmp7_, G_MOUNT_UNMOUNT_NONE, G_TYPE_CHECK_INSTANCE_CAST (_tmp11_, g_mount_operation_get_type (), GMountOperation), NULL, _import_page_on_unmount_finished_gasync_ready_callback, g_object_ref (self));
#line 1069 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_object_unref0 (_tmp11_);
#line 1069 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_object_unref0 (_tmp9_);
#line 1072 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = TRUE;
#line 1072 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 7239 "ImportPage.c"
}


static void import_page_on_unmount_finished (ImportPage* self, GObject* source, GAsyncResult* aresult) {
	GMount* mount = NULL;
	GObject* _tmp0_ = NULL;
	GMount* _tmp1_ = NULL;
	GError * _inner_error_ = NULL;
#line 1075 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_if_fail (IS_IMPORT_PAGE (self));
#line 1075 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_if_fail ((source == NULL) || G_IS_OBJECT (source));
#line 1075 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_if_fail (G_IS_ASYNC_RESULT (aresult));
#line 1076 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_debug ("ImportPage.vala:1076: Async unmount finished");
#line 1078 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = source;
#line 1078 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, g_mount_get_type (), GMount));
#line 1078 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	mount = _tmp1_;
#line 7262 "ImportPage.c"
	{
		GAsyncResult* _tmp2_ = NULL;
#line 1080 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp2_ = aresult;
#line 1080 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		g_mount_unmount_with_operation_finish (mount, _tmp2_, &_inner_error_);
#line 1080 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 7271 "ImportPage.c"
			goto __catch63_g_error;
		}
	}
	goto __finally63;
	__catch63_g_error:
	{
		GError* err = NULL;
		guint _tmp3_ = 0U;
		gboolean _tmp4_ = FALSE;
		GtkProgressBar* _tmp5_ = NULL;
		GtkProgressBar* _tmp6_ = NULL;
		GtkProgressBar* _tmp7_ = NULL;
#line 1079 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		err = _inner_error_;
#line 1079 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_inner_error_ = NULL;
#line 1082 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		app_window_error_message (IMPORT_PAGE_UNMOUNT_FAILED_MSG, NULL);
#line 1085 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		g_signal_parse_name ("unmounted", g_mount_get_type (), &_tmp3_, NULL, FALSE);
#line 1085 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		g_signal_handlers_disconnect_matched (mount, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _import_page_on_unmounted_g_mount_unmounted, self);
#line 1087 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp4_ = self->priv->refreshed;
#line 1087 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		import_page_update_status (self, FALSE, _tmp4_);
#line 1088 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp5_ = self->priv->progress_bar;
#line 1088 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		gtk_progress_bar_set_ellipsize (_tmp5_, PANGO_ELLIPSIZE_NONE);
#line 1089 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp6_ = self->priv->progress_bar;
#line 1089 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		gtk_progress_bar_set_text (_tmp6_, "");
#line 1090 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp7_ = self->priv->progress_bar;
#line 1090 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		gtk_widget_set_visible (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 1079 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_error_free0 (err);
#line 7312 "ImportPage.c"
	}
	__finally63:
#line 1079 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1079 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_object_unref0 (mount);
#line 1079 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1079 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		g_clear_error (&_inner_error_);
#line 1079 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		return;
#line 7325 "ImportPage.c"
	}
#line 1075 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_object_unref0 (mount);
#line 7329 "ImportPage.c"
}


static void import_page_on_unmounted (ImportPage* self, GMount* mount) {
	gboolean _tmp0_ = FALSE;
	GtkProgressBar* _tmp1_ = NULL;
	GtkProgressBar* _tmp2_ = NULL;
	GtkProgressBar* _tmp3_ = NULL;
#line 1094 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_if_fail (IS_IMPORT_PAGE (self));
#line 1094 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_if_fail (G_IS_MOUNT (mount));
#line 1095 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_debug ("ImportPage.vala:1095: on_unmounted");
#line 1097 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = self->priv->refreshed;
#line 1097 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	import_page_update_status (self, FALSE, _tmp0_);
#line 1098 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = self->priv->progress_bar;
#line 1098 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	gtk_progress_bar_set_ellipsize (_tmp1_, PANGO_ELLIPSIZE_NONE);
#line 1099 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp2_ = self->priv->progress_bar;
#line 1099 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	gtk_progress_bar_set_text (_tmp2_, "");
#line 1100 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp3_ = self->priv->progress_bar;
#line 1100 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	gtk_widget_set_visible (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 1102 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	import_page_try_refreshing_camera (self, TRUE);
#line 7362 "ImportPage.c"
}


static void import_page_clear_all_import_sources (ImportPage* self) {
	Marker* marker = NULL;
	SourceCollection* _tmp0_ = NULL;
	Marker* _tmp1_ = NULL;
	SourceCollection* _tmp2_ = NULL;
#line 1105 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_if_fail (IS_IMPORT_PAGE (self));
#line 1106 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = self->priv->import_sources;
#line 1106 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = data_collection_start_marking (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, TYPE_DATA_COLLECTION, DataCollection));
#line 1106 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	marker = _tmp1_;
#line 1107 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	marker_mark_all (marker);
#line 1108 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp2_ = self->priv->import_sources;
#line 1108 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	source_collection_destroy_marked (_tmp2_, marker, FALSE, NULL, NULL, NULL);
#line 1105 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_object_unref0 (marker);
#line 7387 "ImportPage.c"
}


/**
     * @brief Returns whether the current device has a given directory or not.
     *
     * @param fsid The file system id of the camera or other device to search.
     * @param dir The path to start searching from.
     * @param search_target The name of the directory to look for.
     */
static gboolean import_page_check_directory_exists (ImportPage* self, gint fsid, const gchar* dir, const gchar* search_target) {
	gboolean result = FALSE;
	gchar* fulldir = NULL;
	Camera* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gint _tmp2_ = 0;
	const gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	int _result_ = 0;
	CameraList* folders = NULL;
	CameraList* _tmp5_ = NULL;
	int _tmp6_ = 0;
	int _tmp7_ = 0;
	Camera* _tmp8_ = NULL;
	const gchar* _tmp9_ = NULL;
	CameraList* _tmp10_ = NULL;
	GPSpinIdleWrapper* _tmp11_ = NULL;
	GPContext* _tmp12_ = NULL;
	int _tmp13_ = 0;
	int _tmp14_ = 0;
	gint list_len = 0;
	CameraList* _tmp15_ = NULL;
	gint _tmp16_ = 0;
#line 1118 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail (IS_IMPORT_PAGE (self), FALSE);
#line 1118 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail (dir != NULL, FALSE);
#line 1118 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail (search_target != NULL, FALSE);
#line 1119 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = self->priv->camera;
#line 1119 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = self->priv->camera_name;
#line 1119 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp2_ = fsid;
#line 1119 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp3_ = dir;
#line 1119 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp4_ = import_page_get_fulldir (_tmp0_, _tmp1_, _tmp2_, _tmp3_);
#line 1119 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	fulldir = _tmp4_;
#line 1123 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp6_ = gp_list_new (&_tmp5_);
#line 1123 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_gp_list_unref0 (folders);
#line 1123 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	folders = _tmp5_;
#line 1123 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_result_ = _tmp6_;
#line 1124 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp7_ = _result_;
#line 1124 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (_tmp7_ != GP_OK) {
#line 1126 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		result = FALSE;
#line 1126 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_gp_list_unref0 (folders);
#line 1126 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_free0 (fulldir);
#line 1126 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		return result;
#line 7459 "ImportPage.c"
	}
#line 1129 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp8_ = self->priv->camera;
#line 1129 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp9_ = fulldir;
#line 1129 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp10_ = folders;
#line 1129 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp11_ = import_page_spin_idle_context;
#line 1129 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp12_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp11_, GP_TYPE_CONTEXT_WRAPPER, GPContextWrapper)->context;
#line 1129 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp13_ = gp_camera_folder_list_folders (_tmp8_, _tmp9_, _tmp10_, _tmp12_);
#line 1129 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_result_ = _tmp13_;
#line 1130 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp14_ = _result_;
#line 1130 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (_tmp14_ != GP_OK) {
#line 1132 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		result = FALSE;
#line 1132 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_gp_list_unref0 (folders);
#line 1132 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_free0 (fulldir);
#line 1132 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		return result;
#line 7487 "ImportPage.c"
	}
#line 1135 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp15_ = folders;
#line 1135 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp16_ = gp_list_count (_tmp15_);
#line 1135 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	list_len = _tmp16_;
#line 7495 "ImportPage.c"
	{
		gint list_index = 0;
#line 1137 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		list_index = 0;
#line 7500 "ImportPage.c"
		{
			gboolean _tmp17_ = FALSE;
#line 1137 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp17_ = TRUE;
#line 1137 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			while (TRUE) {
#line 7507 "ImportPage.c"
				gint _tmp19_ = 0;
				gint _tmp20_ = 0;
				gchar* tmp = NULL;
				CameraList* _tmp21_ = NULL;
				gint _tmp22_ = 0;
				const gchar* _tmp23_ = NULL;
				gchar* _tmp24_ = NULL;
				const gchar* _tmp25_ = NULL;
				const gchar* _tmp26_ = NULL;
#line 1137 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				if (!_tmp17_) {
#line 7519 "ImportPage.c"
					gint _tmp18_ = 0;
#line 1137 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp18_ = list_index;
#line 1137 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					list_index = _tmp18_ + 1;
#line 7525 "ImportPage.c"
				}
#line 1137 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp17_ = FALSE;
#line 1137 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp19_ = list_index;
#line 1137 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp20_ = list_len;
#line 1137 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				if (!(_tmp19_ < _tmp20_)) {
#line 1137 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					break;
#line 7537 "ImportPage.c"
				}
#line 1140 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp21_ = folders;
#line 1140 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp22_ = list_index;
#line 1140 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				gp_list_get_name (_tmp21_, _tmp22_, &_tmp23_);
#line 1140 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_g_free0 (tmp);
#line 1140 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp24_ = g_strdup (_tmp23_);
#line 1140 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				tmp = _tmp24_;
#line 1141 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp25_ = tmp;
#line 1141 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp26_ = search_target;
#line 1141 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				if (g_strcmp0 (_tmp25_, _tmp26_) == 0) {
#line 1142 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					result = TRUE;
#line 1142 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_g_free0 (tmp);
#line 1142 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_gp_list_unref0 (folders);
#line 1142 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_g_free0 (fulldir);
#line 1142 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					return result;
#line 7567 "ImportPage.c"
				}
#line 1137 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_g_free0 (tmp);
#line 7571 "ImportPage.c"
			}
		}
	}
#line 1145 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = FALSE;
#line 1145 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_gp_list_unref0 (folders);
#line 1145 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_free0 (fulldir);
#line 1145 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 7583 "ImportPage.c"
}


static ImportPageRefreshResult import_page_refresh_camera (ImportPage* self) {
	ImportPageRefreshResult result = 0;
	gboolean _tmp0_ = FALSE;
	const gchar* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	Camera* _tmp3_ = NULL;
	GPSpinIdleWrapper* _tmp4_ = NULL;
	GPContext* _tmp5_ = NULL;
	int _tmp6_ = 0;
	int _tmp7_ = 0;
	gboolean _tmp13_ = FALSE;
	GtkProgressBar* _tmp14_ = NULL;
	GtkProgressBar* _tmp15_ = NULL;
	const gchar* _tmp16_ = NULL;
	GtkProgressBar* _tmp17_ = NULL;
	GtkProgressBar* _tmp18_ = NULL;
	GtkProgressBar* _tmp19_ = NULL;
	GeeArrayList* import_list = NULL;
	GeeArrayList* _tmp20_ = NULL;
	CameraStorageInformation* sifs = NULL;
	gint count = 0;
	Camera* _tmp21_ = NULL;
	GPSpinIdleWrapper* _tmp22_ = NULL;
	GPContext* _tmp23_ = NULL;
	gint _tmp24_ = 0;
	int _tmp25_ = 0;
	int _tmp26_ = 0;
	GeeArrayList* _tmp75_ = NULL;
	GeeArrayList* _tmp76_ = NULL;
	GtkProgressBar* _tmp77_ = NULL;
	GtkProgressBar* _tmp78_ = NULL;
	GtkProgressBar* _tmp79_ = NULL;
	GtkProgressBar* _tmp80_ = NULL;
	int res = 0;
	Camera* _tmp81_ = NULL;
	GPSpinIdleWrapper* _tmp82_ = NULL;
	GPContext* _tmp83_ = NULL;
	int _tmp84_ = 0;
	int _tmp85_ = 0;
	int _tmp89_ = 0;
	int _tmp94_ = 0;
#line 1148 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail (IS_IMPORT_PAGE (self), 0);
#line 1149 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = self->priv->busy;
#line 1149 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (_tmp0_) {
#line 1150 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		result = IMPORT_PAGE_REFRESH_RESULT_BUSY;
#line 1150 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		return result;
#line 7638 "ImportPage.c"
	}
#line 1152 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = _ ("Starting import, please wait...");
#line 1152 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	checkerboard_page_set_page_message (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_CHECKERBOARD_PAGE, CheckerboardPage), _tmp1_);
#line 1154 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp2_ = self->priv->busy;
#line 1154 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	import_page_update_status (self, _tmp2_, FALSE);
#line 1156 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_free0 (self->priv->refresh_error);
#line 1156 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self->priv->refresh_error = NULL;
#line 1157 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp3_ = self->priv->camera;
#line 1157 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp4_ = import_page_spin_idle_context;
#line 1157 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp5_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, GP_TYPE_CONTEXT_WRAPPER, GPContextWrapper)->context;
#line 1157 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp6_ = gp_camera_init (_tmp3_, _tmp5_);
#line 1157 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self->priv->refresh_result = _tmp6_;
#line 1158 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp7_ = self->priv->refresh_result;
#line 1158 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (_tmp7_ != GP_OK) {
#line 7666 "ImportPage.c"
		int _tmp8_ = 0;
		gchar* _tmp9_ = NULL;
		gchar* _tmp10_ = NULL;
		ImportPageRefreshResult _tmp11_ = 0;
		int _tmp12_ = 0;
#line 1159 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp8_ = self->priv->refresh_result;
#line 1159 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp9_ = gp_result_to_full_string (_tmp8_);
#line 1159 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp10_ = _tmp9_;
#line 1159 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		g_warning ("ImportPage.vala:1159: Unable to initialize camera: %s", _tmp10_);
#line 1159 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_free0 (_tmp10_);
#line 1161 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp12_ = self->priv->refresh_result;
#line 1161 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		if (_tmp12_ == GP_ERROR_IO_LOCK) {
#line 1161 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp11_ = IMPORT_PAGE_REFRESH_RESULT_LOCKED;
#line 7688 "ImportPage.c"
		} else {
#line 1161 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp11_ = IMPORT_PAGE_REFRESH_RESULT_LIBRARY_ERROR;
#line 7692 "ImportPage.c"
		}
#line 1161 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		result = _tmp11_;
#line 1161 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		return result;
#line 7698 "ImportPage.c"
	}
#line 1164 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp13_ = self->priv->refreshed;
#line 1164 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	import_page_update_status (self, TRUE, _tmp13_);
#line 1166 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	import_page_on_view_changed (self);
#line 1168 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp14_ = self->priv->progress_bar;
#line 1168 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	gtk_progress_bar_set_ellipsize (_tmp14_, PANGO_ELLIPSIZE_NONE);
#line 1169 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp15_ = self->priv->progress_bar;
#line 1169 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp16_ = _ ("Fetching photo information");
#line 1169 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	gtk_progress_bar_set_text (_tmp15_, _tmp16_);
#line 1170 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp17_ = self->priv->progress_bar;
#line 1170 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	gtk_progress_bar_set_fraction (_tmp17_, 0.0);
#line 1171 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp18_ = self->priv->progress_bar;
#line 1171 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	gtk_progress_bar_set_pulse_step (_tmp18_, 0.01);
#line 1172 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp19_ = self->priv->progress_bar;
#line 1172 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	gtk_widget_set_visible (G_TYPE_CHECK_INSTANCE_CAST (_tmp19_, gtk_widget_get_type (), GtkWidget), TRUE);
#line 1174 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp20_ = gee_array_list_new (TYPE_IMPORT_SOURCE, (GBoxedCopyFunc) g_object_ref, g_object_unref, NULL, NULL, NULL);
#line 1174 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	import_list = _tmp20_;
#line 1176 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	sifs = NULL;
#line 1177 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	count = 0;
#line 1178 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp21_ = self->priv->camera;
#line 1178 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp22_ = import_page_spin_idle_context;
#line 1178 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp23_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp22_, GP_TYPE_CONTEXT_WRAPPER, GPContextWrapper)->context;
#line 1178 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp25_ = gp_camera_get_storageinfo (_tmp21_, &sifs, &_tmp24_, _tmp23_);
#line 1178 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	count = _tmp24_;
#line 1178 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self->priv->refresh_result = _tmp25_;
#line 1179 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp26_ = self->priv->refresh_result;
#line 1179 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (_tmp26_ == GP_OK) {
#line 7752 "ImportPage.c"
		{
			gint fsid = 0;
#line 1180 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			fsid = 0;
#line 7757 "ImportPage.c"
			{
				gboolean _tmp27_ = FALSE;
#line 1180 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp27_ = TRUE;
#line 1180 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				while (TRUE) {
#line 7764 "ImportPage.c"
					gint _tmp29_ = 0;
					gint _tmp30_ = 0;
					gboolean got_well_known_dir = FALSE;
					gint _tmp31_ = 0;
					gboolean _tmp32_ = FALSE;
					gint _tmp35_ = 0;
					gboolean _tmp36_ = FALSE;
					gint _tmp39_ = 0;
					gboolean _tmp40_ = FALSE;
					gint _tmp43_ = 0;
					gboolean _tmp44_ = FALSE;
					gint _tmp47_ = 0;
					gboolean _tmp48_ = FALSE;
					gint _tmp51_ = 0;
					gboolean _tmp52_ = FALSE;
					gint _tmp55_ = 0;
					gboolean _tmp56_ = FALSE;
					gint _tmp59_ = 0;
					gboolean _tmp60_ = FALSE;
					gint _tmp63_ = 0;
					gboolean _tmp64_ = FALSE;
					gint _tmp67_ = 0;
					gboolean _tmp68_ = FALSE;
					gboolean _tmp71_ = FALSE;
#line 1180 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					if (!_tmp27_) {
#line 7791 "ImportPage.c"
						gint _tmp28_ = 0;
#line 1180 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp28_ = fsid;
#line 1180 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						fsid = _tmp28_ + 1;
#line 7797 "ImportPage.c"
					}
#line 1180 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp27_ = FALSE;
#line 1180 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp29_ = fsid;
#line 1180 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp30_ = count;
#line 1180 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					if (!(_tmp29_ < _tmp30_)) {
#line 1180 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						break;
#line 7809 "ImportPage.c"
					}
#line 1184 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					got_well_known_dir = FALSE;
#line 1187 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp31_ = fsid;
#line 1187 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp32_ = import_page_check_directory_exists (self, _tmp31_, "/", "DCIM");
#line 1187 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					if (_tmp32_) {
#line 7819 "ImportPage.c"
						gint _tmp33_ = 0;
						GeeArrayList* _tmp34_ = NULL;
#line 1188 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp33_ = fsid;
#line 1188 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp34_ = import_list;
#line 1188 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						import_page_enumerate_files (self, _tmp33_, "/DCIM", _tmp34_);
#line 1189 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						got_well_known_dir = TRUE;
#line 7830 "ImportPage.c"
					}
#line 1191 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp35_ = fsid;
#line 1191 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp36_ = import_page_check_directory_exists (self, _tmp35_, "/", "dcim");
#line 1191 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					if (_tmp36_) {
#line 7838 "ImportPage.c"
						gint _tmp37_ = 0;
						GeeArrayList* _tmp38_ = NULL;
#line 1192 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp37_ = fsid;
#line 1192 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp38_ = import_list;
#line 1192 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						import_page_enumerate_files (self, _tmp37_, "/dcim", _tmp38_);
#line 1193 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						got_well_known_dir = TRUE;
#line 7849 "ImportPage.c"
					}
#line 1198 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp39_ = fsid;
#line 1198 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp40_ = import_page_check_directory_exists (self, _tmp39_, "/PRIVATE/", "AVCHD");
#line 1198 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					if (_tmp40_) {
#line 7857 "ImportPage.c"
						gint _tmp41_ = 0;
						GeeArrayList* _tmp42_ = NULL;
#line 1199 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp41_ = fsid;
#line 1199 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp42_ = import_list;
#line 1199 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						import_page_enumerate_files (self, _tmp41_, "/PRIVATE/AVCHD", _tmp42_);
#line 1200 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						got_well_known_dir = TRUE;
#line 7868 "ImportPage.c"
					}
#line 1202 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp43_ = fsid;
#line 1202 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp44_ = import_page_check_directory_exists (self, _tmp43_, "/private/", "avchd");
#line 1202 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					if (_tmp44_) {
#line 7876 "ImportPage.c"
						gint _tmp45_ = 0;
						GeeArrayList* _tmp46_ = NULL;
#line 1203 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp45_ = fsid;
#line 1203 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp46_ = import_list;
#line 1203 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						import_page_enumerate_files (self, _tmp45_, "/private/avchd", _tmp46_);
#line 1204 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						got_well_known_dir = TRUE;
#line 7887 "ImportPage.c"
					}
#line 1206 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp47_ = fsid;
#line 1206 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp48_ = import_page_check_directory_exists (self, _tmp47_, "/", "AVCHD");
#line 1206 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					if (_tmp48_) {
#line 7895 "ImportPage.c"
						gint _tmp49_ = 0;
						GeeArrayList* _tmp50_ = NULL;
#line 1207 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp49_ = fsid;
#line 1207 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp50_ = import_list;
#line 1207 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						import_page_enumerate_files (self, _tmp49_, "/AVCHD", _tmp50_);
#line 1208 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						got_well_known_dir = TRUE;
#line 7906 "ImportPage.c"
					}
#line 1210 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp51_ = fsid;
#line 1210 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp52_ = import_page_check_directory_exists (self, _tmp51_, "/", "avchd");
#line 1210 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					if (_tmp52_) {
#line 7914 "ImportPage.c"
						gint _tmp53_ = 0;
						GeeArrayList* _tmp54_ = NULL;
#line 1211 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp53_ = fsid;
#line 1211 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp54_ = import_list;
#line 1211 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						import_page_enumerate_files (self, _tmp53_, "/avchd", _tmp54_);
#line 1212 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						got_well_known_dir = TRUE;
#line 7925 "ImportPage.c"
					}
#line 1217 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp55_ = fsid;
#line 1217 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp56_ = import_page_check_directory_exists (self, _tmp55_, "/PRIVATE/", "SONY");
#line 1217 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					if (_tmp56_) {
#line 7933 "ImportPage.c"
						gint _tmp57_ = 0;
						GeeArrayList* _tmp58_ = NULL;
#line 1218 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp57_ = fsid;
#line 1218 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp58_ = import_list;
#line 1218 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						import_page_enumerate_files (self, _tmp57_, "/PRIVATE/SONY", _tmp58_);
#line 1219 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						got_well_known_dir = TRUE;
#line 7944 "ImportPage.c"
					}
#line 1221 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp59_ = fsid;
#line 1221 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp60_ = import_page_check_directory_exists (self, _tmp59_, "/private/", "sony");
#line 1221 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					if (_tmp60_) {
#line 7952 "ImportPage.c"
						gint _tmp61_ = 0;
						GeeArrayList* _tmp62_ = NULL;
#line 1222 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp61_ = fsid;
#line 1222 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp62_ = import_list;
#line 1222 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						import_page_enumerate_files (self, _tmp61_, "/private/sony", _tmp62_);
#line 1223 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						got_well_known_dir = TRUE;
#line 7963 "ImportPage.c"
					}
#line 1227 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp63_ = fsid;
#line 1227 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp64_ = import_page_check_directory_exists (self, _tmp63_, "/", "MP_ROOT");
#line 1227 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					if (_tmp64_) {
#line 7971 "ImportPage.c"
						gint _tmp65_ = 0;
						GeeArrayList* _tmp66_ = NULL;
#line 1228 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp65_ = fsid;
#line 1228 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp66_ = import_list;
#line 1228 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						import_page_enumerate_files (self, _tmp65_, "/MP_ROOT", _tmp66_);
#line 1229 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						got_well_known_dir = TRUE;
#line 7982 "ImportPage.c"
					}
#line 1231 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp67_ = fsid;
#line 1231 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp68_ = import_page_check_directory_exists (self, _tmp67_, "/", "mp_root");
#line 1231 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					if (_tmp68_) {
#line 7990 "ImportPage.c"
						gint _tmp69_ = 0;
						GeeArrayList* _tmp70_ = NULL;
#line 1232 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp69_ = fsid;
#line 1232 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp70_ = import_list;
#line 1232 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						import_page_enumerate_files (self, _tmp69_, "/mp_root", _tmp70_);
#line 1233 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						got_well_known_dir = TRUE;
#line 8001 "ImportPage.c"
					}
#line 1238 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp71_ = got_well_known_dir;
#line 1238 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					if (!_tmp71_) {
#line 8007 "ImportPage.c"
						gint _tmp72_ = 0;
						GeeArrayList* _tmp73_ = NULL;
						gboolean _tmp74_ = FALSE;
#line 1239 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp72_ = fsid;
#line 1239 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp73_ = import_list;
#line 1239 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp74_ = import_page_enumerate_files (self, _tmp72_, "/", _tmp73_);
#line 1239 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						if (!_tmp74_) {
#line 1240 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
							break;
#line 8021 "ImportPage.c"
						}
					}
				}
			}
		}
	}
#line 1245 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	import_page_clear_all_import_sources (self);
#line 1248 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp75_ = import_list;
#line 1248 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	import_page_auto_match_raw_jpeg (self, _tmp75_);
#line 1255 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp76_ = import_list;
#line 1255 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	import_page_load_previews_and_metadata (self, G_TYPE_CHECK_INSTANCE_CAST (_tmp76_, GEE_TYPE_LIST, GeeList));
#line 1262 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp77_ = self->priv->progress_bar;
#line 1262 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	gtk_widget_set_visible (G_TYPE_CHECK_INSTANCE_CAST (_tmp77_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 1263 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp78_ = self->priv->progress_bar;
#line 1263 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	gtk_progress_bar_set_ellipsize (_tmp78_, PANGO_ELLIPSIZE_NONE);
#line 1264 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp79_ = self->priv->progress_bar;
#line 1264 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	gtk_progress_bar_set_text (_tmp79_, "");
#line 1265 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp80_ = self->priv->progress_bar;
#line 1265 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	gtk_progress_bar_set_fraction (_tmp80_, 0.0);
#line 1267 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp81_ = self->priv->camera;
#line 1267 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp82_ = import_page_spin_idle_context;
#line 1267 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp83_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp82_, GP_TYPE_CONTEXT_WRAPPER, GPContextWrapper)->context;
#line 1267 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp84_ = gp_camera_exit (_tmp81_, _tmp83_);
#line 1267 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	res = _tmp84_;
#line 1268 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp85_ = res;
#line 1268 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (_tmp85_ != GP_OK) {
#line 8068 "ImportPage.c"
		int _tmp86_ = 0;
		gchar* _tmp87_ = NULL;
		gchar* _tmp88_ = NULL;
#line 1270 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp86_ = res;
#line 1270 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp87_ = gp_result_to_full_string (_tmp86_);
#line 1270 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp88_ = _tmp87_;
#line 1270 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		g_warning ("ImportPage.vala:1270: Unable to unlock camera: %s", _tmp88_);
#line 1270 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_free0 (_tmp88_);
#line 8082 "ImportPage.c"
	}
#line 1273 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp89_ = self->priv->refresh_result;
#line 1273 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (_tmp89_ == GP_OK) {
#line 8088 "ImportPage.c"
		SourceCollection* _tmp90_ = NULL;
		gint _tmp91_ = 0;
#line 1274 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp90_ = self->priv->import_sources;
#line 1274 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp91_ = data_collection_get_count (G_TYPE_CHECK_INSTANCE_CAST (_tmp90_, TYPE_DATA_COLLECTION, DataCollection));
#line 1274 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		if (_tmp91_ == 0) {
#line 8097 "ImportPage.c"
			gchar* _tmp92_ = NULL;
			gchar* _tmp93_ = NULL;
#line 1275 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp92_ = checkerboard_page_get_view_empty_message (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_CHECKERBOARD_PAGE, CheckerboardPage));
#line 1275 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp93_ = _tmp92_;
#line 1275 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			checkerboard_page_set_page_message (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_CHECKERBOARD_PAGE, CheckerboardPage), _tmp93_);
#line 1275 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_g_free0 (_tmp93_);
#line 8108 "ImportPage.c"
		}
#line 1277 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		import_page_update_status (self, FALSE, TRUE);
#line 8112 "ImportPage.c"
	} else {
#line 1279 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		import_page_update_status (self, FALSE, FALSE);
#line 1282 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		import_page_clear_all_import_sources (self);
#line 8118 "ImportPage.c"
	}
#line 1285 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	import_page_on_view_changed (self);
#line 1287 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp94_ = self->priv->refresh_result;
#line 1287 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	switch (_tmp94_) {
#line 1287 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		case GP_OK:
#line 8128 "ImportPage.c"
		{
#line 1289 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			result = IMPORT_PAGE_REFRESH_RESULT_OK;
#line 1289 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_g_object_unref0 (import_list);
#line 1289 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			return result;
#line 8136 "ImportPage.c"
		}
#line 1287 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		case GP_ERROR_IO_LOCK:
#line 8140 "ImportPage.c"
		{
#line 1292 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			result = IMPORT_PAGE_REFRESH_RESULT_LOCKED;
#line 1292 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_g_object_unref0 (import_list);
#line 1292 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			return result;
#line 8148 "ImportPage.c"
		}
		default:
		{
#line 1295 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			result = IMPORT_PAGE_REFRESH_RESULT_LIBRARY_ERROR;
#line 1295 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_g_object_unref0 (import_list);
#line 1295 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			return result;
#line 8158 "ImportPage.c"
		}
	}
#line 1148 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_object_unref0 (import_list);
#line 8163 "ImportPage.c"
}


static gchar string_get (const gchar* self, glong index) {
	gchar result = '\0';
	glong _tmp0_ = 0L;
	gchar _tmp1_ = '\0';
#line 1086 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, '\0');
#line 1087 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp0_ = index;
#line 1087 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp1_ = ((gchar*) self)[_tmp0_];
#line 1087 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	result = _tmp1_;
#line 1087 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	return result;
#line 8181 "ImportPage.c"
}


static gchar* string_slice (const gchar* self, glong start, glong end) {
	gchar* result = NULL;
	glong string_length = 0L;
	gint _tmp0_ = 0;
	gint _tmp1_ = 0;
	glong _tmp2_ = 0L;
	glong _tmp5_ = 0L;
	gboolean _tmp8_ = FALSE;
	glong _tmp9_ = 0L;
	gboolean _tmp12_ = FALSE;
	glong _tmp13_ = 0L;
	glong _tmp16_ = 0L;
	glong _tmp17_ = 0L;
	glong _tmp18_ = 0L;
	glong _tmp19_ = 0L;
	glong _tmp20_ = 0L;
	gchar* _tmp21_ = NULL;
#line 1328 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1329 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp0_ = strlen (self);
#line 1329 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp1_ = _tmp0_;
#line 1329 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	string_length = (glong) _tmp1_;
#line 1330 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp2_ = start;
#line 1330 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	if (_tmp2_ < ((glong) 0)) {
#line 8214 "ImportPage.c"
		glong _tmp3_ = 0L;
		glong _tmp4_ = 0L;
#line 1331 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp3_ = string_length;
#line 1331 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp4_ = start;
#line 1331 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		start = _tmp3_ + _tmp4_;
#line 8223 "ImportPage.c"
	}
#line 1333 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp5_ = end;
#line 1333 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	if (_tmp5_ < ((glong) 0)) {
#line 8229 "ImportPage.c"
		glong _tmp6_ = 0L;
		glong _tmp7_ = 0L;
#line 1334 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp6_ = string_length;
#line 1334 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp7_ = end;
#line 1334 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		end = _tmp6_ + _tmp7_;
#line 8238 "ImportPage.c"
	}
#line 1336 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp9_ = start;
#line 1336 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	if (_tmp9_ >= ((glong) 0)) {
#line 8244 "ImportPage.c"
		glong _tmp10_ = 0L;
		glong _tmp11_ = 0L;
#line 1336 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp10_ = start;
#line 1336 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp11_ = string_length;
#line 1336 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp8_ = _tmp10_ <= _tmp11_;
#line 8253 "ImportPage.c"
	} else {
#line 1336 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp8_ = FALSE;
#line 8257 "ImportPage.c"
	}
#line 1336 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	g_return_val_if_fail (_tmp8_, NULL);
#line 1337 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp13_ = end;
#line 1337 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	if (_tmp13_ >= ((glong) 0)) {
#line 8265 "ImportPage.c"
		glong _tmp14_ = 0L;
		glong _tmp15_ = 0L;
#line 1337 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp14_ = end;
#line 1337 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp15_ = string_length;
#line 1337 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp12_ = _tmp14_ <= _tmp15_;
#line 8274 "ImportPage.c"
	} else {
#line 1337 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp12_ = FALSE;
#line 8278 "ImportPage.c"
	}
#line 1337 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	g_return_val_if_fail (_tmp12_, NULL);
#line 1338 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp16_ = start;
#line 1338 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp17_ = end;
#line 1338 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	g_return_val_if_fail (_tmp16_ <= _tmp17_, NULL);
#line 1339 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp18_ = start;
#line 1339 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp19_ = end;
#line 1339 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp20_ = start;
#line 1339 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp21_ = g_strndup (((gchar*) self) + _tmp18_, (gsize) (_tmp19_ - _tmp20_));
#line 1339 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	result = _tmp21_;
#line 1339 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	return result;
#line 8300 "ImportPage.c"
}


static gchar* import_page_chomp_ch (const gchar* str, gchar ch) {
	gchar* result = NULL;
	glong offset = 0L;
	const gchar* _tmp0_ = NULL;
	gint _tmp1_ = 0;
	gint _tmp2_ = 0;
	gchar* _tmp12_ = NULL;
#line 1299 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail (str != NULL, NULL);
#line 1300 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = str;
#line 1300 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = strlen (_tmp0_);
#line 1300 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp2_ = _tmp1_;
#line 1300 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	offset = (glong) _tmp2_;
#line 1301 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	while (TRUE) {
#line 8323 "ImportPage.c"
		glong _tmp3_ = 0L;
		glong _tmp4_ = 0L;
		const gchar* _tmp5_ = NULL;
		glong _tmp6_ = 0L;
		gchar _tmp7_ = '\0';
		gchar _tmp8_ = '\0';
#line 1301 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp3_ = offset;
#line 1301 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		offset = _tmp3_ - 1;
#line 1301 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp4_ = offset;
#line 1301 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		if (!(_tmp4_ >= ((glong) 0))) {
#line 1301 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			break;
#line 8340 "ImportPage.c"
		}
#line 1302 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp5_ = str;
#line 1302 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp6_ = offset;
#line 1302 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp7_ = string_get (_tmp5_, _tmp6_);
#line 1302 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp8_ = ch;
#line 1302 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		if (_tmp7_ != _tmp8_) {
#line 8352 "ImportPage.c"
			const gchar* _tmp9_ = NULL;
			glong _tmp10_ = 0L;
			gchar* _tmp11_ = NULL;
#line 1303 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp9_ = str;
#line 1303 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp10_ = offset;
#line 1303 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp11_ = string_slice (_tmp9_, (glong) 0, _tmp10_);
#line 1303 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			result = _tmp11_;
#line 1303 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			return result;
#line 8366 "ImportPage.c"
		}
	}
#line 1306 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp12_ = g_strdup ("");
#line 1306 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = _tmp12_;
#line 1306 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 8375 "ImportPage.c"
}


gchar* import_page_append_path (const gchar* basepath, const gchar* addition) {
	gchar* result = NULL;
	gboolean _tmp0_ = FALSE;
	const gchar* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
#line 1309 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail (basepath != NULL, NULL);
#line 1309 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail (addition != NULL, NULL);
#line 1310 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = basepath;
#line 1310 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp2_ = g_str_has_suffix (_tmp1_, "/");
#line 1310 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (!_tmp2_) {
#line 8394 "ImportPage.c"
		const gchar* _tmp3_ = NULL;
		gboolean _tmp4_ = FALSE;
#line 1310 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp3_ = addition;
#line 1310 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp4_ = g_str_has_prefix (_tmp3_, "/");
#line 1310 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp0_ = !_tmp4_;
#line 8403 "ImportPage.c"
	} else {
#line 1310 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp0_ = FALSE;
#line 8407 "ImportPage.c"
	}
#line 1310 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (_tmp0_) {
#line 8411 "ImportPage.c"
		const gchar* _tmp5_ = NULL;
		gchar* _tmp6_ = NULL;
		gchar* _tmp7_ = NULL;
		const gchar* _tmp8_ = NULL;
		gchar* _tmp9_ = NULL;
		gchar* _tmp10_ = NULL;
#line 1311 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp5_ = basepath;
#line 1311 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp6_ = g_strconcat (_tmp5_, "/", NULL);
#line 1311 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp7_ = _tmp6_;
#line 1311 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp8_ = addition;
#line 1311 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp9_ = g_strconcat (_tmp7_, _tmp8_, NULL);
#line 1311 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp10_ = _tmp9_;
#line 1311 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_free0 (_tmp7_);
#line 1311 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		result = _tmp10_;
#line 1311 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		return result;
#line 8436 "ImportPage.c"
	} else {
		gboolean _tmp11_ = FALSE;
		const gchar* _tmp12_ = NULL;
		gboolean _tmp13_ = FALSE;
#line 1312 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp12_ = basepath;
#line 1312 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp13_ = g_str_has_suffix (_tmp12_, "/");
#line 1312 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		if (_tmp13_) {
#line 8447 "ImportPage.c"
			const gchar* _tmp14_ = NULL;
			gboolean _tmp15_ = FALSE;
#line 1312 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp14_ = addition;
#line 1312 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp15_ = g_str_has_prefix (_tmp14_, "/");
#line 1312 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp11_ = _tmp15_;
#line 8456 "ImportPage.c"
		} else {
#line 1312 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp11_ = FALSE;
#line 8460 "ImportPage.c"
		}
#line 1312 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		if (_tmp11_) {
#line 8464 "ImportPage.c"
			const gchar* _tmp16_ = NULL;
			gchar* _tmp17_ = NULL;
			gchar* _tmp18_ = NULL;
			const gchar* _tmp19_ = NULL;
			gchar* _tmp20_ = NULL;
			gchar* _tmp21_ = NULL;
#line 1313 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp16_ = basepath;
#line 1313 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp17_ = import_page_chomp_ch (_tmp16_, '/');
#line 1313 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp18_ = _tmp17_;
#line 1313 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp19_ = addition;
#line 1313 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp20_ = g_strconcat (_tmp18_, _tmp19_, NULL);
#line 1313 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp21_ = _tmp20_;
#line 1313 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_g_free0 (_tmp18_);
#line 1313 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			result = _tmp21_;
#line 1313 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			return result;
#line 8489 "ImportPage.c"
		} else {
			const gchar* _tmp22_ = NULL;
			const gchar* _tmp23_ = NULL;
			gchar* _tmp24_ = NULL;
#line 1315 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp22_ = basepath;
#line 1315 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp23_ = addition;
#line 1315 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp24_ = g_strconcat (_tmp22_, _tmp23_, NULL);
#line 1315 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			result = _tmp24_;
#line 1315 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			return result;
#line 8504 "ImportPage.c"
		}
	}
}


gchar* import_page_get_fs_basedir (Camera* camera, gint fsid) {
	gchar* result = NULL;
	CameraStorageInformation* sifs = NULL;
	gint count = 0;
	int res = 0;
	Camera* _tmp0_ = NULL;
	GPContextWrapper* _tmp1_ = NULL;
	GPContext* _tmp2_ = NULL;
	gint _tmp3_ = 0;
	int _tmp4_ = 0;
	int _tmp5_ = 0;
	gint _tmp6_ = 0;
	gint _tmp7_ = 0;
	CameraStorageInformation* ifs = NULL;
	CameraStorageInformation* _tmp8_ = NULL;
	gint _tmp9_ = 0;
	const gchar* _tmp10_ = NULL;
	CameraStorageInformation* _tmp11_ = NULL;
	CameraStorageInfoFields _tmp12_ = 0;
	gchar* _tmp15_ = NULL;
#line 1320 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail (camera != NULL, NULL);
#line 1321 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	sifs = NULL;
#line 1322 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	count = 0;
#line 1323 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = camera;
#line 1323 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = import_page_null_context;
#line 1323 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp2_ = _tmp1_->context;
#line 1323 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp4_ = gp_camera_get_storageinfo (_tmp0_, &sifs, &_tmp3_, _tmp2_);
#line 1323 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	count = _tmp3_;
#line 1323 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	res = _tmp4_;
#line 1324 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp5_ = res;
#line 1324 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (_tmp5_ != GP_OK) {
#line 1325 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		result = NULL;
#line 1325 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		return result;
#line 8556 "ImportPage.c"
	}
#line 1327 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp6_ = fsid;
#line 1327 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp7_ = count;
#line 1327 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (_tmp6_ >= _tmp7_) {
#line 1328 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		result = NULL;
#line 1328 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		return result;
#line 8568 "ImportPage.c"
	}
#line 1330 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp8_ = sifs;
#line 1330 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp9_ = fsid;
#line 1330 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	ifs = _tmp8_ + _tmp9_;
#line 1332 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp11_ = ifs;
#line 1332 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp12_ = (*_tmp11_).fields;
#line 1332 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if ((_tmp12_ & GP_STORAGEINFO_BASE) != 0) {
#line 8582 "ImportPage.c"
		CameraStorageInformation* _tmp13_ = NULL;
		const gchar* _tmp14_ = NULL;
#line 1332 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp13_ = ifs;
#line 1332 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp14_ = (*_tmp13_).basedir;
#line 1332 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp10_ = _tmp14_;
#line 8591 "ImportPage.c"
	} else {
#line 1332 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp10_ = "/";
#line 8595 "ImportPage.c"
	}
#line 1332 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp15_ = g_strdup (_tmp10_);
#line 1332 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = _tmp15_;
#line 1332 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 8603 "ImportPage.c"
}


gchar* import_page_get_fulldir (Camera* camera, const gchar* camera_name, gint fsid, const gchar* folder) {
	gchar* result = NULL;
	const gchar* _tmp0_ = NULL;
	gint _tmp1_ = 0;
	gint _tmp2_ = 0;
	gchar* basedir = NULL;
	Camera* _tmp3_ = NULL;
	gint _tmp4_ = 0;
	gchar* _tmp5_ = NULL;
	const gchar* _tmp6_ = NULL;
	const gchar* _tmp11_ = NULL;
	const gchar* _tmp12_ = NULL;
	gchar* _tmp13_ = NULL;
#line 1335 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail (camera != NULL, NULL);
#line 1335 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail (camera_name != NULL, NULL);
#line 1335 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail (folder != NULL, NULL);
#line 1336 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = folder;
#line 1336 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = strlen (_tmp0_);
#line 1336 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp2_ = _tmp1_;
#line 1336 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (_tmp2_ > GP_MAX_BASEDIR_LENGTH) {
#line 1337 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		result = NULL;
#line 1337 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		return result;
#line 8638 "ImportPage.c"
	}
#line 1339 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp3_ = camera;
#line 1339 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp4_ = fsid;
#line 1339 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp5_ = import_page_get_fs_basedir (_tmp3_, _tmp4_);
#line 1339 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	basedir = _tmp5_;
#line 1340 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp6_ = basedir;
#line 1340 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (_tmp6_ == NULL) {
#line 8652 "ImportPage.c"
		const gchar* _tmp7_ = NULL;
		gint _tmp8_ = 0;
		const gchar* _tmp9_ = NULL;
		gchar* _tmp10_ = NULL;
#line 1341 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp7_ = camera_name;
#line 1341 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp8_ = fsid;
#line 1341 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		g_debug ("ImportPage.vala:1341: Unable to find base directory for %s fsid %d", _tmp7_, _tmp8_);
#line 1343 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp9_ = folder;
#line 1343 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp10_ = g_strdup (_tmp9_);
#line 1343 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		result = _tmp10_;
#line 1343 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_free0 (basedir);
#line 1343 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		return result;
#line 8673 "ImportPage.c"
	}
#line 1346 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp11_ = basedir;
#line 1346 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp12_ = folder;
#line 1346 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp13_ = import_page_append_path (_tmp11_, _tmp12_);
#line 1346 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = _tmp13_;
#line 1346 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_free0 (basedir);
#line 1346 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 8687 "ImportPage.c"
}


static gboolean import_page_enumerate_files (ImportPage* self, gint fsid, const gchar* dir, GeeArrayList* import_list) {
	gboolean result = FALSE;
	gchar* fulldir = NULL;
	Camera* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gint _tmp2_ = 0;
	const gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
	CameraList* files = NULL;
	CameraList* _tmp7_ = NULL;
	int _tmp8_ = 0;
	int _tmp9_ = 0;
	Camera* _tmp13_ = NULL;
	const gchar* _tmp14_ = NULL;
	CameraList* _tmp15_ = NULL;
	GPSpinIdleWrapper* _tmp16_ = NULL;
	GPContext* _tmp17_ = NULL;
	int _tmp18_ = 0;
	int _tmp19_ = 0;
	CameraList* folders = NULL;
	CameraList* _tmp109_ = NULL;
	int _tmp110_ = 0;
	int _tmp111_ = 0;
	Camera* _tmp115_ = NULL;
	const gchar* _tmp116_ = NULL;
	CameraList* _tmp117_ = NULL;
	GPSpinIdleWrapper* _tmp118_ = NULL;
	GPContext* _tmp119_ = NULL;
	int _tmp120_ = 0;
	int _tmp121_ = 0;
	GError * _inner_error_ = NULL;
#line 1349 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail (IS_IMPORT_PAGE (self), FALSE);
#line 1349 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail (dir != NULL, FALSE);
#line 1349 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail (GEE_IS_ARRAY_LIST (import_list), FALSE);
#line 1350 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = self->priv->camera;
#line 1350 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = self->priv->camera_name;
#line 1350 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp2_ = fsid;
#line 1350 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp3_ = dir;
#line 1350 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp4_ = import_page_get_fulldir (_tmp0_, _tmp1_, _tmp2_, _tmp3_);
#line 1350 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	fulldir = _tmp4_;
#line 1351 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp5_ = fulldir;
#line 1351 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (_tmp5_ == NULL) {
#line 8745 "ImportPage.c"
		const gchar* _tmp6_ = NULL;
#line 1352 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp6_ = dir;
#line 1352 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		g_warning ("ImportPage.vala:1352: Skipping enumerating %s: invalid folder name", _tmp6_);
#line 1354 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		result = TRUE;
#line 1354 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_free0 (fulldir);
#line 1354 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		return result;
#line 8757 "ImportPage.c"
	}
#line 1358 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp8_ = gp_list_new (&_tmp7_);
#line 1358 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_gp_list_unref0 (files);
#line 1358 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	files = _tmp7_;
#line 1358 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self->priv->refresh_result = _tmp8_;
#line 1359 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp9_ = self->priv->refresh_result;
#line 1359 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (_tmp9_ != GP_OK) {
#line 8771 "ImportPage.c"
		int _tmp10_ = 0;
		gchar* _tmp11_ = NULL;
		gchar* _tmp12_ = NULL;
#line 1360 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp10_ = self->priv->refresh_result;
#line 1360 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp11_ = gp_result_to_full_string (_tmp10_);
#line 1360 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp12_ = _tmp11_;
#line 1360 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		g_warning ("ImportPage.vala:1360: Unable to create file list: %s", _tmp12_);
#line 1360 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_free0 (_tmp12_);
#line 1362 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		result = FALSE;
#line 1362 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_gp_list_unref0 (files);
#line 1362 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_free0 (fulldir);
#line 1362 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		return result;
#line 8793 "ImportPage.c"
	}
#line 1365 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp13_ = self->priv->camera;
#line 1365 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp14_ = fulldir;
#line 1365 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp15_ = files;
#line 1365 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp16_ = import_page_spin_idle_context;
#line 1365 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp17_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp16_, GP_TYPE_CONTEXT_WRAPPER, GPContextWrapper)->context;
#line 1365 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp18_ = gp_camera_folder_list_files (_tmp13_, _tmp14_, _tmp15_, _tmp17_);
#line 1365 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self->priv->refresh_result = _tmp18_;
#line 1366 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp19_ = self->priv->refresh_result;
#line 1366 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (_tmp19_ != GP_OK) {
#line 8813 "ImportPage.c"
		const gchar* _tmp20_ = NULL;
		int _tmp21_ = 0;
		gchar* _tmp22_ = NULL;
		gchar* _tmp23_ = NULL;
#line 1367 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp20_ = fulldir;
#line 1367 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp21_ = self->priv->refresh_result;
#line 1367 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp22_ = gp_result_to_full_string (_tmp21_);
#line 1367 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp23_ = _tmp22_;
#line 1367 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		g_warning ("ImportPage.vala:1367: Unable to list files in %s: %s", _tmp20_, _tmp23_);
#line 1367 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_free0 (_tmp23_);
#line 1370 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		self->priv->refresh_result = GP_OK;
#line 1372 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		result = TRUE;
#line 1372 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_gp_list_unref0 (files);
#line 1372 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_free0 (fulldir);
#line 1372 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		return result;
#line 8840 "ImportPage.c"
	}
	{
		gint ctr = 0;
#line 1375 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		ctr = 0;
#line 8846 "ImportPage.c"
		{
			gboolean _tmp24_ = FALSE;
#line 1375 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp24_ = TRUE;
#line 1375 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			while (TRUE) {
#line 8853 "ImportPage.c"
				gint _tmp26_ = 0;
				CameraList* _tmp27_ = NULL;
				gint _tmp28_ = 0;
				gchar* filename = NULL;
				CameraList* _tmp29_ = NULL;
				gint _tmp30_ = 0;
				const gchar* _tmp31_ = NULL;
				int _tmp32_ = 0;
				gchar* _tmp33_ = NULL;
				int _tmp34_ = 0;
#line 1375 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				if (!_tmp24_) {
#line 8866 "ImportPage.c"
					gint _tmp25_ = 0;
#line 1375 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp25_ = ctr;
#line 1375 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					ctr = _tmp25_ + 1;
#line 8872 "ImportPage.c"
				}
#line 1375 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp24_ = FALSE;
#line 1375 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp26_ = ctr;
#line 1375 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp27_ = files;
#line 1375 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp28_ = gp_list_count (_tmp27_);
#line 1375 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				if (!(_tmp26_ < _tmp28_)) {
#line 1375 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					break;
#line 8886 "ImportPage.c"
				}
#line 1377 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp29_ = files;
#line 1377 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp30_ = ctr;
#line 1377 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp32_ = gp_list_get_name (_tmp29_, _tmp30_, &_tmp31_);
#line 1377 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_g_free0 (filename);
#line 1377 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp33_ = g_strdup (_tmp31_);
#line 1377 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				filename = _tmp33_;
#line 1377 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				self->priv->refresh_result = _tmp32_;
#line 1378 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp34_ = self->priv->refresh_result;
#line 1378 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				if (_tmp34_ != GP_OK) {
#line 8906 "ImportPage.c"
					gint _tmp35_ = 0;
					const gchar* _tmp36_ = NULL;
					int _tmp37_ = 0;
					gchar* _tmp38_ = NULL;
					gchar* _tmp39_ = NULL;
#line 1379 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp35_ = ctr;
#line 1379 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp36_ = fulldir;
#line 1379 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp37_ = self->priv->refresh_result;
#line 1379 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp38_ = gp_result_to_full_string (_tmp37_);
#line 1379 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp39_ = _tmp38_;
#line 1379 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					g_warning ("ImportPage.vala:1379: Unable to get the name of file %d in %s: %s", _tmp35_, _tmp36_, _tmp39_);
#line 1379 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_g_free0 (_tmp39_);
#line 1382 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					result = FALSE;
#line 1382 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_g_free0 (filename);
#line 1382 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_gp_list_unref0 (files);
#line 1382 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_g_free0 (fulldir);
#line 1382 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					return result;
#line 8936 "ImportPage.c"
				}
				{
					CameraFileInfo info = {0};
					gboolean _tmp40_ = FALSE;
					GPSpinIdleWrapper* _tmp41_ = NULL;
					GPContext* _tmp42_ = NULL;
					Camera* _tmp43_ = NULL;
					const gchar* _tmp44_ = NULL;
					const gchar* _tmp45_ = NULL;
					CameraFileInfo _tmp46_ = {0};
					gboolean _tmp47_ = FALSE;
					CameraFileInfo _tmp50_ = {0};
					CameraFileInfoFile _tmp51_ = {0};
					CameraFileInfoFields _tmp52_ = 0;
					const gchar* _tmp58_ = NULL;
					gboolean _tmp59_ = FALSE;
					GtkProgressBar* _tmp102_ = NULL;
#line 1387 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp41_ = import_page_spin_idle_context;
#line 1387 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp42_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp41_, GP_TYPE_CONTEXT_WRAPPER, GPContextWrapper)->context;
#line 1387 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp43_ = self->priv->camera;
#line 1387 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp44_ = fulldir;
#line 1387 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp45_ = filename;
#line 1387 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp47_ = gp_get_info (_tmp42_, _tmp43_, _tmp44_, _tmp45_, &_tmp46_, &_inner_error_);
#line 1387 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					 (info);
#line 1387 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					info = _tmp46_;
#line 1387 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp40_ = _tmp47_;
#line 1387 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1387 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						 (info);
#line 8976 "ImportPage.c"
						goto __catch64_g_error;
					}
#line 1387 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					if (!_tmp40_) {
#line 8981 "ImportPage.c"
						const gchar* _tmp48_ = NULL;
						const gchar* _tmp49_ = NULL;
#line 1388 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp48_ = fulldir;
#line 1388 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp49_ = filename;
#line 1388 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						g_warning ("ImportPage.vala:1388: Skipping import of %s/%s: name too long", _tmp48_, _tmp49_);
#line 1390 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						 (info);
#line 1390 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_g_free0 (filename);
#line 1390 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						continue;
#line 8996 "ImportPage.c"
					}
#line 1393 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp50_ = info;
#line 1393 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp51_ = _tmp50_.file;
#line 1393 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp52_ = _tmp51_.fields;
#line 1393 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					if ((_tmp52_ & GP_FILE_INFO_TYPE) == 0) {
#line 9006 "ImportPage.c"
						const gchar* _tmp53_ = NULL;
						const gchar* _tmp54_ = NULL;
						CameraFileInfo _tmp55_ = {0};
						CameraFileInfoFile _tmp56_ = {0};
						CameraFileInfoFields _tmp57_ = 0;
#line 1394 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp53_ = fulldir;
#line 1394 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp54_ = filename;
#line 1394 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp55_ = info;
#line 1394 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp56_ = _tmp55_.file;
#line 1394 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp57_ = _tmp56_.fields;
#line 1394 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						g_message ("ImportPage.vala:1394: Skipping %s/%s: No file (file=%02Xh)", _tmp53_, _tmp54_, (guint) _tmp57_);
#line 1397 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						 (info);
#line 1397 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_g_free0 (filename);
#line 1397 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						continue;
#line 9030 "ImportPage.c"
					}
#line 1400 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp58_ = filename;
#line 1400 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp59_ = video_reader_is_supported_video_filename (_tmp58_);
#line 1400 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					if (_tmp59_) {
#line 9038 "ImportPage.c"
						VideoImportSource* video_source = NULL;
						const gchar* _tmp60_ = NULL;
						Camera* _tmp61_ = NULL;
						gint _tmp62_ = 0;
						const gchar* _tmp63_ = NULL;
						const gchar* _tmp64_ = NULL;
						CameraFileInfo _tmp65_ = {0};
						CameraFileInfoFile _tmp66_ = {0};
						gulong _tmp67_ = 0UL;
						CameraFileInfo _tmp68_ = {0};
						CameraFileInfoFile _tmp69_ = {0};
						time_t _tmp70_ = 0;
						VideoImportSource* _tmp71_ = NULL;
						GeeArrayList* _tmp72_ = NULL;
						VideoImportSource* _tmp73_ = NULL;
#line 1401 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp60_ = self->priv->camera_name;
#line 1401 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp61_ = self->priv->camera;
#line 1401 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp62_ = fsid;
#line 1401 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp63_ = dir;
#line 1401 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp64_ = filename;
#line 1401 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp65_ = info;
#line 1401 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp66_ = _tmp65_.file;
#line 1401 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp67_ = _tmp66_.size;
#line 1401 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp68_ = info;
#line 1401 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp69_ = _tmp68_.file;
#line 1401 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp70_ = _tmp69_.mtime;
#line 1401 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp71_ = video_import_source_new (_tmp60_, _tmp61_, _tmp62_, _tmp63_, _tmp64_, _tmp67_, _tmp70_);
#line 1401 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						video_source = _tmp71_;
#line 1403 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp72_ = import_list;
#line 1403 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp73_ = video_source;
#line 1403 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						gee_abstract_collection_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp72_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection), G_TYPE_CHECK_INSTANCE_CAST (_tmp73_, TYPE_IMPORT_SOURCE, ImportSource));
#line 1400 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_g_object_unref0 (video_source);
#line 9088 "ImportPage.c"
					} else {
						PhotoFileFormat file_format = 0;
						CameraFileInfo _tmp74_ = {0};
						CameraFileInfoFile _tmp75_ = {0};
						const gchar* _tmp76_ = NULL;
						PhotoFileFormat _tmp77_ = 0;
						PhotoFileFormat _tmp78_ = 0;
						GeeArrayList* _tmp87_ = NULL;
						const gchar* _tmp88_ = NULL;
						Camera* _tmp89_ = NULL;
						gint _tmp90_ = 0;
						const gchar* _tmp91_ = NULL;
						const gchar* _tmp92_ = NULL;
						CameraFileInfo _tmp93_ = {0};
						CameraFileInfoFile _tmp94_ = {0};
						gulong _tmp95_ = 0UL;
						CameraFileInfo _tmp96_ = {0};
						CameraFileInfoFile _tmp97_ = {0};
						time_t _tmp98_ = 0;
						PhotoFileFormat _tmp99_ = 0;
						PhotoImportSource* _tmp100_ = NULL;
						PhotoImportSource* _tmp101_ = NULL;
#line 1406 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp74_ = info;
#line 1406 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp75_ = _tmp74_.file;
#line 1406 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp76_ = _tmp75_.type;
#line 1406 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp77_ = photo_file_format_from_gphoto_type (_tmp76_);
#line 1406 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						file_format = _tmp77_;
#line 1407 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp78_ = file_format;
#line 1407 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						if (_tmp78_ == PHOTO_FILE_FORMAT_UNKNOWN) {
#line 9125 "ImportPage.c"
							const gchar* _tmp79_ = NULL;
							PhotoFileFormat _tmp80_ = 0;
							PhotoFileFormat _tmp81_ = 0;
#line 1408 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
							_tmp79_ = filename;
#line 1408 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
							_tmp80_ = photo_file_format_get_by_basename_extension (_tmp79_);
#line 1408 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
							file_format = _tmp80_;
#line 1409 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
							_tmp81_ = file_format;
#line 1409 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
							if (_tmp81_ == PHOTO_FILE_FORMAT_UNKNOWN) {
#line 9139 "ImportPage.c"
								const gchar* _tmp82_ = NULL;
								const gchar* _tmp83_ = NULL;
								CameraFileInfo _tmp84_ = {0};
								CameraFileInfoFile _tmp85_ = {0};
								const gchar* _tmp86_ = NULL;
#line 1410 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
								_tmp82_ = fulldir;
#line 1410 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
								_tmp83_ = filename;
#line 1410 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
								_tmp84_ = info;
#line 1410 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
								_tmp85_ = _tmp84_.file;
#line 1410 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
								_tmp86_ = _tmp85_.type;
#line 1410 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
								g_message ("ImportPage.vala:1410: Skipping %s/%s: Not a supported file extension (" \
"%s)", _tmp82_, _tmp83_, _tmp86_);
#line 1413 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
								 (info);
#line 1413 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
								_g_free0 (filename);
#line 1413 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
								continue;
#line 9163 "ImportPage.c"
							}
						}
#line 1416 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp87_ = import_list;
#line 1416 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp88_ = self->priv->camera_name;
#line 1416 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp89_ = self->priv->camera;
#line 1416 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp90_ = fsid;
#line 1416 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp91_ = dir;
#line 1416 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp92_ = filename;
#line 1416 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp93_ = info;
#line 1416 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp94_ = _tmp93_.file;
#line 1416 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp95_ = _tmp94_.size;
#line 1416 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp96_ = info;
#line 1416 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp97_ = _tmp96_.file;
#line 1416 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp98_ = _tmp97_.mtime;
#line 1416 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp99_ = file_format;
#line 1416 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp100_ = photo_import_source_new (_tmp88_, _tmp89_, _tmp90_, _tmp91_, _tmp92_, _tmp95_, _tmp98_, _tmp99_);
#line 1416 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp101_ = _tmp100_;
#line 1416 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						gee_abstract_collection_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp87_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection), G_TYPE_CHECK_INSTANCE_CAST (_tmp101_, TYPE_IMPORT_SOURCE, ImportSource));
#line 1416 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_g_object_unref0 (_tmp101_);
#line 9200 "ImportPage.c"
					}
#line 1420 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp102_ = self->priv->progress_bar;
#line 1420 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					gtk_progress_bar_pulse (_tmp102_);
#line 1423 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					spin_event_loop ();
#line 1385 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					 (info);
#line 9210 "ImportPage.c"
				}
				goto __finally64;
				__catch64_g_error:
				{
					GError* err = NULL;
					const gchar* _tmp103_ = NULL;
					GError* _tmp104_ = NULL;
					const gchar* _tmp105_ = NULL;
					GError* _tmp106_ = NULL;
					const gchar* _tmp107_ = NULL;
					gchar* _tmp108_ = NULL;
#line 1385 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					err = _inner_error_;
#line 1385 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_inner_error_ = NULL;
#line 1425 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp103_ = fulldir;
#line 1425 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp104_ = err;
#line 1425 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp105_ = _tmp104_->message;
#line 1425 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					g_warning ("ImportPage.vala:1425: Error while enumerating files in %s: %s", _tmp103_, _tmp105_);
#line 1427 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp106_ = err;
#line 1427 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp107_ = _tmp106_->message;
#line 1427 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp108_ = g_strdup (_tmp107_);
#line 1427 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_g_free0 (self->priv->refresh_error);
#line 1427 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					self->priv->refresh_error = _tmp108_;
#line 1429 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					result = FALSE;
#line 1429 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_g_error_free0 (err);
#line 1429 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_g_free0 (filename);
#line 1429 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_gp_list_unref0 (files);
#line 1429 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_g_free0 (fulldir);
#line 1429 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					return result;
#line 9256 "ImportPage.c"
				}
				__finally64:
#line 1385 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1385 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_g_free0 (filename);
#line 1385 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_gp_list_unref0 (files);
#line 1385 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_g_free0 (fulldir);
#line 1385 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1385 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					g_clear_error (&_inner_error_);
#line 1385 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					return FALSE;
#line 9273 "ImportPage.c"
				}
#line 1375 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_g_free0 (filename);
#line 9277 "ImportPage.c"
			}
		}
	}
#line 1434 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp110_ = gp_list_new (&_tmp109_);
#line 1434 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_gp_list_unref0 (folders);
#line 1434 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	folders = _tmp109_;
#line 1434 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self->priv->refresh_result = _tmp110_;
#line 1435 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp111_ = self->priv->refresh_result;
#line 1435 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (_tmp111_ != GP_OK) {
#line 9293 "ImportPage.c"
		int _tmp112_ = 0;
		gchar* _tmp113_ = NULL;
		gchar* _tmp114_ = NULL;
#line 1436 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp112_ = self->priv->refresh_result;
#line 1436 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp113_ = gp_result_to_full_string (_tmp112_);
#line 1436 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp114_ = _tmp113_;
#line 1436 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		g_warning ("ImportPage.vala:1436: Unable to create folder list: %s", _tmp114_);
#line 1436 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_free0 (_tmp114_);
#line 1438 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		result = FALSE;
#line 1438 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_gp_list_unref0 (folders);
#line 1438 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_gp_list_unref0 (files);
#line 1438 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_free0 (fulldir);
#line 1438 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		return result;
#line 9317 "ImportPage.c"
	}
#line 1441 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp115_ = self->priv->camera;
#line 1441 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp116_ = fulldir;
#line 1441 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp117_ = folders;
#line 1441 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp118_ = import_page_spin_idle_context;
#line 1441 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp119_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp118_, GP_TYPE_CONTEXT_WRAPPER, GPContextWrapper)->context;
#line 1441 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp120_ = gp_camera_folder_list_folders (_tmp115_, _tmp116_, _tmp117_, _tmp119_);
#line 1441 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self->priv->refresh_result = _tmp120_;
#line 1442 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp121_ = self->priv->refresh_result;
#line 1442 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (_tmp121_ != GP_OK) {
#line 9337 "ImportPage.c"
		const gchar* _tmp122_ = NULL;
		int _tmp123_ = 0;
		gchar* _tmp124_ = NULL;
		gchar* _tmp125_ = NULL;
#line 1443 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp122_ = fulldir;
#line 1443 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp123_ = self->priv->refresh_result;
#line 1443 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp124_ = gp_result_to_full_string (_tmp123_);
#line 1443 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp125_ = _tmp124_;
#line 1443 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		g_warning ("ImportPage.vala:1443: Unable to list folders in %s: %s", _tmp122_, _tmp125_);
#line 1443 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_free0 (_tmp125_);
#line 1446 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		self->priv->refresh_result = GP_OK;
#line 1448 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		result = TRUE;
#line 1448 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_gp_list_unref0 (folders);
#line 1448 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_gp_list_unref0 (files);
#line 1448 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_free0 (fulldir);
#line 1448 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		return result;
#line 9366 "ImportPage.c"
	}
	{
		gint ctr = 0;
#line 1451 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		ctr = 0;
#line 9372 "ImportPage.c"
		{
			gboolean _tmp126_ = FALSE;
#line 1451 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp126_ = TRUE;
#line 1451 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			while (TRUE) {
#line 9379 "ImportPage.c"
				gint _tmp128_ = 0;
				CameraList* _tmp129_ = NULL;
				gint _tmp130_ = 0;
				gchar* subdir = NULL;
				CameraList* _tmp131_ = NULL;
				gint _tmp132_ = 0;
				const gchar* _tmp133_ = NULL;
				int _tmp134_ = 0;
				gchar* _tmp135_ = NULL;
				int _tmp136_ = 0;
				gint _tmp141_ = 0;
				const gchar* _tmp142_ = NULL;
				const gchar* _tmp143_ = NULL;
				gchar* _tmp144_ = NULL;
				gchar* _tmp145_ = NULL;
				GeeArrayList* _tmp146_ = NULL;
				gboolean _tmp147_ = FALSE;
				gboolean _tmp148_ = FALSE;
#line 1451 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				if (!_tmp126_) {
#line 9400 "ImportPage.c"
					gint _tmp127_ = 0;
#line 1451 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp127_ = ctr;
#line 1451 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					ctr = _tmp127_ + 1;
#line 9406 "ImportPage.c"
				}
#line 1451 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp126_ = FALSE;
#line 1451 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp128_ = ctr;
#line 1451 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp129_ = folders;
#line 1451 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp130_ = gp_list_count (_tmp129_);
#line 1451 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				if (!(_tmp128_ < _tmp130_)) {
#line 1451 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					break;
#line 9420 "ImportPage.c"
				}
#line 1453 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp131_ = folders;
#line 1453 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp132_ = ctr;
#line 1453 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp134_ = gp_list_get_name (_tmp131_, _tmp132_, &_tmp133_);
#line 1453 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_g_free0 (subdir);
#line 1453 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp135_ = g_strdup (_tmp133_);
#line 1453 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				subdir = _tmp135_;
#line 1453 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				self->priv->refresh_result = _tmp134_;
#line 1454 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp136_ = self->priv->refresh_result;
#line 1454 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				if (_tmp136_ != GP_OK) {
#line 9440 "ImportPage.c"
					gint _tmp137_ = 0;
					int _tmp138_ = 0;
					gchar* _tmp139_ = NULL;
					gchar* _tmp140_ = NULL;
#line 1455 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp137_ = ctr;
#line 1455 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp138_ = self->priv->refresh_result;
#line 1455 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp139_ = gp_result_to_full_string (_tmp138_);
#line 1455 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp140_ = _tmp139_;
#line 1455 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					g_warning ("ImportPage.vala:1455: Unable to get name of folder %d: %s", _tmp137_, _tmp140_);
#line 1455 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_g_free0 (_tmp140_);
#line 1457 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					result = FALSE;
#line 1457 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_g_free0 (subdir);
#line 1457 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_gp_list_unref0 (folders);
#line 1457 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_gp_list_unref0 (files);
#line 1457 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_g_free0 (fulldir);
#line 1457 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					return result;
#line 9469 "ImportPage.c"
				}
#line 1460 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp141_ = fsid;
#line 1460 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp142_ = dir;
#line 1460 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp143_ = subdir;
#line 1460 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp144_ = import_page_append_path (_tmp142_, _tmp143_);
#line 1460 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp145_ = _tmp144_;
#line 1460 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp146_ = import_list;
#line 1460 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp147_ = import_page_enumerate_files (self, _tmp141_, _tmp145_, _tmp146_);
#line 1460 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp148_ = !_tmp147_;
#line 1460 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_g_free0 (_tmp145_);
#line 1460 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				if (_tmp148_) {
#line 1461 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					result = FALSE;
#line 1461 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_g_free0 (subdir);
#line 1461 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_gp_list_unref0 (folders);
#line 1461 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_gp_list_unref0 (files);
#line 1461 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_g_free0 (fulldir);
#line 1461 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					return result;
#line 9503 "ImportPage.c"
				}
#line 1451 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_g_free0 (subdir);
#line 9507 "ImportPage.c"
			}
		}
	}
#line 1464 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = TRUE;
#line 1464 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_gp_list_unref0 (folders);
#line 1464 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_gp_list_unref0 (files);
#line 1464 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_free0 (fulldir);
#line 1464 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 9521 "ImportPage.c"
}


static void import_page_auto_match_raw_jpeg (ImportPage* self, GeeArrayList* import_list) {
#line 1468 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_if_fail (IS_IMPORT_PAGE (self));
#line 1468 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_if_fail (GEE_IS_ARRAY_LIST (import_list));
#line 9530 "ImportPage.c"
	{
		gint i = 0;
#line 1469 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		i = 0;
#line 9535 "ImportPage.c"
		{
			gboolean _tmp0_ = FALSE;
#line 1469 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp0_ = TRUE;
#line 1469 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			while (TRUE) {
#line 9542 "ImportPage.c"
				gint _tmp2_ = 0;
				GeeArrayList* _tmp3_ = NULL;
				gint _tmp4_ = 0;
				gint _tmp5_ = 0;
				PhotoImportSource* current = NULL;
				GeeArrayList* _tmp6_ = NULL;
				gint _tmp7_ = 0;
				gpointer _tmp8_ = NULL;
				ImportSource* _tmp9_ = NULL;
				PhotoImportSource* _tmp10_ = NULL;
				PhotoImportSource* _tmp11_ = NULL;
				gint _tmp12_ = 0;
				GeeArrayList* _tmp13_ = NULL;
				gint _tmp14_ = 0;
				gint _tmp15_ = 0;
				PhotoImportSource* next = NULL;
				PhotoImportSource* _tmp21_ = NULL;
				PhotoImportSource* _tmp22_ = NULL;
				gint _tmp23_ = 0;
				PhotoImportSource* prev = NULL;
				PhotoImportSource* _tmp29_ = NULL;
				gboolean _tmp30_ = FALSE;
				PhotoImportSource* _tmp31_ = NULL;
#line 1469 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				if (!_tmp0_) {
#line 9568 "ImportPage.c"
					gint _tmp1_ = 0;
#line 1469 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp1_ = i;
#line 1469 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					i = _tmp1_ + 1;
#line 9574 "ImportPage.c"
				}
#line 1469 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp0_ = FALSE;
#line 1469 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp2_ = i;
#line 1469 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp3_ = import_list;
#line 1469 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp4_ = gee_abstract_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, GEE_TYPE_COLLECTION, GeeCollection));
#line 1469 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp5_ = _tmp4_;
#line 1469 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				if (!(_tmp2_ < _tmp5_)) {
#line 1469 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					break;
#line 9590 "ImportPage.c"
				}
#line 1470 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp6_ = import_list;
#line 1470 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp7_ = i;
#line 1470 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp8_ = gee_abstract_list_get (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, GEE_TYPE_ABSTRACT_LIST, GeeAbstractList), _tmp7_);
#line 1470 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp9_ = (ImportSource*) _tmp8_;
#line 1470 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp10_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp9_, TYPE_PHOTO_IMPORT_SOURCE) ? ((PhotoImportSource*) _tmp9_) : NULL;
#line 1470 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				if (_tmp10_ == NULL) {
#line 1470 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_g_object_unref0 (_tmp9_);
#line 9606 "ImportPage.c"
				}
#line 1470 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				current = _tmp10_;
#line 1471 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp12_ = i;
#line 1471 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp13_ = import_list;
#line 1471 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp14_ = gee_abstract_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp13_, GEE_TYPE_COLLECTION, GeeCollection));
#line 1471 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp15_ = _tmp14_;
#line 1471 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				if ((_tmp12_ + 1) < _tmp15_) {
#line 9620 "ImportPage.c"
					GeeArrayList* _tmp16_ = NULL;
					gint _tmp17_ = 0;
					gpointer _tmp18_ = NULL;
					ImportSource* _tmp19_ = NULL;
					PhotoImportSource* _tmp20_ = NULL;
#line 1472 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp16_ = import_list;
#line 1472 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp17_ = i;
#line 1472 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp18_ = gee_abstract_list_get (G_TYPE_CHECK_INSTANCE_CAST (_tmp16_, GEE_TYPE_ABSTRACT_LIST, GeeAbstractList), _tmp17_ + 1);
#line 1472 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp19_ = (ImportSource*) _tmp18_;
#line 1472 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp20_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp19_, TYPE_PHOTO_IMPORT_SOURCE) ? ((PhotoImportSource*) _tmp19_) : NULL;
#line 1472 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					if (_tmp20_ == NULL) {
#line 1472 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_g_object_unref0 (_tmp19_);
#line 9640 "ImportPage.c"
					}
#line 1472 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_g_object_unref0 (_tmp11_);
#line 1472 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp11_ = _tmp20_;
#line 9646 "ImportPage.c"
				} else {
#line 1472 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_g_object_unref0 (_tmp11_);
#line 1472 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp11_ = NULL;
#line 9652 "ImportPage.c"
				}
#line 1471 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp21_ = _g_object_ref0 (_tmp11_);
#line 1471 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				next = _tmp21_;
#line 1473 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp23_ = i;
#line 1473 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				if (_tmp23_ > 0) {
#line 9662 "ImportPage.c"
					GeeArrayList* _tmp24_ = NULL;
					gint _tmp25_ = 0;
					gpointer _tmp26_ = NULL;
					ImportSource* _tmp27_ = NULL;
					PhotoImportSource* _tmp28_ = NULL;
#line 1474 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp24_ = import_list;
#line 1474 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp25_ = i;
#line 1474 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp26_ = gee_abstract_list_get (G_TYPE_CHECK_INSTANCE_CAST (_tmp24_, GEE_TYPE_ABSTRACT_LIST, GeeAbstractList), _tmp25_ - 1);
#line 1474 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp27_ = (ImportSource*) _tmp26_;
#line 1474 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp28_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp27_, TYPE_PHOTO_IMPORT_SOURCE) ? ((PhotoImportSource*) _tmp27_) : NULL;
#line 1474 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					if (_tmp28_ == NULL) {
#line 1474 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_g_object_unref0 (_tmp27_);
#line 9682 "ImportPage.c"
					}
#line 1474 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_g_object_unref0 (_tmp22_);
#line 1474 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp22_ = _tmp28_;
#line 9688 "ImportPage.c"
				} else {
#line 1474 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_g_object_unref0 (_tmp22_);
#line 1474 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp22_ = NULL;
#line 9694 "ImportPage.c"
				}
#line 1473 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp29_ = _g_object_ref0 (_tmp22_);
#line 1473 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				prev = _tmp29_;
#line 1475 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp31_ = current;
#line 1475 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				if (_tmp31_ != NULL) {
#line 9704 "ImportPage.c"
					PhotoImportSource* _tmp32_ = NULL;
					PhotoFileFormat _tmp33_ = 0;
#line 1475 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp32_ = current;
#line 1475 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp33_ = photo_import_source_get_file_format (_tmp32_);
#line 1475 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp30_ = _tmp33_ == PHOTO_FILE_FORMAT_RAW;
#line 9713 "ImportPage.c"
				} else {
#line 1475 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp30_ = FALSE;
#line 9717 "ImportPage.c"
				}
#line 1475 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				if (_tmp30_) {
#line 9721 "ImportPage.c"
					gchar* current_name = NULL;
					gchar* ext = NULL;
					PhotoImportSource* _tmp34_ = NULL;
					gchar* _tmp35_ = NULL;
					gchar* _tmp36_ = NULL;
					gchar* _tmp37_ = NULL;
					gchar* _tmp38_ = NULL;
					PhotoImportSource* associated = NULL;
					gboolean _tmp39_ = FALSE;
					PhotoImportSource* _tmp40_ = NULL;
					gboolean _tmp52_ = FALSE;
					PhotoImportSource* _tmp53_ = NULL;
					PhotoImportSource* _tmp65_ = NULL;
#line 1478 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp34_ = current;
#line 1478 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp35_ = import_source_get_filename (G_TYPE_CHECK_INSTANCE_CAST (_tmp34_, TYPE_IMPORT_SOURCE, ImportSource));
#line 1478 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp36_ = _tmp35_;
#line 1478 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					disassemble_filename (_tmp36_, &_tmp37_, &_tmp38_);
#line 1478 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_g_free0 (current_name);
#line 1478 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					current_name = _tmp37_;
#line 1478 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_g_free0 (ext);
#line 1478 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					ext = _tmp38_;
#line 1478 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_g_free0 (_tmp36_);
#line 1481 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					associated = NULL;
#line 1482 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp40_ = next;
#line 1482 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					if (_tmp40_ != NULL) {
#line 9759 "ImportPage.c"
						PhotoImportSource* _tmp41_ = NULL;
						PhotoFileFormat _tmp42_ = 0;
#line 1482 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp41_ = next;
#line 1482 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp42_ = photo_import_source_get_file_format (_tmp41_);
#line 1482 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp39_ = _tmp42_ == PHOTO_FILE_FORMAT_JFIF;
#line 9768 "ImportPage.c"
					} else {
#line 1482 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp39_ = FALSE;
#line 9772 "ImportPage.c"
					}
#line 1482 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					if (_tmp39_) {
#line 9776 "ImportPage.c"
						gchar* next_name = NULL;
						PhotoImportSource* _tmp43_ = NULL;
						gchar* _tmp44_ = NULL;
						gchar* _tmp45_ = NULL;
						gchar* _tmp46_ = NULL;
						gchar* _tmp47_ = NULL;
						const gchar* _tmp48_ = NULL;
						const gchar* _tmp49_ = NULL;
#line 1484 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp43_ = next;
#line 1484 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp44_ = import_source_get_filename (G_TYPE_CHECK_INSTANCE_CAST (_tmp43_, TYPE_IMPORT_SOURCE, ImportSource));
#line 1484 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp45_ = _tmp44_;
#line 1484 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						disassemble_filename (_tmp45_, &_tmp46_, &_tmp47_);
#line 1484 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_g_free0 (next_name);
#line 1484 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						next_name = _tmp46_;
#line 1484 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_g_free0 (ext);
#line 1484 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						ext = _tmp47_;
#line 1484 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_g_free0 (_tmp45_);
#line 1485 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp48_ = next_name;
#line 1485 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp49_ = current_name;
#line 1485 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						if (g_strcmp0 (_tmp48_, _tmp49_) == 0) {
#line 9809 "ImportPage.c"
							PhotoImportSource* _tmp50_ = NULL;
							PhotoImportSource* _tmp51_ = NULL;
#line 1486 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
							_tmp50_ = next;
#line 1486 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
							_tmp51_ = _g_object_ref0 (_tmp50_);
#line 1486 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
							_g_object_unref0 (associated);
#line 1486 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
							associated = _tmp51_;
#line 9820 "ImportPage.c"
						}
#line 1482 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_g_free0 (next_name);
#line 9824 "ImportPage.c"
					}
#line 1488 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp53_ = prev;
#line 1488 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					if (_tmp53_ != NULL) {
#line 9830 "ImportPage.c"
						PhotoImportSource* _tmp54_ = NULL;
						PhotoFileFormat _tmp55_ = 0;
#line 1488 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp54_ = prev;
#line 1488 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp55_ = photo_import_source_get_file_format (_tmp54_);
#line 1488 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp52_ = _tmp55_ == PHOTO_FILE_FORMAT_JFIF;
#line 9839 "ImportPage.c"
					} else {
#line 1488 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp52_ = FALSE;
#line 9843 "ImportPage.c"
					}
#line 1488 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					if (_tmp52_) {
#line 9847 "ImportPage.c"
						gchar* prev_name = NULL;
						PhotoImportSource* _tmp56_ = NULL;
						gchar* _tmp57_ = NULL;
						gchar* _tmp58_ = NULL;
						gchar* _tmp59_ = NULL;
						gchar* _tmp60_ = NULL;
						const gchar* _tmp61_ = NULL;
						const gchar* _tmp62_ = NULL;
#line 1490 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp56_ = prev;
#line 1490 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp57_ = import_source_get_filename (G_TYPE_CHECK_INSTANCE_CAST (_tmp56_, TYPE_IMPORT_SOURCE, ImportSource));
#line 1490 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp58_ = _tmp57_;
#line 1490 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						disassemble_filename (_tmp58_, &_tmp59_, &_tmp60_);
#line 1490 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_g_free0 (prev_name);
#line 1490 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						prev_name = _tmp59_;
#line 1490 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_g_free0 (ext);
#line 1490 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						ext = _tmp60_;
#line 1490 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_g_free0 (_tmp58_);
#line 1491 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp61_ = prev_name;
#line 1491 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp62_ = current_name;
#line 1491 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						if (g_strcmp0 (_tmp61_, _tmp62_) == 0) {
#line 9880 "ImportPage.c"
							PhotoImportSource* _tmp63_ = NULL;
							PhotoImportSource* _tmp64_ = NULL;
#line 1492 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
							_tmp63_ = prev;
#line 1492 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
							_tmp64_ = _g_object_ref0 (_tmp63_);
#line 1492 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
							_g_object_unref0 (associated);
#line 1492 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
							associated = _tmp64_;
#line 9891 "ImportPage.c"
						}
#line 1488 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_g_free0 (prev_name);
#line 9895 "ImportPage.c"
					}
#line 1496 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp65_ = associated;
#line 1496 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					if (_tmp65_ != NULL) {
#line 9901 "ImportPage.c"
						PhotoImportSource* _tmp66_ = NULL;
						gchar* _tmp67_ = NULL;
						gchar* _tmp68_ = NULL;
						PhotoImportSource* _tmp69_ = NULL;
						gchar* _tmp70_ = NULL;
						gchar* _tmp71_ = NULL;
						PhotoImportSource* _tmp72_ = NULL;
						PhotoImportSource* _tmp73_ = NULL;
						GeeArrayList* _tmp74_ = NULL;
						PhotoImportSource* _tmp75_ = NULL;
						gboolean _tmp76_ = FALSE;
#line 1497 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp66_ = current;
#line 1497 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp67_ = import_source_get_filename (G_TYPE_CHECK_INSTANCE_CAST (_tmp66_, TYPE_IMPORT_SOURCE, ImportSource));
#line 1497 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp68_ = _tmp67_;
#line 1497 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp69_ = associated;
#line 1497 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp70_ = import_source_get_filename (G_TYPE_CHECK_INSTANCE_CAST (_tmp69_, TYPE_IMPORT_SOURCE, ImportSource));
#line 1497 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp71_ = _tmp70_;
#line 1497 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						g_debug ("ImportPage.vala:1497: Found RAW+JPEG pair: %s and %s", _tmp68_, _tmp71_);
#line 1497 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_g_free0 (_tmp71_);
#line 1497 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_g_free0 (_tmp68_);
#line 1498 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp72_ = current;
#line 1498 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp73_ = associated;
#line 1498 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						photo_import_source_set_associated (_tmp72_, _tmp73_);
#line 1499 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp74_ = import_list;
#line 1499 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp75_ = associated;
#line 1499 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp76_ = gee_abstract_collection_remove (G_TYPE_CHECK_INSTANCE_CAST (_tmp74_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection), G_TYPE_CHECK_INSTANCE_CAST (_tmp75_, TYPE_IMPORT_SOURCE, ImportSource));
#line 1499 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						if (!_tmp76_) {
#line 9945 "ImportPage.c"
							PhotoImportSource* _tmp77_ = NULL;
#line 1500 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
							g_debug ("ImportPage.vala:1500: Unable to associate files");
#line 1501 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
							_tmp77_ = current;
#line 1501 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
							photo_import_source_set_associated (_tmp77_, NULL);
#line 9953 "ImportPage.c"
						}
					}
#line 1475 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_g_object_unref0 (associated);
#line 1475 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_g_free0 (ext);
#line 1475 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_g_free0 (current_name);
#line 9962 "ImportPage.c"
				}
#line 1469 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_g_object_unref0 (prev);
#line 1469 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_g_object_unref0 (_tmp22_);
#line 1469 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_g_object_unref0 (next);
#line 1469 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_g_object_unref0 (_tmp11_);
#line 1469 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_g_object_unref0 (current);
#line 9974 "ImportPage.c"
			}
		}
	}
}


static void import_page_load_previews_and_metadata (ImportPage* self, GeeList* import_list) {
	gint loaded_photos = 0;
	GError * _inner_error_ = NULL;
#line 1508 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_if_fail (IS_IMPORT_PAGE (self));
#line 1508 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_if_fail (GEE_IS_LIST (import_list));
#line 1509 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	loaded_photos = 0;
#line 9990 "ImportPage.c"
	{
		GeeList* _import_source_list = NULL;
		GeeList* _tmp0_ = NULL;
		GeeList* _tmp1_ = NULL;
		gint _import_source_size = 0;
		GeeList* _tmp2_ = NULL;
		gint _tmp3_ = 0;
		gint _tmp4_ = 0;
		gint _import_source_index = 0;
#line 1510 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp0_ = import_list;
#line 1510 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp1_ = _g_object_ref0 (_tmp0_);
#line 1510 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_import_source_list = _tmp1_;
#line 1510 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp2_ = _import_source_list;
#line 1510 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp3_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, GEE_TYPE_COLLECTION, GeeCollection));
#line 1510 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp4_ = _tmp3_;
#line 1510 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_import_source_size = _tmp4_;
#line 1510 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_import_source_index = -1;
#line 1510 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		while (TRUE) {
#line 10018 "ImportPage.c"
			gint _tmp5_ = 0;
			gint _tmp6_ = 0;
			gint _tmp7_ = 0;
			ImportSource* import_source = NULL;
			GeeList* _tmp8_ = NULL;
			gint _tmp9_ = 0;
			gpointer _tmp10_ = NULL;
			gchar* filename = NULL;
			ImportSource* _tmp11_ = NULL;
			gchar* _tmp12_ = NULL;
			gchar* fulldir = NULL;
			ImportSource* _tmp13_ = NULL;
			gchar* _tmp14_ = NULL;
			const gchar* _tmp15_ = NULL;
			PhotoImportSource* associated = NULL;
			gboolean _tmp19_ = FALSE;
			ImportSource* _tmp20_ = NULL;
			GtkProgressBar* _tmp26_ = NULL;
			GtkProgressBar* _tmp27_ = NULL;
			const gchar* _tmp28_ = NULL;
			ImportSource* _tmp29_ = NULL;
			gchar* _tmp30_ = NULL;
			gchar* _tmp31_ = NULL;
			gchar* _tmp32_ = NULL;
			gchar* _tmp33_ = NULL;
			PhotoMetadata* metadata = NULL;
			const gchar* _tmp34_ = NULL;
			gboolean _tmp35_ = FALSE;
			gchar* exif_only_md5 = NULL;
			PhotoMetadata* _tmp48_ = NULL;
			guint8* preview_raw = NULL;
			gint preview_raw_length1 = 0;
			gint _preview_raw_size_ = 0;
			gsize preview_raw_length = 0UL;
			GdkPixbuf* preview = NULL;
			gchar* preview_md5 = NULL;
			gboolean _tmp84_ = FALSE;
			gboolean _tmp85_ = FALSE;
			GdkPixbuf* _tmp86_ = NULL;
			ImportSource* _tmp92_ = NULL;
			ImportSource* _tmp95_ = NULL;
			PhotoImportSource* _tmp101_ = NULL;
			SourceCollection* _tmp125_ = NULL;
			ImportSource* _tmp126_ = NULL;
			GtkProgressBar* _tmp127_ = NULL;
			gint _tmp128_ = 0;
			gint _tmp129_ = 0;
			GeeList* _tmp130_ = NULL;
			gint _tmp131_ = 0;
			gint _tmp132_ = 0;
#line 1510 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp5_ = _import_source_index;
#line 1510 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_import_source_index = _tmp5_ + 1;
#line 1510 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp6_ = _import_source_index;
#line 1510 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp7_ = _import_source_size;
#line 1510 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			if (!(_tmp6_ < _tmp7_)) {
#line 1510 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				break;
#line 10081 "ImportPage.c"
			}
#line 1510 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp8_ = _import_source_list;
#line 1510 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp9_ = _import_source_index;
#line 1510 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp10_ = gee_list_get (_tmp8_, _tmp9_);
#line 1510 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			import_source = (ImportSource*) _tmp10_;
#line 1511 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp11_ = import_source;
#line 1511 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp12_ = import_source_get_filename (_tmp11_);
#line 1511 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			filename = _tmp12_;
#line 1512 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp13_ = import_source;
#line 1512 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp14_ = import_source_get_fulldir (_tmp13_);
#line 1512 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			fulldir = _tmp14_;
#line 1513 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp15_ = fulldir;
#line 1513 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			if (_tmp15_ == NULL) {
#line 10107 "ImportPage.c"
				ImportSource* _tmp16_ = NULL;
				gchar* _tmp17_ = NULL;
				gchar* _tmp18_ = NULL;
#line 1514 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp16_ = import_source;
#line 1514 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp17_ = data_object_to_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp16_, TYPE_DATA_OBJECT, DataObject));
#line 1514 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp18_ = _tmp17_;
#line 1514 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				g_warning ("ImportPage.vala:1514: Skipping loading preview of %s: invalid folder n" \
"ame", _tmp18_);
#line 1514 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_g_free0 (_tmp18_);
#line 1516 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_g_free0 (fulldir);
#line 1516 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_g_free0 (filename);
#line 1516 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_g_object_unref0 (import_source);
#line 1516 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				continue;
#line 10129 "ImportPage.c"
			}
#line 1520 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			associated = NULL;
#line 1521 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp20_ = import_source;
#line 1521 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp20_, TYPE_PHOTO_IMPORT_SOURCE)) {
#line 10137 "ImportPage.c"
				ImportSource* _tmp21_ = NULL;
				PhotoImportSource* _tmp22_ = NULL;
				PhotoImportSource* _tmp23_ = NULL;
#line 1522 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp21_ = import_source;
#line 1522 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp22_ = photo_import_source_get_associated (G_TYPE_CHECK_INSTANCE_CAST (_tmp21_, TYPE_PHOTO_IMPORT_SOURCE, PhotoImportSource));
#line 1522 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp23_ = _tmp22_;
#line 1522 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp19_ = _tmp23_ != NULL;
#line 1522 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_g_object_unref0 (_tmp23_);
#line 10151 "ImportPage.c"
			} else {
#line 1521 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp19_ = FALSE;
#line 10155 "ImportPage.c"
			}
#line 1521 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			if (_tmp19_) {
#line 10159 "ImportPage.c"
				ImportSource* _tmp24_ = NULL;
				PhotoImportSource* _tmp25_ = NULL;
#line 1523 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp24_ = import_source;
#line 1523 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp25_ = photo_import_source_get_associated (G_TYPE_CHECK_INSTANCE_CAST (_tmp24_, TYPE_PHOTO_IMPORT_SOURCE, PhotoImportSource));
#line 1523 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_g_object_unref0 (associated);
#line 1523 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				associated = _tmp25_;
#line 10170 "ImportPage.c"
			}
#line 1526 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp26_ = self->priv->progress_bar;
#line 1526 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			gtk_progress_bar_set_ellipsize (_tmp26_, PANGO_ELLIPSIZE_MIDDLE);
#line 1527 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp27_ = self->priv->progress_bar;
#line 1527 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp28_ = _ ("Fetching preview for %s");
#line 1527 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp29_ = import_source;
#line 1527 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp30_ = data_object_get_name (G_TYPE_CHECK_INSTANCE_CAST (_tmp29_, TYPE_DATA_OBJECT, DataObject));
#line 1527 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp31_ = _tmp30_;
#line 1527 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp32_ = g_strdup_printf (_tmp28_, _tmp31_);
#line 1527 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp33_ = _tmp32_;
#line 1527 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			gtk_progress_bar_set_text (_tmp27_, _tmp33_);
#line 1527 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_g_free0 (_tmp33_);
#line 1527 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_g_free0 (_tmp31_);
#line 1534 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			metadata = NULL;
#line 1535 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp34_ = filename;
#line 1535 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp35_ = video_reader_is_supported_video_filename (_tmp34_);
#line 1535 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			if (!_tmp35_) {
#line 10204 "ImportPage.c"
				{
					PhotoMetadata* _tmp36_ = NULL;
					GPSpinIdleWrapper* _tmp37_ = NULL;
					GPContext* _tmp38_ = NULL;
					Camera* _tmp39_ = NULL;
					const gchar* _tmp40_ = NULL;
					const gchar* _tmp41_ = NULL;
					PhotoMetadata* _tmp42_ = NULL;
					PhotoMetadata* _tmp43_ = NULL;
#line 1537 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp37_ = import_page_spin_idle_context;
#line 1537 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp38_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp37_, GP_TYPE_CONTEXT_WRAPPER, GPContextWrapper)->context;
#line 1537 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp39_ = self->priv->camera;
#line 1537 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp40_ = fulldir;
#line 1537 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp41_ = filename;
#line 1537 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp42_ = gp_load_metadata (_tmp38_, _tmp39_, _tmp40_, _tmp41_, &_inner_error_);
#line 1537 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp36_ = _tmp42_;
#line 1537 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 10230 "ImportPage.c"
						goto __catch65_g_error;
					}
#line 1537 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp43_ = _tmp36_;
#line 1537 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp36_ = NULL;
#line 1537 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_media_metadata_unref0 (metadata);
#line 1537 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					metadata = _tmp43_;
#line 1536 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_media_metadata_unref0 (_tmp36_);
#line 10243 "ImportPage.c"
				}
				goto __finally65;
				__catch65_g_error:
				{
					GError* err = NULL;
					const gchar* _tmp44_ = NULL;
					const gchar* _tmp45_ = NULL;
					GError* _tmp46_ = NULL;
					const gchar* _tmp47_ = NULL;
#line 1536 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					err = _inner_error_;
#line 1536 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_inner_error_ = NULL;
#line 1540 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp44_ = fulldir;
#line 1540 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp45_ = filename;
#line 1540 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp46_ = err;
#line 1540 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp47_ = _tmp46_->message;
#line 1540 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					g_warning ("ImportPage.vala:1540: Unable to fetch metadata for %s/%s: %s", _tmp44_, _tmp45_, _tmp47_);
#line 1536 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_g_error_free0 (err);
#line 10269 "ImportPage.c"
				}
				__finally65:
#line 1536 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1536 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_media_metadata_unref0 (metadata);
#line 1536 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_g_object_unref0 (associated);
#line 1536 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_g_free0 (fulldir);
#line 1536 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_g_free0 (filename);
#line 1536 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_g_object_unref0 (import_source);
#line 1536 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_g_object_unref0 (_import_source_list);
#line 1536 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1536 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					g_clear_error (&_inner_error_);
#line 1536 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					return;
#line 10292 "ImportPage.c"
				}
			}
#line 1546 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			exif_only_md5 = NULL;
#line 1547 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp48_ = metadata;
#line 1547 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			if (_tmp48_ != NULL) {
#line 10301 "ImportPage.c"
				guint8* flattened_sans_thumbnail = NULL;
				PhotoMetadata* _tmp49_ = NULL;
				gint _tmp50_ = 0;
				guint8* _tmp51_ = NULL;
				gint flattened_sans_thumbnail_length1 = 0;
				gint _flattened_sans_thumbnail_size_ = 0;
				gboolean _tmp52_ = FALSE;
				guint8* _tmp53_ = NULL;
				gint _tmp53__length1 = 0;
#line 1548 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp49_ = metadata;
#line 1548 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp51_ = photo_metadata_flatten_exif (_tmp49_, FALSE, &_tmp50_);
#line 1548 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				flattened_sans_thumbnail = _tmp51_;
#line 1548 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				flattened_sans_thumbnail_length1 = _tmp50_;
#line 1548 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_flattened_sans_thumbnail_size_ = flattened_sans_thumbnail_length1;
#line 1549 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp53_ = flattened_sans_thumbnail;
#line 1549 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp53__length1 = flattened_sans_thumbnail_length1;
#line 1549 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				if (_tmp53_ != NULL) {
#line 10327 "ImportPage.c"
					guint8* _tmp54_ = NULL;
					gint _tmp54__length1 = 0;
#line 1549 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp54_ = flattened_sans_thumbnail;
#line 1549 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp54__length1 = flattened_sans_thumbnail_length1;
#line 1549 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp52_ = _tmp54__length1 > 0;
#line 10336 "ImportPage.c"
				} else {
#line 1549 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp52_ = FALSE;
#line 10340 "ImportPage.c"
				}
#line 1549 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				if (_tmp52_) {
#line 10344 "ImportPage.c"
					guint8* _tmp55_ = NULL;
					gint _tmp55__length1 = 0;
					guint8* _tmp56_ = NULL;
					gint _tmp56__length1 = 0;
					gchar* _tmp57_ = NULL;
#line 1550 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp55_ = flattened_sans_thumbnail;
#line 1550 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp55__length1 = flattened_sans_thumbnail_length1;
#line 1550 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp56_ = flattened_sans_thumbnail;
#line 1550 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp56__length1 = flattened_sans_thumbnail_length1;
#line 1550 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp57_ = md5_binary (_tmp55_, (gsize) _tmp56__length1);
#line 1550 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_g_free0 (exif_only_md5);
#line 1550 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					exif_only_md5 = _tmp57_;
#line 10364 "ImportPage.c"
				}
#line 1547 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				flattened_sans_thumbnail = (g_free (flattened_sans_thumbnail), NULL);
#line 10368 "ImportPage.c"
			}
#line 1559 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			preview_raw = NULL;
#line 1559 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			preview_raw_length1 = 0;
#line 1559 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_preview_raw_size_ = preview_raw_length1;
#line 1560 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			preview_raw_length = (gsize) 0;
#line 1561 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			preview = NULL;
#line 10380 "ImportPage.c"
			{
				gchar* preview_fulldir = NULL;
				const gchar* _tmp58_ = NULL;
				gchar* _tmp59_ = NULL;
				gchar* preview_filename = NULL;
				const gchar* _tmp60_ = NULL;
				gchar* _tmp61_ = NULL;
				PhotoImportSource* _tmp62_ = NULL;
				GdkPixbuf* _tmp67_ = NULL;
				GPSpinIdleWrapper* _tmp68_ = NULL;
				GPContext* _tmp69_ = NULL;
				Camera* _tmp70_ = NULL;
				const gchar* _tmp71_ = NULL;
				const gchar* _tmp72_ = NULL;
				guint8* _tmp73_ = NULL;
				gint _tmp74_ = 0;
				gsize _tmp75_ = 0UL;
				GdkPixbuf* _tmp76_ = NULL;
				GdkPixbuf* _tmp77_ = NULL;
#line 1563 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp58_ = fulldir;
#line 1563 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp59_ = g_strdup (_tmp58_);
#line 1563 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				preview_fulldir = _tmp59_;
#line 1564 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp60_ = filename;
#line 1564 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp61_ = g_strdup (_tmp60_);
#line 1564 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				preview_filename = _tmp61_;
#line 1565 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp62_ = associated;
#line 1565 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				if (_tmp62_ != NULL) {
#line 10416 "ImportPage.c"
					PhotoImportSource* _tmp63_ = NULL;
					gchar* _tmp64_ = NULL;
					PhotoImportSource* _tmp65_ = NULL;
					gchar* _tmp66_ = NULL;
#line 1566 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp63_ = associated;
#line 1566 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp64_ = import_source_get_fulldir (G_TYPE_CHECK_INSTANCE_CAST (_tmp63_, TYPE_IMPORT_SOURCE, ImportSource));
#line 1566 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_g_free0 (preview_fulldir);
#line 1566 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					preview_fulldir = _tmp64_;
#line 1567 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp65_ = associated;
#line 1567 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp66_ = import_source_get_filename (G_TYPE_CHECK_INSTANCE_CAST (_tmp65_, TYPE_IMPORT_SOURCE, ImportSource));
#line 1567 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_g_free0 (preview_filename);
#line 1567 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					preview_filename = _tmp66_;
#line 10437 "ImportPage.c"
				}
#line 1569 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp68_ = import_page_spin_idle_context;
#line 1569 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp69_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp68_, GP_TYPE_CONTEXT_WRAPPER, GPContextWrapper)->context;
#line 1569 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp70_ = self->priv->camera;
#line 1569 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp71_ = preview_fulldir;
#line 1569 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp72_ = preview_filename;
#line 1569 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp76_ = gp_load_preview (_tmp69_, _tmp70_, _tmp71_, _tmp72_, &_tmp73_, &_tmp74_, &_tmp75_, &_inner_error_);
#line 1569 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				preview_raw = (g_free (preview_raw), NULL);
#line 1569 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				preview_raw = _tmp73_;
#line 1569 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				preview_raw_length1 = _tmp74_;
#line 1569 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_preview_raw_size_ = preview_raw_length1;
#line 1569 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				preview_raw_length = _tmp75_;
#line 1569 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp67_ = _tmp76_;
#line 1569 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1569 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_g_free0 (preview_filename);
#line 1569 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_g_free0 (preview_fulldir);
#line 10469 "ImportPage.c"
					goto __catch66_g_error;
				}
#line 1569 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp77_ = _tmp67_;
#line 1569 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp67_ = NULL;
#line 1569 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_g_object_unref0 (preview);
#line 1569 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				preview = _tmp77_;
#line 1562 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_g_object_unref0 (_tmp67_);
#line 1562 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_g_free0 (preview_filename);
#line 1562 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_g_free0 (preview_fulldir);
#line 10486 "ImportPage.c"
			}
			goto __finally66;
			__catch66_g_error:
			{
				GError* err = NULL;
				const gchar* _tmp78_ = NULL;
				gboolean _tmp79_ = FALSE;
#line 1562 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				err = _inner_error_;
#line 1562 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_inner_error_ = NULL;
#line 1577 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp78_ = filename;
#line 1577 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp79_ = video_reader_is_supported_video_filename (_tmp78_);
#line 1577 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				if (!_tmp79_) {
#line 10504 "ImportPage.c"
					const gchar* _tmp80_ = NULL;
					const gchar* _tmp81_ = NULL;
					GError* _tmp82_ = NULL;
					const gchar* _tmp83_ = NULL;
#line 1578 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp80_ = fulldir;
#line 1578 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp81_ = filename;
#line 1578 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp82_ = err;
#line 1578 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp83_ = _tmp82_->message;
#line 1578 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					g_warning ("ImportPage.vala:1578: Unable to fetch preview for %s/%s: %s", _tmp80_, _tmp81_, _tmp83_);
#line 10519 "ImportPage.c"
				}
#line 1562 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_g_error_free0 (err);
#line 10523 "ImportPage.c"
			}
			__finally66:
#line 1562 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1562 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_g_object_unref0 (preview);
#line 1562 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				preview_raw = (g_free (preview_raw), NULL);
#line 1562 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_g_free0 (exif_only_md5);
#line 1562 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_media_metadata_unref0 (metadata);
#line 1562 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_g_object_unref0 (associated);
#line 1562 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_g_free0 (fulldir);
#line 1562 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_g_free0 (filename);
#line 1562 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_g_object_unref0 (import_source);
#line 1562 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_g_object_unref0 (_import_source_list);
#line 1562 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1562 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				g_clear_error (&_inner_error_);
#line 1562 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				return;
#line 10552 "ImportPage.c"
			}
#line 1583 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			preview_md5 = NULL;
#line 1584 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp86_ = preview;
#line 1584 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			if (_tmp86_ != NULL) {
#line 10560 "ImportPage.c"
				guint8* _tmp87_ = NULL;
				gint _tmp87__length1 = 0;
#line 1584 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp87_ = preview_raw;
#line 1584 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp87__length1 = preview_raw_length1;
#line 1584 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp85_ = _tmp87_ != NULL;
#line 10569 "ImportPage.c"
			} else {
#line 1584 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp85_ = FALSE;
#line 10573 "ImportPage.c"
			}
#line 1584 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			if (_tmp85_) {
#line 10577 "ImportPage.c"
				gsize _tmp88_ = 0UL;
#line 1584 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp88_ = preview_raw_length;
#line 1584 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp84_ = _tmp88_ > ((gsize) 0);
#line 10583 "ImportPage.c"
			} else {
#line 1584 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp84_ = FALSE;
#line 10587 "ImportPage.c"
			}
#line 1584 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			if (_tmp84_) {
#line 10591 "ImportPage.c"
				guint8* _tmp89_ = NULL;
				gint _tmp89__length1 = 0;
				gsize _tmp90_ = 0UL;
				gchar* _tmp91_ = NULL;
#line 1585 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp89_ = preview_raw;
#line 1585 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp89__length1 = preview_raw_length1;
#line 1585 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp90_ = preview_raw_length;
#line 1585 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp91_ = md5_binary (_tmp89_, _tmp90_);
#line 1585 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_g_free0 (preview_md5);
#line 1585 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				preview_md5 = _tmp91_;
#line 10608 "ImportPage.c"
			}
#line 1591 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp92_ = import_source;
#line 1591 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp92_, TYPE_VIDEO_IMPORT_SOURCE)) {
#line 10614 "ImportPage.c"
				ImportSource* _tmp93_ = NULL;
				GdkPixbuf* _tmp94_ = NULL;
#line 1592 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp93_ = import_source;
#line 1592 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp94_ = preview;
#line 1592 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				video_import_source_update (G_TYPE_CHECK_INSTANCE_TYPE (_tmp93_, TYPE_VIDEO_IMPORT_SOURCE) ? ((VideoImportSource*) _tmp93_) : NULL, _tmp94_);
#line 10623 "ImportPage.c"
			}
#line 1594 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp95_ = import_source;
#line 1594 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp95_, TYPE_PHOTO_IMPORT_SOURCE)) {
#line 10629 "ImportPage.c"
				ImportSource* _tmp96_ = NULL;
				GdkPixbuf* _tmp97_ = NULL;
				const gchar* _tmp98_ = NULL;
				PhotoMetadata* _tmp99_ = NULL;
				const gchar* _tmp100_ = NULL;
#line 1595 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp96_ = import_source;
#line 1595 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp97_ = preview;
#line 1595 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp98_ = preview_md5;
#line 1595 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp99_ = metadata;
#line 1595 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp100_ = exif_only_md5;
#line 1595 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				photo_import_source_update (G_TYPE_CHECK_INSTANCE_TYPE (_tmp96_, TYPE_PHOTO_IMPORT_SOURCE) ? ((PhotoImportSource*) _tmp96_) : NULL, _tmp97_, _tmp98_, _tmp99_, _tmp100_);
#line 10647 "ImportPage.c"
			}
#line 1598 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp101_ = associated;
#line 1598 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			if (_tmp101_ != NULL) {
#line 10653 "ImportPage.c"
				{
					PhotoMetadata* associated_metadata = NULL;
					GPSpinIdleWrapper* _tmp102_ = NULL;
					GPContext* _tmp103_ = NULL;
					Camera* _tmp104_ = NULL;
					PhotoImportSource* _tmp105_ = NULL;
					gchar* _tmp106_ = NULL;
					gchar* _tmp107_ = NULL;
					PhotoImportSource* _tmp108_ = NULL;
					gchar* _tmp109_ = NULL;
					gchar* _tmp110_ = NULL;
					PhotoMetadata* _tmp111_ = NULL;
					PhotoMetadata* _tmp112_ = NULL;
					PhotoImportSource* _tmp113_ = NULL;
					GdkPixbuf* _tmp114_ = NULL;
					const gchar* _tmp115_ = NULL;
					PhotoMetadata* _tmp116_ = NULL;
#line 1600 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp102_ = import_page_spin_idle_context;
#line 1600 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp103_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp102_, GP_TYPE_CONTEXT_WRAPPER, GPContextWrapper)->context;
#line 1600 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp104_ = self->priv->camera;
#line 1600 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp105_ = associated;
#line 1600 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp106_ = import_source_get_fulldir (G_TYPE_CHECK_INSTANCE_CAST (_tmp105_, TYPE_IMPORT_SOURCE, ImportSource));
#line 1600 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp107_ = _tmp106_;
#line 1600 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp108_ = associated;
#line 1600 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp109_ = import_source_get_filename (G_TYPE_CHECK_INSTANCE_CAST (_tmp108_, TYPE_IMPORT_SOURCE, ImportSource));
#line 1600 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp110_ = _tmp109_;
#line 1600 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp111_ = gp_load_metadata (_tmp103_, _tmp104_, _tmp107_, _tmp110_, &_inner_error_);
#line 1600 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp112_ = _tmp111_;
#line 1600 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_g_free0 (_tmp110_);
#line 1600 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_g_free0 (_tmp107_);
#line 1600 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					associated_metadata = _tmp112_;
#line 1600 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 10701 "ImportPage.c"
						goto __catch67_g_error;
					}
#line 1602 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp113_ = associated;
#line 1602 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp114_ = preview;
#line 1602 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp115_ = preview_md5;
#line 1602 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp116_ = associated_metadata;
#line 1602 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					photo_import_source_update (_tmp113_, _tmp114_, _tmp115_, _tmp116_, NULL);
#line 1599 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_media_metadata_unref0 (associated_metadata);
#line 10716 "ImportPage.c"
				}
				goto __finally67;
				__catch67_g_error:
				{
					GError* err = NULL;
					PhotoImportSource* _tmp117_ = NULL;
					gchar* _tmp118_ = NULL;
					gchar* _tmp119_ = NULL;
					PhotoImportSource* _tmp120_ = NULL;
					gchar* _tmp121_ = NULL;
					gchar* _tmp122_ = NULL;
					GError* _tmp123_ = NULL;
					const gchar* _tmp124_ = NULL;
#line 1599 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					err = _inner_error_;
#line 1599 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_inner_error_ = NULL;
#line 1604 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp117_ = associated;
#line 1604 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp118_ = import_source_get_fulldir (G_TYPE_CHECK_INSTANCE_CAST (_tmp117_, TYPE_IMPORT_SOURCE, ImportSource));
#line 1604 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp119_ = _tmp118_;
#line 1604 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp120_ = associated;
#line 1604 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp121_ = import_source_get_filename (G_TYPE_CHECK_INSTANCE_CAST (_tmp120_, TYPE_IMPORT_SOURCE, ImportSource));
#line 1604 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp122_ = _tmp121_;
#line 1604 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp123_ = err;
#line 1604 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp124_ = _tmp123_->message;
#line 1604 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					g_warning ("ImportPage.vala:1604: Unable to fetch metadata for %s/%s: %s", _tmp119_, _tmp122_, _tmp124_);
#line 1604 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_g_free0 (_tmp122_);
#line 1604 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_g_free0 (_tmp119_);
#line 1599 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_g_error_free0 (err);
#line 10758 "ImportPage.c"
				}
				__finally67:
#line 1599 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1599 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_g_free0 (preview_md5);
#line 1599 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_g_object_unref0 (preview);
#line 1599 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					preview_raw = (g_free (preview_raw), NULL);
#line 1599 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_g_free0 (exif_only_md5);
#line 1599 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_media_metadata_unref0 (metadata);
#line 1599 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_g_object_unref0 (associated);
#line 1599 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_g_free0 (fulldir);
#line 1599 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_g_free0 (filename);
#line 1599 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_g_object_unref0 (import_source);
#line 1599 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_g_object_unref0 (_import_source_list);
#line 1599 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1599 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					g_clear_error (&_inner_error_);
#line 1599 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					return;
#line 10789 "ImportPage.c"
				}
			}
#line 1610 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp125_ = self->priv->import_sources;
#line 1610 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp126_ = import_source;
#line 1610 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			data_collection_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp125_, TYPE_DATA_COLLECTION, DataCollection), G_TYPE_CHECK_INSTANCE_CAST (_tmp126_, TYPE_DATA_OBJECT, DataObject));
#line 1612 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp127_ = self->priv->progress_bar;
#line 1612 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp128_ = loaded_photos;
#line 1612 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			loaded_photos = _tmp128_ + 1;
#line 1612 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp129_ = loaded_photos;
#line 1612 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp130_ = import_list;
#line 1612 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp131_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp130_, GEE_TYPE_COLLECTION, GeeCollection));
#line 1612 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp132_ = _tmp131_;
#line 1612 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			gtk_progress_bar_set_fraction (_tmp127_, ((gdouble) _tmp129_) / ((gdouble) _tmp132_));
#line 1619 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			spin_event_loop ();
#line 1510 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_g_free0 (preview_md5);
#line 1510 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_g_object_unref0 (preview);
#line 1510 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			preview_raw = (g_free (preview_raw), NULL);
#line 1510 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_g_free0 (exif_only_md5);
#line 1510 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_media_metadata_unref0 (metadata);
#line 1510 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_g_object_unref0 (associated);
#line 1510 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_g_free0 (fulldir);
#line 1510 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_g_free0 (filename);
#line 1510 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_g_object_unref0 (import_source);
#line 10834 "ImportPage.c"
		}
#line 1510 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_object_unref0 (_import_source_list);
#line 10838 "ImportPage.c"
	}
}


static void import_page_on_hide_imported (ImportPage* self) {
	GtkCheckButton* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	ConfigFacade* _tmp8_ = NULL;
	ConfigFacade* _tmp9_ = NULL;
	GtkCheckButton* _tmp10_ = NULL;
	gboolean _tmp11_ = FALSE;
#line 1623 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_if_fail (IS_IMPORT_PAGE (self));
#line 1624 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = self->priv->hide_imported;
#line 1624 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = gtk_toggle_button_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_toggle_button_get_type (), GtkToggleButton));
#line 1624 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (_tmp1_) {
#line 10858 "ImportPage.c"
		ViewCollection* _tmp2_ = NULL;
		ViewCollection* _tmp3_ = NULL;
		ImportPageHideImportedViewFilter* _tmp4_ = NULL;
#line 1625 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp2_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 1625 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp3_ = _tmp2_;
#line 1625 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp4_ = self->priv->hide_imported_filter;
#line 1625 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		view_collection_install_view_filter (_tmp3_, G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, TYPE_VIEW_FILTER, ViewFilter));
#line 1625 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_data_collection_unref0 (_tmp3_);
#line 10872 "ImportPage.c"
	} else {
		ViewCollection* _tmp5_ = NULL;
		ViewCollection* _tmp6_ = NULL;
		ImportPageHideImportedViewFilter* _tmp7_ = NULL;
#line 1627 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp5_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 1627 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp6_ = _tmp5_;
#line 1627 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp7_ = self->priv->hide_imported_filter;
#line 1627 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		view_collection_remove_view_filter (_tmp6_, G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, TYPE_VIEW_FILTER, ViewFilter));
#line 1627 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_data_collection_unref0 (_tmp6_);
#line 10887 "ImportPage.c"
	}
#line 1629 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp8_ = config_facade_get_instance ();
#line 1629 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp9_ = _tmp8_;
#line 1629 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp10_ = self->priv->hide_imported;
#line 1629 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp11_ = gtk_toggle_button_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, gtk_toggle_button_get_type (), GtkToggleButton));
#line 1629 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	configuration_facade_set_hide_photos_already_imported (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade), _tmp11_);
#line 1629 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_object_unref0 (_tmp9_);
#line 10901 "ImportPage.c"
}


static void import_page_on_import_selected (ImportPage* self) {
	ViewCollection* _tmp0_ = NULL;
	ViewCollection* _tmp1_ = NULL;
	GeeList* _tmp2_ = NULL;
	GeeList* _tmp3_ = NULL;
#line 1632 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_if_fail (IS_IMPORT_PAGE (self));
#line 1633 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 1633 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = _tmp0_;
#line 1633 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp2_ = view_collection_get_selected (_tmp1_);
#line 1633 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp3_ = _tmp2_;
#line 1633 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	import_page_import (self, G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, GEE_TYPE_ITERABLE, GeeIterable));
#line 1633 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_object_unref0 (_tmp3_);
#line 1633 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_data_collection_unref0 (_tmp1_);
#line 10926 "ImportPage.c"
}


static void import_page_on_import_all (ImportPage* self) {
	ViewCollection* _tmp0_ = NULL;
	ViewCollection* _tmp1_ = NULL;
	GeeCollection* _tmp2_ = NULL;
	GeeCollection* _tmp3_ = NULL;
#line 1636 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_if_fail (IS_IMPORT_PAGE (self));
#line 1637 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 1637 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = _tmp0_;
#line 1637 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp2_ = data_collection_get_all (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, TYPE_DATA_COLLECTION, DataCollection));
#line 1637 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp3_ = _tmp2_;
#line 1637 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	import_page_import (self, G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, GEE_TYPE_ITERABLE, GeeIterable));
#line 1637 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_object_unref0 (_tmp3_);
#line 1637 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_data_collection_unref0 (_tmp1_);
#line 10951 "ImportPage.c"
}


static gint64 _import_page_import_job_comparator_comparator (void* a, void* b, gpointer self) {
	gint64 result;
	result = import_page_import_job_comparator ((ImportPage*) self, a, b);
#line 1653 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 10960 "ImportPage.c"
}


static void _import_page_import_reporter_batch_import_import_reporter (ImportManifest* manifest, BatchImportRoll* import_roll, gpointer self) {
#line 1689 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	import_page_import_reporter ((ImportPage*) self, manifest);
#line 10967 "ImportPage.c"
}


static void _import_page_on_import_job_failed_batch_import_import_job_failed (BatchImport* _sender, BatchImportResult* _result_, gpointer self) {
#line 1691 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	import_page_on_import_job_failed ((ImportPage*) self, _result_);
#line 10974 "ImportPage.c"
}


static void _import_page_close_import_batch_import_import_complete (BatchImport* _sender, ImportManifest* manifest, BatchImportRoll* import_roll, gpointer self) {
#line 1692 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	import_page_close_import ((ImportPage*) self);
#line 10981 "ImportPage.c"
}


static void import_page_import (ImportPage* self, GeeIterable* items) {
	int res = 0;
	Camera* _tmp0_ = NULL;
	GPSpinIdleWrapper* _tmp1_ = NULL;
	GPContext* _tmp2_ = NULL;
	int _tmp3_ = 0;
	int _tmp4_ = 0;
	gboolean _tmp11_ = FALSE;
	GtkProgressBar* _tmp12_ = NULL;
	SortedList* jobs = NULL;
	SortedList* _tmp13_ = NULL;
	GeeArrayList* already_imported = NULL;
	GeeArrayList* _tmp14_ = NULL;
	SortedList* _tmp55_ = NULL;
	gint _tmp56_ = 0;
	gint _tmp57_ = 0;
	const gchar* _tmp58_ = NULL;
	SortedList* _tmp59_ = NULL;
	gint _tmp60_ = 0;
	gint _tmp61_ = 0;
#line 1640 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_if_fail (IS_IMPORT_PAGE (self));
#line 1640 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_if_fail (GEE_IS_ITERABLE (items));
#line 1641 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = self->priv->camera;
#line 1641 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = import_page_spin_idle_context;
#line 1641 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp2_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, GP_TYPE_CONTEXT_WRAPPER, GPContextWrapper)->context;
#line 1641 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp3_ = gp_camera_init (_tmp0_, _tmp2_);
#line 1641 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	res = _tmp3_;
#line 1642 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp4_ = res;
#line 1642 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (_tmp4_ != GP_OK) {
#line 11023 "ImportPage.c"
		const gchar* _tmp5_ = NULL;
		int _tmp6_ = 0;
		gchar* _tmp7_ = NULL;
		gchar* _tmp8_ = NULL;
		gchar* _tmp9_ = NULL;
		gchar* _tmp10_ = NULL;
#line 1643 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp5_ = _ ("Unable to lock camera: %s");
#line 1643 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp6_ = res;
#line 1643 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp7_ = gp_result_to_full_string (_tmp6_);
#line 1643 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp8_ = _tmp7_;
#line 1643 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp9_ = g_strdup_printf (_tmp5_, _tmp8_);
#line 1643 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp10_ = _tmp9_;
#line 1643 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		app_window_error_message (_tmp10_, NULL);
#line 1643 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_free0 (_tmp10_);
#line 1643 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_free0 (_tmp8_);
#line 1645 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		return;
#line 11050 "ImportPage.c"
	}
#line 1648 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp11_ = self->priv->refreshed;
#line 1648 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	import_page_update_status (self, TRUE, _tmp11_);
#line 1650 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	import_page_on_view_changed (self);
#line 1651 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp12_ = self->priv->progress_bar;
#line 1651 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	gtk_widget_set_visible (G_TYPE_CHECK_INSTANCE_CAST (_tmp12_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 1653 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp13_ = sorted_list_new (IMPORT_PAGE_TYPE_CAMERA_IMPORT_JOB, (GBoxedCopyFunc) batch_import_job_ref, batch_import_job_unref, _import_page_import_job_comparator_comparator, self);
#line 1653 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	jobs = _tmp13_;
#line 1654 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp14_ = gee_array_list_new (IMPORT_PAGE_TYPE_CAMERA_IMPORT_JOB, (GBoxedCopyFunc) batch_import_job_ref, batch_import_job_unref, NULL, NULL, NULL);
#line 1654 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	already_imported = _tmp14_;
#line 11070 "ImportPage.c"
	{
		GeeIterator* _object_it = NULL;
		GeeIterable* _tmp15_ = NULL;
		GeeIterator* _tmp16_ = NULL;
#line 1656 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp15_ = items;
#line 1656 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp16_ = gee_iterable_iterator (_tmp15_);
#line 1656 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_object_it = _tmp16_;
#line 1656 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		while (TRUE) {
#line 11083 "ImportPage.c"
			GeeIterator* _tmp17_ = NULL;
			gboolean _tmp18_ = FALSE;
			DataObject* object = NULL;
			GeeIterator* _tmp19_ = NULL;
			gpointer _tmp20_ = NULL;
			ImportPreview* preview = NULL;
			DataObject* _tmp21_ = NULL;
			ImportPreview* _tmp22_ = NULL;
			ImportSource* import_file = NULL;
			ImportPreview* _tmp23_ = NULL;
			DataSource* _tmp24_ = NULL;
			ImportPreview* _tmp25_ = NULL;
			gboolean _tmp26_ = FALSE;
			ImportPageCameraImportJob* import_job = NULL;
			GPContextWrapper* _tmp38_ = NULL;
			ImportSource* _tmp39_ = NULL;
			ImportPageCameraImportJob* _tmp40_ = NULL;
			gboolean _tmp41_ = FALSE;
			ImportSource* _tmp42_ = NULL;
			SortedList* _tmp53_ = NULL;
			ImportPageCameraImportJob* _tmp54_ = NULL;
#line 1656 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp17_ = _object_it;
#line 1656 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp18_ = gee_iterator_next (_tmp17_);
#line 1656 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			if (!_tmp18_) {
#line 1656 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				break;
#line 11113 "ImportPage.c"
			}
#line 1656 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp19_ = _object_it;
#line 1656 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp20_ = gee_iterator_get (_tmp19_);
#line 1656 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			object = (DataObject*) _tmp20_;
#line 1657 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp21_ = object;
#line 1657 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp22_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp21_, TYPE_IMPORT_PREVIEW, ImportPreview));
#line 1657 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			preview = _tmp22_;
#line 1658 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp23_ = preview;
#line 1658 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp24_ = data_view_get_source (G_TYPE_CHECK_INSTANCE_CAST (_tmp23_, TYPE_DATA_VIEW, DataView));
#line 1658 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			import_file = G_TYPE_CHECK_INSTANCE_CAST (_tmp24_, TYPE_IMPORT_SOURCE, ImportSource);
#line 1660 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp25_ = preview;
#line 1660 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp26_ = import_preview_is_already_imported (_tmp25_);
#line 1660 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			if (_tmp26_) {
#line 11139 "ImportPage.c"
				ImportSource* _tmp27_ = NULL;
				gchar* _tmp28_ = NULL;
				gchar* _tmp29_ = NULL;
				GeeArrayList* _tmp30_ = NULL;
				GPContextWrapper* _tmp31_ = NULL;
				ImportSource* _tmp32_ = NULL;
				ImportPreview* _tmp33_ = NULL;
				DuplicatedFile* _tmp34_ = NULL;
				DuplicatedFile* _tmp35_ = NULL;
				ImportPageCameraImportJob* _tmp36_ = NULL;
				ImportPageCameraImportJob* _tmp37_ = NULL;
#line 1661 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp27_ = import_file;
#line 1661 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp28_ = import_source_get_filename (_tmp27_);
#line 1661 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp29_ = _tmp28_;
#line 1661 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				g_message ("ImportPage.vala:1661: Skipping import of %s: checksum detected in libr" \
"ary", _tmp29_);
#line 1661 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_g_free0 (_tmp29_);
#line 1664 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp30_ = already_imported;
#line 1664 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp31_ = import_page_null_context;
#line 1664 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp32_ = import_file;
#line 1664 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp33_ = preview;
#line 1664 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp34_ = import_preview_get_duplicated_file (_tmp33_);
#line 1664 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp35_ = _tmp34_;
#line 1664 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp36_ = import_page_camera_import_job_new (_tmp31_, _tmp32_, _tmp35_);
#line 1664 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp37_ = _tmp36_;
#line 1664 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				gee_abstract_collection_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp30_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection), _tmp37_);
#line 1664 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_batch_import_job_unref0 (_tmp37_);
#line 1664 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_g_object_unref0 (_tmp35_);
#line 1667 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_g_object_unref0 (import_file);
#line 1667 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_g_object_unref0 (preview);
#line 1667 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_g_object_unref0 (object);
#line 1667 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				continue;
#line 11191 "ImportPage.c"
			}
#line 1670 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp38_ = import_page_null_context;
#line 1670 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp39_ = import_file;
#line 1670 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp40_ = import_page_camera_import_job_new (_tmp38_, _tmp39_, NULL);
#line 1670 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			import_job = _tmp40_;
#line 1673 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp42_ = import_file;
#line 1673 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp42_, TYPE_PHOTO_IMPORT_SOURCE)) {
#line 11205 "ImportPage.c"
				ImportSource* _tmp43_ = NULL;
				PhotoImportSource* _tmp44_ = NULL;
				PhotoImportSource* _tmp45_ = NULL;
#line 1674 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp43_ = import_file;
#line 1674 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp44_ = photo_import_source_get_associated (G_TYPE_CHECK_INSTANCE_CAST (_tmp43_, TYPE_PHOTO_IMPORT_SOURCE, PhotoImportSource));
#line 1674 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp45_ = _tmp44_;
#line 1674 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp41_ = _tmp45_ != NULL;
#line 1674 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_g_object_unref0 (_tmp45_);
#line 11219 "ImportPage.c"
			} else {
#line 1673 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp41_ = FALSE;
#line 11223 "ImportPage.c"
			}
#line 1673 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			if (_tmp41_) {
#line 11227 "ImportPage.c"
				ImportPageCameraImportJob* _tmp46_ = NULL;
				GPContextWrapper* _tmp47_ = NULL;
				ImportSource* _tmp48_ = NULL;
				PhotoImportSource* _tmp49_ = NULL;
				PhotoImportSource* _tmp50_ = NULL;
				ImportPageCameraImportJob* _tmp51_ = NULL;
				ImportPageCameraImportJob* _tmp52_ = NULL;
#line 1675 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp46_ = import_job;
#line 1675 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp47_ = import_page_null_context;
#line 1675 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp48_ = import_file;
#line 1675 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp49_ = photo_import_source_get_associated (G_TYPE_CHECK_INSTANCE_CAST (_tmp48_, TYPE_PHOTO_IMPORT_SOURCE, PhotoImportSource));
#line 1675 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp50_ = _tmp49_;
#line 1675 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp51_ = import_page_camera_import_job_new (_tmp47_, G_TYPE_CHECK_INSTANCE_CAST (_tmp50_, TYPE_IMPORT_SOURCE, ImportSource), NULL);
#line 1675 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp52_ = _tmp51_;
#line 1675 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				batch_import_job_set_associated (G_TYPE_CHECK_INSTANCE_CAST (_tmp46_, TYPE_BATCH_IMPORT_JOB, BatchImportJob), G_TYPE_CHECK_INSTANCE_CAST (_tmp52_, TYPE_BATCH_IMPORT_JOB, BatchImportJob));
#line 1675 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_batch_import_job_unref0 (_tmp52_);
#line 1675 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_g_object_unref0 (_tmp50_);
#line 11255 "ImportPage.c"
			}
#line 1679 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp53_ = jobs;
#line 1679 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp54_ = import_job;
#line 1679 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			gee_collection_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp53_, GEE_TYPE_COLLECTION, GeeCollection), _tmp54_);
#line 1656 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_batch_import_job_unref0 (import_job);
#line 1656 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_g_object_unref0 (import_file);
#line 1656 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_g_object_unref0 (preview);
#line 1656 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_g_object_unref0 (object);
#line 11271 "ImportPage.c"
		}
#line 1656 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_object_unref0 (_object_it);
#line 11275 "ImportPage.c"
	}
#line 1682 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp55_ = jobs;
#line 1682 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp56_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp55_, GEE_TYPE_COLLECTION, GeeCollection));
#line 1682 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp57_ = _tmp56_;
#line 1682 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp58_ = self->priv->camera_name;
#line 1682 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_debug ("ImportPage.vala:1682: Importing %d files from %s", _tmp57_, _tmp58_);
#line 1684 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp59_ = jobs;
#line 1684 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp60_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp59_, GEE_TYPE_COLLECTION, GeeCollection));
#line 1684 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp61_ = _tmp60_;
#line 1684 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (_tmp61_ > 0) {
#line 11295 "ImportPage.c"
		ImportPage* _tmp62_ = NULL;
		ImportPage* _tmp63_ = NULL;
		BatchImport* batch_import = NULL;
		SortedList* _tmp64_ = NULL;
		const gchar* _tmp65_ = NULL;
		GeeArrayList* _tmp66_ = NULL;
		BatchImport* _tmp67_ = NULL;
		BatchImport* _tmp68_ = NULL;
		BatchImport* _tmp69_ = NULL;
		LibraryWindow* _tmp70_ = NULL;
		LibraryWindow* _tmp71_ = NULL;
		BatchImport* _tmp72_ = NULL;
		LibraryWindow* _tmp73_ = NULL;
		LibraryWindow* _tmp74_ = NULL;
#line 1686 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp62_ = self->priv->local_ref;
#line 1686 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_vala_assert (_tmp62_ == NULL, "local_ref == null");
#line 1687 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp63_ = _g_object_ref0 (self);
#line 1687 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_object_unref0 (self->priv->local_ref);
#line 1687 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		self->priv->local_ref = _tmp63_;
#line 1689 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp64_ = jobs;
#line 1689 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp65_ = self->priv->camera_name;
#line 1689 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp66_ = already_imported;
#line 1689 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp67_ = batch_import_new (G_TYPE_CHECK_INSTANCE_CAST (_tmp64_, GEE_TYPE_ITERABLE, GeeIterable), _tmp65_, _import_page_import_reporter_batch_import_import_reporter, self, NULL, _tmp66_, NULL, NULL, NULL);
#line 1689 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		batch_import = _tmp67_;
#line 1691 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp68_ = batch_import;
#line 1691 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		g_signal_connect_object (_tmp68_, "import-job-failed", (GCallback) _import_page_on_import_job_failed_batch_import_import_job_failed, self, 0);
#line 1692 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp69_ = batch_import;
#line 1692 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		g_signal_connect_object (_tmp69_, "import-complete", (GCallback) _import_page_close_import_batch_import_import_complete, self, 0);
#line 1694 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp70_ = library_window_get_app ();
#line 1694 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp71_ = _tmp70_;
#line 1694 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp72_ = batch_import;
#line 1694 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		library_window_enqueue_batch_import (_tmp71_, _tmp72_, TRUE);
#line 1694 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_object_unref0 (_tmp71_);
#line 1695 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp73_ = library_window_get_app ();
#line 1695 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp74_ = _tmp73_;
#line 1695 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		library_window_switch_to_import_queue_page (_tmp74_);
#line 1695 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_object_unref0 (_tmp74_);
#line 1684 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_object_unref0 (batch_import);
#line 11358 "ImportPage.c"
	} else {
		GeeArrayList* _tmp75_ = NULL;
		gint _tmp76_ = 0;
		gint _tmp77_ = 0;
#line 1699 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp75_ = already_imported;
#line 1699 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp76_ = gee_abstract_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp75_, GEE_TYPE_COLLECTION, GeeCollection));
#line 1699 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp77_ = _tmp76_;
#line 1699 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		if (_tmp77_ > 0) {
#line 11371 "ImportPage.c"
			GeeArrayList* _tmp78_ = NULL;
			ImportManifest* _tmp79_ = NULL;
			ImportManifest* _tmp80_ = NULL;
#line 1700 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp78_ = already_imported;
#line 1700 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp79_ = import_manifest_new (NULL, G_TYPE_CHECK_INSTANCE_CAST (_tmp78_, GEE_TYPE_LIST, GeeList));
#line 1700 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp80_ = _tmp79_;
#line 1700 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			import_page_import_reporter (self, _tmp80_);
#line 1700 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_import_manifest_unref0 (_tmp80_);
#line 11385 "ImportPage.c"
		}
#line 1702 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		import_page_close_import (self);
#line 11389 "ImportPage.c"
	}
#line 1640 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_object_unref0 (already_imported);
#line 1640 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_object_unref0 (jobs);
#line 11395 "ImportPage.c"
}


static void import_page_on_import_job_failed (ImportPage* self, BatchImportResult* _result_) {
	gboolean _tmp0_ = FALSE;
	BatchImportResult* _tmp1_ = NULL;
	GFile* _tmp2_ = NULL;
	GError * _inner_error_ = NULL;
#line 1706 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_if_fail (IS_IMPORT_PAGE (self));
#line 1706 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_if_fail (IS_BATCH_IMPORT_RESULT (_result_));
#line 1707 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = _result_;
#line 1707 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp2_ = _tmp1_->file;
#line 1707 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (_tmp2_ == NULL) {
#line 1707 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp0_ = TRUE;
#line 11416 "ImportPage.c"
	} else {
		BatchImportResult* _tmp3_ = NULL;
		ImportResult _tmp4_ = 0;
#line 1707 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp3_ = _result_;
#line 1707 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp4_ = _tmp3_->result;
#line 1707 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp0_ = _tmp4_ == IMPORT_RESULT_SUCCESS;
#line 11426 "ImportPage.c"
	}
#line 1707 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (_tmp0_) {
#line 1708 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		return;
#line 11432 "ImportPage.c"
	}
	{
		BatchImportResult* _tmp5_ = NULL;
		GFile* _tmp6_ = NULL;
#line 1712 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp5_ = _result_;
#line 1712 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp6_ = _tmp5_->file;
#line 1712 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		g_file_delete (_tmp6_, NULL, &_inner_error_);
#line 1712 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 11445 "ImportPage.c"
			goto __catch68_g_error;
		}
	}
	goto __finally68;
	__catch68_g_error:
	{
		GError* err = NULL;
		BatchImportResult* _tmp7_ = NULL;
		GFile* _tmp8_ = NULL;
		gchar* _tmp9_ = NULL;
		gchar* _tmp10_ = NULL;
		GError* _tmp11_ = NULL;
		const gchar* _tmp12_ = NULL;
#line 1711 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		err = _inner_error_;
#line 1711 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_inner_error_ = NULL;
#line 1714 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp7_ = _result_;
#line 1714 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp8_ = _tmp7_->file;
#line 1714 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp9_ = g_file_get_path (_tmp8_);
#line 1714 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp10_ = _tmp9_;
#line 1714 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp11_ = err;
#line 1714 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp12_ = _tmp11_->message;
#line 1714 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		g_message ("ImportPage.vala:1714: Unable to delete downloaded file %s: %s", _tmp10_, _tmp12_);
#line 1714 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_free0 (_tmp10_);
#line 1711 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_error_free0 (err);
#line 11481 "ImportPage.c"
	}
	__finally68:
#line 1711 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1711 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1711 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		g_clear_error (&_inner_error_);
#line 1711 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		return;
#line 11492 "ImportPage.c"
	}
}


static gpointer _batch_import_job_ref0 (gpointer self) {
#line 1758 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return self ? batch_import_job_ref (self) : NULL;
#line 11500 "ImportPage.c"
}


static gboolean _progress_dialog_monitor_progress_monitor (guint64 current, guint64 total, gboolean do_event_loop, gpointer self) {
	gboolean result;
	result = progress_dialog_monitor ((ProgressDialog*) self, current, total, do_event_loop);
#line 1765 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 11509 "ImportPage.c"
}


static void import_page_import_reporter (ImportPage* self, ImportManifest* manifest) {
	ImportPage* local_ref = NULL;
	ImportPage* _tmp0_ = NULL;
	ImportPage* _tmp1_ = NULL;
	ImportManifest* _tmp2_ = NULL;
	GeeList* _tmp3_ = NULL;
	gint _tmp4_ = 0;
	gint _tmp5_ = 0;
	Marker* marker = NULL;
	SourceCollection* _tmp60_ = NULL;
	Marker* _tmp61_ = NULL;
	ProgressDialog* progress = NULL;
	AppWindow* _tmp81_ = NULL;
	AppWindow* _tmp82_ = NULL;
	const gchar* _tmp83_ = NULL;
	GCancellable* _tmp84_ = NULL;
	GCancellable* _tmp85_ = NULL;
	ProgressDialog* _tmp86_ = NULL;
	ProgressDialog* _tmp87_ = NULL;
	gint error_count = 0;
	SourceCollection* _tmp88_ = NULL;
	Marker* _tmp89_ = NULL;
	ProgressDialog* _tmp90_ = NULL;
	gint _tmp91_ = 0;
	gint _tmp92_ = 0;
	ProgressDialog* _tmp98_ = NULL;
#line 1718 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_if_fail (IS_IMPORT_PAGE (self));
#line 1718 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_if_fail (IS_IMPORT_MANIFEST (manifest));
#line 1724 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = self->priv->local_ref;
#line 1724 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 1724 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	local_ref = _tmp1_;
#line 1725 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_object_unref0 (self->priv->local_ref);
#line 1725 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self->priv->local_ref = NULL;
#line 1727 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp2_ = manifest;
#line 1727 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp3_ = _tmp2_->success;
#line 1727 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp4_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, GEE_TYPE_COLLECTION, GeeCollection));
#line 1727 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp5_ = _tmp4_;
#line 1727 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (_tmp5_ > 0) {
#line 11563 "ImportPage.c"
		gchar* photos_string = NULL;
		ImportManifest* _tmp6_ = NULL;
		GeeList* _tmp7_ = NULL;
		gint _tmp8_ = 0;
		gint _tmp9_ = 0;
		const gchar* _tmp10_ = NULL;
		ImportManifest* _tmp11_ = NULL;
		GeeList* _tmp12_ = NULL;
		gint _tmp13_ = 0;
		gint _tmp14_ = 0;
		gchar* _tmp15_ = NULL;
		gchar* videos_string = NULL;
		ImportManifest* _tmp16_ = NULL;
		GeeList* _tmp17_ = NULL;
		gint _tmp18_ = 0;
		gint _tmp19_ = 0;
		const gchar* _tmp20_ = NULL;
		ImportManifest* _tmp21_ = NULL;
		GeeList* _tmp22_ = NULL;
		gint _tmp23_ = 0;
		gint _tmp24_ = 0;
		gchar* _tmp25_ = NULL;
		gchar* both_string = NULL;
		ImportManifest* _tmp26_ = NULL;
		GeeList* _tmp27_ = NULL;
		gint _tmp28_ = 0;
		gint _tmp29_ = 0;
		const gchar* _tmp30_ = NULL;
		ImportManifest* _tmp31_ = NULL;
		GeeList* _tmp32_ = NULL;
		gint _tmp33_ = 0;
		gint _tmp34_ = 0;
		gchar* _tmp35_ = NULL;
		gchar* neither_string = NULL;
		ImportManifest* _tmp36_ = NULL;
		GeeList* _tmp37_ = NULL;
		gint _tmp38_ = 0;
		gint _tmp39_ = 0;
		const gchar* _tmp40_ = NULL;
		ImportManifest* _tmp41_ = NULL;
		GeeList* _tmp42_ = NULL;
		gint _tmp43_ = 0;
		gint _tmp44_ = 0;
		gchar* _tmp45_ = NULL;
		gchar* question_string = NULL;
		ImportManifest* _tmp46_ = NULL;
		GeeList* _tmp47_ = NULL;
		const gchar* _tmp48_ = NULL;
		const gchar* _tmp49_ = NULL;
		const gchar* _tmp50_ = NULL;
		const gchar* _tmp51_ = NULL;
		gchar* _tmp52_ = NULL;
		ImportUIQuestionParams* question = NULL;
		const gchar* _tmp53_ = NULL;
		const gchar* _tmp54_ = NULL;
		ImportUIQuestionParams* _tmp55_ = NULL;
		ImportManifest* _tmp56_ = NULL;
		ImportUIQuestionParams* _tmp57_ = NULL;
		gboolean _tmp58_ = FALSE;
#line 1728 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp6_ = manifest;
#line 1728 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp7_ = _tmp6_->success;
#line 1728 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp8_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, GEE_TYPE_COLLECTION, GeeCollection));
#line 1728 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp9_ = _tmp8_;
#line 1728 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp10_ = ngettext ("Delete this photo from camera?", "Delete these %d photos from camera?", (gulong) _tmp9_);
#line 1728 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp11_ = manifest;
#line 1728 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp12_ = _tmp11_->success;
#line 1728 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp13_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp12_, GEE_TYPE_COLLECTION, GeeCollection));
#line 1728 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp14_ = _tmp13_;
#line 1728 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp15_ = g_strdup_printf (_tmp10_, _tmp14_);
#line 1728 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		photos_string = _tmp15_;
#line 1731 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp16_ = manifest;
#line 1731 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp17_ = _tmp16_->success;
#line 1731 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp18_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp17_, GEE_TYPE_COLLECTION, GeeCollection));
#line 1731 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp19_ = _tmp18_;
#line 1731 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp20_ = ngettext ("Delete this video from camera?", "Delete these %d videos from camera?", (gulong) _tmp19_);
#line 1731 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp21_ = manifest;
#line 1731 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp22_ = _tmp21_->success;
#line 1731 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp23_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp22_, GEE_TYPE_COLLECTION, GeeCollection));
#line 1731 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp24_ = _tmp23_;
#line 1731 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp25_ = g_strdup_printf (_tmp20_, _tmp24_);
#line 1731 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		videos_string = _tmp25_;
#line 1734 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp26_ = manifest;
#line 1734 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp27_ = _tmp26_->success;
#line 1734 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp28_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp27_, GEE_TYPE_COLLECTION, GeeCollection));
#line 1734 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp29_ = _tmp28_;
#line 1734 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp30_ = ngettext ("Delete this photo/video from camera?", "Delete these %d photos/videos from camera?", (gulong) _tmp29_);
#line 1734 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp31_ = manifest;
#line 1734 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp32_ = _tmp31_->success;
#line 1734 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp33_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp32_, GEE_TYPE_COLLECTION, GeeCollection));
#line 1734 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp34_ = _tmp33_;
#line 1734 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp35_ = g_strdup_printf (_tmp30_, _tmp34_);
#line 1734 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		both_string = _tmp35_;
#line 1737 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp36_ = manifest;
#line 1737 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp37_ = _tmp36_->success;
#line 1737 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp38_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp37_, GEE_TYPE_COLLECTION, GeeCollection));
#line 1737 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp39_ = _tmp38_;
#line 1737 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp40_ = ngettext ("Delete these files from camera?", "Delete these %d files from camera?", (gulong) _tmp39_);
#line 1737 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp41_ = manifest;
#line 1737 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp42_ = _tmp41_->success;
#line 1737 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp43_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp42_, GEE_TYPE_COLLECTION, GeeCollection));
#line 1737 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp44_ = _tmp43_;
#line 1737 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp45_ = g_strdup_printf (_tmp40_, _tmp44_);
#line 1737 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		neither_string = _tmp45_;
#line 1741 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp46_ = manifest;
#line 1741 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp47_ = _tmp46_->success;
#line 1741 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp48_ = photos_string;
#line 1741 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp49_ = videos_string;
#line 1741 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp50_ = both_string;
#line 1741 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp51_ = neither_string;
#line 1741 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp52_ = import_ui_get_media_specific_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp47_, GEE_TYPE_COLLECTION, GeeCollection), _tmp48_, _tmp49_, _tmp50_, _tmp51_);
#line 1741 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		question_string = _tmp52_;
#line 1744 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp53_ = question_string;
#line 1744 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp54_ = _ ("_Keep");
#line 1744 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp55_ = import_ui_question_params_new (_tmp53_, RESOURCES_DELETE_LABEL, _tmp54_);
#line 1744 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		question = _tmp55_;
#line 1747 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp56_ = manifest;
#line 1747 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp57_ = question;
#line 1747 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp58_ = import_ui_report_manifest (_tmp56_, FALSE, _tmp57_);
#line 1747 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		if (!_tmp58_) {
#line 1748 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_import_ui_question_params_unref0 (question);
#line 1748 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_g_free0 (question_string);
#line 1748 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_g_free0 (neither_string);
#line 1748 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_g_free0 (both_string);
#line 1748 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_g_free0 (videos_string);
#line 1748 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_g_free0 (photos_string);
#line 1748 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_g_object_unref0 (local_ref);
#line 1748 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			return;
#line 11759 "ImportPage.c"
		}
#line 1727 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_import_ui_question_params_unref0 (question);
#line 1727 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_free0 (question_string);
#line 1727 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_free0 (neither_string);
#line 1727 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_free0 (both_string);
#line 1727 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_free0 (videos_string);
#line 1727 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_free0 (photos_string);
#line 11773 "ImportPage.c"
	} else {
		ImportManifest* _tmp59_ = NULL;
#line 1750 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp59_ = manifest;
#line 1750 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		import_ui_report_manifest (_tmp59_, FALSE, NULL);
#line 1751 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_object_unref0 (local_ref);
#line 1751 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		return;
#line 11784 "ImportPage.c"
	}
#line 1756 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp60_ = self->priv->import_sources;
#line 1756 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp61_ = data_collection_start_marking (G_TYPE_CHECK_INSTANCE_CAST (_tmp60_, TYPE_DATA_COLLECTION, DataCollection));
#line 1756 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	marker = _tmp61_;
#line 11792 "ImportPage.c"
	{
		GeeList* _batch_result_list = NULL;
		ImportManifest* _tmp62_ = NULL;
		GeeList* _tmp63_ = NULL;
		GeeList* _tmp64_ = NULL;
		gint _batch_result_size = 0;
		GeeList* _tmp65_ = NULL;
		gint _tmp66_ = 0;
		gint _tmp67_ = 0;
		gint _batch_result_index = 0;
#line 1757 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp62_ = manifest;
#line 1757 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp63_ = _tmp62_->success;
#line 1757 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp64_ = _g_object_ref0 (_tmp63_);
#line 1757 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_batch_result_list = _tmp64_;
#line 1757 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp65_ = _batch_result_list;
#line 1757 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp66_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp65_, GEE_TYPE_COLLECTION, GeeCollection));
#line 1757 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp67_ = _tmp66_;
#line 1757 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_batch_result_size = _tmp67_;
#line 1757 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_batch_result_index = -1;
#line 1757 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		while (TRUE) {
#line 11823 "ImportPage.c"
			gint _tmp68_ = 0;
			gint _tmp69_ = 0;
			gint _tmp70_ = 0;
			BatchImportResult* batch_result = NULL;
			GeeList* _tmp71_ = NULL;
			gint _tmp72_ = 0;
			gpointer _tmp73_ = NULL;
			ImportPageCameraImportJob* job = NULL;
			BatchImportResult* _tmp74_ = NULL;
			BatchImportJob* _tmp75_ = NULL;
			ImportPageCameraImportJob* _tmp76_ = NULL;
			Marker* _tmp77_ = NULL;
			ImportPageCameraImportJob* _tmp78_ = NULL;
			ImportSource* _tmp79_ = NULL;
			ImportSource* _tmp80_ = NULL;
#line 1757 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp68_ = _batch_result_index;
#line 1757 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_batch_result_index = _tmp68_ + 1;
#line 1757 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp69_ = _batch_result_index;
#line 1757 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp70_ = _batch_result_size;
#line 1757 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			if (!(_tmp69_ < _tmp70_)) {
#line 1757 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				break;
#line 11851 "ImportPage.c"
			}
#line 1757 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp71_ = _batch_result_list;
#line 1757 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp72_ = _batch_result_index;
#line 1757 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp73_ = gee_list_get (_tmp71_, _tmp72_);
#line 1757 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			batch_result = (BatchImportResult*) _tmp73_;
#line 1758 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp74_ = batch_result;
#line 1758 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp75_ = _tmp74_->job;
#line 1758 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp76_ = _batch_import_job_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp75_, IMPORT_PAGE_TYPE_CAMERA_IMPORT_JOB) ? ((ImportPageCameraImportJob*) _tmp75_) : NULL);
#line 1758 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			job = _tmp76_;
#line 1760 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp77_ = marker;
#line 1760 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp78_ = job;
#line 1760 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp79_ = import_page_camera_import_job_get_source (_tmp78_);
#line 1760 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp80_ = _tmp79_;
#line 1760 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			marker_mark (_tmp77_, G_TYPE_CHECK_INSTANCE_CAST (_tmp80_, TYPE_DATA_OBJECT, DataObject));
#line 1760 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_g_object_unref0 (_tmp80_);
#line 1757 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_batch_import_job_unref0 (job);
#line 1757 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_batch_import_result_unref0 (batch_result);
#line 11885 "ImportPage.c"
		}
#line 1757 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_object_unref0 (_batch_result_list);
#line 11889 "ImportPage.c"
	}
#line 1763 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp81_ = app_window_get_instance ();
#line 1763 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp82_ = _tmp81_;
#line 1763 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp83_ = _ ("Removing photos/videos from camera");
#line 1763 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp84_ = g_cancellable_new ();
#line 1763 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp85_ = _tmp84_;
#line 1763 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp86_ = progress_dialog_new (G_TYPE_CHECK_INSTANCE_CAST (_tmp82_, gtk_window_get_type (), GtkWindow), _tmp83_, _tmp85_);
#line 1763 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_object_ref_sink (_tmp86_);
#line 1763 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp87_ = _tmp86_;
#line 1763 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_object_unref0 (_tmp85_);
#line 1763 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_object_unref0 (_tmp82_);
#line 1763 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	progress = _tmp87_;
#line 1765 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp88_ = self->priv->import_sources;
#line 1765 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp89_ = marker;
#line 1765 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp90_ = progress;
#line 1765 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp91_ = source_collection_destroy_marked (_tmp88_, _tmp89_, TRUE, _progress_dialog_monitor_progress_monitor, _tmp90_, NULL);
#line 1765 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	error_count = _tmp91_;
#line 1766 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp92_ = error_count;
#line 1766 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (_tmp92_ > 0) {
#line 11927 "ImportPage.c"
		gchar* error_string = NULL;
		gint _tmp93_ = 0;
		const gchar* _tmp94_ = NULL;
		gint _tmp95_ = 0;
		gchar* _tmp96_ = NULL;
		const gchar* _tmp97_ = NULL;
#line 1767 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp93_ = error_count;
#line 1767 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp94_ = ngettext ("Unable to delete %d photo/video from the camera due to errors.", "Unable to delete %d photos/videos from the camera due to errors.", (gulong) _tmp93_);
#line 1767 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp95_ = error_count;
#line 1767 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp96_ = g_strdup_printf (_tmp94_, _tmp95_);
#line 1767 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		error_string = _tmp96_;
#line 1771 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp97_ = error_string;
#line 1771 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		app_window_error_message (_tmp97_, NULL);
#line 1766 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_free0 (error_string);
#line 11950 "ImportPage.c"
	}
#line 1774 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp98_ = progress;
#line 1774 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	progress_dialog_close (_tmp98_);
#line 1777 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_object_unref0 (local_ref);
#line 1777 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	local_ref = NULL;
#line 1718 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_object_unref0 (progress);
#line 1718 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_object_unref0 (marker);
#line 1718 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_object_unref0 (local_ref);
#line 11966 "ImportPage.c"
}


static void import_page_close_import (ImportPage* self) {
	int res = 0;
	Camera* _tmp0_ = NULL;
	GPSpinIdleWrapper* _tmp1_ = NULL;
	GPContext* _tmp2_ = NULL;
	int _tmp3_ = 0;
	int _tmp4_ = 0;
	gboolean _tmp8_ = FALSE;
#line 1780 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_if_fail (IS_IMPORT_PAGE (self));
#line 1781 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = self->priv->camera;
#line 1781 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = import_page_spin_idle_context;
#line 1781 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp2_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, GP_TYPE_CONTEXT_WRAPPER, GPContextWrapper)->context;
#line 1781 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp3_ = gp_camera_exit (_tmp0_, _tmp2_);
#line 1781 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	res = _tmp3_;
#line 1782 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp4_ = res;
#line 1782 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (_tmp4_ != GP_OK) {
#line 11994 "ImportPage.c"
		int _tmp5_ = 0;
		gchar* _tmp6_ = NULL;
		gchar* _tmp7_ = NULL;
#line 1784 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp5_ = res;
#line 1784 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp6_ = gp_result_to_full_string (_tmp5_);
#line 1784 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp7_ = _tmp6_;
#line 1784 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		g_message ("ImportPage.vala:1784: Unable to unlock camera: %s", _tmp7_);
#line 1784 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_free0 (_tmp7_);
#line 12008 "ImportPage.c"
	}
#line 1787 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp8_ = self->priv->refreshed;
#line 1787 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	import_page_update_status (self, FALSE, _tmp8_);
#line 1789 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	import_page_on_view_changed (self);
#line 12016 "ImportPage.c"
}


static void import_page_real_set_display_titles (CheckerboardPage* base, gboolean display) {
	ImportPage * self;
	gboolean _tmp0_ = FALSE;
	GtkToggleAction* action = NULL;
	GtkAction* _tmp1_ = NULL;
	GtkToggleAction* _tmp2_ = NULL;
	GtkToggleAction* _tmp3_ = NULL;
#line 1792 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_IMPORT_PAGE, ImportPage);
#line 1793 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = display;
#line 1793 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	CHECKERBOARD_PAGE_CLASS (import_page_parent_class)->set_display_titles (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_CHECKERBOARD_PAGE, CheckerboardPage), _tmp0_);
#line 1795 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = page_get_action (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page), "ViewTitle");
#line 1795 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp2_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, gtk_toggle_action_get_type ()) ? ((GtkToggleAction*) _tmp1_) : NULL;
#line 1795 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (_tmp2_ == NULL) {
#line 1795 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_object_unref0 (_tmp1_);
#line 12041 "ImportPage.c"
	}
#line 1795 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	action = _tmp2_;
#line 1796 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp3_ = action;
#line 1796 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (_tmp3_ != NULL) {
#line 12049 "ImportPage.c"
		GtkToggleAction* _tmp4_ = NULL;
		gboolean _tmp5_ = FALSE;
#line 1797 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp4_ = action;
#line 1797 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp5_ = display;
#line 1797 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		gtk_toggle_action_set_active (_tmp4_, _tmp5_);
#line 12058 "ImportPage.c"
	}
#line 1792 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_object_unref0 (action);
#line 12062 "ImportPage.c"
}


static gpointer _view_filter_ref0 (gpointer self) {
#line 1802 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return self ? view_filter_ref (self) : NULL;
#line 12069 "ImportPage.c"
}


static SearchViewFilter* import_page_real_get_search_view_filter (CheckerboardPage* base) {
	ImportPage * self;
	SearchViewFilter* result = NULL;
	ImportPageImportPageSearchViewFilter* _tmp0_ = NULL;
	SearchViewFilter* _tmp1_ = NULL;
#line 1801 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_IMPORT_PAGE, ImportPage);
#line 1802 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = self->priv->search_filter;
#line 1802 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = _view_filter_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, TYPE_SEARCH_VIEW_FILTER, SearchViewFilter));
#line 1802 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = _tmp1_;
#line 1802 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 12088 "ImportPage.c"
}


static ImportPageImportViewManager* import_page_import_view_manager_construct (GType object_type, ImportPage* owner) {
	ImportPageImportViewManager* self = NULL;
	ImportPage* _tmp0_ = NULL;
	ImportPage* _tmp1_ = NULL;
#line 463 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail (IS_IMPORT_PAGE (owner), NULL);
#line 463 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self = (ImportPageImportViewManager*) view_manager_construct (object_type);
#line 464 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = owner;
#line 464 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 464 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_object_unref0 (self->priv->owner);
#line 464 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self->priv->owner = _tmp1_;
#line 463 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return self;
#line 12110 "ImportPage.c"
}


static ImportPageImportViewManager* import_page_import_view_manager_new (ImportPage* owner) {
#line 463 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return import_page_import_view_manager_construct (IMPORT_PAGE_TYPE_IMPORT_VIEW_MANAGER, owner);
#line 12117 "ImportPage.c"
}


static DataView* import_page_import_view_manager_real_create_view (ViewManager* base, DataSource* source) {
	ImportPageImportViewManager * self;
	DataView* result = NULL;
	DataSource* _tmp0_ = NULL;
	ImportPreview* _tmp1_ = NULL;
#line 467 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, IMPORT_PAGE_TYPE_IMPORT_VIEW_MANAGER, ImportPageImportViewManager);
#line 467 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail (IS_DATA_SOURCE (source), NULL);
#line 468 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = source;
#line 468 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = import_preview_new (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, TYPE_IMPORT_SOURCE, ImportSource));
#line 468 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, TYPE_DATA_VIEW, DataView);
#line 468 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 12138 "ImportPage.c"
}


static void import_page_import_view_manager_class_init (ImportPageImportViewManagerClass * klass) {
#line 460 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	import_page_import_view_manager_parent_class = g_type_class_peek_parent (klass);
#line 460 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	((ViewManagerClass *) klass)->finalize = import_page_import_view_manager_finalize;
#line 460 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_type_class_add_private (klass, sizeof (ImportPageImportViewManagerPrivate));
#line 460 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	((ViewManagerClass *) klass)->create_view = import_page_import_view_manager_real_create_view;
#line 12151 "ImportPage.c"
}


static void import_page_import_view_manager_instance_init (ImportPageImportViewManager * self) {
#line 460 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self->priv = IMPORT_PAGE_IMPORT_VIEW_MANAGER_GET_PRIVATE (self);
#line 12158 "ImportPage.c"
}


static void import_page_import_view_manager_finalize (ViewManager* obj) {
	ImportPageImportViewManager * self;
#line 460 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, IMPORT_PAGE_TYPE_IMPORT_VIEW_MANAGER, ImportPageImportViewManager);
#line 461 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_object_unref0 (self->priv->owner);
#line 460 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	VIEW_MANAGER_CLASS (import_page_import_view_manager_parent_class)->finalize (obj);
#line 12170 "ImportPage.c"
}


static GType import_page_import_view_manager_get_type (void) {
	static volatile gsize import_page_import_view_manager_type_id__volatile = 0;
	if (g_once_init_enter (&import_page_import_view_manager_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (ImportPageImportViewManagerClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) import_page_import_view_manager_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ImportPageImportViewManager), 0, (GInstanceInitFunc) import_page_import_view_manager_instance_init, NULL };
		GType import_page_import_view_manager_type_id;
		import_page_import_view_manager_type_id = g_type_register_static (TYPE_VIEW_MANAGER, "ImportPageImportViewManager", &g_define_type_info, 0);
		g_once_init_leave (&import_page_import_view_manager_type_id__volatile, import_page_import_view_manager_type_id);
	}
	return import_page_import_view_manager_type_id__volatile;
}


static gpointer _gp_context_wrapper_ref0 (gpointer self) {
#line 487 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return self ? gp_context_wrapper_ref (self) : NULL;
#line 12189 "ImportPage.c"
}


static ImportPageCameraImportJob* import_page_camera_import_job_construct (GType object_type, GPContextWrapper* context, ImportSource* import_file, DuplicatedFile* duplicated_file) {
	ImportPageCameraImportJob* self = NULL;
	GPContextWrapper* _tmp0_ = NULL;
	GPContextWrapper* _tmp1_ = NULL;
	ImportSource* _tmp2_ = NULL;
	ImportSource* _tmp3_ = NULL;
	DuplicatedFile* _tmp4_ = NULL;
	DuplicatedFile* _tmp5_ = NULL;
	ImportSource* _tmp6_ = NULL;
	Camera* _tmp7_ = NULL;
	ImportSource* _tmp8_ = NULL;
	gchar* _tmp9_ = NULL;
	const gchar* _tmp10_ = NULL;
	ImportSource* _tmp11_ = NULL;
	gchar* _tmp12_ = NULL;
	ImportSource* _tmp13_ = NULL;
	gulong _tmp14_ = 0UL;
	PhotoMetadata* _tmp15_ = NULL;
	ImportSource* _tmp16_ = NULL;
	PhotoMetadata* _tmp19_ = NULL;
	ImportSource* _tmp20_ = NULL;
	time_t _tmp21_ = 0;
#line 485 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail (GP_IS_CONTEXT_WRAPPER (context), NULL);
#line 485 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail (IS_IMPORT_SOURCE (import_file), NULL);
#line 485 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail ((duplicated_file == NULL) || IS_DUPLICATED_FILE (duplicated_file), NULL);
#line 485 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self = (ImportPageCameraImportJob*) batch_import_job_construct (object_type);
#line 487 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = context;
#line 487 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = _gp_context_wrapper_ref0 (_tmp0_);
#line 487 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_gp_context_wrapper_unref0 (self->priv->context);
#line 487 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self->priv->context = _tmp1_;
#line 488 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp2_ = import_file;
#line 488 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 488 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_object_unref0 (self->priv->import_file);
#line 488 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self->priv->import_file = _tmp3_;
#line 489 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp4_ = duplicated_file;
#line 489 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp5_ = _g_object_ref0 (_tmp4_);
#line 489 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_object_unref0 (self->priv->duplicated_file);
#line 489 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self->priv->duplicated_file = _tmp5_;
#line 492 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp6_ = import_file;
#line 492 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp7_ = import_source_get_camera (_tmp6_);
#line 492 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_gp_camera_unref0 (self->priv->camera);
#line 492 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self->priv->camera = _tmp7_;
#line 493 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp8_ = import_file;
#line 493 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp9_ = import_source_get_fulldir (_tmp8_);
#line 493 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_free0 (self->priv->fulldir);
#line 493 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self->priv->fulldir = _tmp9_;
#line 495 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp10_ = self->priv->fulldir;
#line 495 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_vala_assert (_tmp10_ != NULL, "fulldir != null");
#line 496 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp11_ = import_file;
#line 496 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp12_ = import_source_get_filename (_tmp11_);
#line 496 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_free0 (self->priv->filename);
#line 496 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self->priv->filename = _tmp12_;
#line 497 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp13_ = import_file;
#line 497 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp14_ = import_source_get_filesize (_tmp13_);
#line 497 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self->priv->filesize = (guint64) _tmp14_;
#line 498 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp16_ = import_file;
#line 498 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp16_, TYPE_PHOTO_IMPORT_SOURCE)) {
#line 12285 "ImportPage.c"
		ImportSource* _tmp17_ = NULL;
		PhotoMetadata* _tmp18_ = NULL;
#line 499 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp17_ = import_file;
#line 499 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp18_ = photo_import_source_get_metadata (G_TYPE_CHECK_INSTANCE_TYPE (_tmp17_, TYPE_PHOTO_IMPORT_SOURCE) ? ((PhotoImportSource*) _tmp17_) : NULL);
#line 499 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_media_metadata_unref0 (_tmp15_);
#line 499 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp15_ = _tmp18_;
#line 12296 "ImportPage.c"
	} else {
#line 499 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_media_metadata_unref0 (_tmp15_);
#line 499 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp15_ = NULL;
#line 12302 "ImportPage.c"
	}
#line 498 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp19_ = _media_metadata_ref0 (_tmp15_);
#line 498 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_media_metadata_unref0 (self->priv->metadata);
#line 498 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self->priv->metadata = _tmp19_;
#line 500 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp20_ = import_file;
#line 500 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp21_ = import_source_get_exposure_time (_tmp20_);
#line 500 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self->priv->exposure_time = _tmp21_;
#line 485 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_media_metadata_unref0 (_tmp15_);
#line 485 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return self;
#line 12320 "ImportPage.c"
}


static ImportPageCameraImportJob* import_page_camera_import_job_new (GPContextWrapper* context, ImportSource* import_file, DuplicatedFile* duplicated_file) {
#line 485 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return import_page_camera_import_job_construct (IMPORT_PAGE_TYPE_CAMERA_IMPORT_JOB, context, import_file, duplicated_file);
#line 12327 "ImportPage.c"
}


static time_t import_page_camera_import_job_get_exposure_time (ImportPageCameraImportJob* self) {
	time_t result = 0;
	time_t _tmp0_ = 0;
#line 503 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail (IMPORT_PAGE_IS_CAMERA_IMPORT_JOB (self), 0);
#line 504 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = self->priv->exposure_time;
#line 504 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = _tmp0_;
#line 504 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 12342 "ImportPage.c"
}


static DuplicatedFile* import_page_camera_import_job_real_get_duplicated_file (BatchImportJob* base) {
	ImportPageCameraImportJob * self;
	DuplicatedFile* result = NULL;
	DuplicatedFile* _tmp0_ = NULL;
	DuplicatedFile* _tmp1_ = NULL;
#line 507 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, IMPORT_PAGE_TYPE_CAMERA_IMPORT_JOB, ImportPageCameraImportJob);
#line 508 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = self->priv->duplicated_file;
#line 508 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 508 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = _tmp1_;
#line 508 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 12361 "ImportPage.c"
}


static time_t import_page_camera_import_job_real_get_exposure_time_override (BatchImportJob* base) {
	ImportPageCameraImportJob * self;
	time_t result = 0;
	time_t _tmp0_ = 0;
	ImportSource* _tmp1_ = NULL;
#line 511 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, IMPORT_PAGE_TYPE_CAMERA_IMPORT_JOB, ImportPageCameraImportJob);
#line 512 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = self->priv->import_file;
#line 512 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, TYPE_VIDEO_IMPORT_SOURCE)) {
#line 12376 "ImportPage.c"
		time_t _tmp2_ = 0;
#line 512 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp2_ = import_page_camera_import_job_get_exposure_time (self);
#line 512 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp0_ = _tmp2_;
#line 12382 "ImportPage.c"
	} else {
#line 512 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp0_ = (time_t) 0;
#line 12386 "ImportPage.c"
	}
#line 512 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = _tmp0_;
#line 512 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 12392 "ImportPage.c"
}


static gchar* import_page_camera_import_job_real_get_dest_identifier (BatchImportJob* base) {
	ImportPageCameraImportJob * self;
	gchar* result = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 515 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, IMPORT_PAGE_TYPE_CAMERA_IMPORT_JOB, ImportPageCameraImportJob);
#line 516 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = self->priv->filename;
#line 516 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 516 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = _tmp1_;
#line 516 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 12411 "ImportPage.c"
}


static gchar* import_page_camera_import_job_real_get_source_identifier (BatchImportJob* base) {
	ImportPageCameraImportJob * self;
	gchar* result = NULL;
	ImportSource* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 519 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, IMPORT_PAGE_TYPE_CAMERA_IMPORT_JOB, ImportPageCameraImportJob);
#line 520 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = self->priv->import_file;
#line 520 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = import_source_get_filename (_tmp0_);
#line 520 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = _tmp1_;
#line 520 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 12430 "ImportPage.c"
}


static gchar* import_page_camera_import_job_real_get_basename (BatchImportJob* base) {
	ImportPageCameraImportJob * self;
	gchar* result = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 523 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, IMPORT_PAGE_TYPE_CAMERA_IMPORT_JOB, ImportPageCameraImportJob);
#line 524 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = self->priv->filename;
#line 524 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 524 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = _tmp1_;
#line 524 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 12449 "ImportPage.c"
}


static gchar* import_page_camera_import_job_real_get_path (BatchImportJob* base) {
	ImportPageCameraImportJob * self;
	gchar* result = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 527 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, IMPORT_PAGE_TYPE_CAMERA_IMPORT_JOB, ImportPageCameraImportJob);
#line 528 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = self->priv->fulldir;
#line 528 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 528 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = _tmp1_;
#line 528 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 12468 "ImportPage.c"
}


static void import_page_camera_import_job_real_set_associated (BatchImportJob* base, BatchImportJob* associated) {
	ImportPageCameraImportJob * self;
	BatchImportJob* _tmp0_ = NULL;
	ImportPageCameraImportJob* _tmp1_ = NULL;
#line 531 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, IMPORT_PAGE_TYPE_CAMERA_IMPORT_JOB, ImportPageCameraImportJob);
#line 531 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_if_fail (IS_BATCH_IMPORT_JOB (associated));
#line 532 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = associated;
#line 532 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = _batch_import_job_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, IMPORT_PAGE_TYPE_CAMERA_IMPORT_JOB) ? ((ImportPageCameraImportJob*) _tmp0_) : NULL);
#line 532 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_batch_import_job_unref0 (self->priv->associated);
#line 532 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self->priv->associated = _tmp1_;
#line 12488 "ImportPage.c"
}


static ImportSource* import_page_camera_import_job_get_source (ImportPageCameraImportJob* self) {
	ImportSource* result = NULL;
	ImportSource* _tmp0_ = NULL;
	ImportSource* _tmp1_ = NULL;
#line 535 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail (IMPORT_PAGE_IS_CAMERA_IMPORT_JOB (self), NULL);
#line 536 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = self->priv->import_file;
#line 536 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 536 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = _tmp1_;
#line 536 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 12506 "ImportPage.c"
}


static gboolean import_page_camera_import_job_real_is_directory (BatchImportJob* base) {
	ImportPageCameraImportJob * self;
	gboolean result = FALSE;
#line 539 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, IMPORT_PAGE_TYPE_CAMERA_IMPORT_JOB, ImportPageCameraImportJob);
#line 540 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = FALSE;
#line 540 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 12519 "ImportPage.c"
}


static gboolean import_page_camera_import_job_real_determine_file_size (BatchImportJob* base, guint64* filesize, GFile** file) {
	ImportPageCameraImportJob * self;
	guint64 _vala_filesize = 0ULL;
	GFile* _vala_file = NULL;
	gboolean result = FALSE;
	guint64 _tmp0_ = 0ULL;
#line 543 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, IMPORT_PAGE_TYPE_CAMERA_IMPORT_JOB, ImportPageCameraImportJob);
#line 544 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_object_unref0 (_vala_file);
#line 544 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_vala_file = NULL;
#line 545 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = self->priv->filesize;
#line 545 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_vala_filesize = _tmp0_;
#line 547 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = TRUE;
#line 547 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (filesize) {
#line 547 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		*filesize = _vala_filesize;
#line 12545 "ImportPage.c"
	}
#line 547 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (file) {
#line 547 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		*file = _vala_file;
#line 12551 "ImportPage.c"
	} else {
#line 547 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_object_unref0 (_vala_file);
#line 12555 "ImportPage.c"
	}
#line 547 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 12559 "ImportPage.c"
}


static gboolean import_page_camera_import_job_real_prepare (BatchImportJob* base, GFile** file_to_import, gboolean* copy_to_library, GError** error) {
	ImportPageCameraImportJob * self;
	GFile* _vala_file_to_import = NULL;
	gboolean _vala_copy_to_library = FALSE;
	gboolean result = FALSE;
	GFile* dest_file = NULL;
	GFile* _tmp12_ = NULL;
	GFile* _tmp16_ = NULL;
	ImportPageCameraImportJob* _tmp24_ = NULL;
	GFile* _tmp55_ = NULL;
	GFile* _tmp56_ = NULL;
	GError * _inner_error_ = NULL;
#line 550 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, IMPORT_PAGE_TYPE_CAMERA_IMPORT_JOB, ImportPageCameraImportJob);
#line 551 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_object_unref0 (_vala_file_to_import);
#line 551 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_vala_file_to_import = NULL;
#line 552 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_vala_copy_to_library = FALSE;
#line 554 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	dest_file = NULL;
#line 12585 "ImportPage.c"
	{
		gboolean collision = FALSE;
		GFile* _tmp0_ = NULL;
		const gchar* _tmp1_ = NULL;
		PhotoMetadata* _tmp2_ = NULL;
		time_t _tmp3_ = 0;
		gboolean _tmp4_ = FALSE;
		GFile* _tmp5_ = NULL;
		GFile* _tmp6_ = NULL;
#line 557 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp1_ = self->priv->filename;
#line 557 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp2_ = self->priv->metadata;
#line 557 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp3_ = self->priv->exposure_time;
#line 557 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp5_ = library_files_generate_unique_file (_tmp1_, G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, TYPE_MEDIA_METADATA, MediaMetadata), _tmp3_, &_tmp4_, &_inner_error_);
#line 557 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		collision = _tmp4_;
#line 557 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp0_ = _tmp5_;
#line 557 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 12609 "ImportPage.c"
			goto __catch69_g_error;
		}
#line 557 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp6_ = _tmp0_;
#line 557 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp0_ = NULL;
#line 557 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_object_unref0 (dest_file);
#line 557 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		dest_file = _tmp6_;
#line 555 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_object_unref0 (_tmp0_);
#line 12622 "ImportPage.c"
	}
	goto __finally69;
	__catch69_g_error:
	{
		GError* err = NULL;
		ImportSource* _tmp7_ = NULL;
		gchar* _tmp8_ = NULL;
		gchar* _tmp9_ = NULL;
		GError* _tmp10_ = NULL;
		const gchar* _tmp11_ = NULL;
#line 555 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		err = _inner_error_;
#line 555 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_inner_error_ = NULL;
#line 560 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp7_ = self->priv->import_file;
#line 560 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp8_ = import_source_get_filename (_tmp7_);
#line 560 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp9_ = _tmp8_;
#line 560 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp10_ = err;
#line 560 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp11_ = _tmp10_->message;
#line 560 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		g_warning ("ImportPage.vala:560: Unable to generate local file for %s: %s", _tmp9_, _tmp11_);
#line 560 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_free0 (_tmp9_);
#line 555 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_error_free0 (err);
#line 12653 "ImportPage.c"
	}
	__finally69:
#line 555 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 555 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		g_propagate_error (error, _inner_error_);
#line 555 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_object_unref0 (dest_file);
#line 555 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		return FALSE;
#line 12664 "ImportPage.c"
	}
#line 564 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp12_ = dest_file;
#line 564 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (_tmp12_ == NULL) {
#line 12670 "ImportPage.c"
		ImportSource* _tmp13_ = NULL;
		gchar* _tmp14_ = NULL;
		gchar* _tmp15_ = NULL;
#line 565 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp13_ = self->priv->import_file;
#line 565 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp14_ = import_source_get_filename (_tmp13_);
#line 565 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp15_ = _tmp14_;
#line 565 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		g_message ("ImportPage.vala:565: Unable to generate local file for %s", _tmp15_);
#line 565 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_free0 (_tmp15_);
#line 567 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		result = FALSE;
#line 567 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_object_unref0 (dest_file);
#line 567 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		if (file_to_import) {
#line 567 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			*file_to_import = _vala_file_to_import;
#line 12692 "ImportPage.c"
		} else {
#line 567 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_g_object_unref0 (_vala_file_to_import);
#line 12696 "ImportPage.c"
		}
#line 567 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		if (copy_to_library) {
#line 567 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			*copy_to_library = _vala_copy_to_library;
#line 12702 "ImportPage.c"
		}
#line 567 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		return result;
#line 12706 "ImportPage.c"
	}
#line 572 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp16_ = dest_file;
#line 572 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	library_monitor_blacklist_file (_tmp16_, "CameraImportJob.prepare");
#line 12712 "ImportPage.c"
	{
		GPContextWrapper* _tmp17_ = NULL;
		GPContext* _tmp18_ = NULL;
		Camera* _tmp19_ = NULL;
		const gchar* _tmp20_ = NULL;
		const gchar* _tmp21_ = NULL;
		GFile* _tmp22_ = NULL;
#line 574 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp17_ = self->priv->context;
#line 574 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp18_ = _tmp17_->context;
#line 574 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp19_ = self->priv->camera;
#line 574 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp20_ = self->priv->fulldir;
#line 574 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp21_ = self->priv->filename;
#line 574 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp22_ = dest_file;
#line 574 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		gp_save_image (_tmp18_, _tmp19_, _tmp20_, _tmp21_, _tmp22_, &_inner_error_);
#line 574 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 12736 "ImportPage.c"
			goto __finally70;
		}
	}
	__finally70:
	{
		GFile* _tmp23_ = NULL;
#line 576 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp23_ = dest_file;
#line 576 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		library_monitor_unblacklist_file (_tmp23_);
#line 12747 "ImportPage.c"
	}
#line 573 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 573 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		g_propagate_error (error, _inner_error_);
#line 573 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_object_unref0 (dest_file);
#line 573 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		return FALSE;
#line 12757 "ImportPage.c"
	}
#line 580 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp24_ = self->priv->associated;
#line 580 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (_tmp24_ != NULL) {
#line 12763 "ImportPage.c"
		BackingPhotoRow* _tmp39_ = NULL;
		GFile* assoc_dest = NULL;
		BackingPhotoRow* _tmp42_ = NULL;
		const gchar* _tmp43_ = NULL;
		GFile* _tmp44_ = NULL;
		GFile* _tmp45_ = NULL;
		{
			BackingPhotoRow* _tmp25_ = NULL;
			GFile* _tmp26_ = NULL;
			gchar* _tmp27_ = NULL;
			gchar* _tmp28_ = NULL;
			ImportPageCameraImportJob* _tmp29_ = NULL;
			gchar* _tmp30_ = NULL;
			gchar* _tmp31_ = NULL;
			BackingPhotoRow* _tmp32_ = NULL;
			BackingPhotoRow* _tmp33_ = NULL;
			BackingPhotoRow* _tmp34_ = NULL;
#line 583 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp26_ = dest_file;
#line 583 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp27_ = g_file_get_path (_tmp26_);
#line 583 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp28_ = _tmp27_;
#line 583 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp29_ = self->priv->associated;
#line 583 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp30_ = batch_import_job_get_basename (G_TYPE_CHECK_INSTANCE_CAST (_tmp29_, TYPE_BATCH_IMPORT_JOB, BatchImportJob));
#line 583 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp31_ = _tmp30_;
#line 583 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp32_ = raw_developer_create_backing_row_for_development (RAW_DEVELOPER_CAMERA, _tmp28_, _tmp31_, &_inner_error_);
#line 583 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp33_ = _tmp32_;
#line 583 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_g_free0 (_tmp31_);
#line 583 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_g_free0 (_tmp28_);
#line 583 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp25_ = _tmp33_;
#line 583 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 12805 "ImportPage.c"
				goto __catch71_g_error;
			}
#line 582 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp34_ = _tmp25_;
#line 582 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp25_ = NULL;
#line 582 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_backing_photo_row_unref0 (self->priv->associated_file);
#line 582 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			self->priv->associated_file = _tmp34_;
#line 581 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_backing_photo_row_unref0 (_tmp25_);
#line 12818 "ImportPage.c"
		}
		goto __finally71;
		__catch71_g_error:
		{
			GError* err = NULL;
			ImportPageCameraImportJob* _tmp35_ = NULL;
			const gchar* _tmp36_ = NULL;
			GError* _tmp37_ = NULL;
			const gchar* _tmp38_ = NULL;
#line 581 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			err = _inner_error_;
#line 581 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_inner_error_ = NULL;
#line 586 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp35_ = self->priv->associated;
#line 586 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp36_ = _tmp35_->priv->filename;
#line 586 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp37_ = err;
#line 586 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp38_ = _tmp37_->message;
#line 586 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			g_warning ("ImportPage.vala:586: Unable to generate backing associated file for %s" \
": %s", _tmp36_, _tmp38_);
#line 581 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_g_error_free0 (err);
#line 12844 "ImportPage.c"
		}
		__finally71:
#line 581 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 581 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			g_propagate_error (error, _inner_error_);
#line 581 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_g_object_unref0 (dest_file);
#line 581 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			return FALSE;
#line 12855 "ImportPage.c"
		}
#line 590 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp39_ = self->priv->associated_file;
#line 590 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		if (_tmp39_ == NULL) {
#line 12861 "ImportPage.c"
			ImportPageCameraImportJob* _tmp40_ = NULL;
			const gchar* _tmp41_ = NULL;
#line 591 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp40_ = self->priv->associated;
#line 591 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp41_ = _tmp40_->priv->filename;
#line 591 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			g_message ("ImportPage.vala:591: Unable to generate backing associated file for %s", _tmp41_);
#line 592 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			result = FALSE;
#line 592 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_g_object_unref0 (dest_file);
#line 592 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			if (file_to_import) {
#line 592 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				*file_to_import = _vala_file_to_import;
#line 12878 "ImportPage.c"
			} else {
#line 592 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_g_object_unref0 (_vala_file_to_import);
#line 12882 "ImportPage.c"
			}
#line 592 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			if (copy_to_library) {
#line 592 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				*copy_to_library = _vala_copy_to_library;
#line 12888 "ImportPage.c"
			}
#line 592 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			return result;
#line 12892 "ImportPage.c"
		}
#line 595 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp42_ = self->priv->associated_file;
#line 595 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp43_ = _tmp42_->filepath;
#line 595 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp44_ = g_file_new_for_path (_tmp43_);
#line 595 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		assoc_dest = _tmp44_;
#line 596 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp45_ = assoc_dest;
#line 596 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		library_monitor_blacklist_file (_tmp45_, "CameraImportJob.prepare");
#line 12906 "ImportPage.c"
		{
			GPContextWrapper* _tmp46_ = NULL;
			GPContext* _tmp47_ = NULL;
			Camera* _tmp48_ = NULL;
			ImportPageCameraImportJob* _tmp49_ = NULL;
			const gchar* _tmp50_ = NULL;
			ImportPageCameraImportJob* _tmp51_ = NULL;
			const gchar* _tmp52_ = NULL;
			GFile* _tmp53_ = NULL;
#line 598 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp46_ = self->priv->context;
#line 598 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp47_ = _tmp46_->context;
#line 598 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp48_ = self->priv->camera;
#line 598 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp49_ = self->priv->associated;
#line 598 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp50_ = _tmp49_->priv->fulldir;
#line 598 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp51_ = self->priv->associated;
#line 598 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp52_ = _tmp51_->priv->filename;
#line 598 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp53_ = assoc_dest;
#line 598 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			gp_save_image (_tmp47_, _tmp48_, _tmp50_, _tmp52_, _tmp53_, &_inner_error_);
#line 598 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 12936 "ImportPage.c"
				goto __finally72;
			}
		}
		__finally72:
		{
			GFile* _tmp54_ = NULL;
#line 601 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp54_ = assoc_dest;
#line 601 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			library_monitor_unblacklist_file (_tmp54_);
#line 12947 "ImportPage.c"
		}
#line 597 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 597 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			g_propagate_error (error, _inner_error_);
#line 597 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_g_object_unref0 (assoc_dest);
#line 597 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_g_object_unref0 (dest_file);
#line 597 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			return FALSE;
#line 12959 "ImportPage.c"
		}
#line 580 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_object_unref0 (assoc_dest);
#line 12963 "ImportPage.c"
	}
#line 605 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp55_ = dest_file;
#line 605 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp56_ = _g_object_ref0 (_tmp55_);
#line 605 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_object_unref0 (_vala_file_to_import);
#line 605 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_vala_file_to_import = _tmp56_;
#line 606 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_vala_copy_to_library = FALSE;
#line 608 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = TRUE;
#line 608 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_object_unref0 (dest_file);
#line 608 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (file_to_import) {
#line 608 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		*file_to_import = _vala_file_to_import;
#line 12983 "ImportPage.c"
	} else {
#line 608 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_object_unref0 (_vala_file_to_import);
#line 12987 "ImportPage.c"
	}
#line 608 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (copy_to_library) {
#line 608 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		*copy_to_library = _vala_copy_to_library;
#line 12993 "ImportPage.c"
	}
#line 608 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 12997 "ImportPage.c"
}


static gboolean import_page_camera_import_job_real_complete (BatchImportJob* base, MediaSource* source, BatchImportRoll* import_roll, GError** error) {
	ImportPageCameraImportJob * self;
	gboolean result = FALSE;
	gboolean ret = FALSE;
	MediaSource* _tmp0_ = NULL;
	GError * _inner_error_ = NULL;
#line 611 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, IMPORT_PAGE_TYPE_CAMERA_IMPORT_JOB, ImportPageCameraImportJob);
#line 611 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail (IS_MEDIA_SOURCE (source), FALSE);
#line 611 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail (IS_BATCH_IMPORT_ROLL (import_roll), FALSE);
#line 612 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	ret = FALSE;
#line 613 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = source;
#line 613 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, TYPE_PHOTO)) {
#line 13019 "ImportPage.c"
		Photo* photo = NULL;
		MediaSource* _tmp1_ = NULL;
		Photo* _tmp2_ = NULL;
		BackingPhotoRow* _tmp3_ = NULL;
#line 614 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp1_ = source;
#line 614 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp2_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, TYPE_PHOTO) ? ((Photo*) _tmp1_) : NULL);
#line 614 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		photo = _tmp2_;
#line 617 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp3_ = self->priv->associated_file;
#line 617 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		if (_tmp3_ != NULL) {
#line 13034 "ImportPage.c"
			Photo* _tmp4_ = NULL;
			BackingPhotoRow* _tmp5_ = NULL;
			Photo* _tmp6_ = NULL;
			ConfigFacade* _tmp7_ = NULL;
			ConfigFacade* _tmp8_ = NULL;
			RawDeveloper _tmp9_ = 0;
#line 618 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp4_ = photo;
#line 618 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp5_ = self->priv->associated_file;
#line 618 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			photo_add_backing_photo_for_development (_tmp4_, RAW_DEVELOPER_CAMERA, _tmp5_, &_inner_error_);
#line 618 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 618 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				g_propagate_error (error, _inner_error_);
#line 618 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_g_object_unref0 (photo);
#line 618 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				return FALSE;
#line 13055 "ImportPage.c"
			}
#line 619 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			ret = TRUE;
#line 620 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp6_ = photo;
#line 620 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp7_ = config_facade_get_instance ();
#line 620 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp8_ = _tmp7_;
#line 620 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp9_ = configuration_facade_get_default_raw_developer (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade));
#line 620 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			photo_set_raw_developer (_tmp6_, _tmp9_);
#line 620 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_g_object_unref0 (_tmp8_);
#line 13071 "ImportPage.c"
		}
#line 613 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_g_object_unref0 (photo);
#line 13075 "ImportPage.c"
	}
#line 623 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = ret;
#line 623 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 13081 "ImportPage.c"
}


static void import_page_camera_import_job_class_init (ImportPageCameraImportJobClass * klass) {
#line 472 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	import_page_camera_import_job_parent_class = g_type_class_peek_parent (klass);
#line 472 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	((BatchImportJobClass *) klass)->finalize = import_page_camera_import_job_finalize;
#line 472 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_type_class_add_private (klass, sizeof (ImportPageCameraImportJobPrivate));
#line 472 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	((BatchImportJobClass *) klass)->get_duplicated_file = import_page_camera_import_job_real_get_duplicated_file;
#line 472 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	((BatchImportJobClass *) klass)->get_exposure_time_override = import_page_camera_import_job_real_get_exposure_time_override;
#line 472 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	((BatchImportJobClass *) klass)->get_dest_identifier = import_page_camera_import_job_real_get_dest_identifier;
#line 472 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	((BatchImportJobClass *) klass)->get_source_identifier = import_page_camera_import_job_real_get_source_identifier;
#line 472 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	((BatchImportJobClass *) klass)->get_basename = import_page_camera_import_job_real_get_basename;
#line 472 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	((BatchImportJobClass *) klass)->get_path = import_page_camera_import_job_real_get_path;
#line 472 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	((BatchImportJobClass *) klass)->set_associated = import_page_camera_import_job_real_set_associated;
#line 472 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	((BatchImportJobClass *) klass)->is_directory = import_page_camera_import_job_real_is_directory;
#line 472 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	((BatchImportJobClass *) klass)->determine_file_size = import_page_camera_import_job_real_determine_file_size;
#line 472 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	((BatchImportJobClass *) klass)->prepare = import_page_camera_import_job_real_prepare;
#line 472 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	((BatchImportJobClass *) klass)->complete = import_page_camera_import_job_real_complete;
#line 13114 "ImportPage.c"
}


static void import_page_camera_import_job_instance_init (ImportPageCameraImportJob * self) {
#line 472 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self->priv = IMPORT_PAGE_CAMERA_IMPORT_JOB_GET_PRIVATE (self);
#line 481 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self->priv->associated = NULL;
#line 482 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self->priv->associated_file = NULL;
#line 13125 "ImportPage.c"
}


static void import_page_camera_import_job_finalize (BatchImportJob* obj) {
	ImportPageCameraImportJob * self;
#line 472 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, IMPORT_PAGE_TYPE_CAMERA_IMPORT_JOB, ImportPageCameraImportJob);
#line 473 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_gp_context_wrapper_unref0 (self->priv->context);
#line 474 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_object_unref0 (self->priv->import_file);
#line 475 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_gp_camera_unref0 (self->priv->camera);
#line 476 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_free0 (self->priv->fulldir);
#line 477 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_free0 (self->priv->filename);
#line 479 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_media_metadata_unref0 (self->priv->metadata);
#line 481 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_batch_import_job_unref0 (self->priv->associated);
#line 482 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_backing_photo_row_unref0 (self->priv->associated_file);
#line 483 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_object_unref0 (self->priv->duplicated_file);
#line 472 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	BATCH_IMPORT_JOB_CLASS (import_page_camera_import_job_parent_class)->finalize (obj);
#line 13153 "ImportPage.c"
}


static GType import_page_camera_import_job_get_type (void) {
	static volatile gsize import_page_camera_import_job_type_id__volatile = 0;
	if (g_once_init_enter (&import_page_camera_import_job_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (ImportPageCameraImportJobClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) import_page_camera_import_job_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ImportPageCameraImportJob), 0, (GInstanceInitFunc) import_page_camera_import_job_instance_init, NULL };
		GType import_page_camera_import_job_type_id;
		import_page_camera_import_job_type_id = g_type_register_static (TYPE_BATCH_IMPORT_JOB, "ImportPageCameraImportJob", &g_define_type_info, 0);
		g_once_init_leave (&import_page_camera_import_job_type_id__volatile, import_page_camera_import_job_type_id);
	}
	return import_page_camera_import_job_type_id__volatile;
}


static guint import_page_import_page_search_view_filter_real_get_criteria (SearchViewFilter* base) {
	ImportPageImportPageSearchViewFilter * self;
	guint result = 0U;
#line 628 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, IMPORT_PAGE_TYPE_IMPORT_PAGE_SEARCH_VIEW_FILTER, ImportPageImportPageSearchViewFilter);
#line 629 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = (guint) (SEARCH_FILTER_CRITERIA_TEXT | SEARCH_FILTER_CRITERIA_MEDIA);
#line 629 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 13178 "ImportPage.c"
}


static gboolean string_contains (const gchar* self, const gchar* needle) {
	gboolean result = FALSE;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 1376 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, FALSE);
#line 1376 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	g_return_val_if_fail (needle != NULL, FALSE);
#line 1377 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp0_ = needle;
#line 1377 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp1_ = strstr ((gchar*) self, (gchar*) _tmp0_);
#line 1377 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	result = _tmp1_ != NULL;
#line 1377 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	return result;
#line 13198 "ImportPage.c"
}


static gboolean import_page_import_page_search_view_filter_real_predicate (ViewFilter* base, DataView* view) {
	ImportPageImportPageSearchViewFilter * self;
	gboolean result = FALSE;
	ImportSource* source = NULL;
	DataView* _tmp0_ = NULL;
	ImportSource* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	guint _tmp3_ = 0U;
	guint _tmp26_ = 0U;
#line 632 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, IMPORT_PAGE_TYPE_IMPORT_PAGE_SEARCH_VIEW_FILTER, ImportPageImportPageSearchViewFilter);
#line 632 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail (IS_DATA_VIEW (view), FALSE);
#line 633 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = view;
#line 633 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = import_preview_get_import_source (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, TYPE_IMPORT_PREVIEW, ImportPreview));
#line 633 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	source = _tmp1_;
#line 636 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp3_ = search_view_filter_get_criteria (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_SEARCH_VIEW_FILTER, SearchViewFilter));
#line 636 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if ((gboolean) (SEARCH_FILTER_CRITERIA_MEDIA & _tmp3_)) {
#line 13225 "ImportPage.c"
		gboolean _tmp4_ = FALSE;
#line 636 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp4_ = search_view_filter_filter_by_media_type (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_SEARCH_VIEW_FILTER, SearchViewFilter));
#line 636 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp2_ = _tmp4_;
#line 13231 "ImportPage.c"
	} else {
#line 636 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp2_ = FALSE;
#line 13235 "ImportPage.c"
	}
#line 636 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if (_tmp2_) {
#line 13239 "ImportPage.c"
		ImportSource* _tmp5_ = NULL;
#line 637 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp5_ = source;
#line 637 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp5_, TYPE_VIDEO_IMPORT_SOURCE)) {
#line 13245 "ImportPage.c"
			gboolean _tmp6_ = FALSE;
			gboolean _tmp7_ = FALSE;
#line 638 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp6_ = search_view_filter_get_show_media_video (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_SEARCH_VIEW_FILTER, SearchViewFilter));
#line 638 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp7_ = _tmp6_;
#line 638 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			if (!_tmp7_) {
#line 639 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				result = FALSE;
#line 639 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_g_object_unref0 (source);
#line 639 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				return result;
#line 13260 "ImportPage.c"
			}
		} else {
			ImportSource* _tmp8_ = NULL;
#line 640 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_tmp8_ = source;
#line 640 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp8_, TYPE_PHOTO_IMPORT_SOURCE)) {
#line 13268 "ImportPage.c"
				PhotoImportSource* photo = NULL;
				ImportSource* _tmp9_ = NULL;
				PhotoImportSource* _tmp10_ = NULL;
				PhotoImportSource* _tmp11_ = NULL;
				PhotoFileFormat _tmp12_ = 0;
#line 641 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp9_ = source;
#line 641 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp10_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp9_, TYPE_PHOTO_IMPORT_SOURCE) ? ((PhotoImportSource*) _tmp9_) : NULL);
#line 641 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				photo = _tmp10_;
#line 642 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp11_ = photo;
#line 642 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_tmp12_ = photo_import_source_get_file_format (_tmp11_);
#line 642 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				if (_tmp12_ == PHOTO_FILE_FORMAT_RAW) {
#line 13286 "ImportPage.c"
					PhotoImportSource* _tmp13_ = NULL;
					PhotoImportSource* _tmp14_ = NULL;
					PhotoImportSource* _tmp15_ = NULL;
					gboolean _tmp16_ = FALSE;
#line 643 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp13_ = photo;
#line 643 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp14_ = photo_import_source_get_associated (_tmp13_);
#line 643 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp15_ = _tmp14_;
#line 643 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp16_ = _tmp15_ != NULL;
#line 643 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_g_object_unref0 (_tmp15_);
#line 643 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					if (_tmp16_) {
#line 13303 "ImportPage.c"
						gboolean _tmp17_ = FALSE;
						gboolean _tmp18_ = FALSE;
						gboolean _tmp19_ = FALSE;
#line 644 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp18_ = search_view_filter_get_show_media_photos (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_SEARCH_VIEW_FILTER, SearchViewFilter));
#line 644 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp19_ = _tmp18_;
#line 644 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						if (!_tmp19_) {
#line 13313 "ImportPage.c"
							gboolean _tmp20_ = FALSE;
							gboolean _tmp21_ = FALSE;
#line 644 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
							_tmp20_ = search_view_filter_get_show_media_raw (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_SEARCH_VIEW_FILTER, SearchViewFilter));
#line 644 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
							_tmp21_ = _tmp20_;
#line 644 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
							_tmp17_ = !_tmp21_;
#line 13322 "ImportPage.c"
						} else {
#line 644 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
							_tmp17_ = FALSE;
#line 13326 "ImportPage.c"
						}
#line 644 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						if (_tmp17_) {
#line 645 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
							result = FALSE;
#line 645 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
							_g_object_unref0 (photo);
#line 645 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
							_g_object_unref0 (source);
#line 645 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
							return result;
#line 13338 "ImportPage.c"
						}
					} else {
						gboolean _tmp22_ = FALSE;
						gboolean _tmp23_ = FALSE;
#line 646 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp22_ = search_view_filter_get_show_media_raw (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_SEARCH_VIEW_FILTER, SearchViewFilter));
#line 646 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_tmp23_ = _tmp22_;
#line 646 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						if (!_tmp23_) {
#line 647 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
							result = FALSE;
#line 647 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
							_g_object_unref0 (photo);
#line 647 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
							_g_object_unref0 (source);
#line 647 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
							return result;
#line 13357 "ImportPage.c"
						}
					}
				} else {
					gboolean _tmp24_ = FALSE;
					gboolean _tmp25_ = FALSE;
#line 649 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp24_ = search_view_filter_get_show_media_photos (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_SEARCH_VIEW_FILTER, SearchViewFilter));
#line 649 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp25_ = _tmp24_;
#line 649 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					if (!_tmp25_) {
#line 650 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						result = FALSE;
#line 650 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_g_object_unref0 (photo);
#line 650 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_g_object_unref0 (source);
#line 650 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						return result;
#line 13377 "ImportPage.c"
					}
				}
#line 640 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				_g_object_unref0 (photo);
#line 13382 "ImportPage.c"
			}
		}
	}
#line 654 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp26_ = search_view_filter_get_criteria (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_SEARCH_VIEW_FILTER, SearchViewFilter));
#line 654 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	if ((gboolean) (SEARCH_FILTER_CRITERIA_TEXT & _tmp26_)) {
#line 13390 "ImportPage.c"
		const gchar* keywords = NULL;
		ImportSource* _tmp27_ = NULL;
		const gchar* _tmp28_ = NULL;
		const gchar* _tmp29_ = NULL;
		gboolean _tmp30_ = FALSE;
		gint _tmp31_ = 0;
		gchar** _tmp32_ = NULL;
#line 655 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp27_ = source;
#line 655 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp28_ = indexable_get_indexable_keywords (G_TYPE_CHECK_INSTANCE_CAST (_tmp27_, TYPE_INDEXABLE, Indexable));
#line 655 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		keywords = _tmp28_;
#line 656 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp29_ = keywords;
#line 656 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp30_ = is_string_empty (_tmp29_);
#line 656 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		if (_tmp30_) {
#line 657 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			result = FALSE;
#line 657 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			_g_object_unref0 (source);
#line 657 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			return result;
#line 13416 "ImportPage.c"
		}
#line 660 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
		_tmp32_ = search_view_filter_get_search_filter_words (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_SEARCH_VIEW_FILTER, SearchViewFilter), &_tmp31_);
#line 13420 "ImportPage.c"
		{
			gchar** word_collection = NULL;
			gint word_collection_length1 = 0;
			gint _word_collection_size_ = 0;
			gint word_it = 0;
#line 660 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			word_collection = _tmp32_;
#line 660 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			word_collection_length1 = _tmp31_;
#line 660 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
			for (word_it = 0; word_it < _tmp31_; word_it = word_it + 1) {
#line 13432 "ImportPage.c"
				const gchar* word = NULL;
#line 660 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
				word = word_collection[word_it];
#line 13436 "ImportPage.c"
				{
					const gchar* _tmp33_ = NULL;
					const gchar* _tmp34_ = NULL;
					gboolean _tmp35_ = FALSE;
#line 661 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp33_ = keywords;
#line 661 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp34_ = word;
#line 661 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					_tmp35_ = string_contains (_tmp33_, _tmp34_);
#line 661 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
					if (!_tmp35_) {
#line 662 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						result = FALSE;
#line 662 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						_g_object_unref0 (source);
#line 662 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
						return result;
#line 13455 "ImportPage.c"
					}
				}
			}
		}
	}
#line 666 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = TRUE;
#line 666 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_object_unref0 (source);
#line 666 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 13467 "ImportPage.c"
}


static ImportPageImportPageSearchViewFilter* import_page_import_page_search_view_filter_construct (GType object_type) {
	ImportPageImportPageSearchViewFilter* self = NULL;
#line 627 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self = (ImportPageImportPageSearchViewFilter*) search_view_filter_construct (object_type);
#line 627 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return self;
#line 13477 "ImportPage.c"
}


static ImportPageImportPageSearchViewFilter* import_page_import_page_search_view_filter_new (void) {
#line 627 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return import_page_import_page_search_view_filter_construct (IMPORT_PAGE_TYPE_IMPORT_PAGE_SEARCH_VIEW_FILTER);
#line 13484 "ImportPage.c"
}


static void import_page_import_page_search_view_filter_class_init (ImportPageImportPageSearchViewFilterClass * klass) {
#line 627 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	import_page_import_page_search_view_filter_parent_class = g_type_class_peek_parent (klass);
#line 627 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	((SearchViewFilterClass *) klass)->get_criteria = import_page_import_page_search_view_filter_real_get_criteria;
#line 627 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	((ViewFilterClass *) klass)->predicate = import_page_import_page_search_view_filter_real_predicate;
#line 13495 "ImportPage.c"
}


static void import_page_import_page_search_view_filter_instance_init (ImportPageImportPageSearchViewFilter * self) {
}


static GType import_page_import_page_search_view_filter_get_type (void) {
	static volatile gsize import_page_import_page_search_view_filter_type_id__volatile = 0;
	if (g_once_init_enter (&import_page_import_page_search_view_filter_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (ImportPageImportPageSearchViewFilterClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) import_page_import_page_search_view_filter_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ImportPageImportPageSearchViewFilter), 0, (GInstanceInitFunc) import_page_import_page_search_view_filter_instance_init, NULL };
		GType import_page_import_page_search_view_filter_type_id;
		import_page_import_page_search_view_filter_type_id = g_type_register_static (TYPE_SEARCH_VIEW_FILTER, "ImportPageImportPageSearchViewFilter", &g_define_type_info, 0);
		g_once_init_leave (&import_page_import_page_search_view_filter_type_id__volatile, import_page_import_page_search_view_filter_type_id);
	}
	return import_page_import_page_search_view_filter_type_id__volatile;
}


static gboolean import_page_hide_imported_view_filter_real_predicate (ViewFilter* base, DataView* view) {
	ImportPageHideImportedViewFilter * self;
	gboolean result = FALSE;
	DataView* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
#line 672 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, IMPORT_PAGE_TYPE_HIDE_IMPORTED_VIEW_FILTER, ImportPageHideImportedViewFilter);
#line 672 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_return_val_if_fail (IS_DATA_VIEW (view), FALSE);
#line 673 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = view;
#line 673 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = import_preview_is_already_imported (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, TYPE_IMPORT_PREVIEW, ImportPreview));
#line 673 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	result = !_tmp1_;
#line 673 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return result;
#line 13532 "ImportPage.c"
}


static ImportPageHideImportedViewFilter* import_page_hide_imported_view_filter_construct (GType object_type) {
	ImportPageHideImportedViewFilter* self = NULL;
#line 671 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self = (ImportPageHideImportedViewFilter*) view_filter_construct (object_type);
#line 671 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return self;
#line 13542 "ImportPage.c"
}


static ImportPageHideImportedViewFilter* import_page_hide_imported_view_filter_new (void) {
#line 671 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	return import_page_hide_imported_view_filter_construct (IMPORT_PAGE_TYPE_HIDE_IMPORTED_VIEW_FILTER);
#line 13549 "ImportPage.c"
}


static void import_page_hide_imported_view_filter_class_init (ImportPageHideImportedViewFilterClass * klass) {
#line 671 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	import_page_hide_imported_view_filter_parent_class = g_type_class_peek_parent (klass);
#line 671 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	((ViewFilterClass *) klass)->predicate = import_page_hide_imported_view_filter_real_predicate;
#line 13558 "ImportPage.c"
}


static void import_page_hide_imported_view_filter_instance_init (ImportPageHideImportedViewFilter * self) {
}


static GType import_page_hide_imported_view_filter_get_type (void) {
	static volatile gsize import_page_hide_imported_view_filter_type_id__volatile = 0;
	if (g_once_init_enter (&import_page_hide_imported_view_filter_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (ImportPageHideImportedViewFilterClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) import_page_hide_imported_view_filter_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ImportPageHideImportedViewFilter), 0, (GInstanceInitFunc) import_page_hide_imported_view_filter_instance_init, NULL };
		GType import_page_hide_imported_view_filter_type_id;
		import_page_hide_imported_view_filter_type_id = g_type_register_static (TYPE_VIEW_FILTER, "ImportPageHideImportedViewFilter", &g_define_type_info, 0);
		g_once_init_leave (&import_page_hide_imported_view_filter_type_id__volatile, import_page_hide_imported_view_filter_type_id);
	}
	return import_page_hide_imported_view_filter_type_id__volatile;
}


static void import_page_class_init (ImportPageClass * klass) {
#line 457 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	import_page_parent_class = g_type_class_peek_parent (klass);
#line 457 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_type_class_add_private (klass, sizeof (ImportPagePrivate));
#line 457 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	((PageClass *) klass)->get_toolbar = import_page_real_get_toolbar;
#line 457 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	((CheckerboardPageClass *) klass)->get_view_tracker = import_page_real_get_view_tracker;
#line 457 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	((CheckerboardPageClass *) klass)->get_view_empty_message = import_page_real_get_view_empty_message;
#line 457 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	((CheckerboardPageClass *) klass)->get_filter_no_match_message = import_page_real_get_filter_no_match_message;
#line 457 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	((PageClass *) klass)->init_collect_ui_filenames = import_page_real_init_collect_ui_filenames;
#line 457 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	((PageClass *) klass)->init_collect_toggle_action_entries = import_page_real_init_collect_toggle_action_entries;
#line 457 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	((PageClass *) klass)->init_collect_action_entries = import_page_real_init_collect_action_entries;
#line 457 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	((PageClass *) klass)->init_actions = import_page_real_init_actions;
#line 457 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	((PageClass *) klass)->switched_to = import_page_real_switched_to;
#line 457 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	((PageClass *) klass)->ready = import_page_real_ready;
#line 457 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	((CheckerboardPageClass *) klass)->set_display_titles = import_page_real_set_display_titles;
#line 457 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	((CheckerboardPageClass *) klass)->get_search_view_filter = import_page_real_get_search_view_filter;
#line 457 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	G_OBJECT_CLASS (klass)->finalize = import_page_finalize;
#line 13609 "ImportPage.c"
}


static void import_page_instance_init (ImportPage * self) {
	GtkLabel* _tmp0_ = NULL;
	GtkProgressBar* _tmp1_ = NULL;
	ImportPageImportPageSearchViewFilter* _tmp2_ = NULL;
	ImportPageHideImportedViewFilter* _tmp3_ = NULL;
#line 457 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self->priv = IMPORT_PAGE_GET_PRIVATE (self);
#line 680 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self->priv->import_sources = NULL;
#line 681 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = (GtkLabel*) gtk_label_new (NULL);
#line 681 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_object_ref_sink (_tmp0_);
#line 681 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self->priv->camera_label = _tmp0_;
#line 683 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp1_ = (GtkProgressBar*) gtk_progress_bar_new ();
#line 683 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_object_ref_sink (_tmp1_);
#line 683 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self->priv->progress_bar = _tmp1_;
#line 686 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self->priv->busy = FALSE;
#line 687 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self->priv->refreshed = FALSE;
#line 688 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self->priv->refresh_result = GP_OK;
#line 689 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self->priv->refresh_error = NULL;
#line 691 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self->priv->volume_monitor = NULL;
#line 692 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self->priv->local_ref = NULL;
#line 694 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp2_ = import_page_import_page_search_view_filter_new ();
#line 694 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self->priv->search_filter = _tmp2_;
#line 695 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp3_ = import_page_hide_imported_view_filter_new ();
#line 695 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self->priv->hide_imported_filter = _tmp3_;
#line 13654 "ImportPage.c"
}


static void import_page_finalize (GObject* obj) {
	ImportPage * self;
	LibraryPhotoSourceCollection* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
	VideoSourceCollection* _tmp2_ = NULL;
	guint _tmp3_ = 0U;
#line 457 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_IMPORT_PAGE, ImportPage);
#line 766 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp0_ = library_photo_global;
#line 766 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_signal_parse_name ("contents-altered", TYPE_DATA_COLLECTION, &_tmp1_, NULL, FALSE);
#line 766 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_signal_handlers_disconnect_matched (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, TYPE_DATA_COLLECTION, DataCollection), G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _import_page_on_media_added_removed_data_collection_contents_altered, self);
#line 767 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_tmp2_ = video_global;
#line 767 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_signal_parse_name ("contents-altered", TYPE_DATA_COLLECTION, &_tmp3_, NULL, FALSE);
#line 767 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	g_signal_handlers_disconnect_matched (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, TYPE_DATA_COLLECTION, DataCollection), G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _import_page_on_media_added_removed_data_collection_contents_altered, self);
#line 680 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_data_collection_unref0 (self->priv->import_sources);
#line 681 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_object_unref0 (self->priv->camera_label);
#line 682 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_object_unref0 (self->priv->hide_imported);
#line 683 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_object_unref0 (self->priv->progress_bar);
#line 684 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_gp_camera_unref0 (self->priv->camera);
#line 685 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_free0 (self->priv->uri);
#line 689 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_free0 (self->priv->refresh_error);
#line 690 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_free0 (self->priv->camera_name);
#line 691 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_object_unref0 (self->priv->volume_monitor);
#line 692 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_object_unref0 (self->priv->local_ref);
#line 693 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_g_free0 (self->priv->icon);
#line 694 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_view_filter_unref0 (self->priv->search_filter);
#line 695 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_view_filter_unref0 (self->priv->hide_imported_filter);
#line 696 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	_core_tracker_unref0 (self->priv->tracker);
#line 457 "/home/jens/Source/shotwell/src/camera/ImportPage.vala"
	G_OBJECT_CLASS (import_page_parent_class)->finalize (obj);
#line 13708 "ImportPage.c"
}


GType import_page_get_type (void) {
	static volatile gsize import_page_type_id__volatile = 0;
	if (g_once_init_enter (&import_page_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (ImportPageClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) import_page_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ImportPage), 0, (GInstanceInitFunc) import_page_instance_init, NULL };
		GType import_page_type_id;
		import_page_type_id = g_type_register_static (TYPE_CHECKERBOARD_PAGE, "ImportPage", &g_define_type_info, 0);
		g_once_init_leave (&import_page_type_id__volatile, import_page_type_id);
	}
	return import_page_type_id__volatile;
}



