/* GalleryConnector.c generated by valac 0.32.1, the Vala compiler
 * generated from GalleryConnector.vala, do not modify */

/* Copyright 2012-2013 Joe Sapp nixphoeni@gentoo.org
 *
 * This software is licensed under the GNU LGPL (version 2.1 or later).
 * See the COPYING file in this distribution.
 */

#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <shotwell-plugin-dev-1.0.h>
#include <gio/gio.h>
#include <glib/gi18n-lib.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include "shotwell-plugin-common.h"
#include <json-glib/json-glib.h>
#include <gtk/gtk.h>
#include <float.h>
#include <math.h>
#include <gobject/gvaluecollector.h>


#define TYPE_SHOTWELL_PUBLISHING_GALLERY3 (shotwell_publishing_gallery3_get_type ())
#define SHOTWELL_PUBLISHING_GALLERY3(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SHOTWELL_PUBLISHING_GALLERY3, ShotwellPublishingGallery3))
#define SHOTWELL_PUBLISHING_GALLERY3_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SHOTWELL_PUBLISHING_GALLERY3, ShotwellPublishingGallery3Class))
#define IS_SHOTWELL_PUBLISHING_GALLERY3(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SHOTWELL_PUBLISHING_GALLERY3))
#define IS_SHOTWELL_PUBLISHING_GALLERY3_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SHOTWELL_PUBLISHING_GALLERY3))
#define SHOTWELL_PUBLISHING_GALLERY3_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SHOTWELL_PUBLISHING_GALLERY3, ShotwellPublishingGallery3Class))

typedef struct _ShotwellPublishingGallery3 ShotwellPublishingGallery3;
typedef struct _ShotwellPublishingGallery3Class ShotwellPublishingGallery3Class;
typedef struct _ShotwellPublishingGallery3Private ShotwellPublishingGallery3Private;

#define TYPE_GALLERY3_SERVICE (gallery3_service_get_type ())
#define GALLERY3_SERVICE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GALLERY3_SERVICE, Gallery3Service))
#define GALLERY3_SERVICE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GALLERY3_SERVICE, Gallery3ServiceClass))
#define IS_GALLERY3_SERVICE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GALLERY3_SERVICE))
#define IS_GALLERY3_SERVICE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GALLERY3_SERVICE))
#define GALLERY3_SERVICE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GALLERY3_SERVICE, Gallery3ServiceClass))

typedef struct _Gallery3Service Gallery3Service;
typedef struct _Gallery3ServiceClass Gallery3ServiceClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
typedef struct _Gallery3ServicePrivate Gallery3ServicePrivate;
#define _g_free0(var) (var = (g_free (var), NULL))

#define PUBLISHING_GALLERY3_TYPE_GALLERY_PUBLISHER (publishing_gallery3_gallery_publisher_get_type ())
#define PUBLISHING_GALLERY3_GALLERY_PUBLISHER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_GALLERY3_TYPE_GALLERY_PUBLISHER, PublishingGallery3GalleryPublisher))
#define PUBLISHING_GALLERY3_GALLERY_PUBLISHER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_GALLERY3_TYPE_GALLERY_PUBLISHER, PublishingGallery3GalleryPublisherClass))
#define PUBLISHING_GALLERY3_IS_GALLERY_PUBLISHER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_GALLERY3_TYPE_GALLERY_PUBLISHER))
#define PUBLISHING_GALLERY3_IS_GALLERY_PUBLISHER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_GALLERY3_TYPE_GALLERY_PUBLISHER))
#define PUBLISHING_GALLERY3_GALLERY_PUBLISHER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_GALLERY3_TYPE_GALLERY_PUBLISHER, PublishingGallery3GalleryPublisherClass))

typedef struct _PublishingGallery3GalleryPublisher PublishingGallery3GalleryPublisher;
typedef struct _PublishingGallery3GalleryPublisherClass PublishingGallery3GalleryPublisherClass;

#define PUBLISHING_GALLERY3_TYPE_ALBUM (publishing_gallery3_album_get_type ())
#define PUBLISHING_GALLERY3_ALBUM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_GALLERY3_TYPE_ALBUM, PublishingGallery3Album))
#define PUBLISHING_GALLERY3_ALBUM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_GALLERY3_TYPE_ALBUM, PublishingGallery3AlbumClass))
#define PUBLISHING_GALLERY3_IS_ALBUM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_GALLERY3_TYPE_ALBUM))
#define PUBLISHING_GALLERY3_IS_ALBUM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_GALLERY3_TYPE_ALBUM))
#define PUBLISHING_GALLERY3_ALBUM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_GALLERY3_TYPE_ALBUM, PublishingGallery3AlbumClass))

typedef struct _PublishingGallery3Album PublishingGallery3Album;
typedef struct _PublishingGallery3AlbumClass PublishingGallery3AlbumClass;
typedef struct _PublishingGallery3AlbumPrivate PublishingGallery3AlbumPrivate;
typedef struct _PublishingGallery3ParamSpecAlbum PublishingGallery3ParamSpecAlbum;

#define PUBLISHING_GALLERY3_TYPE_BASE_GALLERY_TRANSACTION (publishing_gallery3_base_gallery_transaction_get_type ())
#define PUBLISHING_GALLERY3_BASE_GALLERY_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_GALLERY3_TYPE_BASE_GALLERY_TRANSACTION, PublishingGallery3BaseGalleryTransaction))
#define PUBLISHING_GALLERY3_BASE_GALLERY_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_GALLERY3_TYPE_BASE_GALLERY_TRANSACTION, PublishingGallery3BaseGalleryTransactionClass))
#define PUBLISHING_GALLERY3_IS_BASE_GALLERY_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_GALLERY3_TYPE_BASE_GALLERY_TRANSACTION))
#define PUBLISHING_GALLERY3_IS_BASE_GALLERY_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_GALLERY3_TYPE_BASE_GALLERY_TRANSACTION))
#define PUBLISHING_GALLERY3_BASE_GALLERY_TRANSACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_GALLERY3_TYPE_BASE_GALLERY_TRANSACTION, PublishingGallery3BaseGalleryTransactionClass))

typedef struct _PublishingGallery3BaseGalleryTransaction PublishingGallery3BaseGalleryTransaction;
typedef struct _PublishingGallery3BaseGalleryTransactionClass PublishingGallery3BaseGalleryTransactionClass;
typedef struct _PublishingGallery3BaseGalleryTransactionPrivate PublishingGallery3BaseGalleryTransactionPrivate;

#define PUBLISHING_GALLERY3_TYPE_SESSION (publishing_gallery3_session_get_type ())
#define PUBLISHING_GALLERY3_SESSION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_GALLERY3_TYPE_SESSION, PublishingGallery3Session))
#define PUBLISHING_GALLERY3_SESSION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_GALLERY3_TYPE_SESSION, PublishingGallery3SessionClass))
#define PUBLISHING_GALLERY3_IS_SESSION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_GALLERY3_TYPE_SESSION))
#define PUBLISHING_GALLERY3_IS_SESSION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_GALLERY3_TYPE_SESSION))
#define PUBLISHING_GALLERY3_SESSION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_GALLERY3_TYPE_SESSION, PublishingGallery3SessionClass))

typedef struct _PublishingGallery3Session PublishingGallery3Session;
typedef struct _PublishingGallery3SessionClass PublishingGallery3SessionClass;
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))

#define PUBLISHING_GALLERY3_TYPE_KEY_FETCH_TRANSACTION (publishing_gallery3_key_fetch_transaction_get_type ())
#define PUBLISHING_GALLERY3_KEY_FETCH_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_GALLERY3_TYPE_KEY_FETCH_TRANSACTION, PublishingGallery3KeyFetchTransaction))
#define PUBLISHING_GALLERY3_KEY_FETCH_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_GALLERY3_TYPE_KEY_FETCH_TRANSACTION, PublishingGallery3KeyFetchTransactionClass))
#define PUBLISHING_GALLERY3_IS_KEY_FETCH_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_GALLERY3_TYPE_KEY_FETCH_TRANSACTION))
#define PUBLISHING_GALLERY3_IS_KEY_FETCH_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_GALLERY3_TYPE_KEY_FETCH_TRANSACTION))
#define PUBLISHING_GALLERY3_KEY_FETCH_TRANSACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_GALLERY3_TYPE_KEY_FETCH_TRANSACTION, PublishingGallery3KeyFetchTransactionClass))

typedef struct _PublishingGallery3KeyFetchTransaction PublishingGallery3KeyFetchTransaction;
typedef struct _PublishingGallery3KeyFetchTransactionClass PublishingGallery3KeyFetchTransactionClass;
typedef struct _PublishingGallery3KeyFetchTransactionPrivate PublishingGallery3KeyFetchTransactionPrivate;

#define PUBLISHING_GALLERY3_TYPE_GALLERY_REQUEST_TRANSACTION (publishing_gallery3_gallery_request_transaction_get_type ())
#define PUBLISHING_GALLERY3_GALLERY_REQUEST_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_GALLERY3_TYPE_GALLERY_REQUEST_TRANSACTION, PublishingGallery3GalleryRequestTransaction))
#define PUBLISHING_GALLERY3_GALLERY_REQUEST_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_GALLERY3_TYPE_GALLERY_REQUEST_TRANSACTION, PublishingGallery3GalleryRequestTransactionClass))
#define PUBLISHING_GALLERY3_IS_GALLERY_REQUEST_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_GALLERY3_TYPE_GALLERY_REQUEST_TRANSACTION))
#define PUBLISHING_GALLERY3_IS_GALLERY_REQUEST_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_GALLERY3_TYPE_GALLERY_REQUEST_TRANSACTION))
#define PUBLISHING_GALLERY3_GALLERY_REQUEST_TRANSACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_GALLERY3_TYPE_GALLERY_REQUEST_TRANSACTION, PublishingGallery3GalleryRequestTransactionClass))

typedef struct _PublishingGallery3GalleryRequestTransaction PublishingGallery3GalleryRequestTransaction;
typedef struct _PublishingGallery3GalleryRequestTransactionClass PublishingGallery3GalleryRequestTransactionClass;
typedef struct _PublishingGallery3GalleryRequestTransactionPrivate PublishingGallery3GalleryRequestTransactionPrivate;

#define PUBLISHING_GALLERY3_TYPE_GET_ALBUM_UR_LS_TRANSACTION (publishing_gallery3_get_album_ur_ls_transaction_get_type ())
#define PUBLISHING_GALLERY3_GET_ALBUM_UR_LS_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_GALLERY3_TYPE_GET_ALBUM_UR_LS_TRANSACTION, PublishingGallery3GetAlbumURLsTransaction))
#define PUBLISHING_GALLERY3_GET_ALBUM_UR_LS_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_GALLERY3_TYPE_GET_ALBUM_UR_LS_TRANSACTION, PublishingGallery3GetAlbumURLsTransactionClass))
#define PUBLISHING_GALLERY3_IS_GET_ALBUM_UR_LS_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_GALLERY3_TYPE_GET_ALBUM_UR_LS_TRANSACTION))
#define PUBLISHING_GALLERY3_IS_GET_ALBUM_UR_LS_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_GALLERY3_TYPE_GET_ALBUM_UR_LS_TRANSACTION))
#define PUBLISHING_GALLERY3_GET_ALBUM_UR_LS_TRANSACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_GALLERY3_TYPE_GET_ALBUM_UR_LS_TRANSACTION, PublishingGallery3GetAlbumURLsTransactionClass))

typedef struct _PublishingGallery3GetAlbumURLsTransaction PublishingGallery3GetAlbumURLsTransaction;
typedef struct _PublishingGallery3GetAlbumURLsTransactionClass PublishingGallery3GetAlbumURLsTransactionClass;
typedef struct _PublishingGallery3GetAlbumURLsTransactionPrivate PublishingGallery3GetAlbumURLsTransactionPrivate;

#define PUBLISHING_GALLERY3_TYPE_GET_ALBUMS_TRANSACTION (publishing_gallery3_get_albums_transaction_get_type ())
#define PUBLISHING_GALLERY3_GET_ALBUMS_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_GALLERY3_TYPE_GET_ALBUMS_TRANSACTION, PublishingGallery3GetAlbumsTransaction))
#define PUBLISHING_GALLERY3_GET_ALBUMS_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_GALLERY3_TYPE_GET_ALBUMS_TRANSACTION, PublishingGallery3GetAlbumsTransactionClass))
#define PUBLISHING_GALLERY3_IS_GET_ALBUMS_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_GALLERY3_TYPE_GET_ALBUMS_TRANSACTION))
#define PUBLISHING_GALLERY3_IS_GET_ALBUMS_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_GALLERY3_TYPE_GET_ALBUMS_TRANSACTION))
#define PUBLISHING_GALLERY3_GET_ALBUMS_TRANSACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_GALLERY3_TYPE_GET_ALBUMS_TRANSACTION, PublishingGallery3GetAlbumsTransactionClass))

typedef struct _PublishingGallery3GetAlbumsTransaction PublishingGallery3GetAlbumsTransaction;
typedef struct _PublishingGallery3GetAlbumsTransactionClass PublishingGallery3GetAlbumsTransactionClass;
typedef struct _PublishingGallery3GetAlbumsTransactionPrivate PublishingGallery3GetAlbumsTransactionPrivate;
#define _publishing_gallery3_album_unref0(var) ((var == NULL) ? NULL : (var = (publishing_gallery3_album_unref (var), NULL)))

#define PUBLISHING_GALLERY3_TYPE_GALLERY_GET_TAG_TRANSACTION (publishing_gallery3_gallery_get_tag_transaction_get_type ())
#define PUBLISHING_GALLERY3_GALLERY_GET_TAG_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_GALLERY3_TYPE_GALLERY_GET_TAG_TRANSACTION, PublishingGallery3GalleryGetTagTransaction))
#define PUBLISHING_GALLERY3_GALLERY_GET_TAG_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_GALLERY3_TYPE_GALLERY_GET_TAG_TRANSACTION, PublishingGallery3GalleryGetTagTransactionClass))
#define PUBLISHING_GALLERY3_IS_GALLERY_GET_TAG_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_GALLERY3_TYPE_GALLERY_GET_TAG_TRANSACTION))
#define PUBLISHING_GALLERY3_IS_GALLERY_GET_TAG_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_GALLERY3_TYPE_GALLERY_GET_TAG_TRANSACTION))
#define PUBLISHING_GALLERY3_GALLERY_GET_TAG_TRANSACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_GALLERY3_TYPE_GALLERY_GET_TAG_TRANSACTION, PublishingGallery3GalleryGetTagTransactionClass))

typedef struct _PublishingGallery3GalleryGetTagTransaction PublishingGallery3GalleryGetTagTransaction;
typedef struct _PublishingGallery3GalleryGetTagTransactionClass PublishingGallery3GalleryGetTagTransactionClass;
typedef struct _PublishingGallery3GalleryGetTagTransactionPrivate PublishingGallery3GalleryGetTagTransactionPrivate;
#define _json_object_unref0(var) ((var == NULL) ? NULL : (var = (json_object_unref (var), NULL)))
#define __vala_JsonNode_free0(var) ((var == NULL) ? NULL : (var = (_vala_JsonNode_free (var), NULL)))

#define PUBLISHING_GALLERY3_TYPE_GALLERY_GET_ITEM_TAGS_UR_LS_TRANSACTION (publishing_gallery3_gallery_get_item_tags_ur_ls_transaction_get_type ())
#define PUBLISHING_GALLERY3_GALLERY_GET_ITEM_TAGS_UR_LS_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_GALLERY3_TYPE_GALLERY_GET_ITEM_TAGS_UR_LS_TRANSACTION, PublishingGallery3GalleryGetItemTagsURLsTransaction))
#define PUBLISHING_GALLERY3_GALLERY_GET_ITEM_TAGS_UR_LS_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_GALLERY3_TYPE_GALLERY_GET_ITEM_TAGS_UR_LS_TRANSACTION, PublishingGallery3GalleryGetItemTagsURLsTransactionClass))
#define PUBLISHING_GALLERY3_IS_GALLERY_GET_ITEM_TAGS_UR_LS_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_GALLERY3_TYPE_GALLERY_GET_ITEM_TAGS_UR_LS_TRANSACTION))
#define PUBLISHING_GALLERY3_IS_GALLERY_GET_ITEM_TAGS_UR_LS_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_GALLERY3_TYPE_GALLERY_GET_ITEM_TAGS_UR_LS_TRANSACTION))
#define PUBLISHING_GALLERY3_GALLERY_GET_ITEM_TAGS_UR_LS_TRANSACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_GALLERY3_TYPE_GALLERY_GET_ITEM_TAGS_UR_LS_TRANSACTION, PublishingGallery3GalleryGetItemTagsURLsTransactionClass))

typedef struct _PublishingGallery3GalleryGetItemTagsURLsTransaction PublishingGallery3GalleryGetItemTagsURLsTransaction;
typedef struct _PublishingGallery3GalleryGetItemTagsURLsTransactionClass PublishingGallery3GalleryGetItemTagsURLsTransactionClass;
typedef struct _PublishingGallery3GalleryGetItemTagsURLsTransactionPrivate PublishingGallery3GalleryGetItemTagsURLsTransactionPrivate;

#define PUBLISHING_GALLERY3_TYPE_GALLERY_SET_TAG_RELATIONSHIP_TRANSACTION (publishing_gallery3_gallery_set_tag_relationship_transaction_get_type ())
#define PUBLISHING_GALLERY3_GALLERY_SET_TAG_RELATIONSHIP_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_GALLERY3_TYPE_GALLERY_SET_TAG_RELATIONSHIP_TRANSACTION, PublishingGallery3GallerySetTagRelationshipTransaction))
#define PUBLISHING_GALLERY3_GALLERY_SET_TAG_RELATIONSHIP_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_GALLERY3_TYPE_GALLERY_SET_TAG_RELATIONSHIP_TRANSACTION, PublishingGallery3GallerySetTagRelationshipTransactionClass))
#define PUBLISHING_GALLERY3_IS_GALLERY_SET_TAG_RELATIONSHIP_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_GALLERY3_TYPE_GALLERY_SET_TAG_RELATIONSHIP_TRANSACTION))
#define PUBLISHING_GALLERY3_IS_GALLERY_SET_TAG_RELATIONSHIP_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_GALLERY3_TYPE_GALLERY_SET_TAG_RELATIONSHIP_TRANSACTION))
#define PUBLISHING_GALLERY3_GALLERY_SET_TAG_RELATIONSHIP_TRANSACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_GALLERY3_TYPE_GALLERY_SET_TAG_RELATIONSHIP_TRANSACTION, PublishingGallery3GallerySetTagRelationshipTransactionClass))

typedef struct _PublishingGallery3GallerySetTagRelationshipTransaction PublishingGallery3GallerySetTagRelationshipTransaction;
typedef struct _PublishingGallery3GallerySetTagRelationshipTransactionClass PublishingGallery3GallerySetTagRelationshipTransactionClass;
typedef struct _PublishingGallery3GallerySetTagRelationshipTransactionPrivate PublishingGallery3GallerySetTagRelationshipTransactionPrivate;

#define PUBLISHING_GALLERY3_TYPE_GALLERY_ALBUM_CREATE_TRANSACTION (publishing_gallery3_gallery_album_create_transaction_get_type ())
#define PUBLISHING_GALLERY3_GALLERY_ALBUM_CREATE_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_GALLERY3_TYPE_GALLERY_ALBUM_CREATE_TRANSACTION, PublishingGallery3GalleryAlbumCreateTransaction))
#define PUBLISHING_GALLERY3_GALLERY_ALBUM_CREATE_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_GALLERY3_TYPE_GALLERY_ALBUM_CREATE_TRANSACTION, PublishingGallery3GalleryAlbumCreateTransactionClass))
#define PUBLISHING_GALLERY3_IS_GALLERY_ALBUM_CREATE_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_GALLERY3_TYPE_GALLERY_ALBUM_CREATE_TRANSACTION))
#define PUBLISHING_GALLERY3_IS_GALLERY_ALBUM_CREATE_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_GALLERY3_TYPE_GALLERY_ALBUM_CREATE_TRANSACTION))
#define PUBLISHING_GALLERY3_GALLERY_ALBUM_CREATE_TRANSACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_GALLERY3_TYPE_GALLERY_ALBUM_CREATE_TRANSACTION, PublishingGallery3GalleryAlbumCreateTransactionClass))

typedef struct _PublishingGallery3GalleryAlbumCreateTransaction PublishingGallery3GalleryAlbumCreateTransaction;
typedef struct _PublishingGallery3GalleryAlbumCreateTransactionClass PublishingGallery3GalleryAlbumCreateTransactionClass;
typedef struct _PublishingGallery3GalleryAlbumCreateTransactionPrivate PublishingGallery3GalleryAlbumCreateTransactionPrivate;

#define PUBLISHING_GALLERY3_TYPE_PUBLISHING_PARAMETERS (publishing_gallery3_publishing_parameters_get_type ())
#define PUBLISHING_GALLERY3_PUBLISHING_PARAMETERS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_GALLERY3_TYPE_PUBLISHING_PARAMETERS, PublishingGallery3PublishingParameters))
#define PUBLISHING_GALLERY3_PUBLISHING_PARAMETERS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_GALLERY3_TYPE_PUBLISHING_PARAMETERS, PublishingGallery3PublishingParametersClass))
#define PUBLISHING_GALLERY3_IS_PUBLISHING_PARAMETERS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_GALLERY3_TYPE_PUBLISHING_PARAMETERS))
#define PUBLISHING_GALLERY3_IS_PUBLISHING_PARAMETERS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_GALLERY3_TYPE_PUBLISHING_PARAMETERS))
#define PUBLISHING_GALLERY3_PUBLISHING_PARAMETERS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_GALLERY3_TYPE_PUBLISHING_PARAMETERS, PublishingGallery3PublishingParametersClass))

typedef struct _PublishingGallery3PublishingParameters PublishingGallery3PublishingParameters;
typedef struct _PublishingGallery3PublishingParametersClass PublishingGallery3PublishingParametersClass;
#define _publishing_gallery3_publishing_parameters_unref0(var) ((var == NULL) ? NULL : (var = (publishing_gallery3_publishing_parameters_unref (var), NULL)))

#define PUBLISHING_GALLERY3_TYPE_GALLERY_UPLOAD_TRANSACTION (publishing_gallery3_gallery_upload_transaction_get_type ())
#define PUBLISHING_GALLERY3_GALLERY_UPLOAD_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_GALLERY3_TYPE_GALLERY_UPLOAD_TRANSACTION, PublishingGallery3GalleryUploadTransaction))
#define PUBLISHING_GALLERY3_GALLERY_UPLOAD_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_GALLERY3_TYPE_GALLERY_UPLOAD_TRANSACTION, PublishingGallery3GalleryUploadTransactionClass))
#define PUBLISHING_GALLERY3_IS_GALLERY_UPLOAD_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_GALLERY3_TYPE_GALLERY_UPLOAD_TRANSACTION))
#define PUBLISHING_GALLERY3_IS_GALLERY_UPLOAD_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_GALLERY3_TYPE_GALLERY_UPLOAD_TRANSACTION))
#define PUBLISHING_GALLERY3_GALLERY_UPLOAD_TRANSACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_GALLERY3_TYPE_GALLERY_UPLOAD_TRANSACTION, PublishingGallery3GalleryUploadTransactionClass))

typedef struct _PublishingGallery3GalleryUploadTransaction PublishingGallery3GalleryUploadTransaction;
typedef struct _PublishingGallery3GalleryUploadTransactionClass PublishingGallery3GalleryUploadTransactionClass;
typedef struct _PublishingGallery3GalleryUploadTransactionPrivate PublishingGallery3GalleryUploadTransactionPrivate;
#define _publishing_rest_support_session_unref0(var) ((var == NULL) ? NULL : (var = (publishing_rest_support_session_unref (var), NULL)))
#define _g_hash_table_unref0(var) ((var == NULL) ? NULL : (var = (g_hash_table_unref (var), NULL)))
#define _publishing_rest_support_transaction_unref0(var) ((var == NULL) ? NULL : (var = (publishing_rest_support_transaction_unref (var), NULL)))
typedef struct _PublishingGallery3GalleryPublisherPrivate PublishingGallery3GalleryPublisherPrivate;

#define PUBLISHING_GALLERY3_TYPE_PUBLISHING_OPTIONS_PANE (publishing_gallery3_publishing_options_pane_get_type ())
#define PUBLISHING_GALLERY3_PUBLISHING_OPTIONS_PANE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_GALLERY3_TYPE_PUBLISHING_OPTIONS_PANE, PublishingGallery3PublishingOptionsPane))
#define PUBLISHING_GALLERY3_PUBLISHING_OPTIONS_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_GALLERY3_TYPE_PUBLISHING_OPTIONS_PANE, PublishingGallery3PublishingOptionsPaneClass))
#define PUBLISHING_GALLERY3_IS_PUBLISHING_OPTIONS_PANE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_GALLERY3_TYPE_PUBLISHING_OPTIONS_PANE))
#define PUBLISHING_GALLERY3_IS_PUBLISHING_OPTIONS_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_GALLERY3_TYPE_PUBLISHING_OPTIONS_PANE))
#define PUBLISHING_GALLERY3_PUBLISHING_OPTIONS_PANE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_GALLERY3_TYPE_PUBLISHING_OPTIONS_PANE, PublishingGallery3PublishingOptionsPaneClass))

typedef struct _PublishingGallery3PublishingOptionsPane PublishingGallery3PublishingOptionsPane;
typedef struct _PublishingGallery3PublishingOptionsPaneClass PublishingGallery3PublishingOptionsPaneClass;

#define PUBLISHING_GALLERY3_CREDENTIALS_PANE_TYPE_MODE (publishing_gallery3_credentials_pane_mode_get_type ())

#define PUBLISHING_GALLERY3_TYPE_CREDENTIALS_PANE (publishing_gallery3_credentials_pane_get_type ())
#define PUBLISHING_GALLERY3_CREDENTIALS_PANE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_GALLERY3_TYPE_CREDENTIALS_PANE, PublishingGallery3CredentialsPane))
#define PUBLISHING_GALLERY3_CREDENTIALS_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_GALLERY3_TYPE_CREDENTIALS_PANE, PublishingGallery3CredentialsPaneClass))
#define PUBLISHING_GALLERY3_IS_CREDENTIALS_PANE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_GALLERY3_TYPE_CREDENTIALS_PANE))
#define PUBLISHING_GALLERY3_IS_CREDENTIALS_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_GALLERY3_TYPE_CREDENTIALS_PANE))
#define PUBLISHING_GALLERY3_CREDENTIALS_PANE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_GALLERY3_TYPE_CREDENTIALS_PANE, PublishingGallery3CredentialsPaneClass))

typedef struct _PublishingGallery3CredentialsPane PublishingGallery3CredentialsPane;
typedef struct _PublishingGallery3CredentialsPaneClass PublishingGallery3CredentialsPaneClass;

#define PUBLISHING_GALLERY3_TYPE_UPLOADER (publishing_gallery3_uploader_get_type ())
#define PUBLISHING_GALLERY3_UPLOADER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_GALLERY3_TYPE_UPLOADER, PublishingGallery3Uploader))
#define PUBLISHING_GALLERY3_UPLOADER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_GALLERY3_TYPE_UPLOADER, PublishingGallery3UploaderClass))
#define PUBLISHING_GALLERY3_IS_UPLOADER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_GALLERY3_TYPE_UPLOADER))
#define PUBLISHING_GALLERY3_IS_UPLOADER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_GALLERY3_TYPE_UPLOADER))
#define PUBLISHING_GALLERY3_UPLOADER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_GALLERY3_TYPE_UPLOADER, PublishingGallery3UploaderClass))

typedef struct _PublishingGallery3Uploader PublishingGallery3Uploader;
typedef struct _PublishingGallery3UploaderClass PublishingGallery3UploaderClass;
#define _publishing_rest_support_batch_uploader_unref0(var) ((var == NULL) ? NULL : (var = (publishing_rest_support_batch_uploader_unref (var), NULL)))
typedef struct _PublishingGallery3PublishingOptionsPanePrivate PublishingGallery3PublishingOptionsPanePrivate;
#define _g_slist_free0(var) ((var == NULL) ? NULL : (var = (g_slist_free (var), NULL)))
typedef struct _PublishingGallery3PublishingParametersPrivate PublishingGallery3PublishingParametersPrivate;
typedef struct _PublishingGallery3ParamSpecPublishingParameters PublishingGallery3ParamSpecPublishingParameters;
typedef struct _PublishingGallery3CredentialsPanePrivate PublishingGallery3CredentialsPanePrivate;

#define PUBLISHING_GALLERY3_TYPE_CREDENTIALS_GRID (publishing_gallery3_credentials_grid_get_type ())
#define PUBLISHING_GALLERY3_CREDENTIALS_GRID(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_GALLERY3_TYPE_CREDENTIALS_GRID, PublishingGallery3CredentialsGrid))
#define PUBLISHING_GALLERY3_CREDENTIALS_GRID_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_GALLERY3_TYPE_CREDENTIALS_GRID, PublishingGallery3CredentialsGridClass))
#define PUBLISHING_GALLERY3_IS_CREDENTIALS_GRID(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_GALLERY3_TYPE_CREDENTIALS_GRID))
#define PUBLISHING_GALLERY3_IS_CREDENTIALS_GRID_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_GALLERY3_TYPE_CREDENTIALS_GRID))
#define PUBLISHING_GALLERY3_CREDENTIALS_GRID_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_GALLERY3_TYPE_CREDENTIALS_GRID, PublishingGallery3CredentialsGridClass))

typedef struct _PublishingGallery3CredentialsGrid PublishingGallery3CredentialsGrid;
typedef struct _PublishingGallery3CredentialsGridClass PublishingGallery3CredentialsGridClass;
typedef struct _PublishingGallery3CredentialsGridPrivate PublishingGallery3CredentialsGridPrivate;
typedef struct _PublishingGallery3SessionPrivate PublishingGallery3SessionPrivate;
typedef struct _PublishingGallery3UploaderPrivate PublishingGallery3UploaderPrivate;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _ShotwellPublishingGallery3 {
	GObject parent_instance;
	ShotwellPublishingGallery3Private * priv;
};

struct _ShotwellPublishingGallery3Class {
	GObjectClass parent_class;
};

struct _ShotwellPublishingGallery3Private {
	SpitPluggable** pluggables;
	gint pluggables_length1;
	gint _pluggables_size_;
};

struct _Gallery3Service {
	GObject parent_instance;
	Gallery3ServicePrivate * priv;
};

struct _Gallery3ServiceClass {
	GObjectClass parent_class;
};

struct _PublishingGallery3Album {
	GTypeInstance parent_instance;
	volatile int ref_count;
	PublishingGallery3AlbumPrivate * priv;
};

struct _PublishingGallery3AlbumClass {
	GTypeClass parent_class;
	void (*finalize) (PublishingGallery3Album *self);
};

struct _PublishingGallery3AlbumPrivate {
	gchar* _name;
	gchar* _title;
	gchar* _summary;
	gchar* _parentname;
	gchar* _url;
	gchar* _path;
	gboolean _editable;
};

struct _PublishingGallery3ParamSpecAlbum {
	GParamSpec parent_instance;
};

struct _PublishingGallery3BaseGalleryTransaction {
	PublishingRESTSupportTransaction parent_instance;
	PublishingGallery3BaseGalleryTransactionPrivate * priv;
	JsonParser* parser;
};

struct _PublishingGallery3BaseGalleryTransactionClass {
	PublishingRESTSupportTransactionClass parent_class;
};

struct _PublishingGallery3KeyFetchTransaction {
	PublishingGallery3BaseGalleryTransaction parent_instance;
	PublishingGallery3KeyFetchTransactionPrivate * priv;
};

struct _PublishingGallery3KeyFetchTransactionClass {
	PublishingGallery3BaseGalleryTransactionClass parent_class;
};

struct _PublishingGallery3KeyFetchTransactionPrivate {
	gchar* key;
};

struct _PublishingGallery3GalleryRequestTransaction {
	PublishingGallery3BaseGalleryTransaction parent_instance;
	PublishingGallery3GalleryRequestTransactionPrivate * priv;
};

struct _PublishingGallery3GalleryRequestTransactionClass {
	PublishingGallery3BaseGalleryTransactionClass parent_class;
};

struct _PublishingGallery3GetAlbumURLsTransaction {
	PublishingGallery3GalleryRequestTransaction parent_instance;
	PublishingGallery3GetAlbumURLsTransactionPrivate * priv;
};

struct _PublishingGallery3GetAlbumURLsTransactionClass {
	PublishingGallery3GalleryRequestTransactionClass parent_class;
};

struct _PublishingGallery3GetAlbumsTransaction {
	PublishingGallery3GalleryRequestTransaction parent_instance;
	PublishingGallery3GetAlbumsTransactionPrivate * priv;
};

struct _PublishingGallery3GetAlbumsTransactionClass {
	PublishingGallery3GalleryRequestTransactionClass parent_class;
};

struct _PublishingGallery3GetAlbumsTransactionPrivate {
	gchar** _album_urls;
	gint _album_urls_length1;
	gint __album_urls_size_;
	guint _urls_sent;
	gboolean _more_urls;
};

struct _PublishingGallery3GalleryGetTagTransaction {
	PublishingGallery3BaseGalleryTransaction parent_instance;
	PublishingGallery3GalleryGetTagTransactionPrivate * priv;
};

struct _PublishingGallery3GalleryGetTagTransactionClass {
	PublishingGallery3BaseGalleryTransactionClass parent_class;
};

struct _PublishingGallery3GalleryGetItemTagsURLsTransaction {
	PublishingGallery3GalleryRequestTransaction parent_instance;
	PublishingGallery3GalleryGetItemTagsURLsTransactionPrivate * priv;
};

struct _PublishingGallery3GalleryGetItemTagsURLsTransactionClass {
	PublishingGallery3GalleryRequestTransactionClass parent_class;
};

struct _PublishingGallery3GalleryGetItemTagsURLsTransactionPrivate {
	gchar* item_tags_path;
};

struct _PublishingGallery3GallerySetTagRelationshipTransaction {
	PublishingGallery3BaseGalleryTransaction parent_instance;
	PublishingGallery3GallerySetTagRelationshipTransactionPrivate * priv;
};

struct _PublishingGallery3GallerySetTagRelationshipTransactionClass {
	PublishingGallery3BaseGalleryTransactionClass parent_class;
};

struct _PublishingGallery3GalleryAlbumCreateTransaction {
	PublishingGallery3BaseGalleryTransaction parent_instance;
	PublishingGallery3GalleryAlbumCreateTransactionPrivate * priv;
};

struct _PublishingGallery3GalleryAlbumCreateTransactionClass {
	PublishingGallery3BaseGalleryTransactionClass parent_class;
};

struct _PublishingGallery3GalleryAlbumCreateTransactionPrivate {
	PublishingGallery3PublishingParameters* _parameters;
	gchar* session_url;
};

struct _PublishingGallery3GalleryUploadTransaction {
	PublishingRESTSupportUploadTransaction parent_instance;
	PublishingGallery3GalleryUploadTransactionPrivate * priv;
};

struct _PublishingGallery3GalleryUploadTransactionClass {
	PublishingRESTSupportUploadTransactionClass parent_class;
};

struct _PublishingGallery3GalleryUploadTransactionPrivate {
	PublishingGallery3Session* session;
	JsonGenerator* generator;
	PublishingGallery3PublishingParameters* parameters;
	gchar* item_url;
	gchar* item_path;
	gchar* item_tags_path;
};

struct _PublishingGallery3GalleryPublisher {
	GObject parent_instance;
	PublishingGallery3GalleryPublisherPrivate * priv;
};

struct _PublishingGallery3GalleryPublisherClass {
	GObjectClass parent_class;
};

struct _PublishingGallery3GalleryPublisherPrivate {
	SpitPublishingPluginHost* host;
	SpitPublishingProgressCallback progress_reporter;
	gpointer progress_reporter_target;
	GDestroyNotify progress_reporter_target_destroy_notify;
	SpitPublishingService* service;
	PublishingGallery3Session* session;
	gboolean running;
	PublishingGallery3Album** albums;
	gint albums_length1;
	gint _albums_size_;
	gchar* key;
	PublishingGallery3PublishingOptionsPane* publishing_options_pane;
};

typedef enum  {
	PUBLISHING_GALLERY3_CREDENTIALS_PANE_MODE_INTRO,
	PUBLISHING_GALLERY3_CREDENTIALS_PANE_MODE_FAILED_RETRY,
	PUBLISHING_GALLERY3_CREDENTIALS_PANE_MODE_NOT_GALLERY_URL
} PublishingGallery3CredentialsPaneMode;

struct _PublishingGallery3PublishingOptionsPane {
	GObject parent_instance;
	PublishingGallery3PublishingOptionsPanePrivate * priv;
};

struct _PublishingGallery3PublishingOptionsPaneClass {
	GObjectClass parent_class;
};

struct _PublishingGallery3PublishingOptionsPanePrivate {
	GtkBuilder* builder;
	GtkGrid* pane_widget;
	GtkLabel* title_label;
	GtkRadioButton* use_existing_radio;
	GtkComboBoxText* existing_albums_combo;
	GtkRadioButton* create_new_radio;
	GtkEntry* new_album_entry;
	GtkComboBoxText* scaling_combo;
	GtkEntry* pixels;
	GtkCheckButton* strip_metadata_check;
	GtkButton* publish_button;
	GtkButton* logout_button;
	PublishingGallery3Album** albums;
	gint albums_length1;
	gint _albums_size_;
	SpitPublishingPluginHost* host;
};

struct _PublishingGallery3PublishingParameters {
	GTypeInstance parent_instance;
	volatile int ref_count;
	PublishingGallery3PublishingParametersPrivate * priv;
};

struct _PublishingGallery3PublishingParametersClass {
	GTypeClass parent_class;
	void (*finalize) (PublishingGallery3PublishingParameters *self);
};

struct _PublishingGallery3PublishingParametersPrivate {
	gchar* _album_title;
	gchar* _album_name;
	gchar* _album_path;
	gchar* _entity_title;
	gint _photo_major_axis_size;
	gboolean _strip_metadata;
};

struct _PublishingGallery3ParamSpecPublishingParameters {
	GParamSpec parent_instance;
};

struct _PublishingGallery3CredentialsPane {
	GObject parent_instance;
	PublishingGallery3CredentialsPanePrivate * priv;
};

struct _PublishingGallery3CredentialsPaneClass {
	GObjectClass parent_class;
};

struct _PublishingGallery3CredentialsPanePrivate {
	PublishingGallery3CredentialsGrid* frame;
	GtkWidget* grid_widget;
};

struct _PublishingGallery3CredentialsGrid {
	GObject parent_instance;
	PublishingGallery3CredentialsGridPrivate * priv;
};

struct _PublishingGallery3CredentialsGridClass {
	GObjectClass parent_class;
};

struct _PublishingGallery3CredentialsGridPrivate {
	GtkGrid* _pane_widget;
	SpitPublishingPluginHost* host;
	GtkBuilder* builder;
	GtkLabel* intro_message_label;
	GtkEntry* url_entry;
	GtkEntry* username_entry;
	GtkEntry* password_entry;
	GtkEntry* key_entry;
	GtkButton* login_button;
	GtkButton* go_back_button;
	gchar* url;
	gchar* username;
	gchar* key;
};

struct _PublishingGallery3Session {
	PublishingRESTSupportSession parent_instance;
	PublishingGallery3SessionPrivate * priv;
};

struct _PublishingGallery3SessionClass {
	PublishingRESTSupportSessionClass parent_class;
};

struct _PublishingGallery3SessionPrivate {
	gchar* _url;
	gchar* _username;
	gchar* _key;
};

struct _PublishingGallery3Uploader {
	PublishingRESTSupportBatchUploader parent_instance;
	PublishingGallery3UploaderPrivate * priv;
};

struct _PublishingGallery3UploaderClass {
	PublishingRESTSupportBatchUploaderClass parent_class;
};

struct _PublishingGallery3UploaderPrivate {
	PublishingGallery3PublishingParameters* parameters;
	gchar* _current_publishable_name;
	SpitPublishingPublisherMediaType _current_media_type;
	PublishingRESTSupportTransaction* _current_transaction;
};


static gpointer shotwell_publishing_gallery3_parent_class = NULL;
static SpitModuleIface* shotwell_publishing_gallery3_spit_module_parent_iface = NULL;
static gpointer gallery3_service_parent_class = NULL;
static GdkPixbuf** gallery3_service_icon_pixbuf_set;
static gint gallery3_service_icon_pixbuf_set_length1;
static GdkPixbuf** gallery3_service_icon_pixbuf_set = NULL;
static gint gallery3_service_icon_pixbuf_set_length1 = 0;
static gint _gallery3_service_icon_pixbuf_set_size_ = 0;
static SpitPluggableIface* gallery3_service_spit_pluggable_parent_iface = NULL;
static SpitPublishingServiceIface* gallery3_service_spit_publishing_service_parent_iface = NULL;
static gpointer publishing_gallery3_album_parent_class = NULL;
static gpointer publishing_gallery3_base_gallery_transaction_parent_class = NULL;
static gpointer publishing_gallery3_key_fetch_transaction_parent_class = NULL;
static gpointer publishing_gallery3_gallery_request_transaction_parent_class = NULL;
static gpointer publishing_gallery3_get_album_ur_ls_transaction_parent_class = NULL;
static gpointer publishing_gallery3_get_albums_transaction_parent_class = NULL;
static gpointer publishing_gallery3_gallery_get_tag_transaction_parent_class = NULL;
static gpointer publishing_gallery3_gallery_get_item_tags_ur_ls_transaction_parent_class = NULL;
static gpointer publishing_gallery3_gallery_set_tag_relationship_transaction_parent_class = NULL;
static gpointer publishing_gallery3_gallery_album_create_transaction_parent_class = NULL;
static gpointer publishing_gallery3_gallery_upload_transaction_parent_class = NULL;
static gpointer publishing_gallery3_gallery_publisher_parent_class = NULL;
static SpitPublishingPublisherIface* publishing_gallery3_gallery_publisher_spit_publishing_publisher_parent_iface = NULL;
static gpointer publishing_gallery3_publishing_options_pane_parent_class = NULL;
static SpitPublishingDialogPaneIface* publishing_gallery3_publishing_options_pane_spit_publishing_dialog_pane_parent_iface = NULL;
static gpointer publishing_gallery3_publishing_parameters_parent_class = NULL;
static gpointer publishing_gallery3_credentials_pane_parent_class = NULL;
static SpitPublishingDialogPaneIface* publishing_gallery3_credentials_pane_spit_publishing_dialog_pane_parent_iface = NULL;
static gpointer publishing_gallery3_credentials_grid_parent_class = NULL;
static gpointer publishing_gallery3_session_parent_class = NULL;
static gpointer publishing_gallery3_uploader_parent_class = NULL;

#define G3_VERSION "0.1"
#define G3_LICENSE "\n" \
"The Gallery3Publishing module is free software; you can redistribute i" \
"t\n" \
"and/or modify it under the terms of the GNU Lesser General Public\n" \
"License as published by the Free Software Foundation; either version 2" \
".1\n" \
"of the License, or (at your option) any later version.\n" \
"\n" \
"The Gallery3Publishing module is distributed in the hope that it will " \
"be\n" \
"useful, but WITHOUT ANY WARRANTY; without even the implied warranty of" \
"\n" \
"MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Less" \
"er\n" \
"General Public License for more details.\n" \
"\n" \
"You should have received a copy of the GNU Lesser General Public Licen" \
"se\n" \
"along with The Gallery3Publishing module; if not, write to the Free\n" \
"Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA\n" \
"02110-1301 USA\n"
#define WEBSITE_URL "https://github.com/sappjw/shotwell-gallery3"
GType shotwell_publishing_gallery3_get_type (void) G_GNUC_CONST;
#define SHOTWELL_PUBLISHING_GALLERY3_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_SHOTWELL_PUBLISHING_GALLERY3, ShotwellPublishingGallery3Private))
enum  {
	SHOTWELL_PUBLISHING_GALLERY3_DUMMY_PROPERTY
};
ShotwellPublishingGallery3* shotwell_publishing_gallery3_new (GFile* module_file);
ShotwellPublishingGallery3* shotwell_publishing_gallery3_construct (GType object_type, GFile* module_file);
Gallery3Service* gallery3_service_new (GFile* resource_directory);
Gallery3Service* gallery3_service_construct (GType object_type, GFile* resource_directory);
GType gallery3_service_get_type (void) G_GNUC_CONST;
static void _vala_array_add1 (SpitPluggable*** array, int* length, int* size, SpitPluggable* value);
static const gchar* shotwell_publishing_gallery3_real_get_module_name (SpitModule* base);
static const gchar* shotwell_publishing_gallery3_real_get_version (SpitModule* base);
static const gchar* shotwell_publishing_gallery3_real_get_id (SpitModule* base);
static SpitPluggable** shotwell_publishing_gallery3_real_get_pluggables (SpitModule* base, int* result_length1);
static void shotwell_publishing_gallery3_finalize (GObject* obj);
enum  {
	GALLERY3_SERVICE_DUMMY_PROPERTY
};
#define GALLERY3_SERVICE_ICON_FILENAME "gallery3.png"
static gint gallery3_service_real_get_pluggable_interface (SpitPluggable* base, gint min_host_interface, gint max_host_interface);
static const gchar* gallery3_service_real_get_id (SpitPluggable* base);
static const gchar* gallery3_service_real_get_pluggable_name (SpitPluggable* base);
static void gallery3_service_real_get_info (SpitPluggable* base, SpitPluggableInfo* info);
static GdkPixbuf** _vala_array_dup1 (GdkPixbuf** self, int length);
static void gallery3_service_real_activation (SpitPluggable* base, gboolean enabled);
static SpitPublishingPublisher* gallery3_service_real_create_publisher (SpitPublishingService* base, SpitPublishingPluginHost* host);
PublishingGallery3GalleryPublisher* publishing_gallery3_gallery_publisher_new (SpitPublishingService* service, SpitPublishingPluginHost* host);
PublishingGallery3GalleryPublisher* publishing_gallery3_gallery_publisher_construct (GType object_type, SpitPublishingService* service, SpitPublishingPluginHost* host);
GType publishing_gallery3_gallery_publisher_get_type (void) G_GNUC_CONST;
static SpitPublishingPublisherMediaType gallery3_service_real_get_supported_media (SpitPublishingService* base);
static void gallery3_service_finalize (GObject* obj);
#define PUBLISHING_GALLERY3_SERVICE_NAME "Gallery3"
#define PUBLISHING_GALLERY3_SERVICE_WELCOME_MESSAGE _ ("You are not currently logged into your Gallery.\n" \
"\n" \
"You must have already signed up for a Gallery3 account to complete the" \
" login process.")
#define PUBLISHING_GALLERY3_DEFAULT_ALBUM_DIR _ ("Shotwell")
#define PUBLISHING_GALLERY3_DEFAULT_ALBUM_TITLE _ ("Shotwell default directory")
#define PUBLISHING_GALLERY3_REST_PATH "/index.php/rest"
gpointer publishing_gallery3_album_ref (gpointer instance);
void publishing_gallery3_album_unref (gpointer instance);
GParamSpec* publishing_gallery3_param_spec_album (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void publishing_gallery3_value_set_album (GValue* value, gpointer v_object);
void publishing_gallery3_value_take_album (GValue* value, gpointer v_object);
gpointer publishing_gallery3_value_get_album (const GValue* value);
GType publishing_gallery3_album_get_type (void) G_GNUC_CONST;
#define PUBLISHING_GALLERY3_ALBUM_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_GALLERY3_TYPE_ALBUM, PublishingGallery3AlbumPrivate))
enum  {
	PUBLISHING_GALLERY3_ALBUM_DUMMY_PROPERTY
};
PublishingGallery3Album* publishing_gallery3_album_new (JsonObject* collection);
PublishingGallery3Album* publishing_gallery3_album_construct (GType object_type, JsonObject* collection);
static void publishing_gallery3_album_set_title (PublishingGallery3Album* self, const gchar* value);
static void publishing_gallery3_album_set_name (PublishingGallery3Album* self, const gchar* value);
static void publishing_gallery3_album_set_parentname (PublishingGallery3Album* self, const gchar* value);
static void publishing_gallery3_album_set_url (PublishingGallery3Album* self, const gchar* value);
static void publishing_gallery3_album_set_editable (PublishingGallery3Album* self, gboolean value);
gchar* publishing_gallery3_strip_session_url (const gchar* url);
const gchar* publishing_gallery3_album_get_url (PublishingGallery3Album* self);
static void publishing_gallery3_album_set_path (PublishingGallery3Album* self, const gchar* value);
const gchar* publishing_gallery3_album_get_name (PublishingGallery3Album* self);
const gchar* publishing_gallery3_album_get_title (PublishingGallery3Album* self);
const gchar* publishing_gallery3_album_get_summary (PublishingGallery3Album* self);
static void publishing_gallery3_album_set_summary (PublishingGallery3Album* self, const gchar* value);
const gchar* publishing_gallery3_album_get_parentname (PublishingGallery3Album* self);
const gchar* publishing_gallery3_album_get_path (PublishingGallery3Album* self);
gboolean publishing_gallery3_album_get_editable (PublishingGallery3Album* self);
static void publishing_gallery3_album_finalize (PublishingGallery3Album* obj);
GType publishing_gallery3_base_gallery_transaction_get_type (void) G_GNUC_CONST;
enum  {
	PUBLISHING_GALLERY3_BASE_GALLERY_TRANSACTION_DUMMY_PROPERTY
};
GType publishing_gallery3_session_get_type (void) G_GNUC_CONST;
PublishingGallery3BaseGalleryTransaction* publishing_gallery3_base_gallery_transaction_new (PublishingGallery3Session* session, const gchar* endpoint_url, const gchar* item_path, PublishingRESTSupportHttpMethod method);
PublishingGallery3BaseGalleryTransaction* publishing_gallery3_base_gallery_transaction_construct (GType object_type, PublishingGallery3Session* session, const gchar* endpoint_url, const gchar* item_path, PublishingRESTSupportHttpMethod method);
JsonNode* publishing_gallery3_base_gallery_transaction_get_root_node (PublishingGallery3BaseGalleryTransaction* self, GError** error);
static void publishing_gallery3_base_gallery_transaction_finalize (PublishingRESTSupportTransaction* obj);
GType publishing_gallery3_key_fetch_transaction_get_type (void) G_GNUC_CONST;
#define PUBLISHING_GALLERY3_KEY_FETCH_TRANSACTION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_GALLERY3_TYPE_KEY_FETCH_TRANSACTION, PublishingGallery3KeyFetchTransactionPrivate))
enum  {
	PUBLISHING_GALLERY3_KEY_FETCH_TRANSACTION_DUMMY_PROPERTY
};
PublishingGallery3KeyFetchTransaction* publishing_gallery3_key_fetch_transaction_new (PublishingGallery3Session* session, const gchar* url, const gchar* username, const gchar* password);
PublishingGallery3KeyFetchTransaction* publishing_gallery3_key_fetch_transaction_construct (GType object_type, PublishingGallery3Session* session, const gchar* url, const gchar* username, const gchar* password);
gchar* publishing_gallery3_key_fetch_transaction_get_key (PublishingGallery3KeyFetchTransaction* self);
static void publishing_gallery3_key_fetch_transaction_finalize (PublishingRESTSupportTransaction* obj);
GType publishing_gallery3_gallery_request_transaction_get_type (void) G_GNUC_CONST;
enum  {
	PUBLISHING_GALLERY3_GALLERY_REQUEST_TRANSACTION_DUMMY_PROPERTY
};
PublishingGallery3GalleryRequestTransaction* publishing_gallery3_gallery_request_transaction_new (PublishingGallery3Session* session, const gchar* item, PublishingRESTSupportHttpMethod method);
PublishingGallery3GalleryRequestTransaction* publishing_gallery3_gallery_request_transaction_construct (GType object_type, PublishingGallery3Session* session, const gchar* item, PublishingRESTSupportHttpMethod method);
const gchar* publishing_gallery3_session_get_url (PublishingGallery3Session* self);
const gchar* publishing_gallery3_session_get_key (PublishingGallery3Session* self);
GType publishing_gallery3_get_album_ur_ls_transaction_get_type (void) G_GNUC_CONST;
enum  {
	PUBLISHING_GALLERY3_GET_ALBUM_UR_LS_TRANSACTION_DUMMY_PROPERTY
};
PublishingGallery3GetAlbumURLsTransaction* publishing_gallery3_get_album_ur_ls_transaction_new (PublishingGallery3Session* session);
PublishingGallery3GetAlbumURLsTransaction* publishing_gallery3_get_album_ur_ls_transaction_construct (GType object_type, PublishingGallery3Session* session);
gchar** publishing_gallery3_get_album_ur_ls_transaction_get_album_urls (PublishingGallery3GetAlbumURLsTransaction* self, int* result_length1);
static void _vala_array_add2 (gchar*** array, int* length, int* size, gchar* value);
GType publishing_gallery3_get_albums_transaction_get_type (void) G_GNUC_CONST;
#define PUBLISHING_GALLERY3_GET_ALBUMS_TRANSACTION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_GALLERY3_TYPE_GET_ALBUMS_TRANSACTION, PublishingGallery3GetAlbumsTransactionPrivate))
enum  {
	PUBLISHING_GALLERY3_GET_ALBUMS_TRANSACTION_DUMMY_PROPERTY
};
PublishingGallery3GetAlbumsTransaction* publishing_gallery3_get_albums_transaction_new (PublishingGallery3Session* session, gchar** _album_urls, int _album_urls_length1, guint start);
PublishingGallery3GetAlbumsTransaction* publishing_gallery3_get_albums_transaction_construct (GType object_type, PublishingGallery3Session* session, gchar** _album_urls, int _album_urls_length1, guint start);
static void publishing_gallery3_get_albums_transaction_set_album_urls (PublishingGallery3GetAlbumsTransaction* self, gchar** value, int value_length1);
gchar** publishing_gallery3_get_albums_transaction_get_album_urls (PublishingGallery3GetAlbumsTransaction* self, int* result_length1);
static void publishing_gallery3_get_albums_transaction_set_urls_sent (PublishingGallery3GetAlbumsTransaction* self, guint value);
guint publishing_gallery3_get_albums_transaction_get_urls_sent (PublishingGallery3GetAlbumsTransaction* self);
static void _vala_array_add3 (gchar*** array, int* length, int* size, gchar* value);
static void publishing_gallery3_get_albums_transaction_set_more_urls (PublishingGallery3GetAlbumsTransaction* self, gboolean value);
PublishingGallery3Album** publishing_gallery3_get_albums_transaction_get_albums (PublishingGallery3GetAlbumsTransaction* self, int* result_length1, GError** error);
static void _vala_array_add4 (PublishingGallery3Album*** array, int* length, int* size, PublishingGallery3Album* value);
static gchar** _vala_array_dup2 (gchar** self, int length);
gboolean publishing_gallery3_get_albums_transaction_get_more_urls (PublishingGallery3GetAlbumsTransaction* self);
static void publishing_gallery3_get_albums_transaction_finalize (PublishingRESTSupportTransaction* obj);
GType publishing_gallery3_gallery_get_tag_transaction_get_type (void) G_GNUC_CONST;
enum  {
	PUBLISHING_GALLERY3_GALLERY_GET_TAG_TRANSACTION_DUMMY_PROPERTY
};
PublishingGallery3GalleryGetTagTransaction* publishing_gallery3_gallery_get_tag_transaction_new (PublishingGallery3Session* session, const gchar* tag_name);
PublishingGallery3GalleryGetTagTransaction* publishing_gallery3_gallery_get_tag_transaction_construct (GType object_type, PublishingGallery3Session* session, const gchar* tag_name);
static void _vala_JsonNode_free (JsonNode* self);
gchar* publishing_gallery3_gallery_get_tag_transaction_tag_url (PublishingGallery3GalleryGetTagTransaction* self);
GType publishing_gallery3_gallery_get_item_tags_ur_ls_transaction_get_type (void) G_GNUC_CONST;
#define PUBLISHING_GALLERY3_GALLERY_GET_ITEM_TAGS_UR_LS_TRANSACTION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_GALLERY3_TYPE_GALLERY_GET_ITEM_TAGS_UR_LS_TRANSACTION, PublishingGallery3GalleryGetItemTagsURLsTransactionPrivate))
enum  {
	PUBLISHING_GALLERY3_GALLERY_GET_ITEM_TAGS_UR_LS_TRANSACTION_DUMMY_PROPERTY
};
PublishingGallery3GalleryGetItemTagsURLsTransaction* publishing_gallery3_gallery_get_item_tags_ur_ls_transaction_new (PublishingGallery3Session* session, const gchar* item_url);
PublishingGallery3GalleryGetItemTagsURLsTransaction* publishing_gallery3_gallery_get_item_tags_ur_ls_transaction_construct (GType object_type, PublishingGallery3Session* session, const gchar* item_url);
gchar* publishing_gallery3_gallery_get_item_tags_ur_ls_transaction_get_item_tags_path (PublishingGallery3GalleryGetItemTagsURLsTransaction* self);
static void publishing_gallery3_gallery_get_item_tags_ur_ls_transaction_finalize (PublishingRESTSupportTransaction* obj);
GType publishing_gallery3_gallery_set_tag_relationship_transaction_get_type (void) G_GNUC_CONST;
enum  {
	PUBLISHING_GALLERY3_GALLERY_SET_TAG_RELATIONSHIP_TRANSACTION_DUMMY_PROPERTY
};
PublishingGallery3GallerySetTagRelationshipTransaction* publishing_gallery3_gallery_set_tag_relationship_transaction_new (PublishingGallery3Session* session, const gchar* item_tags_path, const gchar* tag_url, const gchar* item_url);
PublishingGallery3GallerySetTagRelationshipTransaction* publishing_gallery3_gallery_set_tag_relationship_transaction_construct (GType object_type, PublishingGallery3Session* session, const gchar* item_tags_path, const gchar* tag_url, const gchar* item_url);
GType publishing_gallery3_gallery_album_create_transaction_get_type (void) G_GNUC_CONST;
gpointer publishing_gallery3_publishing_parameters_ref (gpointer instance);
void publishing_gallery3_publishing_parameters_unref (gpointer instance);
GParamSpec* publishing_gallery3_param_spec_publishing_parameters (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void publishing_gallery3_value_set_publishing_parameters (GValue* value, gpointer v_object);
void publishing_gallery3_value_take_publishing_parameters (GValue* value, gpointer v_object);
gpointer publishing_gallery3_value_get_publishing_parameters (const GValue* value);
GType publishing_gallery3_publishing_parameters_get_type (void) G_GNUC_CONST;
#define PUBLISHING_GALLERY3_GALLERY_ALBUM_CREATE_TRANSACTION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_GALLERY3_TYPE_GALLERY_ALBUM_CREATE_TRANSACTION, PublishingGallery3GalleryAlbumCreateTransactionPrivate))
enum  {
	PUBLISHING_GALLERY3_GALLERY_ALBUM_CREATE_TRANSACTION_DUMMY_PROPERTY
};
PublishingGallery3GalleryAlbumCreateTransaction* publishing_gallery3_gallery_album_create_transaction_new (PublishingGallery3Session* session, PublishingGallery3PublishingParameters* parameters);
PublishingGallery3GalleryAlbumCreateTransaction* publishing_gallery3_gallery_album_create_transaction_construct (GType object_type, PublishingGallery3Session* session, PublishingGallery3PublishingParameters* parameters);
static void publishing_gallery3_gallery_album_create_transaction_set_parameters (PublishingGallery3GalleryAlbumCreateTransaction* self, PublishingGallery3PublishingParameters* value);
const gchar* publishing_gallery3_publishing_parameters_get_album_name (PublishingGallery3PublishingParameters* self);
const gchar* publishing_gallery3_publishing_parameters_get_album_title (PublishingGallery3PublishingParameters* self);
gchar* publishing_gallery3_gallery_album_create_transaction_get_new_album_path (PublishingGallery3GalleryAlbumCreateTransaction* self);
PublishingGallery3PublishingParameters* publishing_gallery3_gallery_album_create_transaction_get_parameters (PublishingGallery3GalleryAlbumCreateTransaction* self);
static void publishing_gallery3_gallery_album_create_transaction_finalize (PublishingRESTSupportTransaction* obj);
GType publishing_gallery3_gallery_upload_transaction_get_type (void) G_GNUC_CONST;
#define PUBLISHING_GALLERY3_GALLERY_UPLOAD_TRANSACTION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_GALLERY3_TYPE_GALLERY_UPLOAD_TRANSACTION, PublishingGallery3GalleryUploadTransactionPrivate))
enum  {
	PUBLISHING_GALLERY3_GALLERY_UPLOAD_TRANSACTION_DUMMY_PROPERTY
};
PublishingGallery3GalleryUploadTransaction* publishing_gallery3_gallery_upload_transaction_new (PublishingGallery3Session* session, PublishingGallery3PublishingParameters* parameters, SpitPublishingPublishable* publishable);
PublishingGallery3GalleryUploadTransaction* publishing_gallery3_gallery_upload_transaction_construct (GType object_type, PublishingGallery3Session* session, PublishingGallery3PublishingParameters* parameters, SpitPublishingPublishable* publishable);
const gchar* publishing_gallery3_publishing_parameters_get_album_path (PublishingGallery3PublishingParameters* self);
static void _g_free0_ (gpointer var);
static gchar* publishing_gallery3_gallery_upload_transaction_get_new_item_url (PublishingGallery3GalleryUploadTransaction* self);
static void publishing_gallery3_gallery_upload_transaction_do_set_tag_relationship (PublishingGallery3GalleryUploadTransaction* self, const gchar* tag_url, GError** error);
static gchar* publishing_gallery3_gallery_upload_transaction_get_new_item_tags_path (PublishingGallery3GalleryUploadTransaction* self);
static gchar* publishing_gallery3_gallery_upload_transaction_get_tag_url (PublishingGallery3GalleryUploadTransaction* self, const gchar* tag);
static void publishing_gallery3_gallery_upload_transaction_on_upload_completed (PublishingGallery3GalleryUploadTransaction* self, GError** error);
gboolean publishing_gallery3_publishing_parameters_get_strip_metadata (PublishingGallery3PublishingParameters* self);
static void publishing_gallery3_gallery_upload_transaction_real_execute (PublishingRESTSupportTransaction* base, GError** error);
static void publishing_gallery3_gallery_upload_transaction_finalize (PublishingRESTSupportTransaction* obj);
GType publishing_gallery3_publishing_options_pane_get_type (void) G_GNUC_CONST;
#define PUBLISHING_GALLERY3_GALLERY_PUBLISHER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_GALLERY3_TYPE_GALLERY_PUBLISHER, PublishingGallery3GalleryPublisherPrivate))
enum  {
	PUBLISHING_GALLERY3_GALLERY_PUBLISHER_DUMMY_PROPERTY
};
#define PUBLISHING_GALLERY3_GALLERY_PUBLISHER_BAD_FILE_MSG _ ("\n" \
"\n" \
"The file \"%s\" may not be supported by or may be too large for this i" \
"nstance of Gallery3.")
#define PUBLISHING_GALLERY3_GALLERY_PUBLISHER_BAD_MOVIE_MSG _ ("\n" \
"Note that Gallery3 only supports the video types that Flowplayer does.")
PublishingGallery3Session* publishing_gallery3_session_new (void);
PublishingGallery3Session* publishing_gallery3_session_construct (GType object_type);
static gboolean publishing_gallery3_gallery_publisher_real_is_running (SpitPublishingPublisher* base);
static SpitPublishingService* publishing_gallery3_gallery_publisher_real_get_service (SpitPublishingPublisher* base);
static void publishing_gallery3_gallery_publisher_real_start (SpitPublishingPublisher* base);
gchar* publishing_gallery3_gallery_publisher_get_api_key (PublishingGallery3GalleryPublisher* self);
static void publishing_gallery3_gallery_publisher_do_show_service_welcome_pane (PublishingGallery3GalleryPublisher* self);
gchar* publishing_gallery3_gallery_publisher_get_gallery_url (PublishingGallery3GalleryPublisher* self);
gchar* publishing_gallery3_gallery_publisher_get_gallery_username (PublishingGallery3GalleryPublisher* self);
void publishing_gallery3_session_authenticate (PublishingGallery3Session* self, const gchar* gallery_url, const gchar* username, const gchar* key);
static void publishing_gallery3_gallery_publisher_do_fetch_album_urls (PublishingGallery3GalleryPublisher* self);
static void publishing_gallery3_gallery_publisher_real_stop (SpitPublishingPublisher* base);
void publishing_gallery3_gallery_publisher_set_api_key (PublishingGallery3GalleryPublisher* self, const gchar* key);
void publishing_gallery3_gallery_publisher_set_gallery_url (PublishingGallery3GalleryPublisher* self, const gchar* url);
void publishing_gallery3_gallery_publisher_set_gallery_username (PublishingGallery3GalleryPublisher* self, const gchar* username);
gboolean* publishing_gallery3_gallery_publisher_get_persistent_strip_metadata (PublishingGallery3GalleryPublisher* self);
static gboolean* _bool_dup (gboolean* self);
void publishing_gallery3_gallery_publisher_set_persistent_strip_metadata (PublishingGallery3GalleryPublisher* self, gboolean strip_metadata);
gint* publishing_gallery3_gallery_publisher_get_scaling_constraint_id (PublishingGallery3GalleryPublisher* self);
static gint* _int_dup (gint* self);
void publishing_gallery3_gallery_publisher_set_scaling_constraint_id (PublishingGallery3GalleryPublisher* self, gint constraint);
gint* publishing_gallery3_gallery_publisher_get_scaling_pixels (PublishingGallery3GalleryPublisher* self);
void publishing_gallery3_gallery_publisher_set_scaling_pixels (PublishingGallery3GalleryPublisher* self, gint pixels);
static void publishing_gallery3_gallery_publisher_on_service_welcome_login (PublishingGallery3GalleryPublisher* self);
static void _publishing_gallery3_gallery_publisher_on_service_welcome_login_spit_publishing_login_callback (gpointer self);
GType publishing_gallery3_credentials_pane_mode_get_type (void) G_GNUC_CONST;
static void publishing_gallery3_gallery_publisher_do_show_credentials_pane (PublishingGallery3GalleryPublisher* self, PublishingGallery3CredentialsPaneMode mode);
gchar* publishing_gallery3_credentials_pane_mode_to_string (PublishingGallery3CredentialsPaneMode self);
void publishing_gallery3_session_deauthenticate (PublishingGallery3Session* self);
GType publishing_gallery3_credentials_pane_get_type (void) G_GNUC_CONST;
PublishingGallery3CredentialsPane* publishing_gallery3_credentials_pane_new (SpitPublishingPluginHost* host, PublishingGallery3CredentialsPaneMode mode, const gchar* url, const gchar* username, const gchar* key);
PublishingGallery3CredentialsPane* publishing_gallery3_credentials_pane_construct (GType object_type, SpitPublishingPluginHost* host, PublishingGallery3CredentialsPaneMode mode, const gchar* url, const gchar* username, const gchar* key);
static void publishing_gallery3_gallery_publisher_on_credentials_go_back (PublishingGallery3GalleryPublisher* self);
static void _publishing_gallery3_gallery_publisher_on_credentials_go_back_publishing_gallery3_credentials_pane_go_back (PublishingGallery3CredentialsPane* _sender, gpointer self);
static void publishing_gallery3_gallery_publisher_on_credentials_login (PublishingGallery3GalleryPublisher* self, const gchar* url, const gchar* username, const gchar* password);
static void _publishing_gallery3_gallery_publisher_on_credentials_login_publishing_gallery3_credentials_pane_login (PublishingGallery3CredentialsPane* _sender, const gchar* url, const gchar* uname, const gchar* password, const gchar* key, gpointer self);
static void publishing_gallery3_gallery_publisher_do_network_login (PublishingGallery3GalleryPublisher* self, const gchar* url, const gchar* username, const gchar* password);
static void publishing_gallery3_gallery_publisher_on_key_fetch_error (PublishingGallery3GalleryPublisher* self, PublishingRESTSupportTransaction* bad_txn, GError* err);
static void _publishing_gallery3_gallery_publisher_on_key_fetch_error_publishing_rest_support_transaction_network_error (PublishingRESTSupportTransaction* _sender, GError* err, gpointer self);
static void publishing_gallery3_gallery_publisher_on_key_fetch_complete (PublishingGallery3GalleryPublisher* self, PublishingRESTSupportTransaction* txn);
static void _publishing_gallery3_gallery_publisher_on_key_fetch_complete_publishing_rest_support_transaction_completed (PublishingRESTSupportTransaction* _sender, gpointer self);
static void publishing_gallery3_gallery_publisher_on_album_urls_fetch_error (PublishingGallery3GalleryPublisher* self, PublishingRESTSupportTransaction* bad_txn, GError* err);
static void _publishing_gallery3_gallery_publisher_on_album_urls_fetch_error_publishing_rest_support_transaction_network_error (PublishingRESTSupportTransaction* _sender, GError* err, gpointer self);
static void publishing_gallery3_gallery_publisher_on_album_urls_fetch_complete (PublishingGallery3GalleryPublisher* self, PublishingRESTSupportTransaction* txn);
static void _publishing_gallery3_gallery_publisher_on_album_urls_fetch_complete_publishing_rest_support_transaction_completed (PublishingRESTSupportTransaction* _sender, gpointer self);
static void publishing_gallery3_gallery_publisher_do_fetch_albums (PublishingGallery3GalleryPublisher* self, gchar** album_urls, int album_urls_length1, guint start);
static void publishing_gallery3_gallery_publisher_on_album_fetch_error (PublishingGallery3GalleryPublisher* self, PublishingRESTSupportTransaction* bad_txn, GError* err);
static void _publishing_gallery3_gallery_publisher_on_album_fetch_error_publishing_rest_support_transaction_network_error (PublishingRESTSupportTransaction* _sender, GError* err, gpointer self);
static void publishing_gallery3_gallery_publisher_on_album_fetch_complete (PublishingGallery3GalleryPublisher* self, PublishingRESTSupportTransaction* txn);
static void _publishing_gallery3_gallery_publisher_on_album_fetch_complete_publishing_rest_support_transaction_completed (PublishingRESTSupportTransaction* _sender, gpointer self);
static void publishing_gallery3_gallery_publisher_do_show_publishing_options_pane (PublishingGallery3GalleryPublisher* self, const gchar* url, const gchar* username);
PublishingGallery3PublishingOptionsPane* publishing_gallery3_publishing_options_pane_new (SpitPublishingPluginHost* host, const gchar* url, const gchar* username, PublishingGallery3Album** albums, int albums_length1, GtkBuilder* builder, gboolean strip_metadata, gint scaling_id, gint scaling_pixels);
PublishingGallery3PublishingOptionsPane* publishing_gallery3_publishing_options_pane_construct (GType object_type, SpitPublishingPluginHost* host, const gchar* url, const gchar* username, PublishingGallery3Album** albums, int albums_length1, GtkBuilder* builder, gboolean strip_metadata, gint scaling_id, gint scaling_pixels);
static void publishing_gallery3_gallery_publisher_on_publishing_options_pane_publish (PublishingGallery3GalleryPublisher* self, PublishingGallery3PublishingParameters* parameters);
static void _publishing_gallery3_gallery_publisher_on_publishing_options_pane_publish_publishing_gallery3_publishing_options_pane_publish (PublishingGallery3PublishingOptionsPane* _sender, PublishingGallery3PublishingParameters* parameters, gpointer self);
static void publishing_gallery3_gallery_publisher_on_publishing_options_pane_logout (PublishingGallery3GalleryPublisher* self);
static void _publishing_gallery3_gallery_publisher_on_publishing_options_pane_logout_publishing_gallery3_publishing_options_pane_logout (PublishingGallery3PublishingOptionsPane* _sender, gpointer self);
static void publishing_gallery3_gallery_publisher_do_create_album (PublishingGallery3GalleryPublisher* self, PublishingGallery3PublishingParameters* parameters);
static void publishing_gallery3_gallery_publisher_on_album_create_error (PublishingGallery3GalleryPublisher* self, PublishingRESTSupportTransaction* bad_txn, GError* err);
static void _publishing_gallery3_gallery_publisher_on_album_create_error_publishing_rest_support_transaction_network_error (PublishingRESTSupportTransaction* _sender, GError* err, gpointer self);
static void publishing_gallery3_gallery_publisher_on_album_create_complete (PublishingGallery3GalleryPublisher* self, PublishingRESTSupportTransaction* txn);
static void _publishing_gallery3_gallery_publisher_on_album_create_complete_publishing_rest_support_transaction_completed (PublishingRESTSupportTransaction* _sender, gpointer self);
static void publishing_gallery3_gallery_publisher_do_publish (PublishingGallery3GalleryPublisher* self, PublishingGallery3PublishingParameters* parameters);
gint publishing_gallery3_publishing_parameters_get_photo_major_axis_size (PublishingGallery3PublishingParameters* self);
GType publishing_gallery3_uploader_get_type (void) G_GNUC_CONST;
PublishingGallery3Uploader* publishing_gallery3_uploader_new (PublishingGallery3Session* session, SpitPublishingPublishable** publishables, int publishables_length1, PublishingGallery3PublishingParameters* parameters);
PublishingGallery3Uploader* publishing_gallery3_uploader_construct (GType object_type, PublishingGallery3Session* session, SpitPublishingPublishable** publishables, int publishables_length1, PublishingGallery3PublishingParameters* parameters);
static void publishing_gallery3_gallery_publisher_on_publish_complete (PublishingGallery3GalleryPublisher* self, PublishingRESTSupportBatchUploader* uploader, gint num_published);
static void _publishing_gallery3_gallery_publisher_on_publish_complete_publishing_rest_support_batch_uploader_upload_complete (PublishingRESTSupportBatchUploader* _sender, gint num_photos_published, gpointer self);
static void publishing_gallery3_gallery_publisher_on_publish_error (PublishingGallery3GalleryPublisher* self, PublishingRESTSupportBatchUploader* _uploader, GError* err);
static void _publishing_gallery3_gallery_publisher_on_publish_error_publishing_rest_support_batch_uploader_upload_error (PublishingRESTSupportBatchUploader* _sender, GError* err, gpointer self);
static void publishing_gallery3_gallery_publisher_on_upload_status_updated (PublishingGallery3GalleryPublisher* self, gint file_number, gdouble completed_fraction);
static void _publishing_gallery3_gallery_publisher_on_upload_status_updated_spit_publishing_progress_callback (gint file_number, gdouble fraction_complete, gpointer self);
static void publishing_gallery3_gallery_publisher_do_show_success_pane (PublishingGallery3GalleryPublisher* self);
const gchar* publishing_gallery3_session_get_username (PublishingGallery3Session* self);
static void _vala_array_add5 (PublishingGallery3Album*** array, int* length, int* size, PublishingGallery3Album* value);
void publishing_gallery3_publishing_parameters_set_album_path (PublishingGallery3PublishingParameters* self, const gchar* value);
const gchar* publishing_gallery3_uploader_get_current_publishable_name (PublishingGallery3Uploader* self);
guint publishing_gallery3_uploader_get_status_code (PublishingGallery3Uploader* self);
SpitPublishingPublisherMediaType publishing_gallery3_uploader_get_current_publishable_type (PublishingGallery3Uploader* self);
gboolean publishing_gallery3_publishing_parameters_is_to_new_album (PublishingGallery3PublishingParameters* self);
static void publishing_gallery3_gallery_publisher_finalize (GObject* obj);
#define PUBLISHING_GALLERY3_PUBLISHING_OPTIONS_PANE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_GALLERY3_TYPE_PUBLISHING_OPTIONS_PANE, PublishingGallery3PublishingOptionsPanePrivate))
enum  {
	PUBLISHING_GALLERY3_PUBLISHING_OPTIONS_PANE_DUMMY_PROPERTY
};
#define PUBLISHING_GALLERY3_PUBLISHING_OPTIONS_PANE_DEFAULT_ALBUM_NAME ""
#define PUBLISHING_GALLERY3_PUBLISHING_OPTIONS_PANE_LAST_ALBUM_CONFIG_KEY "last-album"
static PublishingGallery3Album** _vala_array_dup3 (PublishingGallery3Album** self, int length);
static void publishing_gallery3_publishing_options_pane_on_use_existing_radio_clicked (PublishingGallery3PublishingOptionsPane* self);
static void _publishing_gallery3_publishing_options_pane_on_use_existing_radio_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self);
static void publishing_gallery3_publishing_options_pane_on_create_new_radio_clicked (PublishingGallery3PublishingOptionsPane* self);
static void _publishing_gallery3_publishing_options_pane_on_create_new_radio_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self);
static void publishing_gallery3_publishing_options_pane_on_new_album_entry_changed (PublishingGallery3PublishingOptionsPane* self);
static void _publishing_gallery3_publishing_options_pane_on_new_album_entry_changed_gtk_editable_changed (GtkEditable* _sender, gpointer self);
static void publishing_gallery3_publishing_options_pane_on_scaling_constraint_changed (PublishingGallery3PublishingOptionsPane* self);
static void _publishing_gallery3_publishing_options_pane_on_scaling_constraint_changed_gtk_combo_box_changed (GtkComboBox* _sender, gpointer self);
static void publishing_gallery3_publishing_options_pane_on_pixels_changed (PublishingGallery3PublishingOptionsPane* self);
static void _publishing_gallery3_publishing_options_pane_on_pixels_changed_gtk_editable_changed (GtkEditable* _sender, gpointer self);
static void publishing_gallery3_publishing_options_pane_on_logout_clicked (PublishingGallery3PublishingOptionsPane* self);
static void _publishing_gallery3_publishing_options_pane_on_logout_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self);
static void publishing_gallery3_publishing_options_pane_on_publish_clicked (PublishingGallery3PublishingOptionsPane* self);
static void _publishing_gallery3_publishing_options_pane_on_publish_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self);
PublishingGallery3PublishingParameters* publishing_gallery3_publishing_parameters_new_to_new_album (const gchar* album_title);
PublishingGallery3PublishingParameters* publishing_gallery3_publishing_parameters_construct_to_new_album (GType object_type, const gchar* album_title);
PublishingGallery3PublishingParameters* publishing_gallery3_publishing_parameters_new_to_existing_album (const gchar* album_path);
PublishingGallery3PublishingParameters* publishing_gallery3_publishing_parameters_construct_to_existing_album (GType object_type, const gchar* album_path);
void publishing_gallery3_publishing_parameters_set_photo_major_axis_size (PublishingGallery3PublishingParameters* self, gint value);
void publishing_gallery3_publishing_parameters_set_strip_metadata (PublishingGallery3PublishingParameters* self, gboolean value);
static void publishing_gallery3_publishing_options_pane_update_publish_button_sensitivity (PublishingGallery3PublishingOptionsPane* self);
static void publishing_gallery3_publishing_options_pane_update_pixel_entry_sensitivity (PublishingGallery3PublishingOptionsPane* self);
void publishing_gallery3_publishing_options_pane_installed (PublishingGallery3PublishingOptionsPane* self);
static GtkWidget* publishing_gallery3_publishing_options_pane_real_get_widget (SpitPublishingDialogPane* base);
static SpitPublishingDialogPaneGeometryOptions publishing_gallery3_publishing_options_pane_real_get_preferred_geometry (SpitPublishingDialogPane* base);
static void publishing_gallery3_publishing_options_pane_real_on_pane_installed (SpitPublishingDialogPane* base);
static void publishing_gallery3_publishing_options_pane_real_on_pane_uninstalled (SpitPublishingDialogPane* base);
static void g_cclosure_user_marshal_VOID__PUBLISHING_GALLERY3_PUBLISHING_PARAMETERS (GClosure * closure, GValue * return_value, guint n_param_values, const GValue * param_values, gpointer invocation_hint, gpointer marshal_data);
static void publishing_gallery3_publishing_options_pane_finalize (GObject* obj);
#define PUBLISHING_GALLERY3_PUBLISHING_PARAMETERS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_GALLERY3_TYPE_PUBLISHING_PARAMETERS, PublishingGallery3PublishingParametersPrivate))
enum  {
	PUBLISHING_GALLERY3_PUBLISHING_PARAMETERS_DUMMY_PROPERTY
};
static PublishingGallery3PublishingParameters* publishing_gallery3_publishing_parameters_new (void);
static PublishingGallery3PublishingParameters* publishing_gallery3_publishing_parameters_construct (GType object_type);
static void publishing_gallery3_publishing_parameters_set_album_name (PublishingGallery3PublishingParameters* self, const gchar* value);
static void publishing_gallery3_publishing_parameters_set_album_title (PublishingGallery3PublishingParameters* self, const gchar* value);
const gchar* publishing_gallery3_publishing_parameters_get_entity_title (PublishingGallery3PublishingParameters* self);
static void publishing_gallery3_publishing_parameters_set_entity_title (PublishingGallery3PublishingParameters* self, const gchar* value);
static void publishing_gallery3_publishing_parameters_finalize (PublishingGallery3PublishingParameters* obj);
GType publishing_gallery3_credentials_grid_get_type (void) G_GNUC_CONST;
#define PUBLISHING_GALLERY3_CREDENTIALS_PANE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_GALLERY3_TYPE_CREDENTIALS_PANE, PublishingGallery3CredentialsPanePrivate))
enum  {
	PUBLISHING_GALLERY3_CREDENTIALS_PANE_DUMMY_PROPERTY
};
PublishingGallery3CredentialsGrid* publishing_gallery3_credentials_grid_new (SpitPublishingPluginHost* host, PublishingGallery3CredentialsPaneMode mode, const gchar* url, const gchar* username, const gchar* key, GtkBuilder* builder);
PublishingGallery3CredentialsGrid* publishing_gallery3_credentials_grid_construct (GType object_type, SpitPublishingPluginHost* host, PublishingGallery3CredentialsPaneMode mode, const gchar* url, const gchar* username, const gchar* key, GtkBuilder* builder);
GtkGrid* publishing_gallery3_credentials_grid_get_pane_widget (PublishingGallery3CredentialsGrid* self);
void publishing_gallery3_credentials_pane_notify_go_back (PublishingGallery3CredentialsPane* self);
void publishing_gallery3_credentials_pane_notify_login (PublishingGallery3CredentialsPane* self, const gchar* url, const gchar* uname, const gchar* password, const gchar* key);
static GtkWidget* publishing_gallery3_credentials_pane_real_get_widget (SpitPublishingDialogPane* base);
static SpitPublishingDialogPaneGeometryOptions publishing_gallery3_credentials_pane_real_get_preferred_geometry (SpitPublishingDialogPane* base);
static void publishing_gallery3_credentials_pane_real_on_pane_installed (SpitPublishingDialogPane* base);
static void _publishing_gallery3_credentials_pane_notify_go_back_publishing_gallery3_credentials_grid_go_back (PublishingGallery3CredentialsGrid* _sender, gpointer self);
static void _publishing_gallery3_credentials_pane_notify_login_publishing_gallery3_credentials_grid_login (PublishingGallery3CredentialsGrid* _sender, const gchar* url, const gchar* username, const gchar* password, const gchar* key, gpointer self);
void publishing_gallery3_credentials_grid_installed (PublishingGallery3CredentialsGrid* self);
static void publishing_gallery3_credentials_pane_real_on_pane_uninstalled (SpitPublishingDialogPane* base);
static void g_cclosure_user_marshal_VOID__STRING_STRING_STRING_STRING (GClosure * closure, GValue * return_value, guint n_param_values, const GValue * param_values, gpointer invocation_hint, gpointer marshal_data);
static void publishing_gallery3_credentials_pane_finalize (GObject* obj);
#define PUBLISHING_GALLERY3_CREDENTIALS_GRID_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_GALLERY3_TYPE_CREDENTIALS_GRID, PublishingGallery3CredentialsGridPrivate))
enum  {
	PUBLISHING_GALLERY3_CREDENTIALS_GRID_DUMMY_PROPERTY,
	PUBLISHING_GALLERY3_CREDENTIALS_GRID_PANE_WIDGET
};
#define PUBLISHING_GALLERY3_CREDENTIALS_GRID_INTRO_MESSAGE _ ("Enter the URL for your Gallery3 site and the username and password (or" \
" API key) for your Gallery3 account.")
#define PUBLISHING_GALLERY3_CREDENTIALS_GRID_FAILED_RETRY_MESSAGE _ ("The username and password or API key were incorrect. To try again, re-" \
"enter your username and password below.")
#define PUBLISHING_GALLERY3_CREDENTIALS_GRID_NOT_GALLERY_URL_MESSAGE _ ("The URL entered does not appear to be the main directory of a Gallery3" \
" instance. Please make sure you typed it correctly and it does not hav" \
"e any trailing components (e.g., index.php).")
static void publishing_gallery3_credentials_grid_set_pane_widget (PublishingGallery3CredentialsGrid* self, GtkGrid* value);
static void publishing_gallery3_credentials_grid_on_url_or_username_changed (PublishingGallery3CredentialsGrid* self);
static void _publishing_gallery3_credentials_grid_on_url_or_username_changed_gtk_editable_changed (GtkEditable* _sender, gpointer self);
static void publishing_gallery3_credentials_grid_on_go_back_button_clicked (PublishingGallery3CredentialsGrid* self);
static void _publishing_gallery3_credentials_grid_on_go_back_button_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self);
static void publishing_gallery3_credentials_grid_on_login_button_clicked (PublishingGallery3CredentialsGrid* self);
static void _publishing_gallery3_credentials_grid_on_login_button_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self);
static void publishing_gallery3_credentials_grid_finalize (GObject* obj);
static void _vala_publishing_gallery3_credentials_grid_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_publishing_gallery3_credentials_grid_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
#define PUBLISHING_GALLERY3_SESSION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_GALLERY3_TYPE_SESSION, PublishingGallery3SessionPrivate))
enum  {
	PUBLISHING_GALLERY3_SESSION_DUMMY_PROPERTY
};
static gboolean publishing_gallery3_session_real_is_authenticated (PublishingRESTSupportSession* base);
static void publishing_gallery3_session_set_url (PublishingGallery3Session* self, const gchar* value);
static void publishing_gallery3_session_set_username (PublishingGallery3Session* self, const gchar* value);
static void publishing_gallery3_session_set_key (PublishingGallery3Session* self, const gchar* value);
static void publishing_gallery3_session_finalize (PublishingRESTSupportSession* obj);
#define PUBLISHING_GALLERY3_UPLOADER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_GALLERY3_TYPE_UPLOADER, PublishingGallery3UploaderPrivate))
enum  {
	PUBLISHING_GALLERY3_UPLOADER_DUMMY_PROPERTY
};
static PublishingRESTSupportTransaction* publishing_gallery3_uploader_real_create_transaction (PublishingRESTSupportBatchUploader* base, SpitPublishingPublishable* publishable);
static void publishing_gallery3_uploader_finalize (PublishingRESTSupportBatchUploader* obj);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);


static void _vala_array_add1 (SpitPluggable*** array, int* length, int* size, SpitPluggable* value) {
#line 37 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if ((*length) == (*size)) {
#line 37 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 37 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		*array = g_renew (SpitPluggable*, *array, (*size) + 1);
#line 1002 "GalleryConnector.c"
	}
#line 37 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	(*array)[(*length)++] = value;
#line 37 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	(*array)[*length] = NULL;
#line 1008 "GalleryConnector.c"
}


ShotwellPublishingGallery3* shotwell_publishing_gallery3_construct (GType object_type, GFile* module_file) {
	ShotwellPublishingGallery3 * self = NULL;
	GFile* resource_directory = NULL;
	GFile* _tmp0_ = NULL;
	GFile* _tmp1_ = NULL;
	SpitPluggable** _tmp2_ = NULL;
	gint _tmp2__length1 = 0;
	Gallery3Service* _tmp3_ = NULL;
#line 34 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (G_IS_FILE (module_file), NULL);
#line 34 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = (ShotwellPublishingGallery3*) g_object_new (object_type, NULL);
#line 35 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = module_file;
#line 35 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = g_file_get_parent (_tmp0_);
#line 35 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	resource_directory = _tmp1_;
#line 37 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = self->priv->pluggables;
#line 37 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2__length1 = self->priv->pluggables_length1;
#line 37 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp3_ = gallery3_service_new (resource_directory);
#line 37 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_vala_array_add1 (&self->priv->pluggables, &self->priv->pluggables_length1, &self->priv->_pluggables_size_, G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, SPIT_TYPE_PLUGGABLE, SpitPluggable));
#line 34 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (resource_directory);
#line 34 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return self;
#line 1042 "GalleryConnector.c"
}


ShotwellPublishingGallery3* shotwell_publishing_gallery3_new (GFile* module_file) {
#line 34 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return shotwell_publishing_gallery3_construct (TYPE_SHOTWELL_PUBLISHING_GALLERY3, module_file);
#line 1049 "GalleryConnector.c"
}


static const gchar* shotwell_publishing_gallery3_real_get_module_name (SpitModule* base) {
	ShotwellPublishingGallery3 * self;
	const gchar* result = NULL;
	const gchar* _tmp0_ = NULL;
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_SHOTWELL_PUBLISHING_GALLERY3, ShotwellPublishingGallery3);
#line 41 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = _ ("Gallery3 publishing module");
#line 41 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp0_;
#line 41 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 1065 "GalleryConnector.c"
}


static const gchar* shotwell_publishing_gallery3_real_get_version (SpitModule* base) {
	ShotwellPublishingGallery3 * self;
	const gchar* result = NULL;
#line 44 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_SHOTWELL_PUBLISHING_GALLERY3, ShotwellPublishingGallery3);
#line 45 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = G3_VERSION;
#line 45 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 1078 "GalleryConnector.c"
}


static const gchar* shotwell_publishing_gallery3_real_get_id (SpitModule* base) {
	ShotwellPublishingGallery3 * self;
	const gchar* result = NULL;
#line 48 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_SHOTWELL_PUBLISHING_GALLERY3, ShotwellPublishingGallery3);
#line 49 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = "org.yorba.shotwell.sharing.gallery3";
#line 49 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 1091 "GalleryConnector.c"
}


static SpitPluggable** shotwell_publishing_gallery3_real_get_pluggables (SpitModule* base, int* result_length1) {
	ShotwellPublishingGallery3 * self;
	SpitPluggable** result = NULL;
	SpitPluggable** _tmp0_ = NULL;
	gint _tmp0__length1 = 0;
	SpitPluggable** _tmp1_ = NULL;
	gint _tmp1__length1 = 0;
#line 52 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_SHOTWELL_PUBLISHING_GALLERY3, ShotwellPublishingGallery3);
#line 53 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->pluggables;
#line 53 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0__length1 = self->priv->pluggables_length1;
#line 53 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = _tmp0_;
#line 53 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1__length1 = _tmp0__length1;
#line 53 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (result_length1) {
#line 53 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		*result_length1 = _tmp1__length1;
#line 1116 "GalleryConnector.c"
	}
#line 53 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp1_;
#line 53 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 1122 "GalleryConnector.c"
}


static void shotwell_publishing_gallery3_class_init (ShotwellPublishingGallery3Class * klass) {
#line 31 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	shotwell_publishing_gallery3_parent_class = g_type_class_peek_parent (klass);
#line 31 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_type_class_add_private (klass, sizeof (ShotwellPublishingGallery3Private));
#line 31 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	G_OBJECT_CLASS (klass)->finalize = shotwell_publishing_gallery3_finalize;
#line 1133 "GalleryConnector.c"
}


static void shotwell_publishing_gallery3_spit_module_interface_init (SpitModuleIface * iface) {
#line 31 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	shotwell_publishing_gallery3_spit_module_parent_iface = g_type_interface_peek_parent (iface);
#line 31 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	iface->get_module_name = (const gchar* (*)(SpitModule*)) shotwell_publishing_gallery3_real_get_module_name;
#line 31 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	iface->get_version = (const gchar* (*)(SpitModule*)) shotwell_publishing_gallery3_real_get_version;
#line 31 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	iface->get_id = (const gchar* (*)(SpitModule*)) shotwell_publishing_gallery3_real_get_id;
#line 31 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	iface->get_pluggables = (SpitPluggable** (*)(SpitModule*, int*)) shotwell_publishing_gallery3_real_get_pluggables;
#line 1148 "GalleryConnector.c"
}


static void shotwell_publishing_gallery3_instance_init (ShotwellPublishingGallery3 * self) {
	SpitPluggable** _tmp0_ = NULL;
#line 31 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv = SHOTWELL_PUBLISHING_GALLERY3_GET_PRIVATE (self);
#line 32 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = g_new0 (SpitPluggable*, 0 + 1);
#line 32 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->pluggables = _tmp0_;
#line 32 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->pluggables_length1 = 0;
#line 32 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_pluggables_size_ = self->priv->pluggables_length1;
#line 1164 "GalleryConnector.c"
}


static void shotwell_publishing_gallery3_finalize (GObject* obj) {
	ShotwellPublishingGallery3 * self;
#line 31 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_SHOTWELL_PUBLISHING_GALLERY3, ShotwellPublishingGallery3);
#line 32 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->pluggables = (_vala_array_free (self->priv->pluggables, self->priv->pluggables_length1, (GDestroyNotify) g_object_unref), NULL);
#line 31 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	G_OBJECT_CLASS (shotwell_publishing_gallery3_parent_class)->finalize (obj);
#line 1176 "GalleryConnector.c"
}


GType shotwell_publishing_gallery3_get_type (void) {
	static volatile gsize shotwell_publishing_gallery3_type_id__volatile = 0;
	if (g_once_init_enter (&shotwell_publishing_gallery3_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (ShotwellPublishingGallery3Class), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) shotwell_publishing_gallery3_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ShotwellPublishingGallery3), 0, (GInstanceInitFunc) shotwell_publishing_gallery3_instance_init, NULL };
		static const GInterfaceInfo spit_module_info = { (GInterfaceInitFunc) shotwell_publishing_gallery3_spit_module_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType shotwell_publishing_gallery3_type_id;
		shotwell_publishing_gallery3_type_id = g_type_register_static (G_TYPE_OBJECT, "ShotwellPublishingGallery3", &g_define_type_info, 0);
		g_type_add_interface_static (shotwell_publishing_gallery3_type_id, SPIT_TYPE_MODULE, &spit_module_info);
		g_once_init_leave (&shotwell_publishing_gallery3_type_id__volatile, shotwell_publishing_gallery3_type_id);
	}
	return shotwell_publishing_gallery3_type_id__volatile;
}


Gallery3Service* gallery3_service_construct (GType object_type, GFile* resource_directory) {
	Gallery3Service * self = NULL;
	GdkPixbuf** _tmp0_ = NULL;
	gint _tmp0__length1 = 0;
#line 64 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (G_IS_FILE (resource_directory), NULL);
#line 64 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = (Gallery3Service*) g_object_new (object_type, NULL);
#line 65 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = gallery3_service_icon_pixbuf_set;
#line 65 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0__length1 = gallery3_service_icon_pixbuf_set_length1;
#line 65 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (_tmp0_ == NULL) {
#line 1208 "GalleryConnector.c"
		gint _tmp1_ = 0;
		GdkPixbuf** _tmp2_ = NULL;
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp2_ = resources_load_from_resource (PLUGIN_RESOURCE_PATH "/" GALLERY3_SERVICE_ICON_FILENAME, &_tmp1_);
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		gallery3_service_icon_pixbuf_set = (_vala_array_free (gallery3_service_icon_pixbuf_set, gallery3_service_icon_pixbuf_set_length1, (GDestroyNotify) g_object_unref), NULL);
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		gallery3_service_icon_pixbuf_set = _tmp2_;
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		gallery3_service_icon_pixbuf_set_length1 = _tmp1_;
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_gallery3_service_icon_pixbuf_set_size_ = gallery3_service_icon_pixbuf_set_length1;
#line 1221 "GalleryConnector.c"
	}
#line 64 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return self;
#line 1225 "GalleryConnector.c"
}


Gallery3Service* gallery3_service_new (GFile* resource_directory) {
#line 64 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return gallery3_service_construct (TYPE_GALLERY3_SERVICE, resource_directory);
#line 1232 "GalleryConnector.c"
}


static gint gallery3_service_real_get_pluggable_interface (SpitPluggable* base, gint min_host_interface, gint max_host_interface) {
	Gallery3Service * self;
	gint result = 0;
	gint _tmp0_ = 0;
	gint _tmp1_ = 0;
	gint _tmp2_ = 0;
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_GALLERY3_SERVICE, Gallery3Service);
#line 72 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = min_host_interface;
#line 72 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = max_host_interface;
#line 72 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = spit_negotiate_interfaces (_tmp0_, _tmp1_, SPIT_PUBLISHING_CURRENT_INTERFACE);
#line 72 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp2_;
#line 72 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 1254 "GalleryConnector.c"
}


static const gchar* gallery3_service_real_get_id (SpitPluggable* base) {
	Gallery3Service * self;
	const gchar* result = NULL;
#line 77 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_GALLERY3_SERVICE, Gallery3Service);
#line 78 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = "publishing-gallery3";
#line 78 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 1267 "GalleryConnector.c"
}


static const gchar* gallery3_service_real_get_pluggable_name (SpitPluggable* base) {
	Gallery3Service * self;
	const gchar* result = NULL;
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_GALLERY3_SERVICE, Gallery3Service);
#line 82 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = "Gallery3";
#line 82 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 1280 "GalleryConnector.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 93 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return self ? g_object_ref (self) : NULL;
#line 1287 "GalleryConnector.c"
}


static GdkPixbuf** _vala_array_dup1 (GdkPixbuf** self, int length) {
	GdkPixbuf** result;
	int i;
#line 93 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = g_new0 (GdkPixbuf*, length + 1);
#line 93 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	for (i = 0; i < length; i++) {
#line 1298 "GalleryConnector.c"
		GdkPixbuf* _tmp0_ = NULL;
#line 93 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp0_ = _g_object_ref0 (self[i]);
#line 93 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		result[i] = _tmp0_;
#line 1304 "GalleryConnector.c"
	}
#line 93 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 1308 "GalleryConnector.c"
}


static void gallery3_service_real_get_info (SpitPluggable* base, SpitPluggableInfo* info) {
	Gallery3Service * self;
	gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	GdkPixbuf** _tmp6_ = NULL;
	gint _tmp6__length1 = 0;
	GdkPixbuf** _tmp7_ = NULL;
	gint _tmp7__length1 = 0;
#line 85 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_GALLERY3_SERVICE, Gallery3Service);
#line 85 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (info != NULL);
#line 86 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = g_strdup ("Joe Sapp");
#line 86 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 ((*info).authors);
#line 86 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	(*info).authors = _tmp0_;
#line 87 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = g_strdup ("2012-2013 Joe Sapp");
#line 87 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 ((*info).copyright);
#line 87 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	(*info).copyright = _tmp1_;
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = g_strdup (RESOURCES_TRANSLATORS);
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 ((*info).translators);
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	(*info).translators = _tmp2_;
#line 89 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp3_ = g_strdup (G3_VERSION);
#line 89 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 ((*info).version);
#line 89 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	(*info).version = _tmp3_;
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp4_ = g_strdup (WEBSITE_URL);
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 ((*info).website_url);
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	(*info).website_url = _tmp4_;
#line 91 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	(*info).is_license_wordwrapped = FALSE;
#line 92 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp5_ = g_strdup (G3_LICENSE);
#line 92 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 ((*info).license);
#line 92 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	(*info).license = _tmp5_;
#line 93 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp6_ = gallery3_service_icon_pixbuf_set;
#line 93 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp6__length1 = gallery3_service_icon_pixbuf_set_length1;
#line 93 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp7_ = (_tmp6_ != NULL) ? _vala_array_dup1 (_tmp6_, _tmp6__length1) : ((gpointer) _tmp6_);
#line 93 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp7__length1 = _tmp6__length1;
#line 93 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	(*info).icons = (_vala_array_free ((*info).icons, (*info).icons_length1, (GDestroyNotify) g_object_unref), NULL);
#line 93 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	(*info).icons = _tmp7_;
#line 93 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	(*info).icons_length1 = _tmp7__length1;
#line 1380 "GalleryConnector.c"
}


static void gallery3_service_real_activation (SpitPluggable* base, gboolean enabled) {
	Gallery3Service * self;
#line 96 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_GALLERY3_SERVICE, Gallery3Service);
#line 1388 "GalleryConnector.c"
}


static SpitPublishingPublisher* gallery3_service_real_create_publisher (SpitPublishingService* base, SpitPublishingPluginHost* host) {
	Gallery3Service * self;
	SpitPublishingPublisher* result = NULL;
	SpitPublishingPluginHost* _tmp0_ = NULL;
	PublishingGallery3GalleryPublisher* _tmp1_ = NULL;
#line 99 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_GALLERY3_SERVICE, Gallery3Service);
#line 99 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (SPIT_PUBLISHING_IS_PLUGIN_HOST (host), NULL);
#line 101 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = host;
#line 101 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = publishing_gallery3_gallery_publisher_new (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_SERVICE, SpitPublishingService), _tmp0_);
#line 101 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher);
#line 101 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 1409 "GalleryConnector.c"
}


static SpitPublishingPublisherMediaType gallery3_service_real_get_supported_media (SpitPublishingService* base) {
	Gallery3Service * self;
	SpitPublishingPublisherMediaType result = 0;
#line 104 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_GALLERY3_SERVICE, Gallery3Service);
#line 105 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = SPIT_PUBLISHING_PUBLISHER_MEDIA_TYPE_PHOTO | SPIT_PUBLISHING_PUBLISHER_MEDIA_TYPE_VIDEO;
#line 105 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 1422 "GalleryConnector.c"
}


static void gallery3_service_class_init (Gallery3ServiceClass * klass) {
#line 58 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	gallery3_service_parent_class = g_type_class_peek_parent (klass);
#line 58 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	G_OBJECT_CLASS (klass)->finalize = gallery3_service_finalize;
#line 1431 "GalleryConnector.c"
}


static void gallery3_service_spit_pluggable_interface_init (SpitPluggableIface * iface) {
#line 58 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	gallery3_service_spit_pluggable_parent_iface = g_type_interface_peek_parent (iface);
#line 58 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	iface->get_pluggable_interface = (gint (*)(SpitPluggable*, gint, gint)) gallery3_service_real_get_pluggable_interface;
#line 58 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	iface->get_id = (const gchar* (*)(SpitPluggable*)) gallery3_service_real_get_id;
#line 58 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	iface->get_pluggable_name = (const gchar* (*)(SpitPluggable*)) gallery3_service_real_get_pluggable_name;
#line 58 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	iface->get_info = (void (*)(SpitPluggable*, SpitPluggableInfo*)) gallery3_service_real_get_info;
#line 58 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	iface->activation = (void (*)(SpitPluggable*, gboolean)) gallery3_service_real_activation;
#line 1448 "GalleryConnector.c"
}


static void gallery3_service_spit_publishing_service_interface_init (SpitPublishingServiceIface * iface) {
#line 58 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	gallery3_service_spit_publishing_service_parent_iface = g_type_interface_peek_parent (iface);
#line 58 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	iface->create_publisher = (SpitPublishingPublisher* (*)(SpitPublishingService*, SpitPublishingPluginHost*)) gallery3_service_real_create_publisher;
#line 58 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	iface->get_supported_media = (SpitPublishingPublisherMediaType (*)(SpitPublishingService*)) gallery3_service_real_get_supported_media;
#line 1459 "GalleryConnector.c"
}


static void gallery3_service_instance_init (Gallery3Service * self) {
}


static void gallery3_service_finalize (GObject* obj) {
	Gallery3Service * self;
#line 58 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_GALLERY3_SERVICE, Gallery3Service);
#line 58 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	G_OBJECT_CLASS (gallery3_service_parent_class)->finalize (obj);
#line 1473 "GalleryConnector.c"
}


GType gallery3_service_get_type (void) {
	static volatile gsize gallery3_service_type_id__volatile = 0;
	if (g_once_init_enter (&gallery3_service_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (Gallery3ServiceClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gallery3_service_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (Gallery3Service), 0, (GInstanceInitFunc) gallery3_service_instance_init, NULL };
		static const GInterfaceInfo spit_pluggable_info = { (GInterfaceInitFunc) gallery3_service_spit_pluggable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo spit_publishing_service_info = { (GInterfaceInitFunc) gallery3_service_spit_publishing_service_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType gallery3_service_type_id;
		gallery3_service_type_id = g_type_register_static (G_TYPE_OBJECT, "Gallery3Service", &g_define_type_info, 0);
		g_type_add_interface_static (gallery3_service_type_id, SPIT_TYPE_PLUGGABLE, &spit_pluggable_info);
		g_type_add_interface_static (gallery3_service_type_id, SPIT_PUBLISHING_TYPE_SERVICE, &spit_publishing_service_info);
		g_once_init_leave (&gallery3_service_type_id__volatile, gallery3_service_type_id);
	}
	return gallery3_service_type_id__volatile;
}


PublishingGallery3Album* publishing_gallery3_album_construct (GType object_type, JsonObject* collection) {
	PublishingGallery3Album* self = NULL;
	JsonObject* entity = NULL;
	JsonObject* _tmp0_ = NULL;
	JsonObject* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	JsonObject* _tmp5_ = NULL;
	const gchar* _tmp6_ = NULL;
	gboolean _tmp7_ = FALSE;
	const gchar* _tmp8_ = NULL;
	gchar* _tmp9_ = NULL;
	gchar* _tmp10_ = NULL;
#line 132 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (collection != NULL, NULL);
#line 132 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = (PublishingGallery3Album*) g_type_create_instance (object_type);
#line 134 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = collection;
#line 134 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = json_object_get_object_member (_tmp0_, "entity");
#line 134 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	entity = _tmp1_;
#line 137 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = json_object_get_string_member (entity, "title");
#line 137 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_album_set_title (self, _tmp2_);
#line 138 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp3_ = json_object_get_string_member (entity, "name");
#line 138 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_album_set_name (self, _tmp3_);
#line 139 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp4_ = json_object_get_string_member (entity, "parent");
#line 139 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_album_set_parentname (self, _tmp4_);
#line 140 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp5_ = collection;
#line 140 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp6_ = json_object_get_string_member (_tmp5_, "url");
#line 140 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_album_set_url (self, _tmp6_);
#line 141 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp7_ = json_object_get_boolean_member (entity, "can_edit");
#line 141 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_album_set_editable (self, _tmp7_);
#line 145 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp8_ = self->priv->_url;
#line 145 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp9_ = publishing_gallery3_strip_session_url (_tmp8_);
#line 145 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp10_ = _tmp9_;
#line 145 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_album_set_path (self, _tmp10_);
#line 145 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (_tmp10_);
#line 132 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return self;
#line 1551 "GalleryConnector.c"
}


PublishingGallery3Album* publishing_gallery3_album_new (JsonObject* collection) {
#line 132 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return publishing_gallery3_album_construct (PUBLISHING_GALLERY3_TYPE_ALBUM, collection);
#line 1558 "GalleryConnector.c"
}


const gchar* publishing_gallery3_album_get_name (PublishingGallery3Album* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
#line 123 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_ALBUM (self), NULL);
#line 123 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->_name;
#line 123 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp0_;
#line 123 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 1573 "GalleryConnector.c"
}


static void publishing_gallery3_album_set_name (PublishingGallery3Album* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 123 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_ALBUM (self));
#line 123 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = value;
#line 123 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 123 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->_name);
#line 123 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_name = _tmp1_;
#line 1590 "GalleryConnector.c"
}


const gchar* publishing_gallery3_album_get_title (PublishingGallery3Album* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
#line 124 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_ALBUM (self), NULL);
#line 124 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->_title;
#line 124 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp0_;
#line 124 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 1605 "GalleryConnector.c"
}


static void publishing_gallery3_album_set_title (PublishingGallery3Album* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 124 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_ALBUM (self));
#line 124 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = value;
#line 124 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 124 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->_title);
#line 124 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_title = _tmp1_;
#line 1622 "GalleryConnector.c"
}


const gchar* publishing_gallery3_album_get_summary (PublishingGallery3Album* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
#line 125 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_ALBUM (self), NULL);
#line 125 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->_summary;
#line 125 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp0_;
#line 125 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 1637 "GalleryConnector.c"
}


static void publishing_gallery3_album_set_summary (PublishingGallery3Album* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 125 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_ALBUM (self));
#line 125 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = value;
#line 125 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 125 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->_summary);
#line 125 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_summary = _tmp1_;
#line 1654 "GalleryConnector.c"
}


const gchar* publishing_gallery3_album_get_parentname (PublishingGallery3Album* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
#line 126 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_ALBUM (self), NULL);
#line 126 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->_parentname;
#line 126 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp0_;
#line 126 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 1669 "GalleryConnector.c"
}


static void publishing_gallery3_album_set_parentname (PublishingGallery3Album* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 126 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_ALBUM (self));
#line 126 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = value;
#line 126 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 126 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->_parentname);
#line 126 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_parentname = _tmp1_;
#line 1686 "GalleryConnector.c"
}


const gchar* publishing_gallery3_album_get_url (PublishingGallery3Album* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
#line 127 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_ALBUM (self), NULL);
#line 127 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->_url;
#line 127 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp0_;
#line 127 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 1701 "GalleryConnector.c"
}


static void publishing_gallery3_album_set_url (PublishingGallery3Album* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 127 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_ALBUM (self));
#line 127 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = value;
#line 127 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 127 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->_url);
#line 127 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_url = _tmp1_;
#line 1718 "GalleryConnector.c"
}


const gchar* publishing_gallery3_album_get_path (PublishingGallery3Album* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
#line 128 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_ALBUM (self), NULL);
#line 128 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->_path;
#line 128 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp0_;
#line 128 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 1733 "GalleryConnector.c"
}


static void publishing_gallery3_album_set_path (PublishingGallery3Album* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 128 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_ALBUM (self));
#line 128 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = value;
#line 128 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 128 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->_path);
#line 128 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_path = _tmp1_;
#line 1750 "GalleryConnector.c"
}


gboolean publishing_gallery3_album_get_editable (PublishingGallery3Album* self) {
	gboolean result;
	gboolean _tmp0_ = FALSE;
#line 129 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_ALBUM (self), FALSE);
#line 129 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->_editable;
#line 129 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp0_;
#line 129 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 1765 "GalleryConnector.c"
}


static void publishing_gallery3_album_set_editable (PublishingGallery3Album* self, gboolean value) {
	gboolean _tmp0_ = FALSE;
#line 129 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_ALBUM (self));
#line 129 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = value;
#line 129 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_editable = _tmp0_;
#line 1777 "GalleryConnector.c"
}


static void publishing_gallery3_value_album_init (GValue* value) {
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	value->data[0].v_pointer = NULL;
#line 1784 "GalleryConnector.c"
}


static void publishing_gallery3_value_album_free_value (GValue* value) {
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (value->data[0].v_pointer) {
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_gallery3_album_unref (value->data[0].v_pointer);
#line 1793 "GalleryConnector.c"
	}
}


static void publishing_gallery3_value_album_copy_value (const GValue* src_value, GValue* dest_value) {
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (src_value->data[0].v_pointer) {
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		dest_value->data[0].v_pointer = publishing_gallery3_album_ref (src_value->data[0].v_pointer);
#line 1803 "GalleryConnector.c"
	} else {
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		dest_value->data[0].v_pointer = NULL;
#line 1807 "GalleryConnector.c"
	}
}


static gpointer publishing_gallery3_value_album_peek_pointer (const GValue* value) {
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return value->data[0].v_pointer;
#line 1815 "GalleryConnector.c"
}


static gchar* publishing_gallery3_value_album_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (collect_values[0].v_pointer) {
#line 1822 "GalleryConnector.c"
		PublishingGallery3Album* object;
		object = collect_values[0].v_pointer;
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		if (object->parent_instance.g_class == NULL) {
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 1829 "GalleryConnector.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 1833 "GalleryConnector.c"
		}
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		value->data[0].v_pointer = publishing_gallery3_album_ref (object);
#line 1837 "GalleryConnector.c"
	} else {
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		value->data[0].v_pointer = NULL;
#line 1841 "GalleryConnector.c"
	}
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return NULL;
#line 1845 "GalleryConnector.c"
}


static gchar* publishing_gallery3_value_album_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	PublishingGallery3Album** object_p;
	object_p = collect_values[0].v_pointer;
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (!object_p) {
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 1856 "GalleryConnector.c"
	}
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (!value->data[0].v_pointer) {
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		*object_p = NULL;
#line 1862 "GalleryConnector.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		*object_p = value->data[0].v_pointer;
#line 1866 "GalleryConnector.c"
	} else {
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		*object_p = publishing_gallery3_album_ref (value->data[0].v_pointer);
#line 1870 "GalleryConnector.c"
	}
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return NULL;
#line 1874 "GalleryConnector.c"
}


GParamSpec* publishing_gallery3_param_spec_album (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
	PublishingGallery3ParamSpecAlbum* spec;
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (g_type_is_a (object_type, PUBLISHING_GALLERY3_TYPE_ALBUM), NULL);
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return G_PARAM_SPEC (spec);
#line 1888 "GalleryConnector.c"
}


gpointer publishing_gallery3_value_get_album (const GValue* value) {
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_GALLERY3_TYPE_ALBUM), NULL);
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return value->data[0].v_pointer;
#line 1897 "GalleryConnector.c"
}


void publishing_gallery3_value_set_album (GValue* value, gpointer v_object) {
	PublishingGallery3Album* old;
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_GALLERY3_TYPE_ALBUM));
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	old = value->data[0].v_pointer;
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (v_object) {
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PUBLISHING_GALLERY3_TYPE_ALBUM));
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		value->data[0].v_pointer = v_object;
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_gallery3_album_ref (value->data[0].v_pointer);
#line 1917 "GalleryConnector.c"
	} else {
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		value->data[0].v_pointer = NULL;
#line 1921 "GalleryConnector.c"
	}
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (old) {
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_gallery3_album_unref (old);
#line 1927 "GalleryConnector.c"
	}
}


void publishing_gallery3_value_take_album (GValue* value, gpointer v_object) {
	PublishingGallery3Album* old;
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_GALLERY3_TYPE_ALBUM));
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	old = value->data[0].v_pointer;
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (v_object) {
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PUBLISHING_GALLERY3_TYPE_ALBUM));
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		value->data[0].v_pointer = v_object;
#line 1946 "GalleryConnector.c"
	} else {
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		value->data[0].v_pointer = NULL;
#line 1950 "GalleryConnector.c"
	}
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (old) {
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_gallery3_album_unref (old);
#line 1956 "GalleryConnector.c"
	}
}


static void publishing_gallery3_album_class_init (PublishingGallery3AlbumClass * klass) {
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_album_parent_class = g_type_class_peek_parent (klass);
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	((PublishingGallery3AlbumClass *) klass)->finalize = publishing_gallery3_album_finalize;
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_type_class_add_private (klass, sizeof (PublishingGallery3AlbumPrivate));
#line 1968 "GalleryConnector.c"
}


static void publishing_gallery3_album_instance_init (PublishingGallery3Album * self) {
	gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv = PUBLISHING_GALLERY3_ALBUM_GET_PRIVATE (self);
#line 123 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = g_strdup ("");
#line 123 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_name = _tmp0_;
#line 124 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = g_strdup ("");
#line 124 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_title = _tmp1_;
#line 125 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = g_strdup ("");
#line 125 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_summary = _tmp2_;
#line 126 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp3_ = g_strdup ("");
#line 126 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_parentname = _tmp3_;
#line 127 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp4_ = g_strdup ("");
#line 127 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_url = _tmp4_;
#line 128 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp5_ = g_strdup ("");
#line 128 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_path = _tmp5_;
#line 129 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_editable = FALSE;
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->ref_count = 1;
#line 2009 "GalleryConnector.c"
}


static void publishing_gallery3_album_finalize (PublishingGallery3Album* obj) {
	PublishingGallery3Album * self;
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_GALLERY3_TYPE_ALBUM, PublishingGallery3Album);
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_handlers_destroy (self);
#line 123 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->_name);
#line 124 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->_title);
#line 125 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->_summary);
#line 126 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->_parentname);
#line 127 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->_url);
#line 128 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->_path);
#line 2031 "GalleryConnector.c"
}


GType publishing_gallery3_album_get_type (void) {
	static volatile gsize publishing_gallery3_album_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_gallery3_album_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { publishing_gallery3_value_album_init, publishing_gallery3_value_album_free_value, publishing_gallery3_value_album_copy_value, publishing_gallery3_value_album_peek_pointer, "p", publishing_gallery3_value_album_collect_value, "p", publishing_gallery3_value_album_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (PublishingGallery3AlbumClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_gallery3_album_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingGallery3Album), 0, (GInstanceInitFunc) publishing_gallery3_album_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType publishing_gallery3_album_type_id;
		publishing_gallery3_album_type_id = g_type_register_fundamental (g_type_fundamental_next (), "PublishingGallery3Album", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&publishing_gallery3_album_type_id__volatile, publishing_gallery3_album_type_id);
	}
	return publishing_gallery3_album_type_id__volatile;
}


gpointer publishing_gallery3_album_ref (gpointer instance) {
	PublishingGallery3Album* self;
	self = instance;
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_atomic_int_inc (&self->ref_count);
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return instance;
#line 2056 "GalleryConnector.c"
}


void publishing_gallery3_album_unref (gpointer instance) {
	PublishingGallery3Album* self;
	self = instance;
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		PUBLISHING_GALLERY3_ALBUM_GET_CLASS (self)->finalize (self);
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 2069 "GalleryConnector.c"
	}
}


static gchar string_get (const gchar* self, glong index) {
	gchar result = '\0';
	glong _tmp0_ = 0L;
	gchar _tmp1_ = '\0';
#line 1086 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, '\0');
#line 1087 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp0_ = index;
#line 1087 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp1_ = ((gchar*) self)[_tmp0_];
#line 1087 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	result = _tmp1_;
#line 1087 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	return result;
#line 2088 "GalleryConnector.c"
}


PublishingGallery3BaseGalleryTransaction* publishing_gallery3_base_gallery_transaction_construct (GType object_type, PublishingGallery3Session* session, const gchar* endpoint_url, const gchar* item_path, PublishingRESTSupportHttpMethod method) {
	PublishingGallery3BaseGalleryTransaction* self = NULL;
	gboolean _tmp0_ = FALSE;
	const gchar* _tmp1_ = NULL;
	PublishingGallery3Session* _tmp5_ = NULL;
	const gchar* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
	gchar* _tmp8_ = NULL;
	const gchar* _tmp9_ = NULL;
	gchar* _tmp10_ = NULL;
	gchar* _tmp11_ = NULL;
	PublishingRESTSupportHttpMethod _tmp12_ = 0;
	JsonParser* _tmp13_ = NULL;
#line 157 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_SESSION (session), NULL);
#line 157 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (endpoint_url != NULL, NULL);
#line 157 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (item_path != NULL, NULL);
#line 163 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = item_path;
#line 163 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (g_strcmp0 (_tmp1_, "") != 0) {
#line 2115 "GalleryConnector.c"
		const gchar* _tmp2_ = NULL;
		gchar _tmp3_ = '\0';
#line 163 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp2_ = item_path;
#line 163 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp3_ = string_get (_tmp2_, (glong) 0);
#line 163 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp0_ = _tmp3_ != '/';
#line 2124 "GalleryConnector.c"
	} else {
#line 163 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp0_ = FALSE;
#line 2128 "GalleryConnector.c"
	}
#line 163 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (_tmp0_) {
#line 2132 "GalleryConnector.c"
		const gchar* _tmp4_ = NULL;
#line 164 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_warning ("GalleryConnector.vala:164: Bad item path, this is a bug!");
#line 165 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp4_ = item_path;
#line 165 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_error ("GalleryConnector.vala:165: %s", _tmp4_);
#line 2140 "GalleryConnector.c"
	}
#line 168 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp5_ = session;
#line 168 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp6_ = endpoint_url;
#line 168 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp7_ = g_strconcat (_tmp6_, PUBLISHING_GALLERY3_REST_PATH, NULL);
#line 168 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp8_ = _tmp7_;
#line 168 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp9_ = item_path;
#line 168 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp10_ = g_strconcat (_tmp8_, _tmp9_, NULL);
#line 168 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp11_ = _tmp10_;
#line 168 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp12_ = method;
#line 168 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = (PublishingGallery3BaseGalleryTransaction*) publishing_rest_support_transaction_construct_with_endpoint_url (object_type, G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession), _tmp11_, _tmp12_);
#line 168 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (_tmp11_);
#line 168 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (_tmp8_);
#line 172 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp13_ = json_parser_new ();
#line 172 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->parser);
#line 172 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->parser = _tmp13_;
#line 157 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return self;
#line 2172 "GalleryConnector.c"
}


PublishingGallery3BaseGalleryTransaction* publishing_gallery3_base_gallery_transaction_new (PublishingGallery3Session* session, const gchar* endpoint_url, const gchar* item_path, PublishingRESTSupportHttpMethod method) {
#line 157 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return publishing_gallery3_base_gallery_transaction_construct (PUBLISHING_GALLERY3_TYPE_BASE_GALLERY_TRANSACTION, session, endpoint_url, item_path, method);
#line 2179 "GalleryConnector.c"
}


JsonNode* publishing_gallery3_base_gallery_transaction_get_root_node (PublishingGallery3BaseGalleryTransaction* self, GError** error) {
	JsonNode* result = NULL;
	gchar* json_object = NULL;
	JsonNode* root_node = NULL;
	gchar* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	const gchar* _tmp2_ = NULL;
	JsonParser* _tmp15_ = NULL;
	JsonNode* _tmp16_ = NULL;
	gboolean _tmp17_ = FALSE;
	GError * _inner_error_ = NULL;
#line 176 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_BASE_GALLERY_TRANSACTION (self), NULL);
#line 182 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = publishing_rest_support_transaction_get_response (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction));
#line 182 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (json_object);
#line 182 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	json_object = _tmp0_;
#line 184 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = json_object;
#line 184 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (NULL == _tmp2_) {
#line 184 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp1_ = TRUE;
#line 2208 "GalleryConnector.c"
	} else {
		const gchar* _tmp3_ = NULL;
		gint _tmp4_ = 0;
		gint _tmp5_ = 0;
#line 184 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp3_ = json_object;
#line 184 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp4_ = strlen (_tmp3_);
#line 184 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp5_ = _tmp4_;
#line 184 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp1_ = 0 == _tmp5_;
#line 2221 "GalleryConnector.c"
	}
#line 184 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (_tmp1_) {
#line 2225 "GalleryConnector.c"
		gchar* _tmp6_ = NULL;
		gchar* _tmp7_ = NULL;
		GError* _tmp8_ = NULL;
		GError* _tmp9_ = NULL;
#line 185 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp6_ = publishing_rest_support_transaction_get_endpoint_url (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction));
#line 185 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp7_ = _tmp6_;
#line 185 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp8_ = g_error_new (SPIT_PUBLISHING_PUBLISHING_ERROR, SPIT_PUBLISHING_PUBLISHING_ERROR_MALFORMED_RESPONSE, "No response data from %s", _tmp7_);
#line 185 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp9_ = _tmp8_;
#line 185 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_free0 (_tmp7_);
#line 185 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_inner_error_ = _tmp9_;
#line 185 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 185 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_propagate_error (error, _inner_error_);
#line 185 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_g_free0 (json_object);
#line 185 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			return NULL;
#line 2250 "GalleryConnector.c"
		} else {
#line 185 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_g_free0 (json_object);
#line 185 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 185 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_clear_error (&_inner_error_);
#line 185 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			return NULL;
#line 2260 "GalleryConnector.c"
		}
	}
	{
		JsonParser* _tmp10_ = NULL;
		const gchar* _tmp11_ = NULL;
#line 189 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp10_ = self->parser;
#line 189 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp11_ = json_object;
#line 189 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		json_parser_load_from_data (_tmp10_, _tmp11_, (gssize) -1, &_inner_error_);
#line 189 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2274 "GalleryConnector.c"
			goto __catch0_g_error;
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
		GError* e = NULL;
		GError* _tmp12_ = NULL;
		const gchar* _tmp13_ = NULL;
		GError* _tmp14_ = NULL;
#line 188 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		e = _inner_error_;
#line 188 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_inner_error_ = NULL;
#line 193 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_warning ("GalleryConnector.vala:193: ERROR: didn't load JSON data");
#line 194 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_rest_support_transaction_set_is_executed (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), FALSE);
#line 195 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp12_ = e;
#line 195 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp13_ = _tmp12_->message;
#line 195 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp14_ = g_error_new_literal (SPIT_PUBLISHING_PUBLISHING_ERROR, SPIT_PUBLISHING_PUBLISHING_ERROR_PROTOCOL_ERROR, _tmp13_);
#line 195 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_inner_error_ = _tmp14_;
#line 195 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_error_free0 (e);
#line 2303 "GalleryConnector.c"
		goto __finally0;
	}
	__finally0:
#line 188 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 188 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 188 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_propagate_error (error, _inner_error_);
#line 188 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_g_free0 (json_object);
#line 188 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			return NULL;
#line 2317 "GalleryConnector.c"
		} else {
#line 188 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_g_free0 (json_object);
#line 188 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 188 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_clear_error (&_inner_error_);
#line 188 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			return NULL;
#line 2327 "GalleryConnector.c"
		}
	}
#line 198 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp15_ = self->parser;
#line 198 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp16_ = json_parser_get_root (_tmp15_);
#line 198 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	root_node = _tmp16_;
#line 199 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp17_ = json_node_is_null (root_node);
#line 199 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (_tmp17_) {
#line 2340 "GalleryConnector.c"
		GError* _tmp18_ = NULL;
#line 200 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp18_ = g_error_new_literal (SPIT_PUBLISHING_PUBLISHING_ERROR, SPIT_PUBLISHING_PUBLISHING_ERROR_MALFORMED_RESPONSE, "Root node is null, doesn't appear to be JSON data");
#line 200 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_inner_error_ = _tmp18_;
#line 200 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 200 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_propagate_error (error, _inner_error_);
#line 200 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_g_free0 (json_object);
#line 200 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			return NULL;
#line 2354 "GalleryConnector.c"
		} else {
#line 200 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_g_free0 (json_object);
#line 200 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 200 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_clear_error (&_inner_error_);
#line 200 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			return NULL;
#line 2364 "GalleryConnector.c"
		}
	}
#line 203 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = root_node;
#line 203 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (json_object);
#line 203 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 2373 "GalleryConnector.c"
}


static void publishing_gallery3_base_gallery_transaction_class_init (PublishingGallery3BaseGalleryTransactionClass * klass) {
#line 151 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_base_gallery_transaction_parent_class = g_type_class_peek_parent (klass);
#line 151 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	((PublishingRESTSupportTransactionClass *) klass)->finalize = publishing_gallery3_base_gallery_transaction_finalize;
#line 2382 "GalleryConnector.c"
}


static void publishing_gallery3_base_gallery_transaction_instance_init (PublishingGallery3BaseGalleryTransaction * self) {
}


static void publishing_gallery3_base_gallery_transaction_finalize (PublishingRESTSupportTransaction* obj) {
	PublishingGallery3BaseGalleryTransaction * self;
#line 151 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_GALLERY3_TYPE_BASE_GALLERY_TRANSACTION, PublishingGallery3BaseGalleryTransaction);
#line 154 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->parser);
#line 151 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	PUBLISHING_REST_SUPPORT_TRANSACTION_CLASS (publishing_gallery3_base_gallery_transaction_parent_class)->finalize (obj);
#line 2398 "GalleryConnector.c"
}


GType publishing_gallery3_base_gallery_transaction_get_type (void) {
	static volatile gsize publishing_gallery3_base_gallery_transaction_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_gallery3_base_gallery_transaction_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingGallery3BaseGalleryTransactionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_gallery3_base_gallery_transaction_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingGallery3BaseGalleryTransaction), 0, (GInstanceInitFunc) publishing_gallery3_base_gallery_transaction_instance_init, NULL };
		GType publishing_gallery3_base_gallery_transaction_type_id;
		publishing_gallery3_base_gallery_transaction_type_id = g_type_register_static (PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, "PublishingGallery3BaseGalleryTransaction", &g_define_type_info, 0);
		g_once_init_leave (&publishing_gallery3_base_gallery_transaction_type_id__volatile, publishing_gallery3_base_gallery_transaction_type_id);
	}
	return publishing_gallery3_base_gallery_transaction_type_id__volatile;
}


PublishingGallery3KeyFetchTransaction* publishing_gallery3_key_fetch_transaction_construct (GType object_type, PublishingGallery3Session* session, const gchar* url, const gchar* username, const gchar* password) {
	PublishingGallery3KeyFetchTransaction* self = NULL;
	PublishingGallery3Session* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
#line 216 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_SESSION (session), NULL);
#line 216 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (url != NULL, NULL);
#line 216 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (username != NULL, NULL);
#line 216 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (password != NULL, NULL);
#line 218 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = session;
#line 218 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = url;
#line 218 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = (PublishingGallery3KeyFetchTransaction*) publishing_gallery3_base_gallery_transaction_construct (object_type, _tmp0_, _tmp1_, "", PUBLISHING_REST_SUPPORT_HTTP_METHOD_POST);
#line 219 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = username;
#line 219 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "user", _tmp2_);
#line 220 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp3_ = password;
#line 220 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "password", _tmp3_);
#line 216 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return self;
#line 2444 "GalleryConnector.c"
}


PublishingGallery3KeyFetchTransaction* publishing_gallery3_key_fetch_transaction_new (PublishingGallery3Session* session, const gchar* url, const gchar* username, const gchar* password) {
#line 216 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return publishing_gallery3_key_fetch_transaction_construct (PUBLISHING_GALLERY3_TYPE_KEY_FETCH_TRANSACTION, session, url, username, password);
#line 2451 "GalleryConnector.c"
}


static gchar* string_slice (const gchar* self, glong start, glong end) {
	gchar* result = NULL;
	glong string_length = 0L;
	gint _tmp0_ = 0;
	gint _tmp1_ = 0;
	glong _tmp2_ = 0L;
	glong _tmp5_ = 0L;
	gboolean _tmp8_ = FALSE;
	glong _tmp9_ = 0L;
	gboolean _tmp12_ = FALSE;
	glong _tmp13_ = 0L;
	glong _tmp16_ = 0L;
	glong _tmp17_ = 0L;
	glong _tmp18_ = 0L;
	glong _tmp19_ = 0L;
	glong _tmp20_ = 0L;
	gchar* _tmp21_ = NULL;
#line 1328 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1329 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp0_ = strlen (self);
#line 1329 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp1_ = _tmp0_;
#line 1329 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	string_length = (glong) _tmp1_;
#line 1330 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp2_ = start;
#line 1330 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	if (_tmp2_ < ((glong) 0)) {
#line 2484 "GalleryConnector.c"
		glong _tmp3_ = 0L;
		glong _tmp4_ = 0L;
#line 1331 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp3_ = string_length;
#line 1331 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp4_ = start;
#line 1331 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		start = _tmp3_ + _tmp4_;
#line 2493 "GalleryConnector.c"
	}
#line 1333 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp5_ = end;
#line 1333 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	if (_tmp5_ < ((glong) 0)) {
#line 2499 "GalleryConnector.c"
		glong _tmp6_ = 0L;
		glong _tmp7_ = 0L;
#line 1334 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp6_ = string_length;
#line 1334 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp7_ = end;
#line 1334 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		end = _tmp6_ + _tmp7_;
#line 2508 "GalleryConnector.c"
	}
#line 1336 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp9_ = start;
#line 1336 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	if (_tmp9_ >= ((glong) 0)) {
#line 2514 "GalleryConnector.c"
		glong _tmp10_ = 0L;
		glong _tmp11_ = 0L;
#line 1336 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp10_ = start;
#line 1336 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp11_ = string_length;
#line 1336 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp8_ = _tmp10_ <= _tmp11_;
#line 2523 "GalleryConnector.c"
	} else {
#line 1336 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp8_ = FALSE;
#line 2527 "GalleryConnector.c"
	}
#line 1336 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	g_return_val_if_fail (_tmp8_, NULL);
#line 1337 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp13_ = end;
#line 1337 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	if (_tmp13_ >= ((glong) 0)) {
#line 2535 "GalleryConnector.c"
		glong _tmp14_ = 0L;
		glong _tmp15_ = 0L;
#line 1337 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp14_ = end;
#line 1337 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp15_ = string_length;
#line 1337 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp12_ = _tmp14_ <= _tmp15_;
#line 2544 "GalleryConnector.c"
	} else {
#line 1337 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp12_ = FALSE;
#line 2548 "GalleryConnector.c"
	}
#line 1337 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	g_return_val_if_fail (_tmp12_, NULL);
#line 1338 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp16_ = start;
#line 1338 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp17_ = end;
#line 1338 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	g_return_val_if_fail (_tmp16_ <= _tmp17_, NULL);
#line 1339 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp18_ = start;
#line 1339 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp19_ = end;
#line 1339 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp20_ = start;
#line 1339 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp21_ = g_strndup (((gchar*) self) + _tmp18_, (gsize) (_tmp19_ - _tmp20_));
#line 1339 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	result = _tmp21_;
#line 1339 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	return result;
#line 2570 "GalleryConnector.c"
}


gchar* publishing_gallery3_key_fetch_transaction_get_key (PublishingGallery3KeyFetchTransaction* self) {
	gchar* result = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp3_ = NULL;
	gboolean _tmp4_ = FALSE;
	gboolean _tmp5_ = FALSE;
	const gchar* _tmp6_ = NULL;
	const gchar* _tmp14_ = NULL;
	gchar* _tmp15_ = NULL;
	const gchar* _tmp16_ = NULL;
	gchar* _tmp17_ = NULL;
#line 223 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_KEY_FETCH_TRANSACTION (self), NULL);
#line 225 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->key;
#line 225 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (g_strcmp0 (_tmp0_, "") != 0) {
#line 2591 "GalleryConnector.c"
		const gchar* _tmp1_ = NULL;
		gchar* _tmp2_ = NULL;
#line 226 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp1_ = self->priv->key;
#line 226 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp2_ = g_strdup (_tmp1_);
#line 226 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		result = _tmp2_;
#line 226 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return result;
#line 2602 "GalleryConnector.c"
	}
#line 228 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp3_ = publishing_rest_support_transaction_get_response (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction));
#line 228 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->key);
#line 228 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->key = _tmp3_;
#line 231 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp6_ = self->priv->key;
#line 231 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (NULL == _tmp6_) {
#line 231 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp5_ = TRUE;
#line 2616 "GalleryConnector.c"
	} else {
		const gchar* _tmp7_ = NULL;
#line 231 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp7_ = self->priv->key;
#line 231 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp5_ = g_strcmp0 ("", _tmp7_) == 0;
#line 2623 "GalleryConnector.c"
	}
#line 231 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (_tmp5_) {
#line 231 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp4_ = TRUE;
#line 2629 "GalleryConnector.c"
	} else {
		const gchar* _tmp8_ = NULL;
		gint _tmp9_ = 0;
		gint _tmp10_ = 0;
#line 231 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp8_ = self->priv->key;
#line 231 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp9_ = strlen (_tmp8_);
#line 231 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp10_ = _tmp9_;
#line 231 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp4_ = 0 == _tmp10_;
#line 2642 "GalleryConnector.c"
	}
#line 231 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (_tmp4_) {
#line 2646 "GalleryConnector.c"
		gchar* _tmp11_ = NULL;
		gchar* _tmp12_ = NULL;
		gchar* _tmp13_ = NULL;
#line 232 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp11_ = publishing_rest_support_transaction_get_endpoint_url (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction));
#line 232 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp12_ = _tmp11_;
#line 232 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_warning ("GalleryConnector.vala:232: No response data from \"%s\"", _tmp12_);
#line 232 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_free0 (_tmp12_);
#line 233 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp13_ = g_strdup ("");
#line 233 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		result = _tmp13_;
#line 233 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return result;
#line 2664 "GalleryConnector.c"
	}
#line 237 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp14_ = self->priv->key;
#line 237 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp15_ = string_slice (_tmp14_, (glong) 1, (glong) -1);
#line 237 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->key);
#line 237 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->key = _tmp15_;
#line 239 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp16_ = self->priv->key;
#line 239 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp17_ = g_strdup (_tmp16_);
#line 239 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp17_;
#line 239 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 2682 "GalleryConnector.c"
}


static void publishing_gallery3_key_fetch_transaction_class_init (PublishingGallery3KeyFetchTransactionClass * klass) {
#line 209 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_key_fetch_transaction_parent_class = g_type_class_peek_parent (klass);
#line 209 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	((PublishingRESTSupportTransactionClass *) klass)->finalize = publishing_gallery3_key_fetch_transaction_finalize;
#line 209 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_type_class_add_private (klass, sizeof (PublishingGallery3KeyFetchTransactionPrivate));
#line 2693 "GalleryConnector.c"
}


static void publishing_gallery3_key_fetch_transaction_instance_init (PublishingGallery3KeyFetchTransaction * self) {
	gchar* _tmp0_ = NULL;
#line 209 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv = PUBLISHING_GALLERY3_KEY_FETCH_TRANSACTION_GET_PRIVATE (self);
#line 211 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = g_strdup ("");
#line 211 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->key = _tmp0_;
#line 2705 "GalleryConnector.c"
}


static void publishing_gallery3_key_fetch_transaction_finalize (PublishingRESTSupportTransaction* obj) {
	PublishingGallery3KeyFetchTransaction * self;
#line 209 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_GALLERY3_TYPE_KEY_FETCH_TRANSACTION, PublishingGallery3KeyFetchTransaction);
#line 211 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->key);
#line 209 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	PUBLISHING_REST_SUPPORT_TRANSACTION_CLASS (publishing_gallery3_key_fetch_transaction_parent_class)->finalize (obj);
#line 2717 "GalleryConnector.c"
}


GType publishing_gallery3_key_fetch_transaction_get_type (void) {
	static volatile gsize publishing_gallery3_key_fetch_transaction_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_gallery3_key_fetch_transaction_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingGallery3KeyFetchTransactionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_gallery3_key_fetch_transaction_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingGallery3KeyFetchTransaction), 0, (GInstanceInitFunc) publishing_gallery3_key_fetch_transaction_instance_init, NULL };
		GType publishing_gallery3_key_fetch_transaction_type_id;
		publishing_gallery3_key_fetch_transaction_type_id = g_type_register_static (PUBLISHING_GALLERY3_TYPE_BASE_GALLERY_TRANSACTION, "PublishingGallery3KeyFetchTransaction", &g_define_type_info, 0);
		g_once_init_leave (&publishing_gallery3_key_fetch_transaction_type_id__volatile, publishing_gallery3_key_fetch_transaction_type_id);
	}
	return publishing_gallery3_key_fetch_transaction_type_id__volatile;
}


PublishingGallery3GalleryRequestTransaction* publishing_gallery3_gallery_request_transaction_construct (GType object_type, PublishingGallery3Session* session, const gchar* item, PublishingRESTSupportHttpMethod method) {
	PublishingGallery3GalleryRequestTransaction* self = NULL;
	PublishingGallery3Session* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
#line 249 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_SESSION (session), NULL);
#line 249 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (item != NULL, NULL);
#line 253 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = session;
#line 253 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = publishing_rest_support_session_is_authenticated (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession));
#line 253 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (!_tmp1_) {
#line 254 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_error ("GalleryConnector.vala:254: Not authenticated");
#line 2749 "GalleryConnector.c"
	} else {
		PublishingGallery3Session* _tmp2_ = NULL;
		PublishingGallery3Session* _tmp3_ = NULL;
		const gchar* _tmp4_ = NULL;
		const gchar* _tmp5_ = NULL;
		const gchar* _tmp6_ = NULL;
		PublishingRESTSupportHttpMethod _tmp7_ = 0;
		PublishingGallery3Session* _tmp8_ = NULL;
		const gchar* _tmp9_ = NULL;
		const gchar* _tmp10_ = NULL;
#line 257 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp2_ = session;
#line 257 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp3_ = session;
#line 257 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp4_ = publishing_gallery3_session_get_url (_tmp3_);
#line 257 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp5_ = _tmp4_;
#line 257 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp6_ = item;
#line 257 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp7_ = method;
#line 257 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		self = (PublishingGallery3GalleryRequestTransaction*) publishing_gallery3_base_gallery_transaction_construct (object_type, _tmp2_, _tmp5_, _tmp6_, _tmp7_);
#line 258 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp8_ = session;
#line 258 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp9_ = publishing_gallery3_session_get_key (_tmp8_);
#line 258 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp10_ = _tmp9_;
#line 258 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_rest_support_transaction_add_header (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "X-Gallery-Request-Key", _tmp10_);
#line 259 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_rest_support_transaction_add_header (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "X-Gallery-Request-Method", "GET");
#line 2784 "GalleryConnector.c"
	}
#line 249 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return self;
#line 2788 "GalleryConnector.c"
}


PublishingGallery3GalleryRequestTransaction* publishing_gallery3_gallery_request_transaction_new (PublishingGallery3Session* session, const gchar* item, PublishingRESTSupportHttpMethod method) {
#line 249 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return publishing_gallery3_gallery_request_transaction_construct (PUBLISHING_GALLERY3_TYPE_GALLERY_REQUEST_TRANSACTION, session, item, method);
#line 2795 "GalleryConnector.c"
}


static void publishing_gallery3_gallery_request_transaction_class_init (PublishingGallery3GalleryRequestTransactionClass * klass) {
#line 244 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_gallery_request_transaction_parent_class = g_type_class_peek_parent (klass);
#line 2802 "GalleryConnector.c"
}


static void publishing_gallery3_gallery_request_transaction_instance_init (PublishingGallery3GalleryRequestTransaction * self) {
}


GType publishing_gallery3_gallery_request_transaction_get_type (void) {
	static volatile gsize publishing_gallery3_gallery_request_transaction_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_gallery3_gallery_request_transaction_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingGallery3GalleryRequestTransactionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_gallery3_gallery_request_transaction_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingGallery3GalleryRequestTransaction), 0, (GInstanceInitFunc) publishing_gallery3_gallery_request_transaction_instance_init, NULL };
		GType publishing_gallery3_gallery_request_transaction_type_id;
		publishing_gallery3_gallery_request_transaction_type_id = g_type_register_static (PUBLISHING_GALLERY3_TYPE_BASE_GALLERY_TRANSACTION, "PublishingGallery3GalleryRequestTransaction", &g_define_type_info, 0);
		g_once_init_leave (&publishing_gallery3_gallery_request_transaction_type_id__volatile, publishing_gallery3_gallery_request_transaction_type_id);
	}
	return publishing_gallery3_gallery_request_transaction_type_id__volatile;
}


PublishingGallery3GetAlbumURLsTransaction* publishing_gallery3_get_album_ur_ls_transaction_construct (GType object_type, PublishingGallery3Session* session) {
	PublishingGallery3GetAlbumURLsTransaction* self = NULL;
	PublishingGallery3Session* _tmp0_ = NULL;
#line 268 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_SESSION (session), NULL);
#line 270 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = session;
#line 270 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = (PublishingGallery3GetAlbumURLsTransaction*) publishing_gallery3_gallery_request_transaction_construct (object_type, _tmp0_, "/item/1", PUBLISHING_REST_SUPPORT_HTTP_METHOD_GET);
#line 271 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "type", "album");
#line 272 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "scope", "all");
#line 268 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return self;
#line 2837 "GalleryConnector.c"
}


PublishingGallery3GetAlbumURLsTransaction* publishing_gallery3_get_album_ur_ls_transaction_new (PublishingGallery3Session* session) {
#line 268 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return publishing_gallery3_get_album_ur_ls_transaction_construct (PUBLISHING_GALLERY3_TYPE_GET_ALBUM_UR_LS_TRANSACTION, session);
#line 2844 "GalleryConnector.c"
}


static void _vala_array_add2 (gchar*** array, int* length, int* size, gchar* value) {
#line 294 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if ((*length) == (*size)) {
#line 294 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 294 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		*array = g_renew (gchar*, *array, (*size) + 1);
#line 2855 "GalleryConnector.c"
	}
#line 294 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	(*array)[(*length)++] = value;
#line 294 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	(*array)[*length] = NULL;
#line 2861 "GalleryConnector.c"
}


gchar** publishing_gallery3_get_album_ur_ls_transaction_get_album_urls (PublishingGallery3GetAlbumURLsTransaction* self, int* result_length1) {
	gchar** result = NULL;
	JsonNode* root_node = NULL;
	JsonArray* all_members = NULL;
	JsonObject* _tmp2_ = NULL;
	JsonArray* _tmp3_ = NULL;
	gchar** member_urls = NULL;
	gint member_urls_length1 = 0;
	gint _member_urls_size_ = 0;
	gchar** _tmp14_ = NULL;
	gint _tmp14__length1 = 0;
	GError * _inner_error_ = NULL;
#line 276 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_GET_ALBUM_UR_LS_TRANSACTION (self), NULL);
#line 2879 "GalleryConnector.c"
	{
		JsonNode* _tmp0_ = NULL;
		JsonNode* _tmp1_ = NULL;
#line 282 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp1_ = publishing_gallery3_base_gallery_transaction_get_root_node (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_GALLERY3_TYPE_BASE_GALLERY_TRANSACTION, PublishingGallery3BaseGalleryTransaction), &_inner_error_);
#line 282 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp0_ = _tmp1_;
#line 282 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 282 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 2891 "GalleryConnector.c"
				goto __catch1_spit_publishing_publishing_error;
			}
#line 282 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 282 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_clear_error (&_inner_error_);
#line 282 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			return NULL;
#line 2900 "GalleryConnector.c"
		}
#line 282 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		root_node = _tmp0_;
#line 2904 "GalleryConnector.c"
	}
	goto __finally1;
	__catch1_spit_publishing_publishing_error:
	{
		GError* e = NULL;
#line 281 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		e = _inner_error_;
#line 281 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_inner_error_ = NULL;
#line 285 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_error ("GalleryConnector.vala:285: Could not get root node");
#line 281 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_error_free0 (e);
#line 2918 "GalleryConnector.c"
	}
	__finally1:
#line 281 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 281 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 281 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_clear_error (&_inner_error_);
#line 281 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return NULL;
#line 2929 "GalleryConnector.c"
	}
#line 288 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = json_node_get_object (root_node);
#line 288 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp3_ = json_object_get_array_member (_tmp2_, "members");
#line 288 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	all_members = _tmp3_;
#line 291 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	member_urls = NULL;
#line 291 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	member_urls_length1 = 0;
#line 291 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_member_urls_size_ = member_urls_length1;
#line 2943 "GalleryConnector.c"
	{
		guint i = 0U;
#line 293 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		i = (guint) 0;
#line 2948 "GalleryConnector.c"
		{
			gboolean _tmp4_ = FALSE;
#line 293 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp4_ = TRUE;
#line 293 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			while (TRUE) {
#line 2955 "GalleryConnector.c"
				guint _tmp6_ = 0U;
				JsonArray* _tmp7_ = NULL;
				guint _tmp8_ = 0U;
				gchar** _tmp9_ = NULL;
				gint _tmp9__length1 = 0;
				JsonArray* _tmp10_ = NULL;
				guint _tmp11_ = 0U;
				const gchar* _tmp12_ = NULL;
				gchar* _tmp13_ = NULL;
#line 293 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				if (!_tmp4_) {
#line 2967 "GalleryConnector.c"
					guint _tmp5_ = 0U;
#line 293 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					_tmp5_ = i;
#line 293 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					i = _tmp5_ + 1;
#line 2973 "GalleryConnector.c"
				}
#line 293 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp4_ = FALSE;
#line 293 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp6_ = i;
#line 293 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp7_ = all_members;
#line 293 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp8_ = json_array_get_length (_tmp7_);
#line 293 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				if (!(_tmp6_ <= (_tmp8_ - 1))) {
#line 293 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					break;
#line 2987 "GalleryConnector.c"
				}
#line 294 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp9_ = member_urls;
#line 294 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp9__length1 = member_urls_length1;
#line 294 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp10_ = all_members;
#line 294 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp11_ = i;
#line 294 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp12_ = json_array_get_string_element (_tmp10_, _tmp11_);
#line 294 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp13_ = g_strdup (_tmp12_);
#line 294 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_vala_array_add2 (&member_urls, &member_urls_length1, &_member_urls_size_, _tmp13_);
#line 3003 "GalleryConnector.c"
			}
		}
	}
#line 296 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp14_ = member_urls;
#line 296 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp14__length1 = member_urls_length1;
#line 296 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (result_length1) {
#line 296 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		*result_length1 = _tmp14__length1;
#line 3015 "GalleryConnector.c"
	}
#line 296 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp14_;
#line 296 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 3021 "GalleryConnector.c"
}


static void publishing_gallery3_get_album_ur_ls_transaction_class_init (PublishingGallery3GetAlbumURLsTransactionClass * klass) {
#line 266 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_get_album_ur_ls_transaction_parent_class = g_type_class_peek_parent (klass);
#line 3028 "GalleryConnector.c"
}


static void publishing_gallery3_get_album_ur_ls_transaction_instance_init (PublishingGallery3GetAlbumURLsTransaction * self) {
}


GType publishing_gallery3_get_album_ur_ls_transaction_get_type (void) {
	static volatile gsize publishing_gallery3_get_album_ur_ls_transaction_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_gallery3_get_album_ur_ls_transaction_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingGallery3GetAlbumURLsTransactionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_gallery3_get_album_ur_ls_transaction_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingGallery3GetAlbumURLsTransaction), 0, (GInstanceInitFunc) publishing_gallery3_get_album_ur_ls_transaction_instance_init, NULL };
		GType publishing_gallery3_get_album_ur_ls_transaction_type_id;
		publishing_gallery3_get_album_ur_ls_transaction_type_id = g_type_register_static (PUBLISHING_GALLERY3_TYPE_GALLERY_REQUEST_TRANSACTION, "PublishingGallery3GetAlbumURLsTransaction", &g_define_type_info, 0);
		g_once_init_leave (&publishing_gallery3_get_album_ur_ls_transaction_type_id__volatile, publishing_gallery3_get_album_ur_ls_transaction_type_id);
	}
	return publishing_gallery3_get_album_ur_ls_transaction_type_id__volatile;
}


static void _vala_array_add3 (gchar*** array, int* length, int* size, gchar* value) {
#line 340 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if ((*length) == (*size)) {
#line 340 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 340 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		*array = g_renew (gchar*, *array, (*size) + 1);
#line 3055 "GalleryConnector.c"
	}
#line 340 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	(*array)[(*length)++] = value;
#line 340 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	(*array)[*length] = NULL;
#line 3061 "GalleryConnector.c"
}


static gchar* _vala_g_strjoinv (const gchar* separator, gchar** str_array, int str_array_length1) {
	gchar* result = NULL;
	const gchar* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_ = FALSE;
	gchar** _tmp3_ = NULL;
	gint _tmp3__length1 = 0;
#line 1054 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp0_ = separator;
#line 1054 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	if (_tmp0_ == NULL) {
#line 1055 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		separator = "";
#line 3078 "GalleryConnector.c"
	}
#line 1057 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp3_ = str_array;
#line 1057 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp3__length1 = str_array_length1;
#line 1057 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	if (_tmp3_ != NULL) {
#line 1057 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp2_ = TRUE;
#line 3088 "GalleryConnector.c"
	} else {
		gchar** _tmp4_ = NULL;
		gint _tmp4__length1 = 0;
#line 1057 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp4_ = str_array;
#line 1057 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp4__length1 = str_array_length1;
#line 1057 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp2_ = _tmp4__length1 > 0;
#line 3098 "GalleryConnector.c"
	}
#line 1057 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	if (_tmp2_) {
#line 1057 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp1_ = TRUE;
#line 3104 "GalleryConnector.c"
	} else {
		gboolean _tmp5_ = FALSE;
		gchar** _tmp6_ = NULL;
		gint _tmp6__length1 = 0;
#line 1057 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp6_ = str_array;
#line 1057 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp6__length1 = str_array_length1;
#line 1057 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		if (_tmp6__length1 == -1) {
#line 3115 "GalleryConnector.c"
			gchar** _tmp7_ = NULL;
			gint _tmp7__length1 = 0;
			const gchar* _tmp8_ = NULL;
#line 1057 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
			_tmp7_ = str_array;
#line 1057 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
			_tmp7__length1 = str_array_length1;
#line 1057 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
			_tmp8_ = _tmp7_[0];
#line 1057 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
			_tmp5_ = _tmp8_ != NULL;
#line 3127 "GalleryConnector.c"
		} else {
#line 1057 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
			_tmp5_ = FALSE;
#line 3131 "GalleryConnector.c"
		}
#line 1057 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp1_ = _tmp5_;
#line 3135 "GalleryConnector.c"
	}
#line 1057 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	if (_tmp1_) {
#line 3139 "GalleryConnector.c"
		gint i = 0;
		gsize len = 0UL;
		gint _tmp31_ = 0;
		gint _tmp33_ = 0;
		gint _tmp34_ = 0;
		gsize _tmp35_ = 0UL;
		const gchar* _tmp36_ = NULL;
		gint _tmp37_ = 0;
		gint _tmp38_ = 0;
		gint _tmp39_ = 0;
		const gchar* res = NULL;
		gsize _tmp40_ = 0UL;
		void* _tmp41_ = NULL;
		void* ptr = NULL;
		const gchar* _tmp42_ = NULL;
		gchar** _tmp43_ = NULL;
		gint _tmp43__length1 = 0;
		const gchar* _tmp44_ = NULL;
		void* _tmp45_ = NULL;
		const gchar* _tmp62_ = NULL;
#line 1059 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		len = (gsize) 1;
#line 3162 "GalleryConnector.c"
		{
			gboolean _tmp9_ = FALSE;
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
			i = 0;
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
			_tmp9_ = TRUE;
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
			while (TRUE) {
#line 3171 "GalleryConnector.c"
				gboolean _tmp11_ = FALSE;
				gboolean _tmp12_ = FALSE;
				gchar** _tmp13_ = NULL;
				gint _tmp13__length1 = 0;
				gint _tmp21_ = 0;
				gchar** _tmp22_ = NULL;
				gint _tmp22__length1 = 0;
				gint _tmp23_ = 0;
				const gchar* _tmp24_ = NULL;
				gsize _tmp30_ = 0UL;
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				if (!_tmp9_) {
#line 3184 "GalleryConnector.c"
					gint _tmp10_ = 0;
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp10_ = i;
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					i = _tmp10_ + 1;
#line 3190 "GalleryConnector.c"
				}
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp9_ = FALSE;
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp13_ = str_array;
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp13__length1 = str_array_length1;
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				if (_tmp13__length1 != -1) {
#line 3200 "GalleryConnector.c"
					gint _tmp14_ = 0;
					gchar** _tmp15_ = NULL;
					gint _tmp15__length1 = 0;
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp14_ = i;
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp15_ = str_array;
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp15__length1 = str_array_length1;
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp12_ = _tmp14_ < _tmp15__length1;
#line 3212 "GalleryConnector.c"
				} else {
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp12_ = FALSE;
#line 3216 "GalleryConnector.c"
				}
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				if (_tmp12_) {
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp11_ = TRUE;
#line 3222 "GalleryConnector.c"
				} else {
					gboolean _tmp16_ = FALSE;
					gchar** _tmp17_ = NULL;
					gint _tmp17__length1 = 0;
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp17_ = str_array;
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp17__length1 = str_array_length1;
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					if (_tmp17__length1 == -1) {
#line 3233 "GalleryConnector.c"
						gchar** _tmp18_ = NULL;
						gint _tmp18__length1 = 0;
						gint _tmp19_ = 0;
						const gchar* _tmp20_ = NULL;
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
						_tmp18_ = str_array;
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
						_tmp18__length1 = str_array_length1;
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
						_tmp19_ = i;
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
						_tmp20_ = _tmp18_[_tmp19_];
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
						_tmp16_ = _tmp20_ != NULL;
#line 3248 "GalleryConnector.c"
					} else {
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
						_tmp16_ = FALSE;
#line 3252 "GalleryConnector.c"
					}
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp11_ = _tmp16_;
#line 3256 "GalleryConnector.c"
				}
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				if (!_tmp11_) {
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					break;
#line 3262 "GalleryConnector.c"
				}
#line 1061 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp22_ = str_array;
#line 1061 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp22__length1 = str_array_length1;
#line 1061 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp23_ = i;
#line 1061 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp24_ = _tmp22_[_tmp23_];
#line 1061 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				if (_tmp24_ != NULL) {
#line 3274 "GalleryConnector.c"
					gchar** _tmp25_ = NULL;
					gint _tmp25__length1 = 0;
					gint _tmp26_ = 0;
					const gchar* _tmp27_ = NULL;
					gint _tmp28_ = 0;
					gint _tmp29_ = 0;
#line 1061 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp25_ = str_array;
#line 1061 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp25__length1 = str_array_length1;
#line 1061 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp26_ = i;
#line 1061 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp27_ = _tmp25_[_tmp26_];
#line 1061 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp28_ = strlen ((const gchar*) _tmp27_);
#line 1061 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp29_ = _tmp28_;
#line 1061 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp21_ = _tmp29_;
#line 3295 "GalleryConnector.c"
				} else {
#line 1061 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp21_ = 0;
#line 3299 "GalleryConnector.c"
				}
#line 1061 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp30_ = len;
#line 1061 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				len = _tmp30_ + _tmp21_;
#line 3305 "GalleryConnector.c"
			}
		}
#line 1063 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp31_ = i;
#line 1063 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		if (_tmp31_ == 0) {
#line 3312 "GalleryConnector.c"
			gchar* _tmp32_ = NULL;
#line 1064 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
			_tmp32_ = g_strdup ("");
#line 1064 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
			result = _tmp32_;
#line 1064 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
			return result;
#line 3320 "GalleryConnector.c"
		}
#line 1066 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp33_ = i;
#line 1066 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		str_array_length1 = _tmp33_;
#line 1066 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp34_ = str_array_length1;
#line 1067 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp35_ = len;
#line 1067 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp36_ = separator;
#line 1067 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp37_ = strlen ((const gchar*) _tmp36_);
#line 1067 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp38_ = _tmp37_;
#line 1067 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp39_ = i;
#line 1067 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		len = _tmp35_ + (_tmp38_ * (_tmp39_ - 1));
#line 1069 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp40_ = len;
#line 1069 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp41_ = g_malloc (_tmp40_);
#line 1069 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		res = _tmp41_;
#line 1070 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp42_ = res;
#line 1070 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp43_ = str_array;
#line 1070 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp43__length1 = str_array_length1;
#line 1070 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp44_ = _tmp43_[0];
#line 1070 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp45_ = g_stpcpy ((void*) _tmp42_, (const gchar*) _tmp44_);
#line 1070 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		ptr = _tmp45_;
#line 3358 "GalleryConnector.c"
		{
			gboolean _tmp46_ = FALSE;
#line 1071 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
			i = 1;
#line 1071 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
			_tmp46_ = TRUE;
#line 1071 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
			while (TRUE) {
#line 3367 "GalleryConnector.c"
				gint _tmp48_ = 0;
				gchar** _tmp49_ = NULL;
				gint _tmp49__length1 = 0;
				void* _tmp50_ = NULL;
				const gchar* _tmp51_ = NULL;
				void* _tmp52_ = NULL;
				const gchar* _tmp53_ = NULL;
				gchar** _tmp54_ = NULL;
				gint _tmp54__length1 = 0;
				gint _tmp55_ = 0;
				const gchar* _tmp56_ = NULL;
				void* _tmp60_ = NULL;
				void* _tmp61_ = NULL;
#line 1071 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				if (!_tmp46_) {
#line 3383 "GalleryConnector.c"
					gint _tmp47_ = 0;
#line 1071 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp47_ = i;
#line 1071 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					i = _tmp47_ + 1;
#line 3389 "GalleryConnector.c"
				}
#line 1071 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp46_ = FALSE;
#line 1071 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp48_ = i;
#line 1071 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp49_ = str_array;
#line 1071 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp49__length1 = str_array_length1;
#line 1071 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				if (!(_tmp48_ < _tmp49__length1)) {
#line 1071 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					break;
#line 3403 "GalleryConnector.c"
				}
#line 1072 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp50_ = ptr;
#line 1072 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp51_ = separator;
#line 1072 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp52_ = g_stpcpy (_tmp50_, (const gchar*) _tmp51_);
#line 1072 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				ptr = _tmp52_;
#line 1073 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp54_ = str_array;
#line 1073 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp54__length1 = str_array_length1;
#line 1073 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp55_ = i;
#line 1073 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp56_ = _tmp54_[_tmp55_];
#line 1073 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				if (_tmp56_ != NULL) {
#line 3423 "GalleryConnector.c"
					gchar** _tmp57_ = NULL;
					gint _tmp57__length1 = 0;
					gint _tmp58_ = 0;
					const gchar* _tmp59_ = NULL;
#line 1073 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp57_ = str_array;
#line 1073 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp57__length1 = str_array_length1;
#line 1073 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp58_ = i;
#line 1073 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp59_ = _tmp57_[_tmp58_];
#line 1073 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp53_ = (const gchar*) _tmp59_;
#line 3438 "GalleryConnector.c"
				} else {
#line 1073 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp53_ = "";
#line 3442 "GalleryConnector.c"
				}
#line 1073 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp60_ = ptr;
#line 1073 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp61_ = g_stpcpy (_tmp60_, _tmp53_);
#line 1073 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				ptr = _tmp61_;
#line 3450 "GalleryConnector.c"
			}
		}
#line 1076 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp62_ = res;
#line 1076 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		res = NULL;
#line 1076 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		result = (gchar*) _tmp62_;
#line 1076 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		return result;
#line 3461 "GalleryConnector.c"
	} else {
		gchar* _tmp63_ = NULL;
#line 1078 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp63_ = g_strdup ("");
#line 1078 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		result = _tmp63_;
#line 1078 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		return result;
#line 3470 "GalleryConnector.c"
	}
}


PublishingGallery3GetAlbumsTransaction* publishing_gallery3_get_albums_transaction_construct (GType object_type, PublishingGallery3Session* session, gchar** _album_urls, int _album_urls_length1, guint start) {
	PublishingGallery3GetAlbumsTransaction* self = NULL;
	PublishingGallery3Session* _tmp0_ = NULL;
	gchar** _tmp1_ = NULL;
	gint _tmp1__length1 = 0;
	gchar* url_list = NULL;
	gchar* _tmp2_ = NULL;
	gchar** my_album_urls = NULL;
	gint my_album_urls_length1 = 0;
	gint _my_album_urls_size_ = 0;
	gchar* endpoint_url = NULL;
	PublishingGallery3Session* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	gint _tmp5_ = 0;
	const gchar* _tmp6_ = NULL;
	gint url_length = 0;
	gint _tmp10_ = 0;
	guint _tmp11_ = 0U;
	gchar** _tmp12_ = NULL;
	gint _tmp12__length1 = 0;
	gchar** _tmp13_ = NULL;
	gint _tmp13__length1 = 0;
	const gchar* _tmp51_ = NULL;
	gchar* _tmp52_ = NULL;
	const gchar* _tmp53_ = NULL;
#line 312 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_SESSION (session), NULL);
#line 315 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = session;
#line 315 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = (PublishingGallery3GetAlbumsTransaction*) publishing_gallery3_gallery_request_transaction_construct (object_type, _tmp0_, "/items", PUBLISHING_REST_SUPPORT_HTTP_METHOD_GET);
#line 316 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "scope", "all");
#line 319 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = _album_urls;
#line 319 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1__length1 = _album_urls_length1;
#line 319 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_get_albums_transaction_set_album_urls (self, _tmp1_, _tmp1__length1);
#line 328 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = g_strdup ("[");
#line 328 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	url_list = _tmp2_;
#line 329 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	my_album_urls = NULL;
#line 329 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	my_album_urls_length1 = 0;
#line 329 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_my_album_urls_size_ = my_album_urls_length1;
#line 330 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp3_ = session;
#line 330 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp4_ = publishing_rest_support_session_get_endpoint_url (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession));
#line 330 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	endpoint_url = _tmp4_;
#line 331 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp6_ = endpoint_url;
#line 331 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (NULL != _tmp6_) {
#line 3534 "GalleryConnector.c"
		const gchar* _tmp7_ = NULL;
		gint _tmp8_ = 0;
		gint _tmp9_ = 0;
#line 332 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp7_ = endpoint_url;
#line 332 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp8_ = strlen (_tmp7_);
#line 332 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp9_ = _tmp8_;
#line 332 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp5_ = _tmp9_;
#line 3546 "GalleryConnector.c"
	} else {
#line 332 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp5_ = 0;
#line 3550 "GalleryConnector.c"
	}
#line 331 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	url_length = _tmp5_;
#line 333 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp10_ = url_length;
#line 333 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	url_length = _tmp10_ + 18;
#line 336 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp11_ = start;
#line 336 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp12_ = publishing_gallery3_get_albums_transaction_get_album_urls (self, &_tmp12__length1);
#line 336 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp13_ = _tmp12_;
#line 336 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp13__length1 = _tmp12__length1;
#line 336 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (_tmp11_ <= ((guint) (_tmp13__length1 - 1))) {
#line 3568 "GalleryConnector.c"
		guint _tmp14_ = 0U;
		const gchar* _tmp43_ = NULL;
		gchar** _tmp44_ = NULL;
		gint _tmp44__length1 = 0;
		gchar* _tmp45_ = NULL;
		gchar* _tmp46_ = NULL;
		gchar* _tmp47_ = NULL;
		guint _tmp48_ = 0U;
		gchar** _tmp49_ = NULL;
		gint _tmp49__length1 = 0;
		gchar** _tmp50_ = NULL;
		gint _tmp50__length1 = 0;
#line 338 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp14_ = start;
#line 338 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_gallery3_get_albums_transaction_set_urls_sent (self, _tmp14_);
#line 3585 "GalleryConnector.c"
		{
			gboolean _tmp15_ = FALSE;
#line 339 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp15_ = TRUE;
#line 339 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			while (TRUE) {
#line 3592 "GalleryConnector.c"
				gchar** _tmp27_ = NULL;
				gint _tmp27__length1 = 0;
				gchar** _tmp28_ = NULL;
				gint _tmp28__length1 = 0;
				gchar** _tmp29_ = NULL;
				gint _tmp29__length1 = 0;
				guint _tmp30_ = 0U;
				const gchar* _tmp31_ = NULL;
				gchar* _tmp32_ = NULL;
				gchar* _tmp33_ = NULL;
				gchar* _tmp34_ = NULL;
				gint _tmp35_ = 0;
				gchar** _tmp36_ = NULL;
				gint _tmp36__length1 = 0;
				gchar** _tmp37_ = NULL;
				gint _tmp37__length1 = 0;
				guint _tmp38_ = 0U;
				const gchar* _tmp39_ = NULL;
				gint _tmp40_ = 0;
				gint _tmp41_ = 0;
				guint _tmp42_ = 0U;
#line 339 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				if (!_tmp15_) {
#line 3616 "GalleryConnector.c"
					gboolean _tmp16_ = FALSE;
					guint _tmp17_ = 0U;
					gchar** _tmp18_ = NULL;
					gint _tmp18__length1 = 0;
					gchar** _tmp19_ = NULL;
					gint _tmp19__length1 = 0;
#line 344 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					_tmp17_ = self->priv->_urls_sent;
#line 344 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					_tmp18_ = publishing_gallery3_get_albums_transaction_get_album_urls (self, &_tmp18__length1);
#line 344 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					_tmp19_ = _tmp18_;
#line 344 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					_tmp19__length1 = _tmp18__length1;
#line 344 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					if (_tmp17_ <= ((guint) (_tmp19__length1 - 1))) {
#line 3633 "GalleryConnector.c"
						gint _tmp20_ = 0;
						gchar** _tmp21_ = NULL;
						gint _tmp21__length1 = 0;
						gchar** _tmp22_ = NULL;
						gint _tmp22__length1 = 0;
						guint _tmp23_ = 0U;
						const gchar* _tmp24_ = NULL;
						gint _tmp25_ = 0;
						gint _tmp26_ = 0;
#line 345 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
						_tmp20_ = url_length;
#line 345 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
						_tmp21_ = publishing_gallery3_get_albums_transaction_get_album_urls (self, &_tmp21__length1);
#line 345 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
						_tmp22_ = _tmp21_;
#line 345 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
						_tmp22__length1 = _tmp21__length1;
#line 345 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
						_tmp23_ = self->priv->_urls_sent;
#line 345 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
						_tmp24_ = _tmp22_[_tmp23_];
#line 345 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
						_tmp25_ = strlen (_tmp24_);
#line 345 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
						_tmp26_ = _tmp25_;
#line 345 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
						_tmp16_ = ((_tmp20_ + _tmp26_) + 3) <= 255;
#line 3661 "GalleryConnector.c"
					} else {
#line 344 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
						_tmp16_ = FALSE;
#line 3665 "GalleryConnector.c"
					}
#line 344 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					if (!_tmp16_) {
#line 344 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
						break;
#line 3671 "GalleryConnector.c"
					}
				}
#line 339 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp15_ = FALSE;
#line 340 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp27_ = my_album_urls;
#line 340 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp27__length1 = my_album_urls_length1;
#line 340 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp28_ = publishing_gallery3_get_albums_transaction_get_album_urls (self, &_tmp28__length1);
#line 340 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp29_ = _tmp28_;
#line 340 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp29__length1 = _tmp28__length1;
#line 340 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp30_ = self->priv->_urls_sent;
#line 340 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp31_ = _tmp29_[_tmp30_];
#line 340 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp32_ = g_strconcat ("\"", _tmp31_, NULL);
#line 340 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp33_ = _tmp32_;
#line 340 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp34_ = g_strconcat (_tmp33_, "\"", NULL);
#line 340 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_vala_array_add3 (&my_album_urls, &my_album_urls_length1, &_my_album_urls_size_, _tmp34_);
#line 340 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_g_free0 (_tmp33_);
#line 342 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp35_ = url_length;
#line 342 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp36_ = publishing_gallery3_get_albums_transaction_get_album_urls (self, &_tmp36__length1);
#line 342 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp37_ = _tmp36_;
#line 342 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp37__length1 = _tmp36__length1;
#line 342 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp38_ = self->priv->_urls_sent;
#line 342 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp39_ = _tmp37_[_tmp38_];
#line 342 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp40_ = strlen (_tmp39_);
#line 342 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp41_ = _tmp40_;
#line 342 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				url_length = _tmp35_ + (_tmp41_ + 3);
#line 343 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp42_ = self->priv->_urls_sent;
#line 343 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				publishing_gallery3_get_albums_transaction_set_urls_sent (self, _tmp42_ + 1);
#line 3722 "GalleryConnector.c"
			}
		}
#line 347 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp43_ = url_list;
#line 347 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp44_ = my_album_urls;
#line 347 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp44__length1 = my_album_urls_length1;
#line 347 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp45_ = _vala_g_strjoinv (",", _tmp44_, _tmp44__length1);
#line 347 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp46_ = _tmp45_;
#line 347 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp47_ = g_strconcat (_tmp43_, _tmp46_, NULL);
#line 347 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_free0 (url_list);
#line 347 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		url_list = _tmp47_;
#line 347 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_free0 (_tmp46_);
#line 349 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp48_ = self->priv->_urls_sent;
#line 349 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp49_ = publishing_gallery3_get_albums_transaction_get_album_urls (self, &_tmp49__length1);
#line 349 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp50_ = _tmp49_;
#line 349 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp50__length1 = _tmp49__length1;
#line 349 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_gallery3_get_albums_transaction_set_more_urls (self, _tmp48_ <= ((guint) (_tmp50__length1 - 1)));
#line 3753 "GalleryConnector.c"
	}
#line 352 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp51_ = url_list;
#line 352 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp52_ = g_strconcat (_tmp51_, "]", NULL);
#line 352 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (url_list);
#line 352 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	url_list = _tmp52_;
#line 354 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp53_ = url_list;
#line 354 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "urls", _tmp53_);
#line 312 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (endpoint_url);
#line 312 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	my_album_urls = (_vala_array_free (my_album_urls, my_album_urls_length1, (GDestroyNotify) g_free), NULL);
#line 312 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (url_list);
#line 312 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return self;
#line 3775 "GalleryConnector.c"
}


PublishingGallery3GetAlbumsTransaction* publishing_gallery3_get_albums_transaction_new (PublishingGallery3Session* session, gchar** _album_urls, int _album_urls_length1, guint start) {
#line 312 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return publishing_gallery3_get_albums_transaction_construct (PUBLISHING_GALLERY3_TYPE_GET_ALBUMS_TRANSACTION, session, _album_urls, _album_urls_length1, start);
#line 3782 "GalleryConnector.c"
}


static gpointer _publishing_gallery3_album_ref0 (gpointer self) {
#line 371 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return self ? publishing_gallery3_album_ref (self) : NULL;
#line 3789 "GalleryConnector.c"
}


static void _vala_array_add4 (PublishingGallery3Album*** array, int* length, int* size, PublishingGallery3Album* value) {
#line 371 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if ((*length) == (*size)) {
#line 371 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 371 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		*array = g_renew (PublishingGallery3Album*, *array, (*size) + 1);
#line 3800 "GalleryConnector.c"
	}
#line 371 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	(*array)[(*length)++] = value;
#line 371 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	(*array)[*length] = NULL;
#line 3806 "GalleryConnector.c"
}


static const gchar* string_to_string (const gchar* self) {
	const gchar* result = NULL;
#line 1412 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1413 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	result = self;
#line 1413 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	return result;
#line 3818 "GalleryConnector.c"
}


PublishingGallery3Album** publishing_gallery3_get_albums_transaction_get_albums (PublishingGallery3GetAlbumsTransaction* self, int* result_length1, GError** error) {
	PublishingGallery3Album** result = NULL;
	PublishingGallery3Album** albums = NULL;
	gint albums_length1 = 0;
	gint _albums_size_ = 0;
	PublishingGallery3Album* tmp_album = NULL;
	JsonNode* root_node = NULL;
	JsonNode* _tmp0_ = NULL;
	JsonArray* members = NULL;
	JsonArray* _tmp1_ = NULL;
	PublishingGallery3Album** _tmp23_ = NULL;
	gint _tmp23__length1 = 0;
	GError * _inner_error_ = NULL;
#line 358 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_GET_ALBUMS_TRANSACTION (self), NULL);
#line 361 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	albums = NULL;
#line 361 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	albums_length1 = 0;
#line 361 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_albums_size_ = albums_length1;
#line 363 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = publishing_gallery3_base_gallery_transaction_get_root_node (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_GALLERY3_TYPE_BASE_GALLERY_TRANSACTION, PublishingGallery3BaseGalleryTransaction), &_inner_error_);
#line 363 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	root_node = _tmp0_;
#line 363 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 363 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 363 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_propagate_error (error, _inner_error_);
#line 363 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_publishing_gallery3_album_unref0 (tmp_album);
#line 363 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			albums = (_vala_array_free (albums, albums_length1, (GDestroyNotify) publishing_gallery3_album_unref), NULL);
#line 363 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			return NULL;
#line 3859 "GalleryConnector.c"
		} else {
#line 363 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_publishing_gallery3_album_unref0 (tmp_album);
#line 363 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			albums = (_vala_array_free (albums, albums_length1, (GDestroyNotify) publishing_gallery3_album_unref), NULL);
#line 363 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 363 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_clear_error (&_inner_error_);
#line 363 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			return NULL;
#line 3871 "GalleryConnector.c"
		}
	}
#line 364 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = json_node_get_array (root_node);
#line 364 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	members = _tmp1_;
#line 3878 "GalleryConnector.c"
	{
		guint i = 0U;
#line 367 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		i = (guint) 0;
#line 3883 "GalleryConnector.c"
		{
			gboolean _tmp2_ = FALSE;
#line 367 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp2_ = TRUE;
#line 367 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			while (TRUE) {
#line 3890 "GalleryConnector.c"
				guint _tmp4_ = 0U;
				JsonArray* _tmp5_ = NULL;
				guint _tmp6_ = 0U;
				JsonArray* _tmp7_ = NULL;
				guint _tmp8_ = 0U;
				JsonObject* _tmp9_ = NULL;
				PublishingGallery3Album* _tmp10_ = NULL;
				PublishingGallery3Album* _tmp11_ = NULL;
				gboolean _tmp12_ = FALSE;
				gboolean _tmp13_ = FALSE;
#line 367 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				if (!_tmp2_) {
#line 3903 "GalleryConnector.c"
					guint _tmp3_ = 0U;
#line 367 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					_tmp3_ = i;
#line 367 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					i = _tmp3_ + 1;
#line 3909 "GalleryConnector.c"
				}
#line 367 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp2_ = FALSE;
#line 367 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp4_ = i;
#line 367 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp5_ = members;
#line 367 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp6_ = json_array_get_length (_tmp5_);
#line 367 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				if (!(_tmp4_ <= (_tmp6_ - 1))) {
#line 367 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					break;
#line 3923 "GalleryConnector.c"
				}
#line 368 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp7_ = members;
#line 368 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp8_ = i;
#line 368 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp9_ = json_array_get_object_element (_tmp7_, _tmp8_);
#line 368 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp10_ = publishing_gallery3_album_new (_tmp9_);
#line 368 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_publishing_gallery3_album_unref0 (tmp_album);
#line 368 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				tmp_album = _tmp10_;
#line 370 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp11_ = tmp_album;
#line 370 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp12_ = publishing_gallery3_album_get_editable (_tmp11_);
#line 370 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp13_ = _tmp12_;
#line 370 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				if (_tmp13_) {
#line 3945 "GalleryConnector.c"
					PublishingGallery3Album** _tmp14_ = NULL;
					gint _tmp14__length1 = 0;
					PublishingGallery3Album* _tmp15_ = NULL;
					PublishingGallery3Album* _tmp16_ = NULL;
#line 371 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					_tmp14_ = albums;
#line 371 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					_tmp14__length1 = albums_length1;
#line 371 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					_tmp15_ = tmp_album;
#line 371 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					_tmp16_ = _publishing_gallery3_album_ref0 (_tmp15_);
#line 371 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					_vala_array_add4 (&albums, &albums_length1, &_albums_size_, _tmp16_);
#line 3960 "GalleryConnector.c"
				} else {
					PublishingGallery3Album* _tmp17_ = NULL;
					const gchar* _tmp18_ = NULL;
					const gchar* _tmp19_ = NULL;
					const gchar* _tmp20_ = NULL;
					gchar* _tmp21_ = NULL;
					gchar* _tmp22_ = NULL;
#line 373 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					_tmp17_ = tmp_album;
#line 373 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					_tmp18_ = publishing_gallery3_album_get_title (_tmp17_);
#line 373 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					_tmp19_ = _tmp18_;
#line 373 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					_tmp20_ = string_to_string (_tmp19_);
#line 373 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					_tmp21_ = g_strconcat ("Album \"", _tmp20_, "\" is not editable", NULL);
#line 373 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					_tmp22_ = _tmp21_;
#line 373 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					g_warning ("GalleryConnector.vala:373: %s", _tmp22_);
#line 373 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					_g_free0 (_tmp22_);
#line 3984 "GalleryConnector.c"
				}
			}
		}
	}
#line 376 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp23_ = albums;
#line 376 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp23__length1 = albums_length1;
#line 376 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (result_length1) {
#line 376 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		*result_length1 = _tmp23__length1;
#line 3997 "GalleryConnector.c"
	}
#line 376 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp23_;
#line 376 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_publishing_gallery3_album_unref0 (tmp_album);
#line 376 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 4005 "GalleryConnector.c"
}


gchar** publishing_gallery3_get_albums_transaction_get_album_urls (PublishingGallery3GetAlbumsTransaction* self, int* result_length1) {
	gchar** result;
	gchar** _tmp0_ = NULL;
	gint _tmp0__length1 = 0;
	gchar** _tmp1_ = NULL;
	gint _tmp1__length1 = 0;
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_GET_ALBUMS_TRANSACTION (self), NULL);
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->_album_urls;
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0__length1 = self->priv->_album_urls_length1;
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = _tmp0_;
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1__length1 = _tmp0__length1;
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (result_length1) {
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		*result_length1 = _tmp1__length1;
#line 4029 "GalleryConnector.c"
	}
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp1_;
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 4035 "GalleryConnector.c"
}


static gchar** _vala_array_dup2 (gchar** self, int length) {
	gchar** result;
	int i;
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = g_new0 (gchar*, length + 1);
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	for (i = 0; i < length; i++) {
#line 4046 "GalleryConnector.c"
		gchar* _tmp0_ = NULL;
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp0_ = g_strdup (self[i]);
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		result[i] = _tmp0_;
#line 4052 "GalleryConnector.c"
	}
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 4056 "GalleryConnector.c"
}


static void publishing_gallery3_get_albums_transaction_set_album_urls (PublishingGallery3GetAlbumsTransaction* self, gchar** value, int value_length1) {
	gchar** _tmp0_ = NULL;
	gint _tmp0__length1 = 0;
	gchar** _tmp1_ = NULL;
	gint _tmp1__length1 = 0;
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_GET_ALBUMS_TRANSACTION (self));
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = value;
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0__length1 = value_length1;
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = (_tmp0_ != NULL) ? _vala_array_dup2 (_tmp0_, _tmp0__length1) : ((gpointer) _tmp0_);
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1__length1 = _tmp0__length1;
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_album_urls = (_vala_array_free (self->priv->_album_urls, self->priv->_album_urls_length1, (GDestroyNotify) g_free), NULL);
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_album_urls = _tmp1_;
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_album_urls_length1 = _tmp1__length1;
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->__album_urls_size_ = self->priv->_album_urls_length1;
#line 4083 "GalleryConnector.c"
}


guint publishing_gallery3_get_albums_transaction_get_urls_sent (PublishingGallery3GetAlbumsTransaction* self) {
	guint result;
	guint _tmp0_ = 0U;
#line 308 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_GET_ALBUMS_TRANSACTION (self), 0U);
#line 308 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->_urls_sent;
#line 308 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp0_;
#line 308 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 4098 "GalleryConnector.c"
}


static void publishing_gallery3_get_albums_transaction_set_urls_sent (PublishingGallery3GetAlbumsTransaction* self, guint value) {
	guint _tmp0_ = 0U;
#line 308 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_GET_ALBUMS_TRANSACTION (self));
#line 308 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = value;
#line 308 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_urls_sent = _tmp0_;
#line 4110 "GalleryConnector.c"
}


gboolean publishing_gallery3_get_albums_transaction_get_more_urls (PublishingGallery3GetAlbumsTransaction* self) {
	gboolean result;
	gboolean _tmp0_ = FALSE;
#line 310 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_GET_ALBUMS_TRANSACTION (self), FALSE);
#line 310 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->_more_urls;
#line 310 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp0_;
#line 310 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 4125 "GalleryConnector.c"
}


static void publishing_gallery3_get_albums_transaction_set_more_urls (PublishingGallery3GetAlbumsTransaction* self, gboolean value) {
	gboolean _tmp0_ = FALSE;
#line 310 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_GET_ALBUMS_TRANSACTION (self));
#line 310 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = value;
#line 310 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_more_urls = _tmp0_;
#line 4137 "GalleryConnector.c"
}


static void publishing_gallery3_get_albums_transaction_class_init (PublishingGallery3GetAlbumsTransactionClass * klass) {
#line 302 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_get_albums_transaction_parent_class = g_type_class_peek_parent (klass);
#line 302 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	((PublishingRESTSupportTransactionClass *) klass)->finalize = publishing_gallery3_get_albums_transaction_finalize;
#line 302 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_type_class_add_private (klass, sizeof (PublishingGallery3GetAlbumsTransactionPrivate));
#line 4148 "GalleryConnector.c"
}


static void publishing_gallery3_get_albums_transaction_instance_init (PublishingGallery3GetAlbumsTransaction * self) {
#line 302 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv = PUBLISHING_GALLERY3_GET_ALBUMS_TRANSACTION_GET_PRIVATE (self);
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_album_urls = NULL;
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_album_urls_length1 = 0;
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->__album_urls_size_ = self->priv->_album_urls_length1;
#line 308 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_urls_sent = (guint) 0;
#line 310 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_more_urls = FALSE;
#line 4165 "GalleryConnector.c"
}


static void publishing_gallery3_get_albums_transaction_finalize (PublishingRESTSupportTransaction* obj) {
	PublishingGallery3GetAlbumsTransaction * self;
#line 302 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_GALLERY3_TYPE_GET_ALBUMS_TRANSACTION, PublishingGallery3GetAlbumsTransaction);
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_album_urls = (_vala_array_free (self->priv->_album_urls, self->priv->_album_urls_length1, (GDestroyNotify) g_free), NULL);
#line 302 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	PUBLISHING_REST_SUPPORT_TRANSACTION_CLASS (publishing_gallery3_get_albums_transaction_parent_class)->finalize (obj);
#line 4177 "GalleryConnector.c"
}


GType publishing_gallery3_get_albums_transaction_get_type (void) {
	static volatile gsize publishing_gallery3_get_albums_transaction_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_gallery3_get_albums_transaction_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingGallery3GetAlbumsTransactionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_gallery3_get_albums_transaction_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingGallery3GetAlbumsTransaction), 0, (GInstanceInitFunc) publishing_gallery3_get_albums_transaction_instance_init, NULL };
		GType publishing_gallery3_get_albums_transaction_type_id;
		publishing_gallery3_get_albums_transaction_type_id = g_type_register_static (PUBLISHING_GALLERY3_TYPE_GALLERY_REQUEST_TRANSACTION, "PublishingGallery3GetAlbumsTransaction", &g_define_type_info, 0);
		g_once_init_leave (&publishing_gallery3_get_albums_transaction_type_id__volatile, publishing_gallery3_get_albums_transaction_type_id);
	}
	return publishing_gallery3_get_albums_transaction_type_id__volatile;
}


static void _vala_JsonNode_free (JsonNode* self) {
#line 388 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_boxed_free (json_node_get_type (), self);
#line 4196 "GalleryConnector.c"
}


PublishingGallery3GalleryGetTagTransaction* publishing_gallery3_gallery_get_tag_transaction_construct (GType object_type, PublishingGallery3Session* session, const gchar* tag_name) {
	PublishingGallery3GalleryGetTagTransaction* self = NULL;
	PublishingGallery3Session* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
#line 386 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_SESSION (session), NULL);
#line 386 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (tag_name != NULL, NULL);
#line 388 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = session;
#line 388 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = publishing_rest_support_session_is_authenticated (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession));
#line 388 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (!_tmp1_) {
#line 389 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_error ("GalleryConnector.vala:389: Not authenticated");
#line 4216 "GalleryConnector.c"
	} else {
		JsonGenerator* entity = NULL;
		JsonGenerator* _tmp2_ = NULL;
		JsonNode* root_node = NULL;
		JsonNode* _tmp3_ = NULL;
		JsonObject* obj = NULL;
		JsonObject* _tmp4_ = NULL;
		PublishingGallery3Session* _tmp5_ = NULL;
		PublishingGallery3Session* _tmp6_ = NULL;
		const gchar* _tmp7_ = NULL;
		const gchar* _tmp8_ = NULL;
		PublishingGallery3Session* _tmp9_ = NULL;
		const gchar* _tmp10_ = NULL;
		const gchar* _tmp11_ = NULL;
		const gchar* _tmp12_ = NULL;
		gsize entity_length = 0UL;
		gchar* entity_value = NULL;
		gsize _tmp13_ = 0UL;
		gchar* _tmp14_ = NULL;
#line 392 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp2_ = json_generator_new ();
#line 392 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		entity = _tmp2_;
#line 393 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp3_ = json_node_new (JSON_NODE_OBJECT);
#line 393 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		root_node = _tmp3_;
#line 394 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp4_ = json_object_new ();
#line 394 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		obj = _tmp4_;
#line 396 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp5_ = session;
#line 396 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp6_ = session;
#line 396 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp7_ = publishing_gallery3_session_get_url (_tmp6_);
#line 396 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp8_ = _tmp7_;
#line 396 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		self = (PublishingGallery3GalleryGetTagTransaction*) publishing_gallery3_base_gallery_transaction_construct (object_type, _tmp5_, _tmp8_, "/tags", PUBLISHING_REST_SUPPORT_HTTP_METHOD_POST);
#line 399 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp9_ = session;
#line 399 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp10_ = publishing_gallery3_session_get_key (_tmp9_);
#line 399 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp11_ = _tmp10_;
#line 399 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_rest_support_transaction_add_header (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "X-Gallery-Request-Key", _tmp11_);
#line 400 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_rest_support_transaction_add_header (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "X-Gallery-Request-Method", "POST");
#line 402 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp12_ = tag_name;
#line 402 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		json_object_set_string_member (obj, "name", _tmp12_);
#line 403 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		json_node_set_object (root_node, obj);
#line 404 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		json_generator_set_root (entity, root_node);
#line 407 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp14_ = json_generator_to_data (entity, &_tmp13_);
#line 407 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		entity_length = _tmp13_;
#line 407 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		entity_value = _tmp14_;
#line 409 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_debug ("GalleryConnector.vala:409: created entity: %s", entity_value);
#line 411 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "entity", entity_value);
#line 388 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_free0 (entity_value);
#line 388 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_json_object_unref0 (obj);
#line 388 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		__vala_JsonNode_free0 (root_node);
#line 388 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_object_unref0 (entity);
#line 4294 "GalleryConnector.c"
	}
#line 386 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return self;
#line 4298 "GalleryConnector.c"
}


PublishingGallery3GalleryGetTagTransaction* publishing_gallery3_gallery_get_tag_transaction_new (PublishingGallery3Session* session, const gchar* tag_name) {
#line 386 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return publishing_gallery3_gallery_get_tag_transaction_construct (PUBLISHING_GALLERY3_TYPE_GALLERY_GET_TAG_TRANSACTION, session, tag_name);
#line 4305 "GalleryConnector.c"
}


gchar* publishing_gallery3_gallery_get_tag_transaction_tag_url (PublishingGallery3GalleryGetTagTransaction* self) {
	gchar* result = NULL;
	JsonNode* root_node = NULL;
	gchar* url = NULL;
	JsonObject* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	GError * _inner_error_ = NULL;
#line 416 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_GET_TAG_TRANSACTION (self), NULL);
#line 4319 "GalleryConnector.c"
	{
		JsonNode* _tmp0_ = NULL;
		JsonNode* _tmp1_ = NULL;
#line 422 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp1_ = publishing_gallery3_base_gallery_transaction_get_root_node (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_GALLERY3_TYPE_BASE_GALLERY_TRANSACTION, PublishingGallery3BaseGalleryTransaction), &_inner_error_);
#line 422 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp0_ = _tmp1_;
#line 422 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 422 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 4331 "GalleryConnector.c"
				goto __catch2_spit_publishing_publishing_error;
			}
#line 422 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_g_free0 (url);
#line 422 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 422 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_clear_error (&_inner_error_);
#line 422 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			return NULL;
#line 4342 "GalleryConnector.c"
		}
#line 422 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		root_node = _tmp0_;
#line 4346 "GalleryConnector.c"
	}
	goto __finally2;
	__catch2_spit_publishing_publishing_error:
	{
		GError* e = NULL;
#line 421 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		e = _inner_error_;
#line 421 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_inner_error_ = NULL;
#line 425 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_error ("GalleryConnector.vala:425: Could not get root node");
#line 421 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_error_free0 (e);
#line 4360 "GalleryConnector.c"
	}
	__finally2:
#line 421 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 421 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_free0 (url);
#line 421 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 421 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_clear_error (&_inner_error_);
#line 421 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return NULL;
#line 4373 "GalleryConnector.c"
	}
#line 428 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = json_node_get_object (root_node);
#line 428 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp3_ = json_object_get_string_member (_tmp2_, "url");
#line 428 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp4_ = g_strdup (_tmp3_);
#line 428 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (url);
#line 428 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	url = _tmp4_;
#line 431 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = url;
#line 431 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 4389 "GalleryConnector.c"
}


static void publishing_gallery3_gallery_get_tag_transaction_class_init (PublishingGallery3GalleryGetTagTransactionClass * klass) {
#line 384 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_gallery_get_tag_transaction_parent_class = g_type_class_peek_parent (klass);
#line 4396 "GalleryConnector.c"
}


static void publishing_gallery3_gallery_get_tag_transaction_instance_init (PublishingGallery3GalleryGetTagTransaction * self) {
}


GType publishing_gallery3_gallery_get_tag_transaction_get_type (void) {
	static volatile gsize publishing_gallery3_gallery_get_tag_transaction_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_gallery3_gallery_get_tag_transaction_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingGallery3GalleryGetTagTransactionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_gallery3_gallery_get_tag_transaction_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingGallery3GalleryGetTagTransaction), 0, (GInstanceInitFunc) publishing_gallery3_gallery_get_tag_transaction_instance_init, NULL };
		GType publishing_gallery3_gallery_get_tag_transaction_type_id;
		publishing_gallery3_gallery_get_tag_transaction_type_id = g_type_register_static (PUBLISHING_GALLERY3_TYPE_BASE_GALLERY_TRANSACTION, "PublishingGallery3GalleryGetTagTransaction", &g_define_type_info, 0);
		g_once_init_leave (&publishing_gallery3_gallery_get_tag_transaction_type_id__volatile, publishing_gallery3_gallery_get_tag_transaction_type_id);
	}
	return publishing_gallery3_gallery_get_tag_transaction_type_id__volatile;
}


PublishingGallery3GalleryGetItemTagsURLsTransaction* publishing_gallery3_gallery_get_item_tags_ur_ls_transaction_construct (GType object_type, PublishingGallery3Session* session, const gchar* item_url) {
	PublishingGallery3GalleryGetItemTagsURLsTransaction* self = NULL;
	PublishingGallery3Session* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
#line 443 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_SESSION (session), NULL);
#line 443 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (item_url != NULL, NULL);
#line 446 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = session;
#line 446 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = item_url;
#line 446 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = (PublishingGallery3GalleryGetItemTagsURLsTransaction*) publishing_gallery3_gallery_request_transaction_construct (object_type, _tmp0_, _tmp1_, PUBLISHING_REST_SUPPORT_HTTP_METHOD_GET);
#line 443 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return self;
#line 4432 "GalleryConnector.c"
}


PublishingGallery3GalleryGetItemTagsURLsTransaction* publishing_gallery3_gallery_get_item_tags_ur_ls_transaction_new (PublishingGallery3Session* session, const gchar* item_url) {
#line 443 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return publishing_gallery3_gallery_get_item_tags_ur_ls_transaction_construct (PUBLISHING_GALLERY3_TYPE_GALLERY_GET_ITEM_TAGS_UR_LS_TRANSACTION, session, item_url);
#line 4439 "GalleryConnector.c"
}


gchar* publishing_gallery3_gallery_get_item_tags_ur_ls_transaction_get_item_tags_path (PublishingGallery3GalleryGetItemTagsURLsTransaction* self) {
	gchar* result = NULL;
	JsonNode* root_node = NULL;
	JsonObject* relationships = NULL;
	JsonObject* tags = NULL;
	const gchar* _tmp0_ = NULL;
	const gchar* _tmp13_ = NULL;
	gchar* _tmp14_ = NULL;
	GError * _inner_error_ = NULL;
#line 450 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_GET_ITEM_TAGS_UR_LS_TRANSACTION (self), NULL);
#line 455 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->item_tags_path;
#line 455 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (g_strcmp0 ("", _tmp0_) == 0) {
#line 4458 "GalleryConnector.c"
		JsonNode* _tmp3_ = NULL;
		JsonObject* _tmp4_ = NULL;
		JsonObject* _tmp5_ = NULL;
		JsonObject* _tmp6_ = NULL;
		JsonObject* _tmp7_ = NULL;
		JsonObject* _tmp8_ = NULL;
		const gchar* _tmp9_ = NULL;
		gchar* _tmp10_ = NULL;
		const gchar* _tmp11_ = NULL;
		gchar* _tmp12_ = NULL;
		{
			JsonNode* _tmp1_ = NULL;
			JsonNode* _tmp2_ = NULL;
#line 458 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp2_ = publishing_gallery3_base_gallery_transaction_get_root_node (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_GALLERY3_TYPE_BASE_GALLERY_TRANSACTION, PublishingGallery3BaseGalleryTransaction), &_inner_error_);
#line 458 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp1_ = _tmp2_;
#line 458 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 458 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 4480 "GalleryConnector.c"
					goto __catch3_spit_publishing_publishing_error;
				}
#line 458 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 458 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				g_clear_error (&_inner_error_);
#line 458 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				return NULL;
#line 4489 "GalleryConnector.c"
			}
#line 458 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			root_node = _tmp1_;
#line 4493 "GalleryConnector.c"
		}
		goto __finally3;
		__catch3_spit_publishing_publishing_error:
		{
			GError* e = NULL;
#line 457 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			e = _inner_error_;
#line 457 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_inner_error_ = NULL;
#line 461 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_error ("GalleryConnector.vala:461: Could not get root node");
#line 457 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_g_error_free0 (e);
#line 4507 "GalleryConnector.c"
		}
		__finally3:
#line 457 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 457 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 457 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_clear_error (&_inner_error_);
#line 457 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			return NULL;
#line 4518 "GalleryConnector.c"
		}
#line 464 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp3_ = root_node;
#line 464 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp4_ = json_node_get_object (_tmp3_);
#line 464 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp5_ = json_object_get_object_member (_tmp4_, "relationships");
#line 464 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		relationships = _tmp5_;
#line 466 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp6_ = relationships;
#line 466 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp7_ = json_object_get_object_member (_tmp6_, "tags");
#line 466 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		tags = _tmp7_;
#line 468 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp8_ = tags;
#line 468 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp9_ = json_object_get_string_member (_tmp8_, "url");
#line 468 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp10_ = g_strdup (_tmp9_);
#line 468 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_free0 (self->priv->item_tags_path);
#line 468 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		self->priv->item_tags_path = _tmp10_;
#line 471 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp11_ = self->priv->item_tags_path;
#line 471 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp12_ = publishing_gallery3_strip_session_url (_tmp11_);
#line 471 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_free0 (self->priv->item_tags_path);
#line 471 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		self->priv->item_tags_path = _tmp12_;
#line 4552 "GalleryConnector.c"
	}
#line 475 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp13_ = self->priv->item_tags_path;
#line 475 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp14_ = g_strdup (_tmp13_);
#line 475 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp14_;
#line 475 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 4562 "GalleryConnector.c"
}


static void publishing_gallery3_gallery_get_item_tags_ur_ls_transaction_class_init (PublishingGallery3GalleryGetItemTagsURLsTransactionClass * klass) {
#line 438 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_gallery_get_item_tags_ur_ls_transaction_parent_class = g_type_class_peek_parent (klass);
#line 438 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	((PublishingRESTSupportTransactionClass *) klass)->finalize = publishing_gallery3_gallery_get_item_tags_ur_ls_transaction_finalize;
#line 438 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_type_class_add_private (klass, sizeof (PublishingGallery3GalleryGetItemTagsURLsTransactionPrivate));
#line 4573 "GalleryConnector.c"
}


static void publishing_gallery3_gallery_get_item_tags_ur_ls_transaction_instance_init (PublishingGallery3GalleryGetItemTagsURLsTransaction * self) {
	gchar* _tmp0_ = NULL;
#line 438 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv = PUBLISHING_GALLERY3_GALLERY_GET_ITEM_TAGS_UR_LS_TRANSACTION_GET_PRIVATE (self);
#line 441 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = g_strdup ("");
#line 441 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->item_tags_path = _tmp0_;
#line 4585 "GalleryConnector.c"
}


static void publishing_gallery3_gallery_get_item_tags_ur_ls_transaction_finalize (PublishingRESTSupportTransaction* obj) {
	PublishingGallery3GalleryGetItemTagsURLsTransaction * self;
#line 438 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_GALLERY3_TYPE_GALLERY_GET_ITEM_TAGS_UR_LS_TRANSACTION, PublishingGallery3GalleryGetItemTagsURLsTransaction);
#line 441 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->item_tags_path);
#line 438 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	PUBLISHING_REST_SUPPORT_TRANSACTION_CLASS (publishing_gallery3_gallery_get_item_tags_ur_ls_transaction_parent_class)->finalize (obj);
#line 4597 "GalleryConnector.c"
}


GType publishing_gallery3_gallery_get_item_tags_ur_ls_transaction_get_type (void) {
	static volatile gsize publishing_gallery3_gallery_get_item_tags_ur_ls_transaction_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_gallery3_gallery_get_item_tags_ur_ls_transaction_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingGallery3GalleryGetItemTagsURLsTransactionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_gallery3_gallery_get_item_tags_ur_ls_transaction_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingGallery3GalleryGetItemTagsURLsTransaction), 0, (GInstanceInitFunc) publishing_gallery3_gallery_get_item_tags_ur_ls_transaction_instance_init, NULL };
		GType publishing_gallery3_gallery_get_item_tags_ur_ls_transaction_type_id;
		publishing_gallery3_gallery_get_item_tags_ur_ls_transaction_type_id = g_type_register_static (PUBLISHING_GALLERY3_TYPE_GALLERY_REQUEST_TRANSACTION, "PublishingGallery3GalleryGetItemTagsURLsTransaction", &g_define_type_info, 0);
		g_once_init_leave (&publishing_gallery3_gallery_get_item_tags_ur_ls_transaction_type_id__volatile, publishing_gallery3_gallery_get_item_tags_ur_ls_transaction_type_id);
	}
	return publishing_gallery3_gallery_get_item_tags_ur_ls_transaction_type_id__volatile;
}


PublishingGallery3GallerySetTagRelationshipTransaction* publishing_gallery3_gallery_set_tag_relationship_transaction_construct (GType object_type, PublishingGallery3Session* session, const gchar* item_tags_path, const gchar* tag_url, const gchar* item_url) {
	PublishingGallery3GallerySetTagRelationshipTransaction* self = NULL;
	PublishingGallery3Session* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
#line 485 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_SESSION (session), NULL);
#line 485 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (item_tags_path != NULL, NULL);
#line 485 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (tag_url != NULL, NULL);
#line 485 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (item_url != NULL, NULL);
#line 488 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = session;
#line 488 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = publishing_rest_support_session_is_authenticated (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession));
#line 488 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (!_tmp1_) {
#line 489 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_error ("GalleryConnector.vala:489: Not authenticated");
#line 4633 "GalleryConnector.c"
	} else {
		JsonGenerator* entity = NULL;
		JsonGenerator* _tmp2_ = NULL;
		JsonNode* root_node = NULL;
		JsonNode* _tmp3_ = NULL;
		JsonObject* obj = NULL;
		JsonObject* _tmp4_ = NULL;
		PublishingGallery3Session* _tmp5_ = NULL;
		PublishingGallery3Session* _tmp6_ = NULL;
		const gchar* _tmp7_ = NULL;
		const gchar* _tmp8_ = NULL;
		const gchar* _tmp9_ = NULL;
		PublishingGallery3Session* _tmp10_ = NULL;
		const gchar* _tmp11_ = NULL;
		const gchar* _tmp12_ = NULL;
		const gchar* _tmp13_ = NULL;
		const gchar* _tmp14_ = NULL;
		gsize entity_length = 0UL;
		gchar* entity_value = NULL;
		gsize _tmp15_ = 0UL;
		gchar* _tmp16_ = NULL;
#line 492 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp2_ = json_generator_new ();
#line 492 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		entity = _tmp2_;
#line 493 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp3_ = json_node_new (JSON_NODE_OBJECT);
#line 493 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		root_node = _tmp3_;
#line 494 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp4_ = json_object_new ();
#line 494 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		obj = _tmp4_;
#line 496 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp5_ = session;
#line 496 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp6_ = session;
#line 496 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp7_ = publishing_gallery3_session_get_url (_tmp6_);
#line 496 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp8_ = _tmp7_;
#line 496 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp9_ = item_tags_path;
#line 496 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		self = (PublishingGallery3GallerySetTagRelationshipTransaction*) publishing_gallery3_base_gallery_transaction_construct (object_type, _tmp5_, _tmp8_, _tmp9_, PUBLISHING_REST_SUPPORT_HTTP_METHOD_POST);
#line 499 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp10_ = session;
#line 499 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp11_ = publishing_gallery3_session_get_key (_tmp10_);
#line 499 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp12_ = _tmp11_;
#line 499 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_rest_support_transaction_add_header (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "X-Gallery-Request-Key", _tmp12_);
#line 500 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_rest_support_transaction_add_header (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "X-Gallery-Request-Method", "POST");
#line 502 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp13_ = tag_url;
#line 502 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		json_object_set_string_member (obj, "tag", _tmp13_);
#line 503 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp14_ = item_url;
#line 503 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		json_object_set_string_member (obj, "item", _tmp14_);
#line 504 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		json_node_set_object (root_node, obj);
#line 505 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		json_generator_set_root (entity, root_node);
#line 508 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp16_ = json_generator_to_data (entity, &_tmp15_);
#line 508 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		entity_length = _tmp15_;
#line 508 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		entity_value = _tmp16_;
#line 510 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_debug ("GalleryConnector.vala:510: created entity: %s", entity_value);
#line 512 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "entity", entity_value);
#line 488 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_free0 (entity_value);
#line 488 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_json_object_unref0 (obj);
#line 488 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		__vala_JsonNode_free0 (root_node);
#line 488 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_object_unref0 (entity);
#line 4719 "GalleryConnector.c"
	}
#line 485 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return self;
#line 4723 "GalleryConnector.c"
}


PublishingGallery3GallerySetTagRelationshipTransaction* publishing_gallery3_gallery_set_tag_relationship_transaction_new (PublishingGallery3Session* session, const gchar* item_tags_path, const gchar* tag_url, const gchar* item_url) {
#line 485 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return publishing_gallery3_gallery_set_tag_relationship_transaction_construct (PUBLISHING_GALLERY3_TYPE_GALLERY_SET_TAG_RELATIONSHIP_TRANSACTION, session, item_tags_path, tag_url, item_url);
#line 4730 "GalleryConnector.c"
}


static void publishing_gallery3_gallery_set_tag_relationship_transaction_class_init (PublishingGallery3GallerySetTagRelationshipTransactionClass * klass) {
#line 482 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_gallery_set_tag_relationship_transaction_parent_class = g_type_class_peek_parent (klass);
#line 4737 "GalleryConnector.c"
}


static void publishing_gallery3_gallery_set_tag_relationship_transaction_instance_init (PublishingGallery3GallerySetTagRelationshipTransaction * self) {
}


GType publishing_gallery3_gallery_set_tag_relationship_transaction_get_type (void) {
	static volatile gsize publishing_gallery3_gallery_set_tag_relationship_transaction_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_gallery3_gallery_set_tag_relationship_transaction_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingGallery3GallerySetTagRelationshipTransactionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_gallery3_gallery_set_tag_relationship_transaction_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingGallery3GallerySetTagRelationshipTransaction), 0, (GInstanceInitFunc) publishing_gallery3_gallery_set_tag_relationship_transaction_instance_init, NULL };
		GType publishing_gallery3_gallery_set_tag_relationship_transaction_type_id;
		publishing_gallery3_gallery_set_tag_relationship_transaction_type_id = g_type_register_static (PUBLISHING_GALLERY3_TYPE_BASE_GALLERY_TRANSACTION, "PublishingGallery3GallerySetTagRelationshipTransaction", &g_define_type_info, 0);
		g_once_init_leave (&publishing_gallery3_gallery_set_tag_relationship_transaction_type_id__volatile, publishing_gallery3_gallery_set_tag_relationship_transaction_type_id);
	}
	return publishing_gallery3_gallery_set_tag_relationship_transaction_type_id__volatile;
}


PublishingGallery3GalleryAlbumCreateTransaction* publishing_gallery3_gallery_album_create_transaction_construct (GType object_type, PublishingGallery3Session* session, PublishingGallery3PublishingParameters* parameters) {
	PublishingGallery3GalleryAlbumCreateTransaction* self = NULL;
	PublishingGallery3Session* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
#line 529 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_SESSION (session), NULL);
#line 529 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_PUBLISHING_PARAMETERS (parameters), NULL);
#line 532 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = session;
#line 532 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = publishing_rest_support_session_is_authenticated (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession));
#line 532 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (!_tmp1_) {
#line 533 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_error ("GalleryConnector.vala:533: Not authenticated");
#line 4773 "GalleryConnector.c"
	} else {
		JsonGenerator* entity = NULL;
		JsonGenerator* _tmp2_ = NULL;
		JsonNode* root_node = NULL;
		JsonNode* _tmp3_ = NULL;
		JsonObject* obj = NULL;
		JsonObject* _tmp4_ = NULL;
		PublishingGallery3Session* _tmp5_ = NULL;
		PublishingGallery3Session* _tmp6_ = NULL;
		const gchar* _tmp7_ = NULL;
		const gchar* _tmp8_ = NULL;
		PublishingGallery3Session* _tmp9_ = NULL;
		const gchar* _tmp10_ = NULL;
		const gchar* _tmp11_ = NULL;
		PublishingGallery3Session* _tmp12_ = NULL;
		const gchar* _tmp13_ = NULL;
		const gchar* _tmp14_ = NULL;
		gchar* _tmp15_ = NULL;
		PublishingGallery3PublishingParameters* _tmp16_ = NULL;
		PublishingGallery3PublishingParameters* _tmp17_ = NULL;
		const gchar* _tmp18_ = NULL;
		const gchar* _tmp19_ = NULL;
		PublishingGallery3PublishingParameters* _tmp20_ = NULL;
		const gchar* _tmp21_ = NULL;
		const gchar* _tmp22_ = NULL;
		gchar* entity_value = NULL;
		gchar* _tmp23_ = NULL;
#line 536 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp2_ = json_generator_new ();
#line 536 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		entity = _tmp2_;
#line 537 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp3_ = json_node_new (JSON_NODE_OBJECT);
#line 537 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		root_node = _tmp3_;
#line 538 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp4_ = json_object_new ();
#line 538 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		obj = _tmp4_;
#line 540 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp5_ = session;
#line 540 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp6_ = session;
#line 540 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp7_ = publishing_gallery3_session_get_url (_tmp6_);
#line 540 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp8_ = _tmp7_;
#line 540 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		self = (PublishingGallery3GalleryAlbumCreateTransaction*) publishing_gallery3_base_gallery_transaction_construct (object_type, _tmp5_, _tmp8_, "/item/1", PUBLISHING_REST_SUPPORT_HTTP_METHOD_POST);
#line 542 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp9_ = session;
#line 542 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp10_ = publishing_gallery3_session_get_key (_tmp9_);
#line 542 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp11_ = _tmp10_;
#line 542 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_rest_support_transaction_add_header (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "X-Gallery-Request-Key", _tmp11_);
#line 543 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_rest_support_transaction_add_header (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "X-Gallery-Request-Method", "POST");
#line 545 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp12_ = session;
#line 545 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp13_ = publishing_gallery3_session_get_url (_tmp12_);
#line 545 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp14_ = _tmp13_;
#line 545 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp15_ = g_strdup (_tmp14_);
#line 545 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_free0 (self->priv->session_url);
#line 545 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		self->priv->session_url = _tmp15_;
#line 546 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp16_ = parameters;
#line 546 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_gallery3_gallery_album_create_transaction_set_parameters (self, _tmp16_);
#line 548 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp17_ = parameters;
#line 548 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp18_ = publishing_gallery3_publishing_parameters_get_album_name (_tmp17_);
#line 548 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp19_ = _tmp18_;
#line 548 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		json_object_set_string_member (obj, "name", _tmp19_);
#line 549 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		json_object_set_string_member (obj, "type", "album");
#line 550 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp20_ = parameters;
#line 550 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp21_ = publishing_gallery3_publishing_parameters_get_album_title (_tmp20_);
#line 550 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp22_ = _tmp21_;
#line 550 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		json_object_set_string_member (obj, "title", _tmp22_);
#line 551 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		json_node_set_object (root_node, obj);
#line 552 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		json_generator_set_root (entity, root_node);
#line 554 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp23_ = json_generator_to_data (entity, NULL);
#line 554 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		entity_value = _tmp23_;
#line 556 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_debug ("GalleryConnector.vala:556: created entity: %s", entity_value);
#line 558 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "entity", entity_value);
#line 532 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_free0 (entity_value);
#line 532 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_json_object_unref0 (obj);
#line 532 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		__vala_JsonNode_free0 (root_node);
#line 532 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_object_unref0 (entity);
#line 4887 "GalleryConnector.c"
	}
#line 529 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return self;
#line 4891 "GalleryConnector.c"
}


PublishingGallery3GalleryAlbumCreateTransaction* publishing_gallery3_gallery_album_create_transaction_new (PublishingGallery3Session* session, PublishingGallery3PublishingParameters* parameters) {
#line 529 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return publishing_gallery3_gallery_album_create_transaction_construct (PUBLISHING_GALLERY3_TYPE_GALLERY_ALBUM_CREATE_TRANSACTION, session, parameters);
#line 4898 "GalleryConnector.c"
}


gchar* publishing_gallery3_gallery_album_create_transaction_get_new_album_path (PublishingGallery3GalleryAlbumCreateTransaction* self) {
	gchar* result = NULL;
	JsonNode* root_node = NULL;
	gchar* new_path = NULL;
	JsonObject* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	GError * _inner_error_ = NULL;
#line 563 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_ALBUM_CREATE_TRANSACTION (self), NULL);
#line 4914 "GalleryConnector.c"
	{
		JsonNode* _tmp0_ = NULL;
		JsonNode* _tmp1_ = NULL;
#line 569 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp1_ = publishing_gallery3_base_gallery_transaction_get_root_node (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_GALLERY3_TYPE_BASE_GALLERY_TRANSACTION, PublishingGallery3BaseGalleryTransaction), &_inner_error_);
#line 569 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp0_ = _tmp1_;
#line 569 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 569 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 4926 "GalleryConnector.c"
				goto __catch4_spit_publishing_publishing_error;
			}
#line 569 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_g_free0 (new_path);
#line 569 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 569 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_clear_error (&_inner_error_);
#line 569 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			return NULL;
#line 4937 "GalleryConnector.c"
		}
#line 569 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		root_node = _tmp0_;
#line 4941 "GalleryConnector.c"
	}
	goto __finally4;
	__catch4_spit_publishing_publishing_error:
	{
		GError* e = NULL;
#line 568 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		e = _inner_error_;
#line 568 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_inner_error_ = NULL;
#line 572 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_error ("GalleryConnector.vala:572: Could not get root node");
#line 568 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_error_free0 (e);
#line 4955 "GalleryConnector.c"
	}
	__finally4:
#line 568 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 568 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_free0 (new_path);
#line 568 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 568 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_clear_error (&_inner_error_);
#line 568 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return NULL;
#line 4968 "GalleryConnector.c"
	}
#line 575 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = json_node_get_object (root_node);
#line 575 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp3_ = json_object_get_string_member (_tmp2_, "url");
#line 575 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp4_ = g_strdup (_tmp3_);
#line 575 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (new_path);
#line 575 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	new_path = _tmp4_;
#line 577 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp5_ = new_path;
#line 577 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp6_ = publishing_gallery3_strip_session_url (_tmp5_);
#line 577 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (new_path);
#line 577 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	new_path = _tmp6_;
#line 579 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = new_path;
#line 579 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 4992 "GalleryConnector.c"
}


PublishingGallery3PublishingParameters* publishing_gallery3_gallery_album_create_transaction_get_parameters (PublishingGallery3GalleryAlbumCreateTransaction* self) {
	PublishingGallery3PublishingParameters* result;
	PublishingGallery3PublishingParameters* _tmp0_ = NULL;
#line 522 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_ALBUM_CREATE_TRANSACTION (self), NULL);
#line 522 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->_parameters;
#line 522 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp0_;
#line 522 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 5007 "GalleryConnector.c"
}


static gpointer _publishing_gallery3_publishing_parameters_ref0 (gpointer self) {
#line 522 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return self ? publishing_gallery3_publishing_parameters_ref (self) : NULL;
#line 5014 "GalleryConnector.c"
}


static void publishing_gallery3_gallery_album_create_transaction_set_parameters (PublishingGallery3GalleryAlbumCreateTransaction* self, PublishingGallery3PublishingParameters* value) {
	PublishingGallery3PublishingParameters* _tmp0_ = NULL;
	PublishingGallery3PublishingParameters* _tmp1_ = NULL;
#line 522 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_ALBUM_CREATE_TRANSACTION (self));
#line 522 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = value;
#line 522 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = _publishing_gallery3_publishing_parameters_ref0 (_tmp0_);
#line 522 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_publishing_gallery3_publishing_parameters_unref0 (self->priv->_parameters);
#line 522 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_parameters = _tmp1_;
#line 5031 "GalleryConnector.c"
}


static void publishing_gallery3_gallery_album_create_transaction_class_init (PublishingGallery3GalleryAlbumCreateTransactionClass * klass) {
#line 519 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_gallery_album_create_transaction_parent_class = g_type_class_peek_parent (klass);
#line 519 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	((PublishingRESTSupportTransactionClass *) klass)->finalize = publishing_gallery3_gallery_album_create_transaction_finalize;
#line 519 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_type_class_add_private (klass, sizeof (PublishingGallery3GalleryAlbumCreateTransactionPrivate));
#line 5042 "GalleryConnector.c"
}


static void publishing_gallery3_gallery_album_create_transaction_instance_init (PublishingGallery3GalleryAlbumCreateTransaction * self) {
#line 519 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv = PUBLISHING_GALLERY3_GALLERY_ALBUM_CREATE_TRANSACTION_GET_PRIVATE (self);
#line 5049 "GalleryConnector.c"
}


static void publishing_gallery3_gallery_album_create_transaction_finalize (PublishingRESTSupportTransaction* obj) {
	PublishingGallery3GalleryAlbumCreateTransaction * self;
#line 519 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_GALLERY3_TYPE_GALLERY_ALBUM_CREATE_TRANSACTION, PublishingGallery3GalleryAlbumCreateTransaction);
#line 522 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_publishing_gallery3_publishing_parameters_unref0 (self->priv->_parameters);
#line 524 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->session_url);
#line 519 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	PUBLISHING_REST_SUPPORT_TRANSACTION_CLASS (publishing_gallery3_gallery_album_create_transaction_parent_class)->finalize (obj);
#line 5063 "GalleryConnector.c"
}


GType publishing_gallery3_gallery_album_create_transaction_get_type (void) {
	static volatile gsize publishing_gallery3_gallery_album_create_transaction_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_gallery3_gallery_album_create_transaction_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingGallery3GalleryAlbumCreateTransactionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_gallery3_gallery_album_create_transaction_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingGallery3GalleryAlbumCreateTransaction), 0, (GInstanceInitFunc) publishing_gallery3_gallery_album_create_transaction_instance_init, NULL };
		GType publishing_gallery3_gallery_album_create_transaction_type_id;
		publishing_gallery3_gallery_album_create_transaction_type_id = g_type_register_static (PUBLISHING_GALLERY3_TYPE_BASE_GALLERY_TRANSACTION, "PublishingGallery3GalleryAlbumCreateTransaction", &g_define_type_info, 0);
		g_once_init_leave (&publishing_gallery3_gallery_album_create_transaction_type_id__volatile, publishing_gallery3_gallery_album_create_transaction_type_id);
	}
	return publishing_gallery3_gallery_album_create_transaction_type_id__volatile;
}


static gpointer _publishing_rest_support_session_ref0 (gpointer self) {
#line 609 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return self ? publishing_rest_support_session_ref (self) : NULL;
#line 5082 "GalleryConnector.c"
}


static void _g_free0_ (gpointer var) {
#line 614 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	var = (g_free (var), NULL);
#line 5089 "GalleryConnector.c"
}


PublishingGallery3GalleryUploadTransaction* publishing_gallery3_gallery_upload_transaction_construct (GType object_type, PublishingGallery3Session* session, PublishingGallery3PublishingParameters* parameters, SpitPublishingPublishable* publishable) {
	PublishingGallery3GalleryUploadTransaction* self = NULL;
	PublishingGallery3PublishingParameters* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	gchar _tmp3_ = '\0';
	PublishingGallery3Session* _tmp7_ = NULL;
	SpitPublishingPublishable* _tmp8_ = NULL;
	PublishingGallery3Session* _tmp9_ = NULL;
	const gchar* _tmp10_ = NULL;
	const gchar* _tmp11_ = NULL;
	gchar* _tmp12_ = NULL;
	gchar* _tmp13_ = NULL;
	PublishingGallery3PublishingParameters* _tmp14_ = NULL;
	const gchar* _tmp15_ = NULL;
	const gchar* _tmp16_ = NULL;
	gchar* _tmp17_ = NULL;
	gchar* _tmp18_ = NULL;
	PublishingGallery3PublishingParameters* _tmp19_ = NULL;
	PublishingGallery3PublishingParameters* _tmp20_ = NULL;
	PublishingGallery3Session* _tmp21_ = NULL;
	PublishingGallery3Session* _tmp22_ = NULL;
	PublishingGallery3Session* _tmp23_ = NULL;
	const gchar* _tmp24_ = NULL;
	const gchar* _tmp25_ = NULL;
	GHashTable* disposition_table = NULL;
	GHashFunc _tmp26_ = NULL;
	GEqualFunc _tmp27_ = NULL;
	GHashTable* _tmp28_ = NULL;
	gchar* title = NULL;
	SpitPublishingPublishable* _tmp29_ = NULL;
	gchar* _tmp30_ = NULL;
	gchar* filename = NULL;
	SpitPublishingPublishable* _tmp31_ = NULL;
	gchar* _tmp32_ = NULL;
	gboolean _tmp33_ = FALSE;
	const gchar* _tmp34_ = NULL;
	GHashTable* _tmp38_ = NULL;
	gchar* _tmp39_ = NULL;
	const gchar* _tmp40_ = NULL;
	const gchar* _tmp41_ = NULL;
	gchar* _tmp42_ = NULL;
	GHashTable* _tmp43_ = NULL;
	gchar* _tmp44_ = NULL;
	gchar* _tmp45_ = NULL;
	GHashTable* _tmp46_ = NULL;
	JsonGenerator* _tmp47_ = NULL;
	gchar* desc = NULL;
	SpitPublishingPublishable* _tmp48_ = NULL;
	gchar* _tmp49_ = NULL;
	const gchar* _tmp50_ = NULL;
	SpitPublishingPublishable* _tmp51_ = NULL;
	SpitPublishingPublisherMediaType _tmp52_ = 0;
	gchar* type = NULL;
	gchar* _tmp53_ = NULL;
	JsonNode* root_node = NULL;
	JsonNode* _tmp54_ = NULL;
	JsonObject* obj = NULL;
	JsonObject* _tmp55_ = NULL;
	const gchar* _tmp56_ = NULL;
	const gchar* _tmp57_ = NULL;
	const gchar* _tmp58_ = NULL;
	JsonGenerator* _tmp59_ = NULL;
	JsonGenerator* _tmp60_ = NULL;
	gchar* _tmp61_ = NULL;
	gchar* _tmp62_ = NULL;
#line 595 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_SESSION (session), NULL);
#line 595 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_PUBLISHING_PARAMETERS (parameters), NULL);
#line 595 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (SPIT_PUBLISHING_IS_PUBLISHABLE (publishable), NULL);
#line 600 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = parameters;
#line 600 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = publishing_gallery3_publishing_parameters_get_album_path (_tmp0_);
#line 600 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = _tmp1_;
#line 600 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp3_ = string_get (_tmp2_, (glong) 0);
#line 600 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (_tmp3_ != '/') {
#line 5175 "GalleryConnector.c"
		PublishingGallery3PublishingParameters* _tmp4_ = NULL;
		const gchar* _tmp5_ = NULL;
		const gchar* _tmp6_ = NULL;
#line 601 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_warning ("GalleryConnector.vala:601: Bad upload item path, this is a bug!");
#line 602 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp4_ = parameters;
#line 602 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp5_ = publishing_gallery3_publishing_parameters_get_album_path (_tmp4_);
#line 602 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp6_ = _tmp5_;
#line 602 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_error ("GalleryConnector.vala:602: %s", _tmp6_);
#line 5189 "GalleryConnector.c"
	}
#line 605 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp7_ = session;
#line 605 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp8_ = publishable;
#line 605 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp9_ = session;
#line 605 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp10_ = publishing_gallery3_session_get_url (_tmp9_);
#line 605 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp11_ = _tmp10_;
#line 605 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp12_ = g_strconcat (_tmp11_, PUBLISHING_GALLERY3_REST_PATH, NULL);
#line 605 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp13_ = _tmp12_;
#line 605 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp14_ = parameters;
#line 605 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp15_ = publishing_gallery3_publishing_parameters_get_album_path (_tmp14_);
#line 605 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp16_ = _tmp15_;
#line 605 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp17_ = g_strconcat (_tmp13_, _tmp16_, NULL);
#line 605 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp18_ = _tmp17_;
#line 605 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = (PublishingGallery3GalleryUploadTransaction*) publishing_rest_support_upload_transaction_construct_with_endpoint_url (object_type, G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession), _tmp8_, _tmp18_);
#line 605 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (_tmp18_);
#line 605 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (_tmp13_);
#line 608 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp19_ = parameters;
#line 608 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp20_ = _publishing_gallery3_publishing_parameters_ref0 (_tmp19_);
#line 608 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_publishing_gallery3_publishing_parameters_unref0 (self->priv->parameters);
#line 608 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->parameters = _tmp20_;
#line 609 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp21_ = session;
#line 609 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp22_ = _publishing_rest_support_session_ref0 (_tmp21_);
#line 609 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_publishing_rest_support_session_unref0 (self->priv->session);
#line 609 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->session = _tmp22_;
#line 611 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp23_ = session;
#line 611 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp24_ = publishing_gallery3_session_get_key (_tmp23_);
#line 611 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp25_ = _tmp24_;
#line 611 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_rest_support_transaction_add_header (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "X-Gallery-Request-Key", _tmp25_);
#line 612 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_rest_support_transaction_add_header (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "X-Gallery-Request-Method", "POST");
#line 614 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp26_ = g_str_hash;
#line 614 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp27_ = g_str_equal;
#line 614 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp28_ = g_hash_table_new_full (_tmp26_, _tmp27_, _g_free0_, _g_free0_);
#line 614 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	disposition_table = _tmp28_;
#line 617 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp29_ = publishable;
#line 617 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp30_ = spit_publishing_publishable_get_publishing_name (_tmp29_);
#line 617 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	title = _tmp30_;
#line 618 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp31_ = publishable;
#line 618 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp32_ = spit_publishing_publishable_get_param_string (_tmp31_, SPIT_PUBLISHING_PUBLISHABLE_PARAM_STRING_BASENAME);
#line 618 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	filename = _tmp32_;
#line 620 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp34_ = title;
#line 620 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (_tmp34_ == NULL) {
#line 620 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp33_ = TRUE;
#line 5273 "GalleryConnector.c"
	} else {
		const gchar* _tmp35_ = NULL;
#line 620 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp35_ = title;
#line 620 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp33_ = g_strcmp0 (_tmp35_, "") == 0;
#line 5280 "GalleryConnector.c"
	}
#line 620 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (_tmp33_) {
#line 5284 "GalleryConnector.c"
		const gchar* _tmp36_ = NULL;
		gchar* _tmp37_ = NULL;
#line 622 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp36_ = filename;
#line 622 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp37_ = g_strdup (_tmp36_);
#line 622 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_free0 (title);
#line 622 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		title = _tmp37_;
#line 5295 "GalleryConnector.c"
	}
#line 624 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp38_ = disposition_table;
#line 624 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp39_ = g_strdup ("filename");
#line 624 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp40_ = filename;
#line 624 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp41_ = string_to_string (_tmp40_);
#line 624 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp42_ = g_strdup (_tmp41_);
#line 624 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_hash_table_insert (_tmp38_, _tmp39_, _tmp42_);
#line 625 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp43_ = disposition_table;
#line 625 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp44_ = g_strdup ("name");
#line 625 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp45_ = g_strdup ("file");
#line 625 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_hash_table_insert (_tmp43_, _tmp44_, _tmp45_);
#line 627 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp46_ = disposition_table;
#line 627 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_rest_support_upload_transaction_set_binary_disposition_table (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_UPLOAD_TRANSACTION, PublishingRESTSupportUploadTransaction), _tmp46_);
#line 630 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp47_ = json_generator_new ();
#line 630 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->generator);
#line 630 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->generator = _tmp47_;
#line 631 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp48_ = publishable;
#line 631 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp49_ = spit_publishing_publishable_get_param_string (_tmp48_, SPIT_PUBLISHING_PUBLISHABLE_PARAM_STRING_COMMENT);
#line 631 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	desc = _tmp49_;
#line 633 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp51_ = publishable;
#line 633 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp52_ = spit_publishing_publishable_get_media_type (_tmp51_);
#line 633 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (_tmp52_ == SPIT_PUBLISHING_PUBLISHER_MEDIA_TYPE_VIDEO) {
#line 635 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp50_ = "movie";
#line 5341 "GalleryConnector.c"
	} else {
#line 635 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp50_ = "photo";
#line 5345 "GalleryConnector.c"
	}
#line 633 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp53_ = g_strdup (_tmp50_);
#line 633 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	type = _tmp53_;
#line 637 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp54_ = json_node_new (JSON_NODE_OBJECT);
#line 637 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	root_node = _tmp54_;
#line 638 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp55_ = json_object_new ();
#line 638 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	obj = _tmp55_;
#line 639 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp56_ = filename;
#line 639 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	json_object_set_string_member (obj, "name", _tmp56_);
#line 640 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	json_object_set_string_member (obj, "type", type);
#line 641 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp57_ = title;
#line 641 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	json_object_set_string_member (obj, "title", _tmp57_);
#line 642 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp58_ = desc;
#line 642 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	json_object_set_string_member (obj, "description", _tmp58_);
#line 644 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	json_node_set_object (root_node, obj);
#line 645 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp59_ = self->priv->generator;
#line 645 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	json_generator_set_root (_tmp59_, root_node);
#line 647 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp60_ = self->priv->generator;
#line 647 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp61_ = json_generator_to_data (_tmp60_, NULL);
#line 647 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp62_ = _tmp61_;
#line 647 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "entity", _tmp62_);
#line 647 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (_tmp62_);
#line 595 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_json_object_unref0 (obj);
#line 595 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	__vala_JsonNode_free0 (root_node);
#line 595 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (type);
#line 595 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (desc);
#line 595 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (filename);
#line 595 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (title);
#line 595 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_hash_table_unref0 (disposition_table);
#line 595 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return self;
#line 5405 "GalleryConnector.c"
}


PublishingGallery3GalleryUploadTransaction* publishing_gallery3_gallery_upload_transaction_new (PublishingGallery3Session* session, PublishingGallery3PublishingParameters* parameters, SpitPublishingPublishable* publishable) {
#line 595 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return publishing_gallery3_gallery_upload_transaction_construct (PUBLISHING_GALLERY3_TYPE_GALLERY_UPLOAD_TRANSACTION, session, parameters, publishable);
#line 5412 "GalleryConnector.c"
}


static gchar* publishing_gallery3_gallery_upload_transaction_get_new_item_url (PublishingGallery3GalleryUploadTransaction* self) {
	gchar* result = NULL;
	gchar* json_object = NULL;
	gchar* new_url = NULL;
	JsonNode* root_node = NULL;
	JsonParser* parser = NULL;
	JsonParser* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	const gchar* _tmp3_ = NULL;
	const gchar* _tmp10_ = NULL;
	JsonParser* _tmp14_ = NULL;
	JsonNode* _tmp15_ = NULL;
	JsonNode* _tmp16_ = NULL;
	gboolean _tmp17_ = FALSE;
	JsonNode* _tmp19_ = NULL;
	JsonObject* _tmp20_ = NULL;
	const gchar* _tmp21_ = NULL;
	gchar* _tmp22_ = NULL;
	GError * _inner_error_ = NULL;
#line 650 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_UPLOAD_TRANSACTION (self), NULL);
#line 655 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = json_parser_new ();
#line 655 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	parser = _tmp0_;
#line 657 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = publishing_rest_support_transaction_get_response (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction));
#line 657 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (json_object);
#line 657 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	json_object = _tmp1_;
#line 659 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp3_ = json_object;
#line 659 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (NULL == _tmp3_) {
#line 659 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp2_ = TRUE;
#line 5454 "GalleryConnector.c"
	} else {
		const gchar* _tmp4_ = NULL;
		gint _tmp5_ = 0;
		gint _tmp6_ = 0;
#line 659 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp4_ = json_object;
#line 659 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp5_ = strlen (_tmp4_);
#line 659 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp6_ = _tmp5_;
#line 659 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp2_ = 0 == _tmp6_;
#line 5467 "GalleryConnector.c"
	}
#line 659 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (_tmp2_) {
#line 5471 "GalleryConnector.c"
		gchar* _tmp7_ = NULL;
		gchar* _tmp8_ = NULL;
		gchar* _tmp9_ = NULL;
#line 660 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp7_ = publishing_rest_support_transaction_get_endpoint_url (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction));
#line 660 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp8_ = _tmp7_;
#line 660 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_warning ("GalleryConnector.vala:660: No response data from %s", _tmp8_);
#line 660 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_free0 (_tmp8_);
#line 661 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp9_ = g_strdup ("");
#line 661 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		result = _tmp9_;
#line 661 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_object_unref0 (parser);
#line 661 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_free0 (new_url);
#line 661 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_free0 (json_object);
#line 661 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return result;
#line 5495 "GalleryConnector.c"
	}
#line 664 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp10_ = json_object;
#line 664 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_debug ("GalleryConnector.vala:664: json_object: %s", _tmp10_);
#line 5501 "GalleryConnector.c"
	{
		JsonParser* _tmp11_ = NULL;
		const gchar* _tmp12_ = NULL;
#line 667 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp11_ = parser;
#line 667 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp12_ = json_object;
#line 667 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		json_parser_load_from_data (_tmp11_, _tmp12_, (gssize) -1, &_inner_error_);
#line 667 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 5513 "GalleryConnector.c"
			goto __catch5_g_error;
		}
	}
	goto __finally5;
	__catch5_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp13_ = NULL;
#line 666 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		e = _inner_error_;
#line 666 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_inner_error_ = NULL;
#line 672 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_warning ("GalleryConnector.vala:672: ERROR: didn't load JSON data");
#line 673 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_rest_support_transaction_set_is_executed (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), FALSE);
#line 674 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp13_ = e->message;
#line 674 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_error ("GalleryConnector.vala:674: %s", _tmp13_);
#line 666 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_error_free0 (e);
#line 5536 "GalleryConnector.c"
	}
	__finally5:
#line 666 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 666 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_object_unref0 (parser);
#line 666 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_free0 (new_url);
#line 666 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_free0 (json_object);
#line 666 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 666 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_clear_error (&_inner_error_);
#line 666 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return NULL;
#line 5553 "GalleryConnector.c"
	}
#line 677 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp14_ = parser;
#line 677 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp15_ = json_parser_get_root (_tmp14_);
#line 677 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	root_node = _tmp15_;
#line 678 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp16_ = root_node;
#line 678 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp17_ = json_node_is_null (_tmp16_);
#line 678 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (_tmp17_) {
#line 5567 "GalleryConnector.c"
		gchar* _tmp18_ = NULL;
#line 679 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_warning ("GalleryConnector.vala:679: Root node is null, doesn't appear to be JSO" \
"N data");
#line 680 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp18_ = g_strdup ("");
#line 680 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		result = _tmp18_;
#line 680 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_object_unref0 (parser);
#line 680 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_free0 (new_url);
#line 680 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_free0 (json_object);
#line 680 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return result;
#line 5583 "GalleryConnector.c"
	}
#line 683 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp19_ = root_node;
#line 683 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp20_ = json_node_get_object (_tmp19_);
#line 683 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp21_ = json_object_get_string_member (_tmp20_, "url");
#line 683 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp22_ = g_strdup (_tmp21_);
#line 683 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (new_url);
#line 683 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	new_url = _tmp22_;
#line 686 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = new_url;
#line 686 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (parser);
#line 686 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (json_object);
#line 686 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 5605 "GalleryConnector.c"
}


static void publishing_gallery3_gallery_upload_transaction_do_set_tag_relationship (PublishingGallery3GalleryUploadTransaction* self, const gchar* tag_url, GError** error) {
	PublishingGallery3GallerySetTagRelationshipTransaction* tag_txn = NULL;
	PublishingRESTSupportSession* _tmp0_ = NULL;
	PublishingGallery3Session* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	PublishingGallery3GallerySetTagRelationshipTransaction* _tmp5_ = NULL;
	PublishingGallery3GallerySetTagRelationshipTransaction* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
	gchar* _tmp8_ = NULL;
	GError * _inner_error_ = NULL;
#line 690 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_UPLOAD_TRANSACTION (self));
#line 690 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (tag_url != NULL);
#line 692 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = publishing_rest_support_transaction_get_parent_session (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction));
#line 692 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, PUBLISHING_GALLERY3_TYPE_SESSION, PublishingGallery3Session);
#line 692 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = self->priv->item_tags_path;
#line 692 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp3_ = tag_url;
#line 692 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp4_ = self->priv->item_url;
#line 692 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp5_ = publishing_gallery3_gallery_set_tag_relationship_transaction_new (_tmp1_, _tmp2_, _tmp3_, _tmp4_);
#line 692 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp6_ = _tmp5_;
#line 692 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_publishing_rest_support_session_unref0 (_tmp1_);
#line 692 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	tag_txn = _tmp6_;
#line 697 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_rest_support_transaction_execute (G_TYPE_CHECK_INSTANCE_CAST (tag_txn, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), &_inner_error_);
#line 697 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 697 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 697 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_propagate_error (error, _inner_error_);
#line 697 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_publishing_rest_support_transaction_unref0 (tag_txn);
#line 697 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			return;
#line 5655 "GalleryConnector.c"
		} else {
#line 697 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_publishing_rest_support_transaction_unref0 (tag_txn);
#line 697 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 697 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_clear_error (&_inner_error_);
#line 697 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			return;
#line 5665 "GalleryConnector.c"
		}
	}
#line 699 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp7_ = publishing_rest_support_transaction_get_response (G_TYPE_CHECK_INSTANCE_CAST (tag_txn, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction));
#line 699 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp8_ = _tmp7_;
#line 699 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_debug ("GalleryConnector.vala:699: Response from setting tag relationship: %s", _tmp8_);
#line 699 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (_tmp8_);
#line 690 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_publishing_rest_support_transaction_unref0 (tag_txn);
#line 5678 "GalleryConnector.c"
}


static gchar* publishing_gallery3_gallery_upload_transaction_get_new_item_tags_path (PublishingGallery3GalleryUploadTransaction* self) {
	gchar* result = NULL;
	PublishingGallery3GalleryGetItemTagsURLsTransaction* tag_urls_txn = NULL;
	PublishingRESTSupportSession* _tmp0_ = NULL;
	PublishingGallery3Session* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	PublishingGallery3GalleryGetItemTagsURLsTransaction* _tmp3_ = NULL;
	PublishingGallery3GalleryGetItemTagsURLsTransaction* _tmp4_ = NULL;
	PublishingGallery3GalleryGetItemTagsURLsTransaction* _tmp9_ = NULL;
	gchar* _tmp10_ = NULL;
	GError * _inner_error_ = NULL;
#line 703 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_UPLOAD_TRANSACTION (self), NULL);
#line 704 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = publishing_rest_support_transaction_get_parent_session (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction));
#line 704 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, PUBLISHING_GALLERY3_TYPE_SESSION, PublishingGallery3Session);
#line 704 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = self->priv->item_path;
#line 704 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp3_ = publishing_gallery3_gallery_get_item_tags_ur_ls_transaction_new (_tmp1_, _tmp2_);
#line 704 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp4_ = _tmp3_;
#line 704 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_publishing_rest_support_session_unref0 (_tmp1_);
#line 704 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	tag_urls_txn = _tmp4_;
#line 5709 "GalleryConnector.c"
	{
		PublishingGallery3GalleryGetItemTagsURLsTransaction* _tmp5_ = NULL;
#line 709 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp5_ = tag_urls_txn;
#line 709 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_rest_support_transaction_execute (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), &_inner_error_);
#line 709 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 709 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 5720 "GalleryConnector.c"
				goto __catch6_spit_publishing_publishing_error;
			}
#line 709 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_publishing_rest_support_transaction_unref0 (tag_urls_txn);
#line 709 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 709 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_clear_error (&_inner_error_);
#line 709 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			return NULL;
#line 5731 "GalleryConnector.c"
		}
	}
	goto __finally6;
	__catch6_spit_publishing_publishing_error:
	{
		GError* err = NULL;
		GError* _tmp6_ = NULL;
		const gchar* _tmp7_ = NULL;
		gchar* _tmp8_ = NULL;
#line 708 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		err = _inner_error_;
#line 708 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_inner_error_ = NULL;
#line 711 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp6_ = err;
#line 711 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp7_ = _tmp6_->message;
#line 711 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_debug ("GalleryConnector.vala:711: Problem getting the item_tags URL: %s", _tmp7_);
#line 713 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp8_ = g_strdup ("");
#line 713 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		result = _tmp8_;
#line 713 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_error_free0 (err);
#line 713 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_publishing_rest_support_transaction_unref0 (tag_urls_txn);
#line 713 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return result;
#line 5761 "GalleryConnector.c"
	}
	__finally6:
#line 708 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 708 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_publishing_rest_support_transaction_unref0 (tag_urls_txn);
#line 708 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 708 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_clear_error (&_inner_error_);
#line 708 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return NULL;
#line 5774 "GalleryConnector.c"
	}
#line 716 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp9_ = tag_urls_txn;
#line 716 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp10_ = publishing_gallery3_gallery_get_item_tags_ur_ls_transaction_get_item_tags_path (_tmp9_);
#line 716 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp10_;
#line 716 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_publishing_rest_support_transaction_unref0 (tag_urls_txn);
#line 716 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 5786 "GalleryConnector.c"
}


static gchar* publishing_gallery3_gallery_upload_transaction_get_tag_url (PublishingGallery3GalleryUploadTransaction* self, const gchar* tag) {
	gchar* result = NULL;
	PublishingGallery3GalleryGetTagTransaction* tag_txn = NULL;
	PublishingRESTSupportSession* _tmp0_ = NULL;
	PublishingGallery3Session* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	PublishingGallery3GalleryGetTagTransaction* _tmp3_ = NULL;
	PublishingGallery3GalleryGetTagTransaction* _tmp4_ = NULL;
	PublishingGallery3GalleryGetTagTransaction* _tmp9_ = NULL;
	gchar* _tmp10_ = NULL;
	GError * _inner_error_ = NULL;
#line 719 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_UPLOAD_TRANSACTION (self), NULL);
#line 719 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (tag != NULL, NULL);
#line 721 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = publishing_rest_support_transaction_get_parent_session (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction));
#line 721 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, PUBLISHING_GALLERY3_TYPE_SESSION, PublishingGallery3Session);
#line 721 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = tag;
#line 721 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp3_ = publishing_gallery3_gallery_get_tag_transaction_new (_tmp1_, _tmp2_);
#line 721 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp4_ = _tmp3_;
#line 721 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_publishing_rest_support_session_unref0 (_tmp1_);
#line 721 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	tag_txn = _tmp4_;
#line 5819 "GalleryConnector.c"
	{
		PublishingGallery3GalleryGetTagTransaction* _tmp5_ = NULL;
#line 726 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp5_ = tag_txn;
#line 726 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_rest_support_transaction_execute (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), &_inner_error_);
#line 726 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 726 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 5830 "GalleryConnector.c"
				goto __catch7_spit_publishing_publishing_error;
			}
#line 726 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_publishing_rest_support_transaction_unref0 (tag_txn);
#line 726 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 726 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_clear_error (&_inner_error_);
#line 726 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			return NULL;
#line 5841 "GalleryConnector.c"
		}
	}
	goto __finally7;
	__catch7_spit_publishing_publishing_error:
	{
		GError* err = NULL;
		GError* _tmp6_ = NULL;
		const gchar* _tmp7_ = NULL;
		gchar* _tmp8_ = NULL;
#line 725 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		err = _inner_error_;
#line 725 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_inner_error_ = NULL;
#line 728 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp6_ = err;
#line 728 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp7_ = _tmp6_->message;
#line 728 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_debug ("GalleryConnector.vala:728: Problem getting the tags URL: %s", _tmp7_);
#line 730 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp8_ = g_strdup ("");
#line 730 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		result = _tmp8_;
#line 730 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_error_free0 (err);
#line 730 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_publishing_rest_support_transaction_unref0 (tag_txn);
#line 730 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return result;
#line 5871 "GalleryConnector.c"
	}
	__finally7:
#line 725 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 725 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_publishing_rest_support_transaction_unref0 (tag_txn);
#line 725 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 725 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_clear_error (&_inner_error_);
#line 725 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return NULL;
#line 5884 "GalleryConnector.c"
	}
#line 733 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp9_ = tag_txn;
#line 733 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp10_ = publishing_gallery3_gallery_get_tag_transaction_tag_url (_tmp9_);
#line 733 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp10_;
#line 733 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_publishing_rest_support_transaction_unref0 (tag_txn);
#line 733 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 5896 "GalleryConnector.c"
}


static gpointer _g_error_copy0 (gpointer self) {
#line 781 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return self ? g_error_copy (self) : NULL;
#line 5903 "GalleryConnector.c"
}


static void publishing_gallery3_gallery_upload_transaction_on_upload_completed (PublishingGallery3GalleryUploadTransaction* self, GError** error) {
	PublishingGallery3PublishingParameters* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_ = FALSE;
	GError * _inner_error_ = NULL;
#line 737 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_UPLOAD_TRANSACTION (self));
#line 740 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_debug ("GalleryConnector.vala:740: EVENT: upload completed");
#line 742 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->parameters;
#line 742 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = publishing_gallery3_publishing_parameters_get_strip_metadata (_tmp0_);
#line 742 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = _tmp1_;
#line 742 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (!_tmp2_) {
#line 5924 "GalleryConnector.c"
		gchar** keywords = NULL;
		gint keywords_length1 = 0;
		gint _keywords_size_ = 0;
		SpitPublishingPublishable* _tmp3_ = NULL;
		gint _tmp4_ = 0;
		gchar** _tmp5_ = NULL;
		gchar** _tmp6_ = NULL;
		gint _tmp6__length1 = 0;
		gchar* _tmp7_ = NULL;
		const gchar* _tmp8_ = NULL;
		gchar* _tmp9_ = NULL;
		gchar* _tmp10_ = NULL;
		const gchar* _tmp11_ = NULL;
		const gchar* _tmp12_ = NULL;
		gboolean _tmp13_ = FALSE;
		const gchar* _tmp14_ = NULL;
		gchar** _tmp17_ = NULL;
		gint _tmp17__length1 = 0;
#line 746 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_debug ("GalleryConnector.vala:746: EVENT: evaluating tags");
#line 748 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp3_ = G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_UPLOAD_TRANSACTION, PublishingRESTSupportUploadTransaction)->publishable;
#line 748 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp5_ = spit_publishing_publishable_get_publishing_keywords (_tmp3_, &_tmp4_);
#line 748 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		keywords = (_vala_array_free (keywords, keywords_length1, (GDestroyNotify) g_free), NULL);
#line 748 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		keywords = _tmp5_;
#line 748 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		keywords_length1 = _tmp4_;
#line 748 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_keywords_size_ = keywords_length1;
#line 751 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp6_ = keywords;
#line 751 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp6__length1 = keywords_length1;
#line 751 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		if (NULL == _tmp6_) {
#line 752 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_debug ("GalleryConnector.vala:752: No tags");
#line 753 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			keywords = (_vala_array_free (keywords, keywords_length1, (GDestroyNotify) g_free), NULL);
#line 753 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			return;
#line 5969 "GalleryConnector.c"
		}
#line 757 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp7_ = publishing_gallery3_gallery_upload_transaction_get_new_item_url (self);
#line 757 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_free0 (self->priv->item_url);
#line 757 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		self->priv->item_url = _tmp7_;
#line 758 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp8_ = self->priv->item_url;
#line 758 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp9_ = publishing_gallery3_strip_session_url (_tmp8_);
#line 758 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_free0 (self->priv->item_path);
#line 758 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		self->priv->item_path = _tmp9_;
#line 759 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp10_ = publishing_gallery3_gallery_upload_transaction_get_new_item_tags_path (self);
#line 759 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_free0 (self->priv->item_tags_path);
#line 759 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		self->priv->item_tags_path = _tmp10_;
#line 760 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp11_ = self->priv->item_path;
#line 760 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_debug ("GalleryConnector.vala:760: new item path is %s", _tmp11_);
#line 761 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp12_ = self->priv->item_tags_path;
#line 761 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_debug ("GalleryConnector.vala:761: item_tags path is %s", _tmp12_);
#line 764 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp14_ = self->priv->item_path;
#line 764 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		if (g_strcmp0 ("", _tmp14_) == 0) {
#line 764 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp13_ = TRUE;
#line 6005 "GalleryConnector.c"
		} else {
			const gchar* _tmp15_ = NULL;
#line 764 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp15_ = self->priv->item_tags_path;
#line 764 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp13_ = g_strcmp0 ("", _tmp15_) == 0;
#line 6012 "GalleryConnector.c"
		}
#line 764 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		if (_tmp13_) {
#line 6016 "GalleryConnector.c"
			GError* _tmp16_ = NULL;
#line 765 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp16_ = g_error_new_literal (SPIT_PUBLISHING_PUBLISHING_ERROR, SPIT_PUBLISHING_PUBLISHING_ERROR_COMMUNICATION_FAILED, "Could not obtain URL of uploaded item or its " "\"item_tags\" relationship URL");
#line 765 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_inner_error_ = _tmp16_;
#line 765 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 765 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				g_propagate_error (error, _inner_error_);
#line 765 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				keywords = (_vala_array_free (keywords, keywords_length1, (GDestroyNotify) g_free), NULL);
#line 765 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				return;
#line 6030 "GalleryConnector.c"
			} else {
#line 765 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				keywords = (_vala_array_free (keywords, keywords_length1, (GDestroyNotify) g_free), NULL);
#line 765 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 765 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				g_clear_error (&_inner_error_);
#line 765 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				return;
#line 6040 "GalleryConnector.c"
			}
		}
#line 772 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp17_ = keywords;
#line 772 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp17__length1 = keywords_length1;
#line 6047 "GalleryConnector.c"
		{
			gchar** tag_collection = NULL;
			gint tag_collection_length1 = 0;
			gint _tag_collection_size_ = 0;
			gint tag_it = 0;
#line 772 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			tag_collection = _tmp17_;
#line 772 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			tag_collection_length1 = _tmp17__length1;
#line 772 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			for (tag_it = 0; tag_it < _tmp17__length1; tag_it = tag_it + 1) {
#line 6059 "GalleryConnector.c"
				gchar* _tmp18_ = NULL;
				gchar* tag = NULL;
#line 772 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp18_ = g_strdup (tag_collection[tag_it]);
#line 772 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				tag = _tmp18_;
#line 6066 "GalleryConnector.c"
				{
					const gchar* _tmp19_ = NULL;
					const gchar* _tmp20_ = NULL;
					gchar* _tmp21_ = NULL;
					gchar* _tmp22_ = NULL;
					gchar* new_tag_url = NULL;
					const gchar* _tmp23_ = NULL;
					gchar* _tmp24_ = NULL;
#line 773 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					_tmp19_ = tag;
#line 773 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					_tmp20_ = string_to_string (_tmp19_);
#line 773 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					_tmp21_ = g_strconcat ("Found tag: ", _tmp20_, NULL);
#line 773 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					_tmp22_ = _tmp21_;
#line 773 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					g_debug ("GalleryConnector.vala:773: %s", _tmp22_);
#line 773 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					_g_free0 (_tmp22_);
#line 774 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					_tmp23_ = tag;
#line 774 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					_tmp24_ = publishing_gallery3_gallery_upload_transaction_get_tag_url (self, _tmp23_);
#line 774 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					new_tag_url = _tmp24_;
#line 6093 "GalleryConnector.c"
					{
						const gchar* _tmp25_ = NULL;
#line 777 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
						_tmp25_ = new_tag_url;
#line 777 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
						publishing_gallery3_gallery_upload_transaction_do_set_tag_relationship (self, _tmp25_, &_inner_error_);
#line 777 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
						if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 777 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
							if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 6104 "GalleryConnector.c"
								goto __catch8_spit_publishing_publishing_error;
							}
#line 777 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
							_g_free0 (new_tag_url);
#line 777 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
							_g_free0 (tag);
#line 777 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
							keywords = (_vala_array_free (keywords, keywords_length1, (GDestroyNotify) g_free), NULL);
#line 777 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
							g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 777 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
							g_clear_error (&_inner_error_);
#line 777 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
							return;
#line 6119 "GalleryConnector.c"
						}
					}
					goto __finally8;
					__catch8_spit_publishing_publishing_error:
					{
						GError* err = NULL;
						GError* _tmp26_ = NULL;
						const gchar* _tmp27_ = NULL;
						GError* _tmp28_ = NULL;
						GError* _tmp29_ = NULL;
#line 776 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
						err = _inner_error_;
#line 776 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
						_inner_error_ = NULL;
#line 779 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
						_tmp26_ = err;
#line 779 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
						_tmp27_ = _tmp26_->message;
#line 779 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
						g_debug ("Problem setting the relationship between tag " "and item: %s", _tmp27_);
#line 781 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
						_tmp28_ = err;
#line 781 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
						_tmp29_ = _g_error_copy0 (_tmp28_);
#line 781 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
						_inner_error_ = _tmp29_;
#line 781 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
						_g_error_free0 (err);
#line 6148 "GalleryConnector.c"
						goto __finally8;
					}
					__finally8:
#line 776 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 776 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
						if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 776 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
							g_propagate_error (error, _inner_error_);
#line 776 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
							_g_free0 (new_tag_url);
#line 776 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
							_g_free0 (tag);
#line 776 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
							keywords = (_vala_array_free (keywords, keywords_length1, (GDestroyNotify) g_free), NULL);
#line 776 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
							return;
#line 6166 "GalleryConnector.c"
						} else {
#line 776 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
							_g_free0 (new_tag_url);
#line 776 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
							_g_free0 (tag);
#line 776 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
							keywords = (_vala_array_free (keywords, keywords_length1, (GDestroyNotify) g_free), NULL);
#line 776 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
							g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 776 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
							g_clear_error (&_inner_error_);
#line 776 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
							return;
#line 6180 "GalleryConnector.c"
						}
					}
#line 772 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					_g_free0 (new_tag_url);
#line 772 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					_g_free0 (tag);
#line 6187 "GalleryConnector.c"
				}
			}
		}
#line 742 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		keywords = (_vala_array_free (keywords, keywords_length1, (GDestroyNotify) g_free), NULL);
#line 6193 "GalleryConnector.c"
	}
}


static void publishing_gallery3_gallery_upload_transaction_real_execute (PublishingRESTSupportTransaction* base, GError** error) {
	PublishingGallery3GalleryUploadTransaction * self;
	GError * _inner_error_ = NULL;
#line 789 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_GALLERY3_TYPE_GALLERY_UPLOAD_TRANSACTION, PublishingGallery3GalleryUploadTransaction);
#line 791 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	PUBLISHING_REST_SUPPORT_TRANSACTION_CLASS (publishing_gallery3_gallery_upload_transaction_parent_class)->execute (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_UPLOAD_TRANSACTION, PublishingRESTSupportUploadTransaction), PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), &_inner_error_);
#line 791 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 791 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 791 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_propagate_error (error, _inner_error_);
#line 791 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			return;
#line 6213 "GalleryConnector.c"
		} else {
#line 791 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 791 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_clear_error (&_inner_error_);
#line 791 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			return;
#line 6221 "GalleryConnector.c"
		}
	}
#line 794 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_gallery_upload_transaction_on_upload_completed (self, &_inner_error_);
#line 794 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 794 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 794 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_propagate_error (error, _inner_error_);
#line 794 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			return;
#line 6234 "GalleryConnector.c"
		} else {
#line 794 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 794 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_clear_error (&_inner_error_);
#line 794 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			return;
#line 6242 "GalleryConnector.c"
		}
	}
}


static void publishing_gallery3_gallery_upload_transaction_class_init (PublishingGallery3GalleryUploadTransactionClass * klass) {
#line 585 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_gallery_upload_transaction_parent_class = g_type_class_peek_parent (klass);
#line 585 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	((PublishingRESTSupportTransactionClass *) klass)->finalize = publishing_gallery3_gallery_upload_transaction_finalize;
#line 585 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_type_class_add_private (klass, sizeof (PublishingGallery3GalleryUploadTransactionPrivate));
#line 585 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	((PublishingRESTSupportTransactionClass *) klass)->execute = publishing_gallery3_gallery_upload_transaction_real_execute;
#line 6257 "GalleryConnector.c"
}


static void publishing_gallery3_gallery_upload_transaction_instance_init (PublishingGallery3GalleryUploadTransaction * self) {
#line 585 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv = PUBLISHING_GALLERY3_GALLERY_UPLOAD_TRANSACTION_GET_PRIVATE (self);
#line 6264 "GalleryConnector.c"
}


static void publishing_gallery3_gallery_upload_transaction_finalize (PublishingRESTSupportTransaction* obj) {
	PublishingGallery3GalleryUploadTransaction * self;
#line 585 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_GALLERY3_TYPE_GALLERY_UPLOAD_TRANSACTION, PublishingGallery3GalleryUploadTransaction);
#line 588 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_publishing_rest_support_session_unref0 (self->priv->session);
#line 589 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->generator);
#line 590 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_publishing_gallery3_publishing_parameters_unref0 (self->priv->parameters);
#line 591 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->item_url);
#line 592 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->item_path);
#line 593 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->item_tags_path);
#line 585 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	PUBLISHING_REST_SUPPORT_TRANSACTION_CLASS (publishing_gallery3_gallery_upload_transaction_parent_class)->finalize (obj);
#line 6286 "GalleryConnector.c"
}


GType publishing_gallery3_gallery_upload_transaction_get_type (void) {
	static volatile gsize publishing_gallery3_gallery_upload_transaction_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_gallery3_gallery_upload_transaction_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingGallery3GalleryUploadTransactionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_gallery3_gallery_upload_transaction_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingGallery3GalleryUploadTransaction), 0, (GInstanceInitFunc) publishing_gallery3_gallery_upload_transaction_instance_init, NULL };
		GType publishing_gallery3_gallery_upload_transaction_type_id;
		publishing_gallery3_gallery_upload_transaction_type_id = g_type_register_static (PUBLISHING_REST_SUPPORT_TYPE_UPLOAD_TRANSACTION, "PublishingGallery3GalleryUploadTransaction", &g_define_type_info, 0);
		g_once_init_leave (&publishing_gallery3_gallery_upload_transaction_type_id__volatile, publishing_gallery3_gallery_upload_transaction_type_id);
	}
	return publishing_gallery3_gallery_upload_transaction_type_id__volatile;
}


PublishingGallery3GalleryPublisher* publishing_gallery3_gallery_publisher_construct (GType object_type, SpitPublishingService* service, SpitPublishingPluginHost* host) {
	PublishingGallery3GalleryPublisher * self = NULL;
	SpitPublishingService* _tmp0_ = NULL;
	SpitPublishingPluginHost* _tmp1_ = NULL;
	PublishingGallery3Session* _tmp2_ = NULL;
#line 814 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (SPIT_PUBLISHING_IS_SERVICE (service), NULL);
#line 814 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (SPIT_PUBLISHING_IS_PLUGIN_HOST (host), NULL);
#line 814 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = (PublishingGallery3GalleryPublisher*) g_object_new (object_type, NULL);
#line 816 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = service;
#line 816 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->service = _tmp0_;
#line 817 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = host;
#line 817 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->host = _tmp1_;
#line 818 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = publishing_gallery3_session_new ();
#line 818 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_publishing_rest_support_session_unref0 (self->priv->session);
#line 818 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->session = _tmp2_;
#line 814 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return self;
#line 6329 "GalleryConnector.c"
}


PublishingGallery3GalleryPublisher* publishing_gallery3_gallery_publisher_new (SpitPublishingService* service, SpitPublishingPluginHost* host) {
#line 814 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return publishing_gallery3_gallery_publisher_construct (PUBLISHING_GALLERY3_TYPE_GALLERY_PUBLISHER, service, host);
#line 6336 "GalleryConnector.c"
}


static gboolean publishing_gallery3_gallery_publisher_real_is_running (SpitPublishingPublisher* base) {
	PublishingGallery3GalleryPublisher * self;
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
#line 821 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_GALLERY3_TYPE_GALLERY_PUBLISHER, PublishingGallery3GalleryPublisher);
#line 822 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->running;
#line 822 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp0_;
#line 822 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 6352 "GalleryConnector.c"
}


static SpitPublishingService* publishing_gallery3_gallery_publisher_real_get_service (SpitPublishingPublisher* base) {
	PublishingGallery3GalleryPublisher * self;
	SpitPublishingService* result = NULL;
	SpitPublishingService* _tmp0_ = NULL;
	SpitPublishingService* _tmp1_ = NULL;
#line 825 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_GALLERY3_TYPE_GALLERY_PUBLISHER, PublishingGallery3GalleryPublisher);
#line 826 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->service;
#line 826 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 826 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp1_;
#line 826 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 6371 "GalleryConnector.c"
}


static void publishing_gallery3_gallery_publisher_real_start (SpitPublishingPublisher* base) {
	PublishingGallery3GalleryPublisher * self;
	gboolean _tmp0_ = FALSE;
	SpitPublishingPluginHost* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gboolean _tmp3_ = FALSE;
	const gchar* _tmp4_ = NULL;
#line 829 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_GALLERY3_TYPE_GALLERY_PUBLISHER, PublishingGallery3GalleryPublisher);
#line 830 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher));
#line 830 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (_tmp0_) {
#line 831 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return;
#line 6390 "GalleryConnector.c"
	}
#line 833 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = self->priv->host;
#line 833 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (_tmp1_ == NULL) {
#line 834 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_error ("GalleryConnector.vala:834: %s", "GalleryPublisher: start( ): can't start; this " "publisher is not restartable.");
#line 6398 "GalleryConnector.c"
	}
#line 837 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_debug ("GalleryConnector.vala:837: GalleryPublisher: starting interaction.");
#line 839 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->running = TRUE;
#line 841 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = publishing_gallery3_gallery_publisher_get_api_key (self);
#line 841 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->key);
#line 841 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->key = _tmp2_;
#line 843 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp4_ = self->priv->key;
#line 843 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (NULL == _tmp4_) {
#line 843 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp3_ = TRUE;
#line 6416 "GalleryConnector.c"
	} else {
		const gchar* _tmp5_ = NULL;
#line 843 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp5_ = self->priv->key;
#line 843 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp3_ = g_strcmp0 ("", _tmp5_) == 0;
#line 6423 "GalleryConnector.c"
	}
#line 843 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (_tmp3_) {
#line 844 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_gallery3_gallery_publisher_do_show_service_welcome_pane (self);
#line 6429 "GalleryConnector.c"
	} else {
		gchar* url = NULL;
		gchar* _tmp6_ = NULL;
		gchar* username = NULL;
		gchar* _tmp7_ = NULL;
		gboolean _tmp8_ = FALSE;
		gboolean _tmp9_ = FALSE;
		const gchar* _tmp10_ = NULL;
#line 846 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp6_ = publishing_gallery3_gallery_publisher_get_gallery_url (self);
#line 846 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		url = _tmp6_;
#line 847 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp7_ = publishing_gallery3_gallery_publisher_get_gallery_username (self);
#line 847 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		username = _tmp7_;
#line 849 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp10_ = username;
#line 849 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		if (NULL == _tmp10_) {
#line 849 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp9_ = TRUE;
#line 6452 "GalleryConnector.c"
		} else {
			const gchar* _tmp11_ = NULL;
#line 849 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp11_ = self->priv->key;
#line 849 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp9_ = NULL == _tmp11_;
#line 6459 "GalleryConnector.c"
		}
#line 849 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		if (_tmp9_) {
#line 849 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp8_ = TRUE;
#line 6465 "GalleryConnector.c"
		} else {
			const gchar* _tmp12_ = NULL;
#line 849 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp12_ = url;
#line 849 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp8_ = NULL == _tmp12_;
#line 6472 "GalleryConnector.c"
		}
#line 849 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		if (_tmp8_) {
#line 850 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			publishing_gallery3_gallery_publisher_do_show_service_welcome_pane (self);
#line 6478 "GalleryConnector.c"
		} else {
			const gchar* _tmp13_ = NULL;
			const gchar* _tmp14_ = NULL;
			SpitPublishingPluginHost* _tmp15_ = NULL;
			PublishingGallery3Session* _tmp16_ = NULL;
			const gchar* _tmp17_ = NULL;
			const gchar* _tmp18_ = NULL;
			const gchar* _tmp19_ = NULL;
#line 852 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp13_ = username;
#line 852 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp14_ = url;
#line 852 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_debug ("ACTION: attempting network login for user " "'%s' at URL '%s' from saved credentials.", _tmp13_, _tmp14_);
#line 856 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp15_ = self->priv->host;
#line 856 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			spit_publishing_plugin_host_install_account_fetch_wait_pane (_tmp15_);
#line 858 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp16_ = self->priv->session;
#line 858 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp17_ = url;
#line 858 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp18_ = username;
#line 858 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp19_ = self->priv->key;
#line 858 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			publishing_gallery3_session_authenticate (_tmp16_, _tmp17_, _tmp18_, _tmp19_);
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			publishing_gallery3_gallery_publisher_do_fetch_album_urls (self);
#line 6509 "GalleryConnector.c"
		}
#line 843 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_free0 (username);
#line 843 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_free0 (url);
#line 6515 "GalleryConnector.c"
	}
}


static void publishing_gallery3_gallery_publisher_real_stop (SpitPublishingPublisher* base) {
	PublishingGallery3GalleryPublisher * self;
#line 866 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_GALLERY3_TYPE_GALLERY_PUBLISHER, PublishingGallery3GalleryPublisher);
#line 867 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_debug ("GalleryConnector.vala:867: GalleryPublisher: stop( ) invoked.");
#line 869 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->running = FALSE;
#line 6528 "GalleryConnector.c"
}


gchar* publishing_gallery3_gallery_publisher_get_api_key (PublishingGallery3GalleryPublisher* self) {
	gchar* result = NULL;
	SpitPublishingPluginHost* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 874 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_PUBLISHER (self), NULL);
#line 875 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->host;
#line 875 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = spit_host_interface_get_config_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "api-key", NULL);
#line 875 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp1_;
#line 875 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 6546 "GalleryConnector.c"
}


void publishing_gallery3_gallery_publisher_set_api_key (PublishingGallery3GalleryPublisher* self, const gchar* key) {
	SpitPublishingPluginHost* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
#line 878 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_PUBLISHER (self));
#line 878 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (key != NULL);
#line 879 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->host;
#line 879 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = key;
#line 879 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	spit_host_interface_set_config_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "api-key", _tmp1_);
#line 6563 "GalleryConnector.c"
}


gchar* publishing_gallery3_gallery_publisher_get_gallery_url (PublishingGallery3GalleryPublisher* self) {
	gchar* result = NULL;
	SpitPublishingPluginHost* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 883 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_PUBLISHER (self), NULL);
#line 884 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->host;
#line 884 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = spit_host_interface_get_config_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "url", NULL);
#line 884 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp1_;
#line 884 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 6581 "GalleryConnector.c"
}


void publishing_gallery3_gallery_publisher_set_gallery_url (PublishingGallery3GalleryPublisher* self, const gchar* url) {
	SpitPublishingPluginHost* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
#line 887 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_PUBLISHER (self));
#line 887 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (url != NULL);
#line 888 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->host;
#line 888 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = url;
#line 888 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	spit_host_interface_set_config_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "url", _tmp1_);
#line 6598 "GalleryConnector.c"
}


gchar* publishing_gallery3_gallery_publisher_get_gallery_username (PublishingGallery3GalleryPublisher* self) {
	gchar* result = NULL;
	SpitPublishingPluginHost* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 892 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_PUBLISHER (self), NULL);
#line 893 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->host;
#line 893 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = spit_host_interface_get_config_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "username", NULL);
#line 893 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp1_;
#line 893 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 6616 "GalleryConnector.c"
}


void publishing_gallery3_gallery_publisher_set_gallery_username (PublishingGallery3GalleryPublisher* self, const gchar* username) {
	SpitPublishingPluginHost* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
#line 896 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_PUBLISHER (self));
#line 896 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (username != NULL);
#line 897 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->host;
#line 897 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = username;
#line 897 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	spit_host_interface_set_config_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "username", _tmp1_);
#line 6633 "GalleryConnector.c"
}


static gboolean* _bool_dup (gboolean* self) {
	gboolean* dup;
#line 901 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	dup = g_new0 (gboolean, 1);
#line 901 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	memcpy (dup, self, sizeof (gboolean));
#line 901 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return dup;
#line 6645 "GalleryConnector.c"
}


static gpointer __bool_dup0 (gpointer self) {
#line 901 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return self ? _bool_dup (self) : NULL;
#line 6652 "GalleryConnector.c"
}


gboolean* publishing_gallery3_gallery_publisher_get_persistent_strip_metadata (PublishingGallery3GalleryPublisher* self) {
	gboolean* result = NULL;
	SpitPublishingPluginHost* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	gboolean* _tmp2_ = NULL;
#line 900 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_PUBLISHER (self), NULL);
#line 901 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->host;
#line 901 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = spit_host_interface_get_config_bool (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "strip-metadata", FALSE);
#line 901 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = __bool_dup0 (&_tmp1_);
#line 901 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp2_;
#line 901 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 6673 "GalleryConnector.c"
}


void publishing_gallery3_gallery_publisher_set_persistent_strip_metadata (PublishingGallery3GalleryPublisher* self, gboolean strip_metadata) {
	SpitPublishingPluginHost* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
#line 904 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_PUBLISHER (self));
#line 905 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->host;
#line 905 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = strip_metadata;
#line 905 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	spit_host_interface_set_config_bool (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "strip-metadata", _tmp1_);
#line 6688 "GalleryConnector.c"
}


static gint* _int_dup (gint* self) {
	gint* dup;
#line 909 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	dup = g_new0 (gint, 1);
#line 909 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	memcpy (dup, self, sizeof (gint));
#line 909 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return dup;
#line 6700 "GalleryConnector.c"
}


static gpointer __int_dup0 (gpointer self) {
#line 909 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return self ? _int_dup (self) : NULL;
#line 6707 "GalleryConnector.c"
}


gint* publishing_gallery3_gallery_publisher_get_scaling_constraint_id (PublishingGallery3GalleryPublisher* self) {
	gint* result = NULL;
	SpitPublishingPluginHost* _tmp0_ = NULL;
	gint _tmp1_ = 0;
	gint* _tmp2_ = NULL;
#line 908 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_PUBLISHER (self), NULL);
#line 909 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->host;
#line 909 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = spit_host_interface_get_config_int (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "scaling-constraint-id", 0);
#line 909 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = __int_dup0 (&_tmp1_);
#line 909 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp2_;
#line 909 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 6728 "GalleryConnector.c"
}


void publishing_gallery3_gallery_publisher_set_scaling_constraint_id (PublishingGallery3GalleryPublisher* self, gint constraint) {
	SpitPublishingPluginHost* _tmp0_ = NULL;
	gint _tmp1_ = 0;
#line 912 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_PUBLISHER (self));
#line 913 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->host;
#line 913 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = constraint;
#line 913 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	spit_host_interface_set_config_int (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "scaling-constraint-id", _tmp1_);
#line 6743 "GalleryConnector.c"
}


gint* publishing_gallery3_gallery_publisher_get_scaling_pixels (PublishingGallery3GalleryPublisher* self) {
	gint* result = NULL;
	SpitPublishingPluginHost* _tmp0_ = NULL;
	gint _tmp1_ = 0;
	gint* _tmp2_ = NULL;
#line 916 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_PUBLISHER (self), NULL);
#line 917 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->host;
#line 917 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = spit_host_interface_get_config_int (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "scaling-pixels", 1024);
#line 917 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = __int_dup0 (&_tmp1_);
#line 917 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp2_;
#line 917 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 6764 "GalleryConnector.c"
}


void publishing_gallery3_gallery_publisher_set_scaling_pixels (PublishingGallery3GalleryPublisher* self, gint pixels) {
	SpitPublishingPluginHost* _tmp0_ = NULL;
	gint _tmp1_ = 0;
#line 920 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_PUBLISHER (self));
#line 921 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->host;
#line 921 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = pixels;
#line 921 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	spit_host_interface_set_config_int (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "scaling-pixels", _tmp1_);
#line 6779 "GalleryConnector.c"
}


static void _publishing_gallery3_gallery_publisher_on_service_welcome_login_spit_publishing_login_callback (gpointer self) {
#line 928 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_gallery_publisher_on_service_welcome_login ((PublishingGallery3GalleryPublisher*) self);
#line 6786 "GalleryConnector.c"
}


static void publishing_gallery3_gallery_publisher_do_show_service_welcome_pane (PublishingGallery3GalleryPublisher* self) {
	SpitPublishingPluginHost* _tmp0_ = NULL;
#line 925 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_PUBLISHER (self));
#line 926 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_debug ("GalleryConnector.vala:926: ACTION: showing service welcome pane.");
#line 928 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->host;
#line 928 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	spit_publishing_plugin_host_install_welcome_pane (_tmp0_, PUBLISHING_GALLERY3_SERVICE_WELCOME_MESSAGE, _publishing_gallery3_gallery_publisher_on_service_welcome_login_spit_publishing_login_callback, self);
#line 6800 "GalleryConnector.c"
}


static void _publishing_gallery3_gallery_publisher_on_credentials_go_back_publishing_gallery3_credentials_pane_go_back (PublishingGallery3CredentialsPane* _sender, gpointer self) {
#line 941 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_gallery_publisher_on_credentials_go_back ((PublishingGallery3GalleryPublisher*) self);
#line 6807 "GalleryConnector.c"
}


static void _publishing_gallery3_gallery_publisher_on_credentials_login_publishing_gallery3_credentials_pane_login (PublishingGallery3CredentialsPane* _sender, const gchar* url, const gchar* uname, const gchar* password, const gchar* key, gpointer self) {
#line 942 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_gallery_publisher_on_credentials_login ((PublishingGallery3GalleryPublisher*) self, url, uname, password);
#line 6814 "GalleryConnector.c"
}


static void publishing_gallery3_gallery_publisher_do_show_credentials_pane (PublishingGallery3GalleryPublisher* self, PublishingGallery3CredentialsPaneMode mode) {
	PublishingGallery3CredentialsPaneMode _tmp0_ = 0;
	gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	PublishingGallery3Session* _tmp3_ = NULL;
	PublishingGallery3CredentialsPane* creds_pane = NULL;
	SpitPublishingPluginHost* _tmp4_ = NULL;
	PublishingGallery3CredentialsPaneMode _tmp5_ = 0;
	gchar* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
	gchar* _tmp8_ = NULL;
	gchar* _tmp9_ = NULL;
	gchar* _tmp10_ = NULL;
	gchar* _tmp11_ = NULL;
	PublishingGallery3CredentialsPane* _tmp12_ = NULL;
	PublishingGallery3CredentialsPane* _tmp13_ = NULL;
	SpitPublishingPluginHost* _tmp14_ = NULL;
#line 932 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_PUBLISHER (self));
#line 933 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = mode;
#line 933 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = publishing_gallery3_credentials_pane_mode_to_string (_tmp0_);
#line 933 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = _tmp1_;
#line 933 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_debug ("GalleryConnector.vala:933: ACTION: showing credentials capture pane in" \
" %s mode.", _tmp2_);
#line 933 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (_tmp2_);
#line 936 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp3_ = self->priv->session;
#line 936 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_session_deauthenticate (_tmp3_);
#line 938 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp4_ = self->priv->host;
#line 938 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp5_ = mode;
#line 938 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp6_ = publishing_gallery3_gallery_publisher_get_gallery_url (self);
#line 938 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp7_ = _tmp6_;
#line 938 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp8_ = publishing_gallery3_gallery_publisher_get_gallery_username (self);
#line 938 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp9_ = _tmp8_;
#line 938 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp10_ = publishing_gallery3_gallery_publisher_get_api_key (self);
#line 938 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp11_ = _tmp10_;
#line 938 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp12_ = publishing_gallery3_credentials_pane_new (_tmp4_, _tmp5_, _tmp7_, _tmp9_, _tmp11_);
#line 938 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp13_ = _tmp12_;
#line 938 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (_tmp11_);
#line 938 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (_tmp9_);
#line 938 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (_tmp7_);
#line 938 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	creds_pane = _tmp13_;
#line 941 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_connect_object (creds_pane, "go-back", (GCallback) _publishing_gallery3_gallery_publisher_on_credentials_go_back_publishing_gallery3_credentials_pane_go_back, self, 0);
#line 942 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_connect_object (creds_pane, "login", (GCallback) _publishing_gallery3_gallery_publisher_on_credentials_login_publishing_gallery3_credentials_pane_login, self, 0);
#line 944 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp14_ = self->priv->host;
#line 944 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	spit_publishing_plugin_host_install_dialog_pane (_tmp14_, G_TYPE_CHECK_INSTANCE_CAST (creds_pane, SPIT_PUBLISHING_TYPE_DIALOG_PANE, SpitPublishingDialogPane), SPIT_PUBLISHING_PLUGIN_HOST_BUTTON_MODE_CANCEL);
#line 932 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (creds_pane);
#line 6889 "GalleryConnector.c"
}


static void _publishing_gallery3_gallery_publisher_on_key_fetch_error_publishing_rest_support_transaction_network_error (PublishingRESTSupportTransaction* _sender, GError* err, gpointer self) {
#line 956 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_gallery_publisher_on_key_fetch_error ((PublishingGallery3GalleryPublisher*) self, _sender, err);
#line 6896 "GalleryConnector.c"
}


static void _publishing_gallery3_gallery_publisher_on_key_fetch_complete_publishing_rest_support_transaction_completed (PublishingRESTSupportTransaction* _sender, gpointer self) {
#line 957 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_gallery_publisher_on_key_fetch_complete ((PublishingGallery3GalleryPublisher*) self, _sender);
#line 6903 "GalleryConnector.c"
}


static void publishing_gallery3_gallery_publisher_do_network_login (PublishingGallery3GalleryPublisher* self, const gchar* url, const gchar* username, const gchar* password) {
	const gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	SpitPublishingPluginHost* _tmp2_ = NULL;
	PublishingGallery3KeyFetchTransaction* fetch_trans = NULL;
	PublishingGallery3Session* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
	const gchar* _tmp6_ = NULL;
	PublishingGallery3KeyFetchTransaction* _tmp7_ = NULL;
	GError * _inner_error_ = NULL;
#line 947 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_PUBLISHER (self));
#line 947 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (url != NULL);
#line 947 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (username != NULL);
#line 947 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (password != NULL);
#line 949 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = username;
#line 949 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = url;
#line 949 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_debug ("ACTION: attempting network login for user '%s' at URL " "'%s'.", _tmp0_, _tmp1_);
#line 952 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = self->priv->host;
#line 952 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	spit_publishing_plugin_host_install_login_wait_pane (_tmp2_);
#line 954 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp3_ = self->priv->session;
#line 954 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp4_ = url;
#line 954 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp5_ = username;
#line 954 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp6_ = password;
#line 954 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp7_ = publishing_gallery3_key_fetch_transaction_new (_tmp3_, _tmp4_, _tmp5_, _tmp6_);
#line 954 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	fetch_trans = _tmp7_;
#line 956 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (fetch_trans, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "network-error", (GCallback) _publishing_gallery3_gallery_publisher_on_key_fetch_error_publishing_rest_support_transaction_network_error, self, 0);
#line 957 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (fetch_trans, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "completed", (GCallback) _publishing_gallery3_gallery_publisher_on_key_fetch_complete_publishing_rest_support_transaction_completed, self, 0);
#line 6952 "GalleryConnector.c"
	{
#line 960 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_rest_support_transaction_execute (G_TYPE_CHECK_INSTANCE_CAST (fetch_trans, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), &_inner_error_);
#line 960 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 960 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 6960 "GalleryConnector.c"
				goto __catch9_spit_publishing_publishing_error;
			}
#line 960 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_publishing_rest_support_transaction_unref0 (fetch_trans);
#line 960 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 960 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_clear_error (&_inner_error_);
#line 960 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			return;
#line 6971 "GalleryConnector.c"
		}
	}
	goto __finally9;
	__catch9_spit_publishing_publishing_error:
	{
		GError* err = NULL;
		GError* _tmp8_ = NULL;
#line 959 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		err = _inner_error_;
#line 959 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_inner_error_ = NULL;
#line 962 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_debug ("GalleryConnector.vala:962: Caught an error attempting to login");
#line 965 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp8_ = err;
#line 965 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_gallery3_gallery_publisher_on_key_fetch_error (self, G_TYPE_CHECK_INSTANCE_CAST (fetch_trans, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), _tmp8_);
#line 959 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_error_free0 (err);
#line 6991 "GalleryConnector.c"
	}
	__finally9:
#line 959 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 959 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_publishing_rest_support_transaction_unref0 (fetch_trans);
#line 959 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 959 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_clear_error (&_inner_error_);
#line 959 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return;
#line 7004 "GalleryConnector.c"
	}
#line 947 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_publishing_rest_support_transaction_unref0 (fetch_trans);
#line 7008 "GalleryConnector.c"
}


static void _publishing_gallery3_gallery_publisher_on_album_urls_fetch_error_publishing_rest_support_transaction_network_error (PublishingRESTSupportTransaction* _sender, GError* err, gpointer self) {
#line 975 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_gallery_publisher_on_album_urls_fetch_error ((PublishingGallery3GalleryPublisher*) self, _sender, err);
#line 7015 "GalleryConnector.c"
}


static void _publishing_gallery3_gallery_publisher_on_album_urls_fetch_complete_publishing_rest_support_transaction_completed (PublishingRESTSupportTransaction* _sender, gpointer self) {
#line 976 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_gallery_publisher_on_album_urls_fetch_complete ((PublishingGallery3GalleryPublisher*) self, _sender);
#line 7022 "GalleryConnector.c"
}


static void publishing_gallery3_gallery_publisher_do_fetch_album_urls (PublishingGallery3GalleryPublisher* self) {
	SpitPublishingPluginHost* _tmp0_ = NULL;
	PublishingGallery3GetAlbumURLsTransaction* album_trans = NULL;
	PublishingGallery3Session* _tmp1_ = NULL;
	PublishingGallery3GetAlbumURLsTransaction* _tmp2_ = NULL;
	GError * _inner_error_ = NULL;
#line 969 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_PUBLISHER (self));
#line 971 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->host;
#line 971 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	spit_publishing_plugin_host_install_account_fetch_wait_pane (_tmp0_);
#line 973 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = self->priv->session;
#line 973 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = publishing_gallery3_get_album_ur_ls_transaction_new (_tmp1_);
#line 973 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	album_trans = _tmp2_;
#line 975 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (album_trans, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "network-error", (GCallback) _publishing_gallery3_gallery_publisher_on_album_urls_fetch_error_publishing_rest_support_transaction_network_error, self, 0);
#line 976 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (album_trans, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "completed", (GCallback) _publishing_gallery3_gallery_publisher_on_album_urls_fetch_complete_publishing_rest_support_transaction_completed, self, 0);
#line 7048 "GalleryConnector.c"
	{
#line 979 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_rest_support_transaction_execute (G_TYPE_CHECK_INSTANCE_CAST (album_trans, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), &_inner_error_);
#line 979 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 979 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 7056 "GalleryConnector.c"
				goto __catch10_spit_publishing_publishing_error;
			}
#line 979 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_publishing_rest_support_transaction_unref0 (album_trans);
#line 979 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 979 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_clear_error (&_inner_error_);
#line 979 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			return;
#line 7067 "GalleryConnector.c"
		}
	}
	goto __finally10;
	__catch10_spit_publishing_publishing_error:
	{
		GError* err = NULL;
		GError* _tmp3_ = NULL;
#line 978 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		err = _inner_error_;
#line 978 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_inner_error_ = NULL;
#line 981 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_debug ("GalleryConnector.vala:981: Caught an error attempting to fetch albums");
#line 984 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp3_ = err;
#line 984 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_gallery3_gallery_publisher_on_album_urls_fetch_error (self, G_TYPE_CHECK_INSTANCE_CAST (album_trans, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), _tmp3_);
#line 978 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_error_free0 (err);
#line 7087 "GalleryConnector.c"
	}
	__finally10:
#line 978 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 978 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_publishing_rest_support_transaction_unref0 (album_trans);
#line 978 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 978 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_clear_error (&_inner_error_);
#line 978 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return;
#line 7100 "GalleryConnector.c"
	}
#line 969 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_publishing_rest_support_transaction_unref0 (album_trans);
#line 7104 "GalleryConnector.c"
}


static void _publishing_gallery3_gallery_publisher_on_album_fetch_error_publishing_rest_support_transaction_network_error (PublishingRESTSupportTransaction* _sender, GError* err, gpointer self) {
#line 993 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_gallery_publisher_on_album_fetch_error ((PublishingGallery3GalleryPublisher*) self, _sender, err);
#line 7111 "GalleryConnector.c"
}


static void _publishing_gallery3_gallery_publisher_on_album_fetch_complete_publishing_rest_support_transaction_completed (PublishingRESTSupportTransaction* _sender, gpointer self) {
#line 994 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_gallery_publisher_on_album_fetch_complete ((PublishingGallery3GalleryPublisher*) self, _sender);
#line 7118 "GalleryConnector.c"
}


static void publishing_gallery3_gallery_publisher_do_fetch_albums (PublishingGallery3GalleryPublisher* self, gchar** album_urls, int album_urls_length1, guint start) {
	PublishingGallery3GetAlbumsTransaction* album_trans = NULL;
	PublishingGallery3Session* _tmp0_ = NULL;
	gchar** _tmp1_ = NULL;
	gint _tmp1__length1 = 0;
	guint _tmp2_ = 0U;
	PublishingGallery3GetAlbumsTransaction* _tmp3_ = NULL;
	GError * _inner_error_ = NULL;
#line 989 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_PUBLISHER (self));
#line 991 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->session;
#line 991 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = album_urls;
#line 991 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1__length1 = album_urls_length1;
#line 991 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = start;
#line 991 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp3_ = publishing_gallery3_get_albums_transaction_new (_tmp0_, _tmp1_, _tmp1__length1, _tmp2_);
#line 991 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	album_trans = _tmp3_;
#line 993 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (album_trans, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "network-error", (GCallback) _publishing_gallery3_gallery_publisher_on_album_fetch_error_publishing_rest_support_transaction_network_error, self, 0);
#line 994 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (album_trans, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "completed", (GCallback) _publishing_gallery3_gallery_publisher_on_album_fetch_complete_publishing_rest_support_transaction_completed, self, 0);
#line 7148 "GalleryConnector.c"
	{
#line 997 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_rest_support_transaction_execute (G_TYPE_CHECK_INSTANCE_CAST (album_trans, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), &_inner_error_);
#line 997 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 997 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 7156 "GalleryConnector.c"
				goto __catch11_spit_publishing_publishing_error;
			}
#line 997 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_publishing_rest_support_transaction_unref0 (album_trans);
#line 997 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 997 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_clear_error (&_inner_error_);
#line 997 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			return;
#line 7167 "GalleryConnector.c"
		}
	}
	goto __finally11;
	__catch11_spit_publishing_publishing_error:
	{
		GError* err = NULL;
		GError* _tmp4_ = NULL;
#line 996 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		err = _inner_error_;
#line 996 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_inner_error_ = NULL;
#line 1001 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp4_ = err;
#line 1001 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_gallery3_gallery_publisher_on_album_fetch_error (self, G_TYPE_CHECK_INSTANCE_CAST (album_trans, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), _tmp4_);
#line 996 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_error_free0 (err);
#line 7185 "GalleryConnector.c"
	}
	__finally11:
#line 996 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 996 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_publishing_rest_support_transaction_unref0 (album_trans);
#line 996 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 996 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_clear_error (&_inner_error_);
#line 996 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return;
#line 7198 "GalleryConnector.c"
	}
#line 989 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_publishing_rest_support_transaction_unref0 (album_trans);
#line 7202 "GalleryConnector.c"
}


static void _publishing_gallery3_gallery_publisher_on_publishing_options_pane_publish_publishing_gallery3_publishing_options_pane_publish (PublishingGallery3PublishingOptionsPane* _sender, PublishingGallery3PublishingParameters* parameters, gpointer self) {
#line 1032 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_gallery_publisher_on_publishing_options_pane_publish ((PublishingGallery3GalleryPublisher*) self, parameters);
#line 7209 "GalleryConnector.c"
}


static void _publishing_gallery3_gallery_publisher_on_publishing_options_pane_logout_publishing_gallery3_publishing_options_pane_logout (PublishingGallery3PublishingOptionsPane* _sender, gpointer self) {
#line 1034 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_gallery_publisher_on_publishing_options_pane_logout ((PublishingGallery3GalleryPublisher*) self);
#line 7216 "GalleryConnector.c"
}


static void publishing_gallery3_gallery_publisher_do_show_publishing_options_pane (PublishingGallery3GalleryPublisher* self, const gchar* url, const gchar* username) {
	GtkBuilder* builder = NULL;
	GtkBuilder* _tmp0_ = NULL;
	SpitPublishingPluginHost* _tmp10_ = NULL;
	const gchar* _tmp11_ = NULL;
	const gchar* _tmp12_ = NULL;
	PublishingGallery3Album** _tmp13_ = NULL;
	gint _tmp13__length1 = 0;
	GtkBuilder* _tmp14_ = NULL;
	gboolean* _tmp15_ = NULL;
	gboolean* _tmp16_ = NULL;
	gint* _tmp17_ = NULL;
	gint* _tmp18_ = NULL;
	gint* _tmp19_ = NULL;
	gint* _tmp20_ = NULL;
	PublishingGallery3PublishingOptionsPane* _tmp21_ = NULL;
	PublishingGallery3PublishingOptionsPane* _tmp22_ = NULL;
	PublishingGallery3PublishingOptionsPane* _tmp23_ = NULL;
	SpitPublishingPluginHost* _tmp24_ = NULL;
	PublishingGallery3PublishingOptionsPane* _tmp25_ = NULL;
	GError * _inner_error_ = NULL;
#line 1006 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_PUBLISHER (self));
#line 1006 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (url != NULL);
#line 1006 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (username != NULL);
#line 1009 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_debug ("GalleryConnector.vala:1009: ACTION: showing publishing options pane");
#line 1011 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = gtk_builder_new ();
#line 1011 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	builder = _tmp0_;
#line 7253 "GalleryConnector.c"
	{
		GtkBuilder* _tmp1_ = NULL;
#line 1014 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp1_ = builder;
#line 1014 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		gtk_builder_add_from_resource (_tmp1_, PLUGIN_RESOURCE_PATH "/gallery3_publishing_options_pane.ui", &_inner_error_);
#line 1014 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 7262 "GalleryConnector.c"
			goto __catch12_g_error;
		}
	}
	goto __finally12;
	__catch12_g_error:
	{
		GError* e = NULL;
		GError* _tmp2_ = NULL;
		const gchar* _tmp3_ = NULL;
		SpitPublishingPluginHost* _tmp4_ = NULL;
		const gchar* _tmp5_ = NULL;
		gchar* _tmp6_ = NULL;
		gchar* _tmp7_ = NULL;
		GError* _tmp8_ = NULL;
		GError* _tmp9_ = NULL;
#line 1013 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		e = _inner_error_;
#line 1013 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_inner_error_ = NULL;
#line 1018 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp2_ = e;
#line 1018 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp3_ = _tmp2_->message;
#line 1018 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_warning ("GalleryConnector.vala:1018: Could not parse UI file! Error: %s.", _tmp3_);
#line 1019 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp4_ = self->priv->host;
#line 1019 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp5_ = _ ("A file required for publishing is unavailable. Publishing to %s can't " \
"continue.");
#line 1019 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp6_ = g_strdup_printf (_tmp5_, PUBLISHING_GALLERY3_SERVICE_NAME);
#line 1019 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp7_ = _tmp6_;
#line 1019 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp8_ = g_error_new_literal (SPIT_PUBLISHING_PUBLISHING_ERROR, SPIT_PUBLISHING_PUBLISHING_ERROR_LOCAL_FILE_ERROR, _tmp7_);
#line 1019 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp9_ = _tmp8_;
#line 1019 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		spit_publishing_plugin_host_post_error (_tmp4_, _tmp9_);
#line 1019 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_error_free0 (_tmp9_);
#line 1019 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_free0 (_tmp7_);
#line 1025 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_error_free0 (e);
#line 1025 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_object_unref0 (builder);
#line 1025 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return;
#line 7312 "GalleryConnector.c"
	}
	__finally12:
#line 1013 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1013 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_object_unref0 (builder);
#line 1013 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1013 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_clear_error (&_inner_error_);
#line 1013 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return;
#line 7325 "GalleryConnector.c"
	}
#line 1028 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp10_ = self->priv->host;
#line 1028 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp11_ = url;
#line 1028 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp12_ = username;
#line 1028 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp13_ = self->priv->albums;
#line 1028 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp13__length1 = self->priv->albums_length1;
#line 1028 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp14_ = builder;
#line 1028 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp15_ = publishing_gallery3_gallery_publisher_get_persistent_strip_metadata (self);
#line 1028 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp16_ = _tmp15_;
#line 1028 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp17_ = publishing_gallery3_gallery_publisher_get_scaling_constraint_id (self);
#line 1028 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp18_ = _tmp17_;
#line 1028 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp19_ = publishing_gallery3_gallery_publisher_get_scaling_pixels (self);
#line 1028 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp20_ = _tmp19_;
#line 1028 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp21_ = publishing_gallery3_publishing_options_pane_new (_tmp10_, _tmp11_, _tmp12_, _tmp13_, _tmp13__length1, _tmp14_, *_tmp16_, *_tmp18_, *_tmp20_);
#line 1028 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->publishing_options_pane);
#line 1028 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->publishing_options_pane = _tmp21_;
#line 1028 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (_tmp20_);
#line 1028 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (_tmp18_);
#line 1028 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (_tmp16_);
#line 1032 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp22_ = self->priv->publishing_options_pane;
#line 1032 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_connect_object (_tmp22_, "publish", (GCallback) _publishing_gallery3_gallery_publisher_on_publishing_options_pane_publish_publishing_gallery3_publishing_options_pane_publish, self, 0);
#line 1034 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp23_ = self->priv->publishing_options_pane;
#line 1034 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_connect_object (_tmp23_, "logout", (GCallback) _publishing_gallery3_gallery_publisher_on_publishing_options_pane_logout_publishing_gallery3_publishing_options_pane_logout, self, 0);
#line 1036 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp24_ = self->priv->host;
#line 1036 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp25_ = self->priv->publishing_options_pane;
#line 1036 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	spit_publishing_plugin_host_install_dialog_pane (_tmp24_, G_TYPE_CHECK_INSTANCE_CAST (_tmp25_, SPIT_PUBLISHING_TYPE_DIALOG_PANE, SpitPublishingDialogPane), SPIT_PUBLISHING_PLUGIN_HOST_BUTTON_MODE_CANCEL);
#line 1006 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (builder);
#line 7379 "GalleryConnector.c"
}


static void _publishing_gallery3_gallery_publisher_on_album_create_error_publishing_rest_support_transaction_network_error (PublishingRESTSupportTransaction* _sender, GError* err, gpointer self) {
#line 1046 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_gallery_publisher_on_album_create_error ((PublishingGallery3GalleryPublisher*) self, _sender, err);
#line 7386 "GalleryConnector.c"
}


static void _publishing_gallery3_gallery_publisher_on_album_create_complete_publishing_rest_support_transaction_completed (PublishingRESTSupportTransaction* _sender, gpointer self) {
#line 1047 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_gallery_publisher_on_album_create_complete ((PublishingGallery3GalleryPublisher*) self, _sender);
#line 7393 "GalleryConnector.c"
}


static void publishing_gallery3_gallery_publisher_do_create_album (PublishingGallery3GalleryPublisher* self, PublishingGallery3PublishingParameters* parameters) {
	PublishingGallery3GalleryAlbumCreateTransaction* album_trans = NULL;
	PublishingGallery3Session* _tmp0_ = NULL;
	PublishingGallery3PublishingParameters* _tmp1_ = NULL;
	PublishingGallery3GalleryAlbumCreateTransaction* _tmp2_ = NULL;
	GError * _inner_error_ = NULL;
#line 1040 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_PUBLISHER (self));
#line 1040 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_PUBLISHING_PARAMETERS (parameters));
#line 1042 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_debug ("GalleryConnector.vala:1042: ACTION: creating album");
#line 1044 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->session;
#line 1044 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = parameters;
#line 1044 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = publishing_gallery3_gallery_album_create_transaction_new (_tmp0_, _tmp1_);
#line 1044 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	album_trans = _tmp2_;
#line 1046 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (album_trans, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "network-error", (GCallback) _publishing_gallery3_gallery_publisher_on_album_create_error_publishing_rest_support_transaction_network_error, self, 0);
#line 1047 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (album_trans, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "completed", (GCallback) _publishing_gallery3_gallery_publisher_on_album_create_complete_publishing_rest_support_transaction_completed, self, 0);
#line 7421 "GalleryConnector.c"
	{
#line 1050 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_rest_support_transaction_execute (G_TYPE_CHECK_INSTANCE_CAST (album_trans, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), &_inner_error_);
#line 1050 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1050 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 7429 "GalleryConnector.c"
				goto __catch13_spit_publishing_publishing_error;
			}
#line 1050 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_publishing_rest_support_transaction_unref0 (album_trans);
#line 1050 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1050 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_clear_error (&_inner_error_);
#line 1050 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			return;
#line 7440 "GalleryConnector.c"
		}
	}
	goto __finally13;
	__catch13_spit_publishing_publishing_error:
	{
		GError* err = NULL;
		GError* _tmp3_ = NULL;
#line 1049 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		err = _inner_error_;
#line 1049 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_inner_error_ = NULL;
#line 1054 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp3_ = err;
#line 1054 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_gallery3_gallery_publisher_on_album_create_error (self, G_TYPE_CHECK_INSTANCE_CAST (album_trans, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), _tmp3_);
#line 1049 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_error_free0 (err);
#line 7458 "GalleryConnector.c"
	}
	__finally13:
#line 1049 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1049 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_publishing_rest_support_transaction_unref0 (album_trans);
#line 1049 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1049 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_clear_error (&_inner_error_);
#line 1049 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return;
#line 7471 "GalleryConnector.c"
	}
#line 1040 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_publishing_rest_support_transaction_unref0 (album_trans);
#line 7475 "GalleryConnector.c"
}


static void _publishing_gallery3_gallery_publisher_on_publish_complete_publishing_rest_support_batch_uploader_upload_complete (PublishingRESTSupportBatchUploader* _sender, gint num_photos_published, gpointer self) {
#line 1083 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_gallery_publisher_on_publish_complete ((PublishingGallery3GalleryPublisher*) self, _sender, num_photos_published);
#line 7482 "GalleryConnector.c"
}


static void _publishing_gallery3_gallery_publisher_on_publish_error_publishing_rest_support_batch_uploader_upload_error (PublishingRESTSupportBatchUploader* _sender, GError* err, gpointer self) {
#line 1084 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_gallery_publisher_on_publish_error ((PublishingGallery3GalleryPublisher*) self, _sender, err);
#line 7489 "GalleryConnector.c"
}


static void _publishing_gallery3_gallery_publisher_on_upload_status_updated_spit_publishing_progress_callback (gint file_number, gdouble fraction_complete, gpointer self) {
#line 1085 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_gallery_publisher_on_upload_status_updated ((PublishingGallery3GalleryPublisher*) self, file_number, fraction_complete);
#line 7496 "GalleryConnector.c"
}


static void publishing_gallery3_gallery_publisher_do_publish (PublishingGallery3GalleryPublisher* self, PublishingGallery3PublishingParameters* parameters) {
	PublishingGallery3PublishingParameters* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_ = FALSE;
	gint _tmp3_ = 0;
	PublishingGallery3PublishingParameters* _tmp4_ = NULL;
	gint _tmp5_ = 0;
	gint _tmp6_ = 0;
	PublishingGallery3PublishingParameters* _tmp7_ = NULL;
	gint _tmp8_ = 0;
	gint _tmp9_ = 0;
	SpitPublishingPluginHost* _tmp10_ = NULL;
	SpitPublishingPluginHost* _tmp11_ = NULL;
	PublishingGallery3PublishingParameters* _tmp12_ = NULL;
	gint _tmp13_ = 0;
	gint _tmp14_ = 0;
	PublishingGallery3PublishingParameters* _tmp15_ = NULL;
	gboolean _tmp16_ = FALSE;
	gboolean _tmp17_ = FALSE;
	void* _tmp18_ = NULL;
	GDestroyNotify _tmp19_ = NULL;
	SpitPublishingProgressCallback _tmp20_ = NULL;
	gboolean _tmp21_ = FALSE;
	PublishingGallery3Uploader* uploader = NULL;
	PublishingGallery3Session* _tmp22_ = NULL;
	SpitPublishingPluginHost* _tmp23_ = NULL;
	gint _tmp24_ = 0;
	SpitPublishingPublishable** _tmp25_ = NULL;
	SpitPublishingPublishable** _tmp26_ = NULL;
	gint _tmp26__length1 = 0;
	PublishingGallery3PublishingParameters* _tmp27_ = NULL;
	PublishingGallery3Uploader* _tmp28_ = NULL;
	PublishingGallery3Uploader* _tmp29_ = NULL;
	PublishingGallery3Uploader* _tmp30_ = NULL;
	PublishingGallery3Uploader* _tmp31_ = NULL;
	PublishingGallery3Uploader* _tmp32_ = NULL;
#line 1059 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_PUBLISHER (self));
#line 1059 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_PUBLISHING_PARAMETERS (parameters));
#line 1061 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_debug ("GalleryConnector.vala:1061: ACTION: publishing items");
#line 1063 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = parameters;
#line 1063 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = publishing_gallery3_publishing_parameters_get_strip_metadata (_tmp0_);
#line 1063 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = _tmp1_;
#line 1063 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_gallery_publisher_set_persistent_strip_metadata (self, _tmp2_);
#line 1065 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp4_ = parameters;
#line 1065 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp5_ = publishing_gallery3_publishing_parameters_get_photo_major_axis_size (_tmp4_);
#line 1065 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp6_ = _tmp5_;
#line 1065 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (_tmp6_ <= 0) {
#line 1065 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp3_ = 0;
#line 7560 "GalleryConnector.c"
	} else {
#line 1065 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp3_ = 1;
#line 7564 "GalleryConnector.c"
	}
#line 1064 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_gallery_publisher_set_scaling_constraint_id (self, _tmp3_);
#line 1066 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp7_ = parameters;
#line 1066 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp8_ = publishing_gallery3_publishing_parameters_get_photo_major_axis_size (_tmp7_);
#line 1066 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp9_ = _tmp8_;
#line 1066 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_gallery_publisher_set_scaling_pixels (self, _tmp9_);
#line 1067 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp10_ = self->priv->host;
#line 1067 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	spit_publishing_plugin_host_set_service_locked (_tmp10_, TRUE);
#line 1068 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp11_ = self->priv->host;
#line 1068 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp12_ = parameters;
#line 1068 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp13_ = publishing_gallery3_publishing_parameters_get_photo_major_axis_size (_tmp12_);
#line 1068 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp14_ = _tmp13_;
#line 1068 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp15_ = parameters;
#line 1068 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp16_ = publishing_gallery3_publishing_parameters_get_strip_metadata (_tmp15_);
#line 1068 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp17_ = _tmp16_;
#line 1068 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp20_ = spit_publishing_plugin_host_serialize_publishables (_tmp11_, _tmp14_, _tmp17_, &_tmp18_, &_tmp19_);
#line 1068 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	(self->priv->progress_reporter_target_destroy_notify == NULL) ? NULL : (self->priv->progress_reporter_target_destroy_notify (self->priv->progress_reporter_target), NULL);
#line 1068 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->progress_reporter = NULL;
#line 1068 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->progress_reporter_target = NULL;
#line 1068 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->progress_reporter_target_destroy_notify = NULL;
#line 1068 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->progress_reporter = _tmp20_;
#line 1068 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->progress_reporter_target = _tmp18_;
#line 1068 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->progress_reporter_target_destroy_notify = _tmp19_;
#line 1077 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp21_ = spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher));
#line 1077 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (!_tmp21_) {
#line 1078 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return;
#line 7616 "GalleryConnector.c"
	}
#line 1080 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp22_ = self->priv->session;
#line 1080 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp23_ = self->priv->host;
#line 1080 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp25_ = spit_publishing_plugin_host_get_publishables (_tmp23_, &_tmp24_);
#line 1080 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp26_ = _tmp25_;
#line 1080 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp26__length1 = _tmp24_;
#line 1080 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp27_ = parameters;
#line 1080 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp28_ = publishing_gallery3_uploader_new (_tmp22_, _tmp26_, _tmp24_, _tmp27_);
#line 1080 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp29_ = _tmp28_;
#line 1080 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp26_ = (_vala_array_free (_tmp26_, _tmp26__length1, (GDestroyNotify) g_object_unref), NULL);
#line 1080 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	uploader = _tmp29_;
#line 1083 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp30_ = uploader;
#line 1083 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp30_, PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, PublishingRESTSupportBatchUploader), "upload-complete", (GCallback) _publishing_gallery3_gallery_publisher_on_publish_complete_publishing_rest_support_batch_uploader_upload_complete, self, 0);
#line 1084 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp31_ = uploader;
#line 1084 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp31_, PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, PublishingRESTSupportBatchUploader), "upload-error", (GCallback) _publishing_gallery3_gallery_publisher_on_publish_error_publishing_rest_support_batch_uploader_upload_error, self, 0);
#line 1085 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp32_ = uploader;
#line 1085 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_rest_support_batch_uploader_upload (G_TYPE_CHECK_INSTANCE_CAST (_tmp32_, PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, PublishingRESTSupportBatchUploader), _publishing_gallery3_gallery_publisher_on_upload_status_updated_spit_publishing_progress_callback, self);
#line 1059 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_publishing_rest_support_batch_uploader_unref0 (uploader);
#line 7652 "GalleryConnector.c"
}


static void publishing_gallery3_gallery_publisher_do_show_success_pane (PublishingGallery3GalleryPublisher* self) {
	SpitPublishingPluginHost* _tmp0_ = NULL;
	SpitPublishingPluginHost* _tmp1_ = NULL;
#line 1089 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_PUBLISHER (self));
#line 1090 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_debug ("GalleryConnector.vala:1090: ACTION: showing success pane.");
#line 1092 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->host;
#line 1092 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	spit_publishing_plugin_host_set_service_locked (_tmp0_, FALSE);
#line 1093 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = self->priv->host;
#line 1093 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	spit_publishing_plugin_host_install_success_pane (_tmp1_);
#line 7671 "GalleryConnector.c"
}


static void publishing_gallery3_gallery_publisher_on_service_welcome_login (PublishingGallery3GalleryPublisher* self) {
	gboolean _tmp0_ = FALSE;
#line 1097 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_PUBLISHER (self));
#line 1098 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher));
#line 1098 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (!_tmp0_) {
#line 1099 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return;
#line 7685 "GalleryConnector.c"
	}
#line 1101 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_debug ("GalleryConnector.vala:1101: EVENT: user clicked 'Login' in welcome pan" \
"e.");
#line 1103 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_gallery_publisher_do_show_credentials_pane (self, PUBLISHING_GALLERY3_CREDENTIALS_PANE_MODE_INTRO);
#line 7691 "GalleryConnector.c"
}


static void publishing_gallery3_gallery_publisher_on_credentials_login (PublishingGallery3GalleryPublisher* self, const gchar* url, const gchar* username, const gchar* password) {
	gboolean _tmp0_ = FALSE;
	const gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
	const gchar* _tmp6_ = NULL;
#line 1106 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_PUBLISHER (self));
#line 1106 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (url != NULL);
#line 1106 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (username != NULL);
#line 1106 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (password != NULL);
#line 1108 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher));
#line 1108 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (!_tmp0_) {
#line 1109 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return;
#line 7717 "GalleryConnector.c"
	}
#line 1111 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = username;
#line 1111 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_debug ("GalleryConnector.vala:1111: EVENT: user '%s' clicked 'Login' in creden" \
"tials pane.", _tmp1_);
#line 1114 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = url;
#line 1114 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_gallery_publisher_set_gallery_url (self, _tmp2_);
#line 1115 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp3_ = username;
#line 1115 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_gallery_publisher_set_gallery_username (self, _tmp3_);
#line 1116 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp4_ = url;
#line 1116 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp5_ = username;
#line 1116 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp6_ = password;
#line 1116 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_gallery_publisher_do_network_login (self, _tmp4_, _tmp5_, _tmp6_);
#line 7739 "GalleryConnector.c"
}


static void publishing_gallery3_gallery_publisher_on_credentials_go_back (PublishingGallery3GalleryPublisher* self) {
	gboolean _tmp0_ = FALSE;
#line 1119 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_PUBLISHER (self));
#line 1120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher));
#line 1120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (!_tmp0_) {
#line 1121 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return;
#line 7753 "GalleryConnector.c"
	}
#line 1123 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_debug ("GalleryConnector.vala:1123: EVENT: user is attempting to go back.");
#line 1125 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_gallery_publisher_do_show_service_welcome_pane (self);
#line 7759 "GalleryConnector.c"
}


static void publishing_gallery3_gallery_publisher_on_key_fetch_error (PublishingGallery3GalleryPublisher* self, PublishingRESTSupportTransaction* bad_txn, GError* err) {
	PublishingRESTSupportTransaction* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
	PublishingRESTSupportTransaction* _tmp2_ = NULL;
	guint _tmp3_ = 0U;
	gboolean _tmp4_ = FALSE;
	PublishingGallery3Session* _tmp5_ = NULL;
	gboolean _tmp6_ = FALSE;
	PublishingRESTSupportTransaction* _tmp7_ = NULL;
	gchar* _tmp8_ = NULL;
	gchar* _tmp9_ = NULL;
	PublishingRESTSupportTransaction* _tmp10_ = NULL;
	guint _tmp11_ = 0U;
#line 1128 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_PUBLISHER (self));
#line 1128 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_TRANSACTION (bad_txn));
#line 1131 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = bad_txn;
#line 1131 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_parse_name ("completed", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp1_, NULL, FALSE);
#line 1131 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_gallery3_gallery_publisher_on_key_fetch_complete_publishing_rest_support_transaction_completed, self);
#line 1132 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = bad_txn;
#line 1132 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_parse_name ("network-error", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp3_, NULL, FALSE);
#line 1132 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_handlers_disconnect_matched (_tmp2_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _publishing_gallery3_gallery_publisher_on_key_fetch_error_publishing_rest_support_transaction_network_error, self);
#line 1134 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp4_ = spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher));
#line 1134 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (!_tmp4_) {
#line 1135 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return;
#line 7798 "GalleryConnector.c"
	}
#line 1138 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp5_ = self->priv->session;
#line 1138 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp6_ = publishing_rest_support_session_is_authenticated (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession));
#line 1138 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (_tmp6_) {
#line 1139 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return;
#line 7808 "GalleryConnector.c"
	}
#line 1141 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp7_ = bad_txn;
#line 1141 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp8_ = publishing_rest_support_transaction_get_response (_tmp7_);
#line 1141 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp9_ = _tmp8_;
#line 1141 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_debug ("EVENT: network transaction to fetch key for login " "failed; response = '%s'.", _tmp9_);
#line 1141 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (_tmp9_);
#line 1150 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp10_ = bad_txn;
#line 1150 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp11_ = publishing_rest_support_transaction_get_status_code (_tmp10_);
#line 1150 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (_tmp11_ == ((guint) 403)) {
#line 1152 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_gallery3_gallery_publisher_do_show_credentials_pane (self, PUBLISHING_GALLERY3_CREDENTIALS_PANE_MODE_FAILED_RETRY);
#line 7828 "GalleryConnector.c"
	} else {
		PublishingRESTSupportTransaction* _tmp12_ = NULL;
		guint _tmp13_ = 0U;
#line 1154 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp12_ = bad_txn;
#line 1154 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp13_ = publishing_rest_support_transaction_get_status_code (_tmp12_);
#line 1154 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		if (_tmp13_ == ((guint) 400)) {
#line 1157 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			publishing_gallery3_gallery_publisher_do_show_credentials_pane (self, PUBLISHING_GALLERY3_CREDENTIALS_PANE_MODE_NOT_GALLERY_URL);
#line 7840 "GalleryConnector.c"
		} else {
			SpitPublishingPluginHost* _tmp14_ = NULL;
			GError* _tmp15_ = NULL;
#line 1160 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp14_ = self->priv->host;
#line 1160 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp15_ = err;
#line 1160 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			spit_publishing_plugin_host_post_error (_tmp14_, _tmp15_);
#line 7850 "GalleryConnector.c"
		}
	}
}


static void publishing_gallery3_gallery_publisher_on_key_fetch_complete (PublishingGallery3GalleryPublisher* self, PublishingRESTSupportTransaction* txn) {
	PublishingRESTSupportTransaction* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
	PublishingRESTSupportTransaction* _tmp2_ = NULL;
	guint _tmp3_ = 0U;
	gboolean _tmp4_ = FALSE;
	PublishingGallery3Session* _tmp5_ = NULL;
	gboolean _tmp6_ = FALSE;
	PublishingRESTSupportTransaction* _tmp7_ = NULL;
	gchar* _tmp8_ = NULL;
	const gchar* _tmp9_ = NULL;
#line 1164 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_PUBLISHER (self));
#line 1164 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_TRANSACTION (txn));
#line 1166 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = txn;
#line 1166 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_parse_name ("completed", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp1_, NULL, FALSE);
#line 1166 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_gallery3_gallery_publisher_on_key_fetch_complete_publishing_rest_support_transaction_completed, self);
#line 1167 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = txn;
#line 1167 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_parse_name ("network-error", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp3_, NULL, FALSE);
#line 1167 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_handlers_disconnect_matched (_tmp2_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _publishing_gallery3_gallery_publisher_on_key_fetch_error_publishing_rest_support_transaction_network_error, self);
#line 1169 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp4_ = spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher));
#line 1169 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (!_tmp4_) {
#line 1170 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return;
#line 7889 "GalleryConnector.c"
	}
#line 1173 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp5_ = self->priv->session;
#line 1173 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp6_ = publishing_rest_support_session_is_authenticated (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession));
#line 1173 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (_tmp6_) {
#line 1174 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return;
#line 7899 "GalleryConnector.c"
	}
#line 1176 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp7_ = txn;
#line 1176 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp8_ = publishing_gallery3_key_fetch_transaction_get_key (G_TYPE_CHECK_INSTANCE_TYPE (_tmp7_, PUBLISHING_GALLERY3_TYPE_KEY_FETCH_TRANSACTION) ? ((PublishingGallery3KeyFetchTransaction*) _tmp7_) : NULL);
#line 1176 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->key);
#line 1176 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->key = _tmp8_;
#line 1178 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp9_ = self->priv->key;
#line 1178 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (_tmp9_ == NULL) {
#line 1178 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_error ("GalleryConnector.vala:1178: key doesn\'t exist");
#line 7915 "GalleryConnector.c"
	} else {
		gchar* url = NULL;
		gchar* _tmp10_ = NULL;
		gchar* username = NULL;
		gchar* _tmp11_ = NULL;
		const gchar* _tmp12_ = NULL;
		PublishingGallery3Session* _tmp13_ = NULL;
		const gchar* _tmp14_ = NULL;
		const gchar* _tmp15_ = NULL;
		const gchar* _tmp16_ = NULL;
#line 1180 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp10_ = publishing_gallery3_gallery_publisher_get_gallery_url (self);
#line 1180 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		url = _tmp10_;
#line 1181 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp11_ = publishing_gallery3_gallery_publisher_get_gallery_username (self);
#line 1181 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		username = _tmp11_;
#line 1183 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_debug ("GalleryConnector.vala:1183: %s", "EVENT: network transaction to fetch key completed " "successfully.");
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp12_ = self->priv->key;
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_gallery3_gallery_publisher_set_api_key (self, _tmp12_);
#line 1187 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp13_ = self->priv->session;
#line 1187 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp14_ = url;
#line 1187 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp15_ = username;
#line 1187 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp16_ = self->priv->key;
#line 1187 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_gallery3_session_authenticate (_tmp13_, _tmp14_, _tmp15_, _tmp16_);
#line 1190 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_gallery3_gallery_publisher_do_fetch_album_urls (self);
#line 1178 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_free0 (username);
#line 1178 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_free0 (url);
#line 7956 "GalleryConnector.c"
	}
}


static void publishing_gallery3_gallery_publisher_on_album_urls_fetch_error (PublishingGallery3GalleryPublisher* self, PublishingRESTSupportTransaction* bad_txn, GError* err) {
	PublishingRESTSupportTransaction* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
	PublishingRESTSupportTransaction* _tmp2_ = NULL;
	guint _tmp3_ = 0U;
	gboolean _tmp4_ = FALSE;
	PublishingGallery3Session* _tmp5_ = NULL;
	gboolean _tmp6_ = FALSE;
	PublishingRESTSupportTransaction* _tmp7_ = NULL;
	gchar* _tmp8_ = NULL;
	gchar* _tmp9_ = NULL;
	PublishingRESTSupportTransaction* _tmp10_ = NULL;
	guint _tmp11_ = 0U;
#line 1194 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_PUBLISHER (self));
#line 1194 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_TRANSACTION (bad_txn));
#line 1197 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = bad_txn;
#line 1197 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_parse_name ("completed", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp1_, NULL, FALSE);
#line 1197 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_gallery3_gallery_publisher_on_album_urls_fetch_complete_publishing_rest_support_transaction_completed, self);
#line 1198 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = bad_txn;
#line 1198 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_parse_name ("network-error", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp3_, NULL, FALSE);
#line 1198 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_handlers_disconnect_matched (_tmp2_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _publishing_gallery3_gallery_publisher_on_album_urls_fetch_error_publishing_rest_support_transaction_network_error, self);
#line 1200 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp4_ = spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher));
#line 1200 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (!_tmp4_) {
#line 1201 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return;
#line 7996 "GalleryConnector.c"
	}
#line 1204 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp5_ = self->priv->session;
#line 1204 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp6_ = publishing_rest_support_session_is_authenticated (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession));
#line 1204 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (!_tmp6_) {
#line 1205 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return;
#line 8006 "GalleryConnector.c"
	}
#line 1207 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp7_ = bad_txn;
#line 1207 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp8_ = publishing_rest_support_transaction_get_response (_tmp7_);
#line 1207 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp9_ = _tmp8_;
#line 1207 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_debug ("EVENT: network transaction to fetch album URLs " "failed; response = \'%s\'.", _tmp9_);
#line 1207 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (_tmp9_);
#line 1216 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp10_ = bad_txn;
#line 1216 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp11_ = publishing_rest_support_transaction_get_status_code (_tmp10_);
#line 1216 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (_tmp11_ == ((guint) 403)) {
#line 1218 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_gallery3_gallery_publisher_do_show_credentials_pane (self, PUBLISHING_GALLERY3_CREDENTIALS_PANE_MODE_FAILED_RETRY);
#line 8026 "GalleryConnector.c"
	} else {
		PublishingRESTSupportTransaction* _tmp12_ = NULL;
		guint _tmp13_ = 0U;
#line 1220 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp12_ = bad_txn;
#line 1220 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp13_ = publishing_rest_support_transaction_get_status_code (_tmp12_);
#line 1220 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		if (_tmp13_ == ((guint) 400)) {
#line 1223 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			publishing_gallery3_gallery_publisher_do_show_credentials_pane (self, PUBLISHING_GALLERY3_CREDENTIALS_PANE_MODE_NOT_GALLERY_URL);
#line 8038 "GalleryConnector.c"
		} else {
			SpitPublishingPluginHost* _tmp14_ = NULL;
			GError* _tmp15_ = NULL;
#line 1226 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp14_ = self->priv->host;
#line 1226 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp15_ = err;
#line 1226 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			spit_publishing_plugin_host_post_error (_tmp14_, _tmp15_);
#line 8048 "GalleryConnector.c"
		}
	}
}


static void publishing_gallery3_gallery_publisher_on_album_urls_fetch_complete (PublishingGallery3GalleryPublisher* self, PublishingRESTSupportTransaction* txn) {
	PublishingRESTSupportTransaction* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
	PublishingRESTSupportTransaction* _tmp2_ = NULL;
	guint _tmp3_ = 0U;
	gboolean _tmp4_ = FALSE;
	PublishingGallery3Session* _tmp5_ = NULL;
	gboolean _tmp6_ = FALSE;
	gchar** album_urls = NULL;
	PublishingRESTSupportTransaction* _tmp7_ = NULL;
	gint _tmp8_ = 0;
	gchar** _tmp9_ = NULL;
	gint album_urls_length1 = 0;
	gint _album_urls_size_ = 0;
	gchar** _tmp10_ = NULL;
	gint _tmp10__length1 = 0;
#line 1230 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_PUBLISHER (self));
#line 1230 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_TRANSACTION (txn));
#line 1232 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = txn;
#line 1232 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_parse_name ("completed", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp1_, NULL, FALSE);
#line 1232 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_gallery3_gallery_publisher_on_album_urls_fetch_complete_publishing_rest_support_transaction_completed, self);
#line 1233 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = txn;
#line 1233 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_parse_name ("network-error", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp3_, NULL, FALSE);
#line 1233 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_handlers_disconnect_matched (_tmp2_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _publishing_gallery3_gallery_publisher_on_album_urls_fetch_error_publishing_rest_support_transaction_network_error, self);
#line 1235 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp4_ = spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher));
#line 1235 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (!_tmp4_) {
#line 1236 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return;
#line 8092 "GalleryConnector.c"
	}
#line 1239 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp5_ = self->priv->session;
#line 1239 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp6_ = publishing_rest_support_session_is_authenticated (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession));
#line 1239 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (!_tmp6_) {
#line 1240 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return;
#line 8102 "GalleryConnector.c"
	}
#line 1242 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_debug ("GalleryConnector.vala:1242: EVENT: retrieving all album URLs.");
#line 1244 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp7_ = txn;
#line 1244 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp9_ = publishing_gallery3_get_album_ur_ls_transaction_get_album_urls (G_TYPE_CHECK_INSTANCE_TYPE (_tmp7_, PUBLISHING_GALLERY3_TYPE_GET_ALBUM_UR_LS_TRANSACTION) ? ((PublishingGallery3GetAlbumURLsTransaction*) _tmp7_) : NULL, &_tmp8_);
#line 1244 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	album_urls = _tmp9_;
#line 1244 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	album_urls_length1 = _tmp8_;
#line 1244 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_album_urls_size_ = album_urls_length1;
#line 1247 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp10_ = album_urls;
#line 1247 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp10__length1 = album_urls_length1;
#line 1247 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (NULL == _tmp10_) {
#line 8122 "GalleryConnector.c"
		gchar* url = NULL;
		PublishingGallery3Session* _tmp11_ = NULL;
		const gchar* _tmp12_ = NULL;
		const gchar* _tmp13_ = NULL;
		gchar* _tmp14_ = NULL;
		gchar* username = NULL;
		PublishingGallery3Session* _tmp15_ = NULL;
		const gchar* _tmp16_ = NULL;
		const gchar* _tmp17_ = NULL;
		gchar* _tmp18_ = NULL;
		const gchar* _tmp19_ = NULL;
		const gchar* _tmp20_ = NULL;
#line 1249 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp11_ = self->priv->session;
#line 1249 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp12_ = publishing_gallery3_session_get_url (_tmp11_);
#line 1249 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp13_ = _tmp12_;
#line 1249 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp14_ = g_strdup (_tmp13_);
#line 1249 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		url = _tmp14_;
#line 1250 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp15_ = self->priv->session;
#line 1250 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp16_ = publishing_gallery3_session_get_username (_tmp15_);
#line 1250 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp17_ = _tmp16_;
#line 1250 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp18_ = g_strdup (_tmp17_);
#line 1250 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		username = _tmp18_;
#line 1252 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp19_ = url;
#line 1252 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp20_ = username;
#line 1252 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_gallery3_gallery_publisher_do_show_publishing_options_pane (self, _tmp19_, _tmp20_);
#line 1247 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_free0 (username);
#line 1247 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_free0 (url);
#line 8165 "GalleryConnector.c"
	} else {
		gchar** _tmp21_ = NULL;
		gint _tmp21__length1 = 0;
#line 1256 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp21_ = album_urls;
#line 1256 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp21__length1 = album_urls_length1;
#line 1256 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_gallery3_gallery_publisher_do_fetch_albums (self, _tmp21_, _tmp21__length1, (guint) 0);
#line 8175 "GalleryConnector.c"
	}
#line 1230 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	album_urls = (_vala_array_free (album_urls, album_urls_length1, (GDestroyNotify) g_free), NULL);
#line 8179 "GalleryConnector.c"
}


static void publishing_gallery3_gallery_publisher_on_album_fetch_error (PublishingGallery3GalleryPublisher* self, PublishingRESTSupportTransaction* bad_txn, GError* err) {
	PublishingRESTSupportTransaction* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
	PublishingRESTSupportTransaction* _tmp2_ = NULL;
	guint _tmp3_ = 0U;
	gboolean _tmp4_ = FALSE;
	PublishingGallery3Session* _tmp5_ = NULL;
	gboolean _tmp6_ = FALSE;
	PublishingRESTSupportTransaction* _tmp7_ = NULL;
	gchar* _tmp8_ = NULL;
	gchar* _tmp9_ = NULL;
	PublishingRESTSupportTransaction* _tmp10_ = NULL;
	guint _tmp11_ = 0U;
#line 1259 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_PUBLISHER (self));
#line 1259 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_TRANSACTION (bad_txn));
#line 1262 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = bad_txn;
#line 1262 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_parse_name ("completed", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp1_, NULL, FALSE);
#line 1262 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_gallery3_gallery_publisher_on_album_fetch_complete_publishing_rest_support_transaction_completed, self);
#line 1263 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = bad_txn;
#line 1263 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_parse_name ("network-error", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp3_, NULL, FALSE);
#line 1263 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_handlers_disconnect_matched (_tmp2_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _publishing_gallery3_gallery_publisher_on_album_fetch_error_publishing_rest_support_transaction_network_error, self);
#line 1265 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp4_ = spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher));
#line 1265 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (!_tmp4_) {
#line 1266 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return;
#line 8218 "GalleryConnector.c"
	}
#line 1269 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp5_ = self->priv->session;
#line 1269 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp6_ = publishing_rest_support_session_is_authenticated (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession));
#line 1269 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (!_tmp6_) {
#line 1270 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return;
#line 8228 "GalleryConnector.c"
	}
#line 1272 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp7_ = bad_txn;
#line 1272 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp8_ = publishing_rest_support_transaction_get_response (_tmp7_);
#line 1272 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp9_ = _tmp8_;
#line 1272 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_debug ("EVENT: network transaction to fetch albums " "failed; response = \'%s\'.", _tmp9_);
#line 1272 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (_tmp9_);
#line 1281 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp10_ = bad_txn;
#line 1281 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp11_ = publishing_rest_support_transaction_get_status_code (_tmp10_);
#line 1281 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (_tmp11_ == ((guint) 403)) {
#line 1283 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_gallery3_gallery_publisher_do_show_credentials_pane (self, PUBLISHING_GALLERY3_CREDENTIALS_PANE_MODE_FAILED_RETRY);
#line 8248 "GalleryConnector.c"
	} else {
		PublishingRESTSupportTransaction* _tmp12_ = NULL;
		guint _tmp13_ = 0U;
#line 1285 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp12_ = bad_txn;
#line 1285 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp13_ = publishing_rest_support_transaction_get_status_code (_tmp12_);
#line 1285 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		if (_tmp13_ == ((guint) 400)) {
#line 1288 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			publishing_gallery3_gallery_publisher_do_show_credentials_pane (self, PUBLISHING_GALLERY3_CREDENTIALS_PANE_MODE_NOT_GALLERY_URL);
#line 8260 "GalleryConnector.c"
		} else {
			SpitPublishingPluginHost* _tmp14_ = NULL;
			GError* _tmp15_ = NULL;
#line 1291 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp14_ = self->priv->host;
#line 1291 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp15_ = err;
#line 1291 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			spit_publishing_plugin_host_post_error (_tmp14_, _tmp15_);
#line 8270 "GalleryConnector.c"
		}
	}
}


static void _vala_array_add5 (PublishingGallery3Album*** array, int* length, int* size, PublishingGallery3Album* value) {
#line 1320 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if ((*length) == (*size)) {
#line 1320 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 1320 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		*array = g_renew (PublishingGallery3Album*, *array, (*size) + 1);
#line 8283 "GalleryConnector.c"
	}
#line 1320 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	(*array)[(*length)++] = value;
#line 1320 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	(*array)[*length] = NULL;
#line 8289 "GalleryConnector.c"
}


static void publishing_gallery3_gallery_publisher_on_album_fetch_complete (PublishingGallery3GalleryPublisher* self, PublishingRESTSupportTransaction* txn) {
	PublishingRESTSupportTransaction* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
	PublishingRESTSupportTransaction* _tmp2_ = NULL;
	guint _tmp3_ = 0U;
	PublishingGallery3Album** new_albums = NULL;
	gint new_albums_length1 = 0;
	gint _new_albums_size_ = 0;
	gboolean _tmp4_ = FALSE;
	PublishingGallery3Session* _tmp5_ = NULL;
	gboolean _tmp6_ = FALSE;
	PublishingRESTSupportTransaction* _tmp23_ = NULL;
	gboolean _tmp24_ = FALSE;
	gboolean _tmp25_ = FALSE;
	GError * _inner_error_ = NULL;
#line 1295 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_PUBLISHER (self));
#line 1295 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_TRANSACTION (txn));
#line 1297 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = txn;
#line 1297 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_parse_name ("completed", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp1_, NULL, FALSE);
#line 1297 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_gallery3_gallery_publisher_on_album_fetch_complete_publishing_rest_support_transaction_completed, self);
#line 1298 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = txn;
#line 1298 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_parse_name ("network-error", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp3_, NULL, FALSE);
#line 1298 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_handlers_disconnect_matched (_tmp2_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _publishing_gallery3_gallery_publisher_on_album_fetch_error_publishing_rest_support_transaction_network_error, self);
#line 1300 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	new_albums = NULL;
#line 1300 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	new_albums_length1 = 0;
#line 1300 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_new_albums_size_ = new_albums_length1;
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp4_ = spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher));
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (!_tmp4_) {
#line 1303 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		new_albums = (_vala_array_free (new_albums, new_albums_length1, (GDestroyNotify) publishing_gallery3_album_unref), NULL);
#line 1303 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return;
#line 8338 "GalleryConnector.c"
	}
#line 1306 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp5_ = self->priv->session;
#line 1306 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp6_ = publishing_rest_support_session_is_authenticated (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession));
#line 1306 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (!_tmp6_) {
#line 1307 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		new_albums = (_vala_array_free (new_albums, new_albums_length1, (GDestroyNotify) publishing_gallery3_album_unref), NULL);
#line 1307 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return;
#line 8350 "GalleryConnector.c"
	}
#line 1309 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_debug ("GalleryConnector.vala:1309: EVENT: user is attempting to populate the " \
"album list.");
#line 8354 "GalleryConnector.c"
	{
		PublishingGallery3Album** _tmp7_ = NULL;
		PublishingRESTSupportTransaction* _tmp8_ = NULL;
		gint _tmp9_ = 0;
		PublishingGallery3Album** _tmp10_ = NULL;
		gint _tmp7__length1 = 0;
		gint __tmp7__size_ = 0;
		PublishingGallery3Album** _tmp11_ = NULL;
		gint _tmp11__length1 = 0;
#line 1313 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp8_ = txn;
#line 1313 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp10_ = publishing_gallery3_get_albums_transaction_get_albums (G_TYPE_CHECK_INSTANCE_TYPE (_tmp8_, PUBLISHING_GALLERY3_TYPE_GET_ALBUMS_TRANSACTION) ? ((PublishingGallery3GetAlbumsTransaction*) _tmp8_) : NULL, &_tmp9_, &_inner_error_);
#line 1313 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp7_ = _tmp10_;
#line 1313 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp7__length1 = _tmp9_;
#line 1313 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		__tmp7__size_ = _tmp7__length1;
#line 1313 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1313 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 8378 "GalleryConnector.c"
				goto __catch14_spit_publishing_publishing_error;
			}
#line 1313 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			new_albums = (_vala_array_free (new_albums, new_albums_length1, (GDestroyNotify) publishing_gallery3_album_unref), NULL);
#line 1313 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1313 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_clear_error (&_inner_error_);
#line 1313 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			return;
#line 8389 "GalleryConnector.c"
		}
#line 1312 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp11_ = _tmp7_;
#line 1312 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp11__length1 = _tmp7__length1;
#line 1312 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp7_ = NULL;
#line 1312 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp7__length1 = 0;
#line 1312 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		new_albums = (_vala_array_free (new_albums, new_albums_length1, (GDestroyNotify) publishing_gallery3_album_unref), NULL);
#line 1312 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		new_albums = _tmp11_;
#line 1312 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		new_albums_length1 = _tmp11__length1;
#line 1312 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_new_albums_size_ = new_albums_length1;
#line 1311 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp7_ = (_vala_array_free (_tmp7_, _tmp7__length1, (GDestroyNotify) publishing_gallery3_album_unref), NULL);
#line 8409 "GalleryConnector.c"
	}
	goto __finally14;
	__catch14_spit_publishing_publishing_error:
	{
		GError* err = NULL;
		PublishingRESTSupportTransaction* _tmp12_ = NULL;
		GError* _tmp13_ = NULL;
#line 1311 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		err = _inner_error_;
#line 1311 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_inner_error_ = NULL;
#line 1315 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp12_ = txn;
#line 1315 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp13_ = err;
#line 1315 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_gallery3_gallery_publisher_on_album_fetch_error (self, _tmp12_, _tmp13_);
#line 1311 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_error_free0 (err);
#line 8429 "GalleryConnector.c"
	}
	__finally14:
#line 1311 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1311 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		new_albums = (_vala_array_free (new_albums, new_albums_length1, (GDestroyNotify) publishing_gallery3_album_unref), NULL);
#line 1311 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1311 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_clear_error (&_inner_error_);
#line 1311 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return;
#line 8442 "GalleryConnector.c"
	}
	{
		gint i = 0;
#line 1319 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		i = 0;
#line 8448 "GalleryConnector.c"
		{
			gboolean _tmp14_ = FALSE;
#line 1319 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp14_ = TRUE;
#line 1319 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			while (TRUE) {
#line 8455 "GalleryConnector.c"
				gint _tmp16_ = 0;
				PublishingGallery3Album** _tmp17_ = NULL;
				gint _tmp17__length1 = 0;
				PublishingGallery3Album** _tmp18_ = NULL;
				gint _tmp18__length1 = 0;
				PublishingGallery3Album** _tmp19_ = NULL;
				gint _tmp19__length1 = 0;
				gint _tmp20_ = 0;
				PublishingGallery3Album* _tmp21_ = NULL;
				PublishingGallery3Album* _tmp22_ = NULL;
#line 1319 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				if (!_tmp14_) {
#line 8468 "GalleryConnector.c"
					gint _tmp15_ = 0;
#line 1319 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					_tmp15_ = i;
#line 1319 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					i = _tmp15_ + 1;
#line 8474 "GalleryConnector.c"
				}
#line 1319 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp14_ = FALSE;
#line 1319 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp16_ = i;
#line 1319 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp17_ = new_albums;
#line 1319 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp17__length1 = new_albums_length1;
#line 1319 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				if (!(_tmp16_ <= (_tmp17__length1 - 1))) {
#line 1319 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					break;
#line 8488 "GalleryConnector.c"
				}
#line 1320 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp18_ = self->priv->albums;
#line 1320 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp18__length1 = self->priv->albums_length1;
#line 1320 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp19_ = new_albums;
#line 1320 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp19__length1 = new_albums_length1;
#line 1320 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp20_ = i;
#line 1320 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp21_ = _tmp19_[_tmp20_];
#line 1320 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp22_ = _publishing_gallery3_album_ref0 (_tmp21_);
#line 1320 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_vala_array_add5 (&self->priv->albums, &self->priv->albums_length1, &self->priv->_albums_size_, _tmp22_);
#line 8506 "GalleryConnector.c"
			}
		}
	}
#line 1322 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp23_ = txn;
#line 1322 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp24_ = publishing_gallery3_get_albums_transaction_get_more_urls (G_TYPE_CHECK_INSTANCE_TYPE (_tmp23_, PUBLISHING_GALLERY3_TYPE_GET_ALBUMS_TRANSACTION) ? ((PublishingGallery3GetAlbumsTransaction*) _tmp23_) : NULL);
#line 1322 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp25_ = _tmp24_;
#line 1322 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (_tmp25_) {
#line 8518 "GalleryConnector.c"
		PublishingRESTSupportTransaction* _tmp26_ = NULL;
		gchar** _tmp27_ = NULL;
		gint _tmp27__length1 = 0;
		gchar** _tmp28_ = NULL;
		gint _tmp28__length1 = 0;
		PublishingRESTSupportTransaction* _tmp29_ = NULL;
		guint _tmp30_ = 0U;
		guint _tmp31_ = 0U;
#line 1324 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp26_ = txn;
#line 1324 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp27_ = publishing_gallery3_get_albums_transaction_get_album_urls (G_TYPE_CHECK_INSTANCE_TYPE (_tmp26_, PUBLISHING_GALLERY3_TYPE_GET_ALBUMS_TRANSACTION) ? ((PublishingGallery3GetAlbumsTransaction*) _tmp26_) : NULL, &_tmp27__length1);
#line 1324 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp28_ = _tmp27_;
#line 1324 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp28__length1 = _tmp27__length1;
#line 1324 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp29_ = txn;
#line 1324 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp30_ = publishing_gallery3_get_albums_transaction_get_urls_sent (G_TYPE_CHECK_INSTANCE_TYPE (_tmp29_, PUBLISHING_GALLERY3_TYPE_GET_ALBUMS_TRANSACTION) ? ((PublishingGallery3GetAlbumsTransaction*) _tmp29_) : NULL);
#line 1324 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp31_ = _tmp30_;
#line 1324 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_gallery3_gallery_publisher_do_fetch_albums (self, _tmp28_, _tmp28__length1, _tmp31_);
#line 8543 "GalleryConnector.c"
	} else {
		gchar* url = NULL;
		PublishingGallery3Session* _tmp32_ = NULL;
		const gchar* _tmp33_ = NULL;
		const gchar* _tmp34_ = NULL;
		gchar* _tmp35_ = NULL;
		gchar* username = NULL;
		PublishingGallery3Session* _tmp36_ = NULL;
		const gchar* _tmp37_ = NULL;
		const gchar* _tmp38_ = NULL;
		gchar* _tmp39_ = NULL;
		const gchar* _tmp40_ = NULL;
		const gchar* _tmp41_ = NULL;
#line 1330 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp32_ = self->priv->session;
#line 1330 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp33_ = publishing_gallery3_session_get_url (_tmp32_);
#line 1330 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp34_ = _tmp33_;
#line 1330 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp35_ = g_strdup (_tmp34_);
#line 1330 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		url = _tmp35_;
#line 1331 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp36_ = self->priv->session;
#line 1331 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp37_ = publishing_gallery3_session_get_username (_tmp36_);
#line 1331 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp38_ = _tmp37_;
#line 1331 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp39_ = g_strdup (_tmp38_);
#line 1331 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		username = _tmp39_;
#line 1333 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp40_ = url;
#line 1333 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp41_ = username;
#line 1333 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_gallery3_gallery_publisher_do_show_publishing_options_pane (self, _tmp40_, _tmp41_);
#line 1322 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_free0 (username);
#line 1322 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_free0 (url);
#line 8587 "GalleryConnector.c"
	}
#line 1295 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	new_albums = (_vala_array_free (new_albums, new_albums_length1, (GDestroyNotify) publishing_gallery3_album_unref), NULL);
#line 8591 "GalleryConnector.c"
}


static void publishing_gallery3_gallery_publisher_on_album_create_error (PublishingGallery3GalleryPublisher* self, PublishingRESTSupportTransaction* bad_txn, GError* err) {
	PublishingRESTSupportTransaction* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
	PublishingRESTSupportTransaction* _tmp2_ = NULL;
	guint _tmp3_ = 0U;
	gboolean _tmp4_ = FALSE;
	PublishingGallery3Session* _tmp5_ = NULL;
	gboolean _tmp6_ = FALSE;
	PublishingRESTSupportTransaction* _tmp7_ = NULL;
	gchar* _tmp8_ = NULL;
	gchar* _tmp9_ = NULL;
	PublishingRESTSupportTransaction* _tmp10_ = NULL;
	guint _tmp11_ = 0U;
#line 1338 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_PUBLISHER (self));
#line 1338 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_TRANSACTION (bad_txn));
#line 1341 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = bad_txn;
#line 1341 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_parse_name ("completed", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp1_, NULL, FALSE);
#line 1341 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_gallery3_gallery_publisher_on_album_create_complete_publishing_rest_support_transaction_completed, self);
#line 1342 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = bad_txn;
#line 1342 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_parse_name ("network-error", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp3_, NULL, FALSE);
#line 1342 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_handlers_disconnect_matched (_tmp2_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _publishing_gallery3_gallery_publisher_on_album_create_error_publishing_rest_support_transaction_network_error, self);
#line 1344 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp4_ = spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher));
#line 1344 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (!_tmp4_) {
#line 1345 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return;
#line 8630 "GalleryConnector.c"
	}
#line 1348 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp5_ = self->priv->session;
#line 1348 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp6_ = publishing_rest_support_session_is_authenticated (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession));
#line 1348 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (!_tmp6_) {
#line 1349 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return;
#line 8640 "GalleryConnector.c"
	}
#line 1351 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp7_ = bad_txn;
#line 1351 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp8_ = publishing_rest_support_transaction_get_response (_tmp7_);
#line 1351 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp9_ = _tmp8_;
#line 1351 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_debug ("EVENT: network transaction to create an album " "failed; response = \'%s\'.", _tmp9_);
#line 1351 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (_tmp9_);
#line 1360 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp10_ = bad_txn;
#line 1360 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp11_ = publishing_rest_support_transaction_get_status_code (_tmp10_);
#line 1360 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (_tmp11_ == ((guint) 403)) {
#line 1362 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_gallery3_gallery_publisher_do_show_credentials_pane (self, PUBLISHING_GALLERY3_CREDENTIALS_PANE_MODE_FAILED_RETRY);
#line 8660 "GalleryConnector.c"
	} else {
		PublishingRESTSupportTransaction* _tmp12_ = NULL;
		guint _tmp13_ = 0U;
#line 1364 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp12_ = bad_txn;
#line 1364 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp13_ = publishing_rest_support_transaction_get_status_code (_tmp12_);
#line 1364 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		if (_tmp13_ == ((guint) 400)) {
#line 1367 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			publishing_gallery3_gallery_publisher_do_show_credentials_pane (self, PUBLISHING_GALLERY3_CREDENTIALS_PANE_MODE_NOT_GALLERY_URL);
#line 8672 "GalleryConnector.c"
		} else {
			SpitPublishingPluginHost* _tmp14_ = NULL;
			GError* _tmp15_ = NULL;
#line 1370 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp14_ = self->priv->host;
#line 1370 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp15_ = err;
#line 1370 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			spit_publishing_plugin_host_post_error (_tmp14_, _tmp15_);
#line 8682 "GalleryConnector.c"
		}
	}
}


static void publishing_gallery3_gallery_publisher_on_album_create_complete (PublishingGallery3GalleryPublisher* self, PublishingRESTSupportTransaction* txn) {
	PublishingRESTSupportTransaction* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
	PublishingRESTSupportTransaction* _tmp2_ = NULL;
	guint _tmp3_ = 0U;
	gboolean _tmp4_ = FALSE;
	PublishingGallery3Session* _tmp5_ = NULL;
	gboolean _tmp6_ = FALSE;
	PublishingGallery3PublishingParameters* new_params = NULL;
	PublishingRESTSupportTransaction* _tmp7_ = NULL;
	PublishingGallery3PublishingParameters* _tmp8_ = NULL;
	PublishingGallery3PublishingParameters* _tmp9_ = NULL;
	PublishingGallery3PublishingParameters* _tmp10_ = NULL;
	PublishingGallery3PublishingParameters* _tmp11_ = NULL;
	PublishingRESTSupportTransaction* _tmp12_ = NULL;
	gchar* _tmp13_ = NULL;
	gchar* _tmp14_ = NULL;
	PublishingGallery3PublishingParameters* _tmp15_ = NULL;
	const gchar* _tmp16_ = NULL;
	const gchar* _tmp17_ = NULL;
	PublishingGallery3PublishingParameters* _tmp18_ = NULL;
#line 1374 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_PUBLISHER (self));
#line 1374 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_TRANSACTION (txn));
#line 1376 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = txn;
#line 1376 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_parse_name ("completed", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp1_, NULL, FALSE);
#line 1376 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_gallery3_gallery_publisher_on_album_create_complete_publishing_rest_support_transaction_completed, self);
#line 1377 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = txn;
#line 1377 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_parse_name ("network-error", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp3_, NULL, FALSE);
#line 1377 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_handlers_disconnect_matched (_tmp2_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _publishing_gallery3_gallery_publisher_on_album_create_error_publishing_rest_support_transaction_network_error, self);
#line 1379 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp4_ = spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher));
#line 1379 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (!_tmp4_) {
#line 1380 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return;
#line 8731 "GalleryConnector.c"
	}
#line 1383 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp5_ = self->priv->session;
#line 1383 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp6_ = publishing_rest_support_session_is_authenticated (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession));
#line 1383 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (!_tmp6_) {
#line 1384 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return;
#line 8741 "GalleryConnector.c"
	}
#line 1386 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp7_ = txn;
#line 1386 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp8_ = publishing_gallery3_gallery_album_create_transaction_get_parameters (G_TYPE_CHECK_INSTANCE_TYPE (_tmp7_, PUBLISHING_GALLERY3_TYPE_GALLERY_ALBUM_CREATE_TRANSACTION) ? ((PublishingGallery3GalleryAlbumCreateTransaction*) _tmp7_) : NULL);
#line 1386 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp9_ = _tmp8_;
#line 1386 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp10_ = _publishing_gallery3_publishing_parameters_ref0 (_tmp9_);
#line 1386 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	new_params = _tmp10_;
#line 1388 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp11_ = new_params;
#line 1388 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp12_ = txn;
#line 1388 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp13_ = publishing_gallery3_gallery_album_create_transaction_get_new_album_path (G_TYPE_CHECK_INSTANCE_TYPE (_tmp12_, PUBLISHING_GALLERY3_TYPE_GALLERY_ALBUM_CREATE_TRANSACTION) ? ((PublishingGallery3GalleryAlbumCreateTransaction*) _tmp12_) : NULL);
#line 1388 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp14_ = _tmp13_;
#line 1388 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_publishing_parameters_set_album_path (_tmp11_, _tmp14_);
#line 1388 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (_tmp14_);
#line 1391 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp15_ = new_params;
#line 1391 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp16_ = publishing_gallery3_publishing_parameters_get_album_path (_tmp15_);
#line 1391 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp17_ = _tmp16_;
#line 1391 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_debug ("GalleryConnector.vala:1391: EVENT: user has created an album at \"%s\"" \
".", _tmp17_);
#line 1394 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp18_ = new_params;
#line 1394 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_gallery_publisher_do_publish (self, _tmp18_);
#line 1374 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_publishing_gallery3_publishing_parameters_unref0 (new_params);
#line 8779 "GalleryConnector.c"
}


static gpointer _publishing_rest_support_batch_uploader_ref0 (gpointer self) {
#line 1403 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return self ? publishing_rest_support_batch_uploader_ref (self) : NULL;
#line 8786 "GalleryConnector.c"
}


static void publishing_gallery3_gallery_publisher_on_publish_error (PublishingGallery3GalleryPublisher* self, PublishingRESTSupportBatchUploader* _uploader, GError* err) {
	gboolean _tmp0_ = FALSE;
	PublishingGallery3Uploader* uploader = NULL;
	PublishingRESTSupportBatchUploader* _tmp1_ = NULL;
	PublishingGallery3Uploader* _tmp2_ = NULL;
	GError* g3_err = NULL;
	GError* _tmp3_ = NULL;
	GError* _tmp4_ = NULL;
	GError* _tmp5_ = NULL;
	const gchar* _tmp6_ = NULL;
	PublishingGallery3Uploader* _tmp7_ = NULL;
	const gchar* _tmp8_ = NULL;
	const gchar* _tmp9_ = NULL;
	PublishingGallery3Uploader* _tmp10_ = NULL;
	guint _tmp11_ = 0U;
	guint _tmp12_ = 0U;
	PublishingGallery3Uploader* _tmp13_ = NULL;
	guint _tmp14_ = 0U;
	PublishingGallery3Uploader* _tmp15_ = NULL;
	guint _tmp16_ = 0U;
	PublishingGallery3Uploader* _tmp17_ = NULL;
	guint _tmp18_ = 0U;
	guint _tmp19_ = 0U;
	SpitPublishingPluginHost* _tmp36_ = NULL;
	GError* _tmp37_ = NULL;
#line 1397 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_PUBLISHER (self));
#line 1397 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_BATCH_UPLOADER (_uploader));
#line 1400 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher));
#line 1400 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (!_tmp0_) {
#line 1401 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return;
#line 8825 "GalleryConnector.c"
	}
#line 1403 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = _uploader;
#line 1403 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = _publishing_rest_support_batch_uploader_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, PUBLISHING_GALLERY3_TYPE_UPLOADER) ? ((PublishingGallery3Uploader*) _tmp1_) : NULL);
#line 1403 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	uploader = _tmp2_;
#line 1404 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp3_ = err;
#line 1404 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp4_ = g_error_copy (_tmp3_);
#line 1404 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g3_err = _tmp4_;
#line 1406 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp5_ = err;
#line 1406 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp6_ = _tmp5_->message;
#line 1406 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp7_ = uploader;
#line 1406 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp8_ = publishing_gallery3_uploader_get_current_publishable_name (_tmp7_);
#line 1406 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp9_ = _tmp8_;
#line 1406 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp10_ = uploader;
#line 1406 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp11_ = publishing_gallery3_uploader_get_status_code (_tmp10_);
#line 1406 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp12_ = _tmp11_;
#line 1406 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_debug ("EVENT: uploader reports upload error = '%s' " "for file '%s' (code %d)", _tmp6_, _tmp9_, _tmp12_);
#line 1410 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp13_ = uploader;
#line 1410 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_parse_name ("upload-complete", PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, &_tmp14_, NULL, FALSE);
#line 1410 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_handlers_disconnect_matched (G_TYPE_CHECK_INSTANCE_CAST (_tmp13_, PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, PublishingRESTSupportBatchUploader), G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp14_, 0, NULL, (GCallback) _publishing_gallery3_gallery_publisher_on_publish_complete_publishing_rest_support_batch_uploader_upload_complete, self);
#line 1411 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp15_ = uploader;
#line 1411 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_parse_name ("upload-error", PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, &_tmp16_, NULL, FALSE);
#line 1411 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_handlers_disconnect_matched (G_TYPE_CHECK_INSTANCE_CAST (_tmp15_, PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, PublishingRESTSupportBatchUploader), G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp16_, 0, NULL, (GCallback) _publishing_gallery3_gallery_publisher_on_publish_error_publishing_rest_support_batch_uploader_upload_error, self);
#line 1414 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp17_ = uploader;
#line 1414 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp18_ = publishing_gallery3_uploader_get_status_code (_tmp17_);
#line 1414 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp19_ = _tmp18_;
#line 1414 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (_tmp19_ == ((guint) 400)) {
#line 8877 "GalleryConnector.c"
		GError* _tmp20_ = NULL;
		GError* _tmp21_ = NULL;
		const gchar* _tmp22_ = NULL;
		PublishingGallery3Uploader* _tmp23_ = NULL;
		const gchar* _tmp24_ = NULL;
		const gchar* _tmp25_ = NULL;
		gchar* _tmp26_ = NULL;
		gchar* _tmp27_ = NULL;
		gchar* _tmp28_ = NULL;
		PublishingGallery3Uploader* _tmp29_ = NULL;
		SpitPublishingPublisherMediaType _tmp30_ = 0;
		SpitPublishingPublisherMediaType _tmp31_ = 0;
#line 1415 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp20_ = g3_err;
#line 1415 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp21_ = g3_err;
#line 1415 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp22_ = _tmp21_->message;
#line 1415 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp23_ = uploader;
#line 1415 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp24_ = publishing_gallery3_uploader_get_current_publishable_name (_tmp23_);
#line 1415 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp25_ = _tmp24_;
#line 1415 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp26_ = g_strdup_printf (PUBLISHING_GALLERY3_GALLERY_PUBLISHER_BAD_FILE_MSG, _tmp25_);
#line 1415 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp27_ = _tmp26_;
#line 1415 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp28_ = g_strconcat (_tmp22_, _tmp27_, NULL);
#line 1415 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_free0 (_tmp21_->message);
#line 1415 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp21_->message = _tmp28_;
#line 1415 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_free0 (_tmp27_);
#line 1419 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp29_ = uploader;
#line 1419 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp30_ = publishing_gallery3_uploader_get_current_publishable_type (_tmp29_);
#line 1419 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp31_ = _tmp30_;
#line 1419 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		if (_tmp31_ == SPIT_PUBLISHING_PUBLISHER_MEDIA_TYPE_VIDEO) {
#line 8922 "GalleryConnector.c"
			GError* _tmp32_ = NULL;
			GError* _tmp33_ = NULL;
			const gchar* _tmp34_ = NULL;
			gchar* _tmp35_ = NULL;
#line 1421 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp32_ = g3_err;
#line 1421 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp33_ = g3_err;
#line 1421 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp34_ = _tmp33_->message;
#line 1421 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp35_ = g_strconcat (_tmp34_, PUBLISHING_GALLERY3_GALLERY_PUBLISHER_BAD_MOVIE_MSG, NULL);
#line 1421 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_g_free0 (_tmp33_->message);
#line 1421 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp33_->message = _tmp35_;
#line 8939 "GalleryConnector.c"
		}
	}
#line 1423 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp36_ = self->priv->host;
#line 1423 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp37_ = g3_err;
#line 1423 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	spit_publishing_plugin_host_post_error (_tmp36_, _tmp37_);
#line 1397 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_error_free0 (g3_err);
#line 1397 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_publishing_rest_support_batch_uploader_unref0 (uploader);
#line 8952 "GalleryConnector.c"
}


static void publishing_gallery3_gallery_publisher_on_upload_status_updated (PublishingGallery3GalleryPublisher* self, gint file_number, gdouble completed_fraction) {
	gboolean _tmp0_ = FALSE;
	gdouble _tmp1_ = 0.0;
	SpitPublishingProgressCallback _tmp2_ = NULL;
	void* _tmp2__target = NULL;
	SpitPublishingProgressCallback _tmp3_ = NULL;
	void* _tmp3__target = NULL;
	gint _tmp4_ = 0;
	gdouble _tmp5_ = 0.0;
#line 1426 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_PUBLISHER (self));
#line 1429 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher));
#line 1429 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (!_tmp0_) {
#line 1430 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return;
#line 8973 "GalleryConnector.c"
	}
#line 1432 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = completed_fraction;
#line 1432 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_debug ("GalleryConnector.vala:1432: EVENT: uploader reports upload %.2f percen" \
"t complete.", 100.0 * _tmp1_);
#line 1435 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = self->priv->progress_reporter;
#line 1435 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2__target = self->priv->progress_reporter_target;
#line 1435 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_vala_assert (_tmp2_ != NULL, "progress_reporter != null");
#line 1437 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp3_ = self->priv->progress_reporter;
#line 1437 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp3__target = self->priv->progress_reporter_target;
#line 1437 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp4_ = file_number;
#line 1437 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp5_ = completed_fraction;
#line 1437 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp3_ (_tmp4_, _tmp5_, _tmp3__target);
#line 8995 "GalleryConnector.c"
}


static void publishing_gallery3_gallery_publisher_on_publish_complete (PublishingGallery3GalleryPublisher* self, PublishingRESTSupportBatchUploader* uploader, gint num_published) {
	PublishingRESTSupportBatchUploader* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
	PublishingRESTSupportBatchUploader* _tmp2_ = NULL;
	guint _tmp3_ = 0U;
	gboolean _tmp4_ = FALSE;
	PublishingGallery3Session* _tmp5_ = NULL;
	gboolean _tmp6_ = FALSE;
	gint _tmp7_ = 0;
#line 1441 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_PUBLISHER (self));
#line 1441 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_BATCH_UPLOADER (uploader));
#line 1444 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = uploader;
#line 1444 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_parse_name ("upload-complete", PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, &_tmp1_, NULL, FALSE);
#line 1444 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_gallery3_gallery_publisher_on_publish_complete_publishing_rest_support_batch_uploader_upload_complete, self);
#line 1445 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = uploader;
#line 1445 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_parse_name ("upload-error", PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, &_tmp3_, NULL, FALSE);
#line 1445 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_handlers_disconnect_matched (_tmp2_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _publishing_gallery3_gallery_publisher_on_publish_error_publishing_rest_support_batch_uploader_upload_error, self);
#line 1447 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp4_ = spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher));
#line 1447 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (!_tmp4_) {
#line 1448 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return;
#line 9030 "GalleryConnector.c"
	}
#line 1451 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp5_ = self->priv->session;
#line 1451 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp6_ = publishing_rest_support_session_is_authenticated (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession));
#line 1451 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (!_tmp6_) {
#line 1452 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return;
#line 9040 "GalleryConnector.c"
	}
#line 1454 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp7_ = num_published;
#line 1454 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_debug ("GalleryConnector.vala:1454: EVENT: publishing complete; %d items publi" \
"shed", _tmp7_);
#line 1457 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_gallery_publisher_do_show_success_pane (self);
#line 9048 "GalleryConnector.c"
}


static void publishing_gallery3_gallery_publisher_on_publishing_options_pane_logout (PublishingGallery3GalleryPublisher* self) {
	PublishingGallery3PublishingOptionsPane* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
	PublishingGallery3PublishingOptionsPane* _tmp2_ = NULL;
	guint _tmp3_ = 0U;
	gboolean _tmp4_ = FALSE;
	PublishingGallery3Session* _tmp5_ = NULL;
#line 1461 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_PUBLISHER (self));
#line 1462 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->publishing_options_pane;
#line 1462 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_parse_name ("publish", PUBLISHING_GALLERY3_TYPE_PUBLISHING_OPTIONS_PANE, &_tmp1_, NULL, FALSE);
#line 1462 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_gallery3_gallery_publisher_on_publishing_options_pane_publish_publishing_gallery3_publishing_options_pane_publish, self);
#line 1464 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = self->priv->publishing_options_pane;
#line 1464 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_parse_name ("logout", PUBLISHING_GALLERY3_TYPE_PUBLISHING_OPTIONS_PANE, &_tmp3_, NULL, FALSE);
#line 1464 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_handlers_disconnect_matched (_tmp2_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _publishing_gallery3_gallery_publisher_on_publishing_options_pane_logout_publishing_gallery3_publishing_options_pane_logout, self);
#line 1467 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp4_ = spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher));
#line 1467 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (!_tmp4_) {
#line 1468 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return;
#line 9079 "GalleryConnector.c"
	}
#line 1470 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_debug ("GalleryConnector.vala:1470: EVENT: user is attempting to log out.");
#line 1472 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp5_ = self->priv->session;
#line 1472 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_session_deauthenticate (_tmp5_);
#line 1473 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_gallery_publisher_do_show_service_welcome_pane (self);
#line 9089 "GalleryConnector.c"
}


static void publishing_gallery3_gallery_publisher_on_publishing_options_pane_publish (PublishingGallery3GalleryPublisher* self, PublishingGallery3PublishingParameters* parameters) {
	PublishingGallery3PublishingOptionsPane* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
	PublishingGallery3PublishingOptionsPane* _tmp2_ = NULL;
	guint _tmp3_ = 0U;
	gboolean _tmp4_ = FALSE;
	PublishingGallery3PublishingParameters* _tmp5_ = NULL;
	gboolean _tmp6_ = FALSE;
#line 1476 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_PUBLISHER (self));
#line 1476 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_PUBLISHING_PARAMETERS (parameters));
#line 1477 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->publishing_options_pane;
#line 1477 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_parse_name ("publish", PUBLISHING_GALLERY3_TYPE_PUBLISHING_OPTIONS_PANE, &_tmp1_, NULL, FALSE);
#line 1477 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_gallery3_gallery_publisher_on_publishing_options_pane_publish_publishing_gallery3_publishing_options_pane_publish, self);
#line 1479 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = self->priv->publishing_options_pane;
#line 1479 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_parse_name ("logout", PUBLISHING_GALLERY3_TYPE_PUBLISHING_OPTIONS_PANE, &_tmp3_, NULL, FALSE);
#line 1479 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_handlers_disconnect_matched (_tmp2_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _publishing_gallery3_gallery_publisher_on_publishing_options_pane_logout_publishing_gallery3_publishing_options_pane_logout, self);
#line 1482 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp4_ = spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher));
#line 1482 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (!_tmp4_) {
#line 1483 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return;
#line 9123 "GalleryConnector.c"
	}
#line 1485 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_debug ("GalleryConnector.vala:1485: EVENT: user is attempting to publish somet" \
"hing.");
#line 1487 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp5_ = parameters;
#line 1487 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp6_ = publishing_gallery3_publishing_parameters_is_to_new_album (_tmp5_);
#line 1487 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (_tmp6_) {
#line 9133 "GalleryConnector.c"
		PublishingGallery3PublishingParameters* _tmp7_ = NULL;
		const gchar* _tmp8_ = NULL;
		const gchar* _tmp9_ = NULL;
		PublishingGallery3PublishingParameters* _tmp10_ = NULL;
#line 1488 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp7_ = parameters;
#line 1488 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp8_ = publishing_gallery3_publishing_parameters_get_album_name (_tmp7_);
#line 1488 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp9_ = _tmp8_;
#line 1488 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_debug ("GalleryConnector.vala:1488: EVENT: must create new album \"%s\" first.", _tmp9_);
#line 1490 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp10_ = parameters;
#line 1490 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_gallery3_gallery_publisher_do_create_album (self, _tmp10_);
#line 9150 "GalleryConnector.c"
	} else {
		PublishingGallery3PublishingParameters* _tmp11_ = NULL;
#line 1493 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp11_ = parameters;
#line 1493 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_gallery3_gallery_publisher_do_publish (self, _tmp11_);
#line 9157 "GalleryConnector.c"
	}
}


static void publishing_gallery3_gallery_publisher_class_init (PublishingGallery3GalleryPublisherClass * klass) {
#line 800 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_gallery_publisher_parent_class = g_type_class_peek_parent (klass);
#line 800 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_type_class_add_private (klass, sizeof (PublishingGallery3GalleryPublisherPrivate));
#line 800 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	G_OBJECT_CLASS (klass)->finalize = publishing_gallery3_gallery_publisher_finalize;
#line 9169 "GalleryConnector.c"
}


static void publishing_gallery3_gallery_publisher_spit_publishing_publisher_interface_init (SpitPublishingPublisherIface * iface) {
#line 800 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_gallery_publisher_spit_publishing_publisher_parent_iface = g_type_interface_peek_parent (iface);
#line 800 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	iface->is_running = (gboolean (*)(SpitPublishingPublisher*)) publishing_gallery3_gallery_publisher_real_is_running;
#line 800 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	iface->get_service = (SpitPublishingService* (*)(SpitPublishingPublisher*)) publishing_gallery3_gallery_publisher_real_get_service;
#line 800 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	iface->start = (void (*)(SpitPublishingPublisher*)) publishing_gallery3_gallery_publisher_real_start;
#line 800 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	iface->stop = (void (*)(SpitPublishingPublisher*)) publishing_gallery3_gallery_publisher_real_stop;
#line 9184 "GalleryConnector.c"
}


static void publishing_gallery3_gallery_publisher_instance_init (PublishingGallery3GalleryPublisher * self) {
#line 800 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv = PUBLISHING_GALLERY3_GALLERY_PUBLISHER_GET_PRIVATE (self);
#line 804 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->host = NULL;
#line 805 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->progress_reporter = NULL;
#line 806 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->service = NULL;
#line 807 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->session = NULL;
#line 808 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->running = FALSE;
#line 809 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->albums = NULL;
#line 809 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->albums_length1 = 0;
#line 809 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_albums_size_ = self->priv->albums_length1;
#line 810 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->key = NULL;
#line 812 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->publishing_options_pane = NULL;
#line 9211 "GalleryConnector.c"
}


static void publishing_gallery3_gallery_publisher_finalize (GObject* obj) {
	PublishingGallery3GalleryPublisher * self;
#line 800 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_GALLERY3_TYPE_GALLERY_PUBLISHER, PublishingGallery3GalleryPublisher);
#line 805 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	(self->priv->progress_reporter_target_destroy_notify == NULL) ? NULL : (self->priv->progress_reporter_target_destroy_notify (self->priv->progress_reporter_target), NULL);
#line 805 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->progress_reporter = NULL;
#line 805 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->progress_reporter_target = NULL;
#line 805 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->progress_reporter_target_destroy_notify = NULL;
#line 807 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_publishing_rest_support_session_unref0 (self->priv->session);
#line 809 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->albums = (_vala_array_free (self->priv->albums, self->priv->albums_length1, (GDestroyNotify) publishing_gallery3_album_unref), NULL);
#line 810 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->key);
#line 812 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->publishing_options_pane);
#line 800 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	G_OBJECT_CLASS (publishing_gallery3_gallery_publisher_parent_class)->finalize (obj);
#line 9237 "GalleryConnector.c"
}


GType publishing_gallery3_gallery_publisher_get_type (void) {
	static volatile gsize publishing_gallery3_gallery_publisher_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_gallery3_gallery_publisher_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingGallery3GalleryPublisherClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_gallery3_gallery_publisher_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingGallery3GalleryPublisher), 0, (GInstanceInitFunc) publishing_gallery3_gallery_publisher_instance_init, NULL };
		static const GInterfaceInfo spit_publishing_publisher_info = { (GInterfaceInitFunc) publishing_gallery3_gallery_publisher_spit_publishing_publisher_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType publishing_gallery3_gallery_publisher_type_id;
		publishing_gallery3_gallery_publisher_type_id = g_type_register_static (G_TYPE_OBJECT, "PublishingGallery3GalleryPublisher", &g_define_type_info, 0);
		g_type_add_interface_static (publishing_gallery3_gallery_publisher_type_id, SPIT_PUBLISHING_TYPE_PUBLISHER, &spit_publishing_publisher_info);
		g_once_init_leave (&publishing_gallery3_gallery_publisher_type_id__volatile, publishing_gallery3_gallery_publisher_type_id);
	}
	return publishing_gallery3_gallery_publisher_type_id__volatile;
}


static PublishingGallery3Album** _vala_array_dup3 (PublishingGallery3Album** self, int length) {
	PublishingGallery3Album** result;
	int i;
#line 1527 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = g_new0 (PublishingGallery3Album*, length + 1);
#line 1527 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	for (i = 0; i < length; i++) {
#line 9262 "GalleryConnector.c"
		PublishingGallery3Album* _tmp0_ = NULL;
#line 1527 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp0_ = _publishing_gallery3_album_ref0 (self[i]);
#line 1527 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		result[i] = _tmp0_;
#line 9268 "GalleryConnector.c"
	}
#line 1527 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 9272 "GalleryConnector.c"
}


static void _publishing_gallery3_publishing_options_pane_on_use_existing_radio_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 1556 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_publishing_options_pane_on_use_existing_radio_clicked ((PublishingGallery3PublishingOptionsPane*) self);
#line 9279 "GalleryConnector.c"
}


static void _publishing_gallery3_publishing_options_pane_on_create_new_radio_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 1557 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_publishing_options_pane_on_create_new_radio_clicked ((PublishingGallery3PublishingOptionsPane*) self);
#line 9286 "GalleryConnector.c"
}


static void _publishing_gallery3_publishing_options_pane_on_new_album_entry_changed_gtk_editable_changed (GtkEditable* _sender, gpointer self) {
#line 1558 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_publishing_options_pane_on_new_album_entry_changed ((PublishingGallery3PublishingOptionsPane*) self);
#line 9293 "GalleryConnector.c"
}


static void _publishing_gallery3_publishing_options_pane_on_scaling_constraint_changed_gtk_combo_box_changed (GtkComboBox* _sender, gpointer self) {
#line 1559 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_publishing_options_pane_on_scaling_constraint_changed ((PublishingGallery3PublishingOptionsPane*) self);
#line 9300 "GalleryConnector.c"
}


static void _publishing_gallery3_publishing_options_pane_on_pixels_changed_gtk_editable_changed (GtkEditable* _sender, gpointer self) {
#line 1560 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_publishing_options_pane_on_pixels_changed ((PublishingGallery3PublishingOptionsPane*) self);
#line 9307 "GalleryConnector.c"
}


static void _publishing_gallery3_publishing_options_pane_on_logout_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 1561 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_publishing_options_pane_on_logout_clicked ((PublishingGallery3PublishingOptionsPane*) self);
#line 9314 "GalleryConnector.c"
}


static void _publishing_gallery3_publishing_options_pane_on_publish_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 1562 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_publishing_options_pane_on_publish_clicked ((PublishingGallery3PublishingOptionsPane*) self);
#line 9321 "GalleryConnector.c"
}


PublishingGallery3PublishingOptionsPane* publishing_gallery3_publishing_options_pane_construct (GType object_type, SpitPublishingPluginHost* host, const gchar* url, const gchar* username, PublishingGallery3Album** albums, int albums_length1, GtkBuilder* builder, gboolean strip_metadata, gint scaling_id, gint scaling_pixels) {
	PublishingGallery3PublishingOptionsPane * self = NULL;
	PublishingGallery3Album** _tmp0_ = NULL;
	gint _tmp0__length1 = 0;
	PublishingGallery3Album** _tmp1_ = NULL;
	gint _tmp1__length1 = 0;
	SpitPublishingPluginHost* _tmp2_ = NULL;
	GtkBuilder* _tmp3_ = NULL;
	GtkBuilder* _tmp4_ = NULL;
	GtkBuilder* _tmp5_ = NULL;
	GtkBuilder* _tmp6_ = NULL;
	GSList* _tmp7_ = NULL;
	GSList* _tmp8_ = NULL;
	guint _tmp9_ = 0U;
	GtkBuilder* _tmp10_ = NULL;
	GObject* _tmp11_ = NULL;
	GtkGrid* _tmp12_ = NULL;
	GtkBuilder* _tmp13_ = NULL;
	GObject* _tmp14_ = NULL;
	GtkLabel* _tmp15_ = NULL;
	GtkBuilder* _tmp16_ = NULL;
	GObject* _tmp17_ = NULL;
	GtkRadioButton* _tmp18_ = NULL;
	GtkBuilder* _tmp19_ = NULL;
	GObject* _tmp20_ = NULL;
	GtkComboBoxText* _tmp21_ = NULL;
	GtkBuilder* _tmp22_ = NULL;
	GObject* _tmp23_ = NULL;
	GtkComboBoxText* _tmp24_ = NULL;
	GtkBuilder* _tmp25_ = NULL;
	GObject* _tmp26_ = NULL;
	GtkEntry* _tmp27_ = NULL;
	GtkBuilder* _tmp28_ = NULL;
	GObject* _tmp29_ = NULL;
	GtkRadioButton* _tmp30_ = NULL;
	GtkBuilder* _tmp31_ = NULL;
	GObject* _tmp32_ = NULL;
	GtkEntry* _tmp33_ = NULL;
	GtkBuilder* _tmp34_ = NULL;
	GObject* _tmp35_ = NULL;
	GtkCheckButton* _tmp36_ = NULL;
	GtkBuilder* _tmp37_ = NULL;
	GObject* _tmp38_ = NULL;
	GtkButton* _tmp39_ = NULL;
	GtkBuilder* _tmp40_ = NULL;
	GObject* _tmp41_ = NULL;
	GtkButton* _tmp42_ = NULL;
	GtkLabel* _tmp43_ = NULL;
	const gchar* _tmp44_ = NULL;
	const gchar* _tmp45_ = NULL;
	const gchar* _tmp46_ = NULL;
	gchar* _tmp47_ = NULL;
	gchar* _tmp48_ = NULL;
	GtkCheckButton* _tmp49_ = NULL;
	gboolean _tmp50_ = FALSE;
	GtkComboBoxText* _tmp51_ = NULL;
	gint _tmp52_ = 0;
	GtkEntry* _tmp53_ = NULL;
	gint _tmp54_ = 0;
	gchar* _tmp55_ = NULL;
	gchar* _tmp56_ = NULL;
	GtkRadioButton* _tmp57_ = NULL;
	GtkRadioButton* _tmp58_ = NULL;
	GtkEntry* _tmp59_ = NULL;
	GtkComboBoxText* _tmp60_ = NULL;
	GtkEntry* _tmp61_ = NULL;
	GtkButton* _tmp62_ = NULL;
	GtkButton* _tmp63_ = NULL;
#line 1523 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (SPIT_PUBLISHING_IS_PLUGIN_HOST (host), NULL);
#line 1523 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (url != NULL, NULL);
#line 1523 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (username != NULL, NULL);
#line 1523 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (GTK_IS_BUILDER (builder), NULL);
#line 1523 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = (PublishingGallery3PublishingOptionsPane*) g_object_new (object_type, NULL);
#line 1527 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = albums;
#line 1527 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0__length1 = albums_length1;
#line 1527 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = (_tmp0_ != NULL) ? _vala_array_dup3 (_tmp0_, _tmp0__length1) : ((gpointer) _tmp0_);
#line 1527 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1__length1 = _tmp0__length1;
#line 1527 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->albums = (_vala_array_free (self->priv->albums, self->priv->albums_length1, (GDestroyNotify) publishing_gallery3_album_unref), NULL);
#line 1527 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->albums = _tmp1_;
#line 1527 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->albums_length1 = _tmp1__length1;
#line 1527 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_albums_size_ = self->priv->albums_length1;
#line 1528 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = host;
#line 1528 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->host = _tmp2_;
#line 1530 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp3_ = builder;
#line 1530 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp4_ = _g_object_ref0 (_tmp3_);
#line 1530 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->builder);
#line 1530 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->builder = _tmp4_;
#line 1531 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp5_ = builder;
#line 1531 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_vala_assert (NULL != _tmp5_, "null != builder");
#line 1532 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp6_ = builder;
#line 1532 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp7_ = gtk_builder_get_objects (_tmp6_);
#line 1532 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp8_ = _tmp7_;
#line 1532 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp9_ = g_slist_length (_tmp8_);
#line 1532 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_vala_assert (_tmp9_ > ((guint) 0), "builder.get_objects().length() > 0");
#line 1532 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_slist_free0 (_tmp8_);
#line 1535 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp10_ = builder;
#line 1535 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp11_ = gtk_builder_get_object (_tmp10_, "pane_widget");
#line 1535 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp12_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp11_, gtk_grid_get_type ()) ? ((GtkGrid*) _tmp11_) : NULL);
#line 1535 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->pane_widget);
#line 1535 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->pane_widget = _tmp12_;
#line 1536 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp13_ = builder;
#line 1536 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp14_ = gtk_builder_get_object (_tmp13_, "title_label");
#line 1536 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp15_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp14_, gtk_label_get_type ()) ? ((GtkLabel*) _tmp14_) : NULL);
#line 1536 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->title_label);
#line 1536 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->title_label = _tmp15_;
#line 1537 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp16_ = builder;
#line 1537 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp17_ = gtk_builder_get_object (_tmp16_, "publish_to_existing_radio");
#line 1537 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp18_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp17_, gtk_radio_button_get_type ()) ? ((GtkRadioButton*) _tmp17_) : NULL);
#line 1537 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->use_existing_radio);
#line 1537 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->use_existing_radio = _tmp18_;
#line 1538 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp19_ = builder;
#line 1538 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp20_ = gtk_builder_get_object (_tmp19_, "existing_albums_combo");
#line 1538 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp21_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp20_, gtk_combo_box_text_get_type ()) ? ((GtkComboBoxText*) _tmp20_) : NULL);
#line 1538 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->existing_albums_combo);
#line 1538 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->existing_albums_combo = _tmp21_;
#line 1539 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp22_ = builder;
#line 1539 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp23_ = gtk_builder_get_object (_tmp22_, "scaling_constraint_combo");
#line 1539 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp24_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp23_, gtk_combo_box_text_get_type ()) ? ((GtkComboBoxText*) _tmp23_) : NULL);
#line 1539 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->scaling_combo);
#line 1539 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->scaling_combo = _tmp24_;
#line 1540 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp25_ = builder;
#line 1540 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp26_ = gtk_builder_get_object (_tmp25_, "major_axis_pixels");
#line 1540 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp27_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp26_, gtk_entry_get_type ()) ? ((GtkEntry*) _tmp26_) : NULL);
#line 1540 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->pixels);
#line 1540 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->pixels = _tmp27_;
#line 1541 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp28_ = builder;
#line 1541 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp29_ = gtk_builder_get_object (_tmp28_, "publish_new_radio");
#line 1541 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp30_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp29_, gtk_radio_button_get_type ()) ? ((GtkRadioButton*) _tmp29_) : NULL);
#line 1541 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->create_new_radio);
#line 1541 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->create_new_radio = _tmp30_;
#line 1542 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp31_ = builder;
#line 1542 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp32_ = gtk_builder_get_object (_tmp31_, "new_album_name");
#line 1542 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp33_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp32_, gtk_entry_get_type ()) ? ((GtkEntry*) _tmp32_) : NULL);
#line 1542 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->new_album_entry);
#line 1542 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->new_album_entry = _tmp33_;
#line 1543 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp34_ = self->priv->builder;
#line 1543 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp35_ = gtk_builder_get_object (_tmp34_, "strip_metadata_check");
#line 1543 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp36_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp35_, gtk_check_button_get_type ()) ? ((GtkCheckButton*) _tmp35_) : NULL);
#line 1543 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->strip_metadata_check);
#line 1543 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->strip_metadata_check = _tmp36_;
#line 1544 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp37_ = builder;
#line 1544 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp38_ = gtk_builder_get_object (_tmp37_, "publish_button");
#line 1544 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp39_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp38_, gtk_button_get_type ()) ? ((GtkButton*) _tmp38_) : NULL);
#line 1544 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->publish_button);
#line 1544 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->publish_button = _tmp39_;
#line 1545 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp40_ = builder;
#line 1545 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp41_ = gtk_builder_get_object (_tmp40_, "logout_button");
#line 1545 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp42_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp41_, gtk_button_get_type ()) ? ((GtkButton*) _tmp41_) : NULL);
#line 1545 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->logout_button);
#line 1545 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->logout_button = _tmp42_;
#line 1549 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp43_ = self->priv->title_label;
#line 1549 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp44_ = _ ("Publishing to %s as %s.");
#line 1549 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp45_ = url;
#line 1549 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp46_ = username;
#line 1549 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp47_ = g_strdup_printf (_tmp44_, _tmp45_, _tmp46_);
#line 1549 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp48_ = _tmp47_;
#line 1549 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	gtk_label_set_label (_tmp43_, _tmp48_);
#line 1549 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (_tmp48_);
#line 1551 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp49_ = self->priv->strip_metadata_check;
#line 1551 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp50_ = strip_metadata;
#line 1551 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	gtk_toggle_button_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp49_, gtk_toggle_button_get_type (), GtkToggleButton), _tmp50_);
#line 1552 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp51_ = self->priv->scaling_combo;
#line 1552 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp52_ = scaling_id;
#line 1552 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	gtk_combo_box_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp51_, gtk_combo_box_get_type (), GtkComboBox), _tmp52_);
#line 1553 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp53_ = self->priv->pixels;
#line 1553 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp54_ = scaling_pixels;
#line 1553 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp55_ = g_strdup_printf ("%i", _tmp54_);
#line 1553 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp56_ = _tmp55_;
#line 1553 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	gtk_entry_set_text (_tmp53_, _tmp56_);
#line 1553 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (_tmp56_);
#line 1556 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp57_ = self->priv->use_existing_radio;
#line 1556 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp57_, gtk_button_get_type (), GtkButton), "clicked", (GCallback) _publishing_gallery3_publishing_options_pane_on_use_existing_radio_clicked_gtk_button_clicked, self, 0);
#line 1557 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp58_ = self->priv->create_new_radio;
#line 1557 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp58_, gtk_button_get_type (), GtkButton), "clicked", (GCallback) _publishing_gallery3_publishing_options_pane_on_create_new_radio_clicked_gtk_button_clicked, self, 0);
#line 1558 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp59_ = self->priv->new_album_entry;
#line 1558 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp59_, GTK_TYPE_EDITABLE, GtkEditable), "changed", (GCallback) _publishing_gallery3_publishing_options_pane_on_new_album_entry_changed_gtk_editable_changed, self, 0);
#line 1559 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp60_ = self->priv->scaling_combo;
#line 1559 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp60_, gtk_combo_box_get_type (), GtkComboBox), "changed", (GCallback) _publishing_gallery3_publishing_options_pane_on_scaling_constraint_changed_gtk_combo_box_changed, self, 0);
#line 1560 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp61_ = self->priv->pixels;
#line 1560 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp61_, GTK_TYPE_EDITABLE, GtkEditable), "changed", (GCallback) _publishing_gallery3_publishing_options_pane_on_pixels_changed_gtk_editable_changed, self, 0);
#line 1561 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp62_ = self->priv->logout_button;
#line 1561 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_connect_object (_tmp62_, "clicked", (GCallback) _publishing_gallery3_publishing_options_pane_on_logout_clicked_gtk_button_clicked, self, 0);
#line 1562 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp63_ = self->priv->publish_button;
#line 1562 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_connect_object (_tmp63_, "clicked", (GCallback) _publishing_gallery3_publishing_options_pane_on_publish_clicked_gtk_button_clicked, self, 0);
#line 1523 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return self;
#line 9627 "GalleryConnector.c"
}


PublishingGallery3PublishingOptionsPane* publishing_gallery3_publishing_options_pane_new (SpitPublishingPluginHost* host, const gchar* url, const gchar* username, PublishingGallery3Album** albums, int albums_length1, GtkBuilder* builder, gboolean strip_metadata, gint scaling_id, gint scaling_pixels) {
#line 1523 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return publishing_gallery3_publishing_options_pane_construct (PUBLISHING_GALLERY3_TYPE_PUBLISHING_OPTIONS_PANE, host, url, username, albums, albums_length1, builder, strip_metadata, scaling_id, scaling_pixels);
#line 9634 "GalleryConnector.c"
}


static void publishing_gallery3_publishing_options_pane_on_publish_clicked (PublishingGallery3PublishingOptionsPane* self) {
	gchar* album_name = NULL;
	gint _tmp0_ = 0;
	GtkComboBoxText* _tmp1_ = NULL;
	gint _tmp2_ = 0;
	gint photo_major_axis_size = 0;
	PublishingGallery3PublishingParameters* param = NULL;
	GtkRadioButton* _tmp6_ = NULL;
	gboolean _tmp7_ = FALSE;
	PublishingGallery3PublishingParameters* _tmp34_ = NULL;
	gint _tmp35_ = 0;
	PublishingGallery3PublishingParameters* _tmp36_ = NULL;
	GtkCheckButton* _tmp37_ = NULL;
	gboolean _tmp38_ = FALSE;
	PublishingGallery3PublishingParameters* _tmp39_ = NULL;
#line 1565 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_PUBLISHING_OPTIONS_PANE (self));
#line 1568 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = self->priv->scaling_combo;
#line 1568 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = gtk_combo_box_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, gtk_combo_box_get_type (), GtkComboBox));
#line 1568 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (_tmp2_ == 1) {
#line 9661 "GalleryConnector.c"
		GtkEntry* _tmp3_ = NULL;
		const gchar* _tmp4_ = NULL;
		gint _tmp5_ = 0;
#line 1569 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp3_ = self->priv->pixels;
#line 1569 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp4_ = gtk_entry_get_text (_tmp3_);
#line 1569 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp5_ = atoi (_tmp4_);
#line 1569 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp0_ = _tmp5_;
#line 9673 "GalleryConnector.c"
	} else {
#line 1569 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp0_ = -1;
#line 9677 "GalleryConnector.c"
	}
#line 1567 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	photo_major_axis_size = _tmp0_;
#line 1572 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp6_ = self->priv->create_new_radio;
#line 1572 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp7_ = gtk_toggle_button_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, gtk_toggle_button_get_type (), GtkToggleButton));
#line 1572 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (_tmp7_) {
#line 9687 "GalleryConnector.c"
		GtkEntry* _tmp8_ = NULL;
		const gchar* _tmp9_ = NULL;
		gchar* _tmp10_ = NULL;
		SpitPublishingPluginHost* _tmp11_ = NULL;
		const gchar* _tmp12_ = NULL;
		const gchar* _tmp13_ = NULL;
		PublishingGallery3PublishingParameters* _tmp14_ = NULL;
		const gchar* _tmp15_ = NULL;
#line 1573 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp8_ = self->priv->new_album_entry;
#line 1573 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp9_ = gtk_entry_get_text (_tmp8_);
#line 1573 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp10_ = g_strdup (_tmp9_);
#line 1573 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_free0 (album_name);
#line 1573 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		album_name = _tmp10_;
#line 1574 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp11_ = self->priv->host;
#line 1574 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp12_ = album_name;
#line 1574 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		spit_host_interface_set_config_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp11_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), PUBLISHING_GALLERY3_PUBLISHING_OPTIONS_PANE_LAST_ALBUM_CONFIG_KEY, _tmp12_);
#line 1575 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp13_ = album_name;
#line 1575 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp14_ = publishing_gallery3_publishing_parameters_new_to_new_album (_tmp13_);
#line 1575 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_publishing_gallery3_publishing_parameters_unref0 (param);
#line 1575 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		param = _tmp14_;
#line 1577 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp15_ = album_name;
#line 1577 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_debug ("GalleryConnector.vala:1577: Trying to publish to \"%s\"", _tmp15_);
#line 9724 "GalleryConnector.c"
	} else {
		PublishingGallery3Album** _tmp16_ = NULL;
		gint _tmp16__length1 = 0;
		GtkComboBoxText* _tmp17_ = NULL;
		gint _tmp18_ = 0;
		PublishingGallery3Album* _tmp19_ = NULL;
		const gchar* _tmp20_ = NULL;
		const gchar* _tmp21_ = NULL;
		gchar* _tmp22_ = NULL;
		SpitPublishingPluginHost* _tmp23_ = NULL;
		const gchar* _tmp24_ = NULL;
		gchar* album_path = NULL;
		PublishingGallery3Album** _tmp25_ = NULL;
		gint _tmp25__length1 = 0;
		GtkComboBoxText* _tmp26_ = NULL;
		gint _tmp27_ = 0;
		PublishingGallery3Album* _tmp28_ = NULL;
		const gchar* _tmp29_ = NULL;
		const gchar* _tmp30_ = NULL;
		gchar* _tmp31_ = NULL;
		const gchar* _tmp32_ = NULL;
		PublishingGallery3PublishingParameters* _tmp33_ = NULL;
#line 1579 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp16_ = self->priv->albums;
#line 1579 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp16__length1 = self->priv->albums_length1;
#line 1579 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp17_ = self->priv->existing_albums_combo;
#line 1579 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp18_ = gtk_combo_box_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp17_, gtk_combo_box_get_type (), GtkComboBox));
#line 1579 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp19_ = _tmp16_[_tmp18_];
#line 1579 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp20_ = publishing_gallery3_album_get_title (_tmp19_);
#line 1579 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp21_ = _tmp20_;
#line 1579 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp22_ = g_strdup (_tmp21_);
#line 1579 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_free0 (album_name);
#line 1579 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		album_name = _tmp22_;
#line 1581 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp23_ = self->priv->host;
#line 1581 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp24_ = album_name;
#line 1581 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		spit_host_interface_set_config_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp23_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), PUBLISHING_GALLERY3_PUBLISHING_OPTIONS_PANE_LAST_ALBUM_CONFIG_KEY, _tmp24_);
#line 1582 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp25_ = self->priv->albums;
#line 1582 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp25__length1 = self->priv->albums_length1;
#line 1582 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp26_ = self->priv->existing_albums_combo;
#line 1582 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp27_ = gtk_combo_box_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp26_, gtk_combo_box_get_type (), GtkComboBox));
#line 1582 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp28_ = _tmp25_[_tmp27_];
#line 1582 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp29_ = publishing_gallery3_album_get_path (_tmp28_);
#line 1582 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp30_ = _tmp29_;
#line 1582 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp31_ = g_strdup (_tmp30_);
#line 1582 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		album_path = _tmp31_;
#line 1584 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp32_ = album_path;
#line 1584 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp33_ = publishing_gallery3_publishing_parameters_new_to_existing_album (_tmp32_);
#line 1584 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_publishing_gallery3_publishing_parameters_unref0 (param);
#line 1584 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		param = _tmp33_;
#line 1572 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_free0 (album_path);
#line 9801 "GalleryConnector.c"
	}
#line 1588 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp34_ = param;
#line 1588 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp35_ = photo_major_axis_size;
#line 1588 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_publishing_parameters_set_photo_major_axis_size (_tmp34_, _tmp35_);
#line 1589 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp36_ = param;
#line 1589 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp37_ = self->priv->strip_metadata_check;
#line 1589 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp38_ = gtk_toggle_button_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp37_, gtk_toggle_button_get_type (), GtkToggleButton));
#line 1589 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_publishing_parameters_set_strip_metadata (_tmp36_, _tmp38_);
#line 1591 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp39_ = param;
#line 1591 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_emit_by_name (self, "publish", _tmp39_);
#line 1565 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_publishing_gallery3_publishing_parameters_unref0 (param);
#line 1565 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (album_name);
#line 9825 "GalleryConnector.c"
}


static void publishing_gallery3_publishing_options_pane_on_use_existing_radio_clicked (PublishingGallery3PublishingOptionsPane* self) {
	GtkComboBoxText* _tmp0_ = NULL;
	GtkEntry* _tmp1_ = NULL;
	GtkComboBoxText* _tmp2_ = NULL;
#line 1594 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_PUBLISHING_OPTIONS_PANE (self));
#line 1595 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->existing_albums_combo;
#line 1595 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_widget_get_type (), GtkWidget), TRUE);
#line 1596 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = self->priv->new_album_entry;
#line 1596 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 1597 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = self->priv->existing_albums_combo;
#line 1597 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	gtk_widget_grab_focus (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, gtk_widget_get_type (), GtkWidget));
#line 1598 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_publishing_options_pane_update_publish_button_sensitivity (self);
#line 9849 "GalleryConnector.c"
}


static void publishing_gallery3_publishing_options_pane_on_create_new_radio_clicked (PublishingGallery3PublishingOptionsPane* self) {
	GtkEntry* _tmp0_ = NULL;
	GtkComboBoxText* _tmp1_ = NULL;
	GtkEntry* _tmp2_ = NULL;
#line 1601 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_PUBLISHING_OPTIONS_PANE (self));
#line 1602 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->new_album_entry;
#line 1602 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_widget_get_type (), GtkWidget), TRUE);
#line 1603 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = self->priv->existing_albums_combo;
#line 1603 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 1604 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = self->priv->new_album_entry;
#line 1604 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	gtk_widget_grab_focus (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, gtk_widget_get_type (), GtkWidget));
#line 1605 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_publishing_options_pane_update_publish_button_sensitivity (self);
#line 9873 "GalleryConnector.c"
}


static void publishing_gallery3_publishing_options_pane_on_logout_clicked (PublishingGallery3PublishingOptionsPane* self) {
#line 1608 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_PUBLISHING_OPTIONS_PANE (self));
#line 1609 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_emit_by_name (self, "logout");
#line 9882 "GalleryConnector.c"
}


static gchar* string_strip (const gchar* self) {
	gchar* result = NULL;
	gchar* _result_ = NULL;
	gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
#line 1207 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1208 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp0_ = g_strdup (self);
#line 1208 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_result_ = _tmp0_;
#line 1209 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp1_ = _result_;
#line 1209 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	g_strstrip (_tmp1_);
#line 1210 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	result = _result_;
#line 1210 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	return result;
#line 9905 "GalleryConnector.c"
}


static void publishing_gallery3_publishing_options_pane_update_publish_button_sensitivity (PublishingGallery3PublishingOptionsPane* self) {
	gchar* album_name = NULL;
	GtkEntry* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gboolean _tmp3_ = FALSE;
	const gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	gboolean _tmp7_ = FALSE;
	GtkButton* _tmp10_ = NULL;
#line 1612 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_PUBLISHING_OPTIONS_PANE (self));
#line 1613 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->new_album_entry;
#line 1613 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = gtk_entry_get_text (_tmp0_);
#line 1613 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = g_strdup (_tmp1_);
#line 1613 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	album_name = _tmp2_;
#line 1614 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp4_ = album_name;
#line 1614 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp5_ = string_strip (_tmp4_);
#line 1614 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp6_ = _tmp5_;
#line 1614 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp7_ = g_strcmp0 (_tmp6_, "") == 0;
#line 1614 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (_tmp6_);
#line 1614 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (_tmp7_) {
#line 9942 "GalleryConnector.c"
		GtkRadioButton* _tmp8_ = NULL;
		gboolean _tmp9_ = FALSE;
#line 1615 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp8_ = self->priv->create_new_radio;
#line 1615 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp9_ = gtk_toggle_button_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, gtk_toggle_button_get_type (), GtkToggleButton));
#line 1615 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp3_ = _tmp9_;
#line 9951 "GalleryConnector.c"
	} else {
#line 1614 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp3_ = FALSE;
#line 9955 "GalleryConnector.c"
	}
#line 1614 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp10_ = self->priv->publish_button;
#line 1614 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, gtk_widget_get_type (), GtkWidget), !_tmp3_);
#line 1612 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (album_name);
#line 9963 "GalleryConnector.c"
}


static void publishing_gallery3_publishing_options_pane_on_new_album_entry_changed (PublishingGallery3PublishingOptionsPane* self) {
#line 1618 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_PUBLISHING_OPTIONS_PANE (self));
#line 1619 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_publishing_options_pane_update_publish_button_sensitivity (self);
#line 9972 "GalleryConnector.c"
}


static void publishing_gallery3_publishing_options_pane_update_pixel_entry_sensitivity (PublishingGallery3PublishingOptionsPane* self) {
	GtkEntry* _tmp0_ = NULL;
	GtkComboBoxText* _tmp1_ = NULL;
	gint _tmp2_ = 0;
#line 1622 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_PUBLISHING_OPTIONS_PANE (self));
#line 1623 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->pixels;
#line 1623 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = self->priv->scaling_combo;
#line 1623 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = gtk_combo_box_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, gtk_combo_box_get_type (), GtkComboBox));
#line 1623 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_widget_get_type (), GtkWidget), _tmp2_ == 1);
#line 9990 "GalleryConnector.c"
}


static void publishing_gallery3_publishing_options_pane_on_scaling_constraint_changed (PublishingGallery3PublishingOptionsPane* self) {
#line 1626 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_PUBLISHING_OPTIONS_PANE (self));
#line 1627 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_publishing_options_pane_update_pixel_entry_sensitivity (self);
#line 9999 "GalleryConnector.c"
}


static glong string_strnlen (gchar* str, glong maxlen) {
	glong result = 0L;
	gchar* end = NULL;
	gchar* _tmp0_ = NULL;
	glong _tmp1_ = 0L;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
#line 1295 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp0_ = str;
#line 1295 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp1_ = maxlen;
#line 1295 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp2_ = memchr (_tmp0_, 0, (gsize) _tmp1_);
#line 1295 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	end = _tmp2_;
#line 1296 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp3_ = end;
#line 1296 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	if (_tmp3_ == NULL) {
#line 10022 "GalleryConnector.c"
		glong _tmp4_ = 0L;
#line 1297 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp4_ = maxlen;
#line 1297 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		result = _tmp4_;
#line 1297 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		return result;
#line 10030 "GalleryConnector.c"
	} else {
		gchar* _tmp5_ = NULL;
		gchar* _tmp6_ = NULL;
#line 1299 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp5_ = end;
#line 1299 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp6_ = str;
#line 1299 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		result = (glong) (_tmp5_ - _tmp6_);
#line 1299 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		return result;
#line 10042 "GalleryConnector.c"
	}
}


static gchar* string_substring (const gchar* self, glong offset, glong len) {
	gchar* result = NULL;
	glong string_length = 0L;
	gboolean _tmp0_ = FALSE;
	glong _tmp1_ = 0L;
	glong _tmp8_ = 0L;
	glong _tmp14_ = 0L;
	glong _tmp17_ = 0L;
	glong _tmp18_ = 0L;
	glong _tmp19_ = 0L;
	glong _tmp20_ = 0L;
	glong _tmp21_ = 0L;
	gchar* _tmp22_ = NULL;
#line 1306 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1308 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp1_ = offset;
#line 1308 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	if (_tmp1_ >= ((glong) 0)) {
#line 10066 "GalleryConnector.c"
		glong _tmp2_ = 0L;
#line 1308 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp2_ = len;
#line 1308 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp0_ = _tmp2_ >= ((glong) 0);
#line 10072 "GalleryConnector.c"
	} else {
#line 1308 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp0_ = FALSE;
#line 10076 "GalleryConnector.c"
	}
#line 1308 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	if (_tmp0_) {
#line 10080 "GalleryConnector.c"
		glong _tmp3_ = 0L;
		glong _tmp4_ = 0L;
		glong _tmp5_ = 0L;
#line 1310 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp3_ = offset;
#line 1310 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp4_ = len;
#line 1310 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp5_ = string_strnlen ((gchar*) self, _tmp3_ + _tmp4_);
#line 1310 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		string_length = _tmp5_;
#line 10092 "GalleryConnector.c"
	} else {
		gint _tmp6_ = 0;
		gint _tmp7_ = 0;
#line 1312 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp6_ = strlen (self);
#line 1312 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp7_ = _tmp6_;
#line 1312 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		string_length = (glong) _tmp7_;
#line 10102 "GalleryConnector.c"
	}
#line 1315 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp8_ = offset;
#line 1315 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	if (_tmp8_ < ((glong) 0)) {
#line 10108 "GalleryConnector.c"
		glong _tmp9_ = 0L;
		glong _tmp10_ = 0L;
		glong _tmp11_ = 0L;
#line 1316 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp9_ = string_length;
#line 1316 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp10_ = offset;
#line 1316 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		offset = _tmp9_ + _tmp10_;
#line 1317 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp11_ = offset;
#line 1317 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		g_return_val_if_fail (_tmp11_ >= ((glong) 0), NULL);
#line 10122 "GalleryConnector.c"
	} else {
		glong _tmp12_ = 0L;
		glong _tmp13_ = 0L;
#line 1319 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp12_ = offset;
#line 1319 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp13_ = string_length;
#line 1319 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		g_return_val_if_fail (_tmp12_ <= _tmp13_, NULL);
#line 10132 "GalleryConnector.c"
	}
#line 1321 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp14_ = len;
#line 1321 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	if (_tmp14_ < ((glong) 0)) {
#line 10138 "GalleryConnector.c"
		glong _tmp15_ = 0L;
		glong _tmp16_ = 0L;
#line 1322 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp15_ = string_length;
#line 1322 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp16_ = offset;
#line 1322 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		len = _tmp15_ - _tmp16_;
#line 10147 "GalleryConnector.c"
	}
#line 1324 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp17_ = offset;
#line 1324 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp18_ = len;
#line 1324 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp19_ = string_length;
#line 1324 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	g_return_val_if_fail ((_tmp17_ + _tmp18_) <= _tmp19_, NULL);
#line 1325 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp20_ = offset;
#line 1325 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp21_ = len;
#line 1325 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp22_ = g_strndup (((gchar*) self) + _tmp20_, (gsize) _tmp21_);
#line 1325 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	result = _tmp22_;
#line 1325 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	return result;
#line 10167 "GalleryConnector.c"
}


static void publishing_gallery3_publishing_options_pane_on_pixels_changed (PublishingGallery3PublishingOptionsPane* self) {
	gchar* orig_text = NULL;
	GtkEntry* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar last_char = '\0';
	const gchar* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	gint _tmp5_ = 0;
	gint _tmp6_ = 0;
	gchar _tmp7_ = '\0';
	const gchar* _tmp8_ = NULL;
	gint _tmp9_ = 0;
	gint _tmp10_ = 0;
#line 1630 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_PUBLISHING_OPTIONS_PANE (self));
#line 1631 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->pixels;
#line 1631 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = gtk_entry_get_text (_tmp0_);
#line 1631 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = g_strdup (_tmp1_);
#line 1631 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	orig_text = _tmp2_;
#line 1632 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp3_ = orig_text;
#line 1632 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp4_ = orig_text;
#line 1632 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp5_ = strlen (_tmp4_);
#line 1632 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp6_ = _tmp5_;
#line 1632 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp7_ = string_get (_tmp3_, (glong) (_tmp6_ - 1));
#line 1632 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	last_char = _tmp7_;
#line 1634 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp8_ = orig_text;
#line 1634 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp9_ = strlen (_tmp8_);
#line 1634 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp10_ = _tmp9_;
#line 1634 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (_tmp10_ > 0) {
#line 10215 "GalleryConnector.c"
		gchar _tmp11_ = '\0';
		gboolean _tmp12_ = FALSE;
#line 1635 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp11_ = last_char;
#line 1635 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp12_ = g_ascii_isdigit (_tmp11_);
#line 1635 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		if (!_tmp12_) {
#line 10224 "GalleryConnector.c"
			GtkEntry* _tmp13_ = NULL;
			const gchar* _tmp14_ = NULL;
			const gchar* _tmp15_ = NULL;
			gint _tmp16_ = 0;
			gint _tmp17_ = 0;
			gchar* _tmp18_ = NULL;
			gchar* _tmp19_ = NULL;
#line 1636 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp13_ = self->priv->pixels;
#line 1636 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp14_ = orig_text;
#line 1636 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp15_ = orig_text;
#line 1636 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp16_ = strlen (_tmp15_);
#line 1636 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp17_ = _tmp16_;
#line 1636 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp18_ = string_substring (_tmp14_, (glong) 0, (glong) (_tmp17_ - 1));
#line 1636 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp19_ = _tmp18_;
#line 1636 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			gtk_entry_set_text (_tmp13_, _tmp19_);
#line 1636 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_g_free0 (_tmp19_);
#line 10250 "GalleryConnector.c"
		}
	}
#line 1630 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (orig_text);
#line 10255 "GalleryConnector.c"
}


void publishing_gallery3_publishing_options_pane_installed (PublishingGallery3PublishingOptionsPane* self) {
	gint default_album_id = 0;
	gchar* last_album = NULL;
	SpitPublishingPluginHost* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	PublishingGallery3Album** _tmp27_ = NULL;
	gint _tmp27__length1 = 0;
#line 1641 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_PUBLISHING_OPTIONS_PANE (self));
#line 1642 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	default_album_id = -1;
#line 1643 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->host;
#line 1643 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = spit_host_interface_get_config_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), PUBLISHING_GALLERY3_PUBLISHING_OPTIONS_PANE_LAST_ALBUM_CONFIG_KEY, "");
#line 1643 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	last_album = _tmp1_;
#line 10276 "GalleryConnector.c"
	{
		gint i = 0;
#line 1645 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		i = 0;
#line 10281 "GalleryConnector.c"
		{
			gboolean _tmp2_ = FALSE;
#line 1645 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp2_ = TRUE;
#line 1645 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			while (TRUE) {
#line 10288 "GalleryConnector.c"
				gint _tmp4_ = 0;
				PublishingGallery3Album** _tmp5_ = NULL;
				gint _tmp5__length1 = 0;
				GtkComboBoxText* _tmp6_ = NULL;
				PublishingGallery3Album** _tmp7_ = NULL;
				gint _tmp7__length1 = 0;
				gint _tmp8_ = 0;
				PublishingGallery3Album* _tmp9_ = NULL;
				const gchar* _tmp10_ = NULL;
				const gchar* _tmp11_ = NULL;
				gboolean _tmp12_ = FALSE;
				PublishingGallery3Album** _tmp13_ = NULL;
				gint _tmp13__length1 = 0;
				gint _tmp14_ = 0;
				PublishingGallery3Album* _tmp15_ = NULL;
				const gchar* _tmp16_ = NULL;
				const gchar* _tmp17_ = NULL;
				const gchar* _tmp18_ = NULL;
#line 1645 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				if (!_tmp2_) {
#line 10309 "GalleryConnector.c"
					gint _tmp3_ = 0;
#line 1645 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					_tmp3_ = i;
#line 1645 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					i = _tmp3_ + 1;
#line 10315 "GalleryConnector.c"
				}
#line 1645 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp2_ = FALSE;
#line 1645 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp4_ = i;
#line 1645 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp5_ = self->priv->albums;
#line 1645 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp5__length1 = self->priv->albums_length1;
#line 1645 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				if (!(_tmp4_ <= (_tmp5__length1 - 1))) {
#line 1645 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					break;
#line 10329 "GalleryConnector.c"
				}
#line 1646 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp6_ = self->priv->existing_albums_combo;
#line 1646 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp7_ = self->priv->albums;
#line 1646 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp7__length1 = self->priv->albums_length1;
#line 1646 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp8_ = i;
#line 1646 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp9_ = _tmp7_[_tmp8_];
#line 1646 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp10_ = publishing_gallery3_album_get_title (_tmp9_);
#line 1646 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp11_ = _tmp10_;
#line 1646 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				gtk_combo_box_text_append_text (_tmp6_, _tmp11_);
#line 1647 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp13_ = self->priv->albums;
#line 1647 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp13__length1 = self->priv->albums_length1;
#line 1647 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp14_ = i;
#line 1647 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp15_ = _tmp13_[_tmp14_];
#line 1647 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp16_ = publishing_gallery3_album_get_title (_tmp15_);
#line 1647 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp17_ = _tmp16_;
#line 1647 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp18_ = last_album;
#line 1647 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				if (g_strcmp0 (_tmp17_, _tmp18_) == 0) {
#line 1647 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					_tmp12_ = TRUE;
#line 10365 "GalleryConnector.c"
				} else {
					gboolean _tmp19_ = FALSE;
					PublishingGallery3Album** _tmp20_ = NULL;
					gint _tmp20__length1 = 0;
					gint _tmp21_ = 0;
					PublishingGallery3Album* _tmp22_ = NULL;
					const gchar* _tmp23_ = NULL;
					const gchar* _tmp24_ = NULL;
#line 1648 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					_tmp20_ = self->priv->albums;
#line 1648 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					_tmp20__length1 = self->priv->albums_length1;
#line 1648 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					_tmp21_ = i;
#line 1648 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					_tmp22_ = _tmp20_[_tmp21_];
#line 1648 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					_tmp23_ = publishing_gallery3_album_get_title (_tmp22_);
#line 1648 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					_tmp24_ = _tmp23_;
#line 1648 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					if (g_strcmp0 (PUBLISHING_GALLERY3_PUBLISHING_OPTIONS_PANE_DEFAULT_ALBUM_NAME, _tmp24_) == 0) {
#line 10388 "GalleryConnector.c"
						gint _tmp25_ = 0;
#line 1649 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
						_tmp25_ = default_album_id;
#line 1649 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
						_tmp19_ = -1 == _tmp25_;
#line 10394 "GalleryConnector.c"
					} else {
#line 1648 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
						_tmp19_ = FALSE;
#line 10398 "GalleryConnector.c"
					}
#line 1648 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					_tmp12_ = _tmp19_;
#line 10402 "GalleryConnector.c"
				}
#line 1647 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				if (_tmp12_) {
#line 10406 "GalleryConnector.c"
					gint _tmp26_ = 0;
#line 1650 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					_tmp26_ = i;
#line 1650 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					default_album_id = _tmp26_;
#line 10412 "GalleryConnector.c"
				}
			}
		}
	}
#line 1653 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp27_ = self->priv->albums;
#line 1653 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp27__length1 = self->priv->albums_length1;
#line 1653 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (_tmp27__length1 == 0) {
#line 10423 "GalleryConnector.c"
		GtkComboBoxText* _tmp28_ = NULL;
		GtkRadioButton* _tmp29_ = NULL;
		GtkRadioButton* _tmp30_ = NULL;
		GtkEntry* _tmp31_ = NULL;
		GtkEntry* _tmp32_ = NULL;
#line 1654 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp28_ = self->priv->existing_albums_combo;
#line 1654 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp28_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 1655 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp29_ = self->priv->use_existing_radio;
#line 1655 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp29_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 1656 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp30_ = self->priv->create_new_radio;
#line 1656 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		gtk_toggle_button_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp30_, gtk_toggle_button_get_type (), GtkToggleButton), TRUE);
#line 1657 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp31_ = self->priv->new_album_entry;
#line 1657 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		gtk_widget_grab_focus (G_TYPE_CHECK_INSTANCE_CAST (_tmp31_, gtk_widget_get_type (), GtkWidget));
#line 1658 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp32_ = self->priv->new_album_entry;
#line 1658 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		gtk_entry_set_text (_tmp32_, PUBLISHING_GALLERY3_PUBLISHING_OPTIONS_PANE_DEFAULT_ALBUM_NAME);
#line 10449 "GalleryConnector.c"
	} else {
		gint _tmp33_ = 0;
#line 1660 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp33_ = default_album_id;
#line 1660 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		if (_tmp33_ >= 0) {
#line 10456 "GalleryConnector.c"
			GtkRadioButton* _tmp34_ = NULL;
			GtkComboBoxText* _tmp35_ = NULL;
			gint _tmp36_ = 0;
			GtkEntry* _tmp37_ = NULL;
#line 1661 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp34_ = self->priv->use_existing_radio;
#line 1661 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			gtk_toggle_button_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp34_, gtk_toggle_button_get_type (), GtkToggleButton), TRUE);
#line 1662 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp35_ = self->priv->existing_albums_combo;
#line 1662 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp36_ = default_album_id;
#line 1662 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			gtk_combo_box_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp35_, gtk_combo_box_get_type (), GtkComboBox), _tmp36_);
#line 1663 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp37_ = self->priv->new_album_entry;
#line 1663 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp37_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 10475 "GalleryConnector.c"
		} else {
			GtkRadioButton* _tmp38_ = NULL;
			GtkComboBoxText* _tmp39_ = NULL;
			GtkEntry* _tmp40_ = NULL;
			GtkEntry* _tmp41_ = NULL;
#line 1665 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp38_ = self->priv->create_new_radio;
#line 1665 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			gtk_toggle_button_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp38_, gtk_toggle_button_get_type (), GtkToggleButton), TRUE);
#line 1666 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp39_ = self->priv->existing_albums_combo;
#line 1666 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			gtk_combo_box_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp39_, gtk_combo_box_get_type (), GtkComboBox), 0);
#line 1667 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp40_ = self->priv->new_album_entry;
#line 1667 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			gtk_entry_set_text (_tmp40_, PUBLISHING_GALLERY3_PUBLISHING_OPTIONS_PANE_DEFAULT_ALBUM_NAME);
#line 1668 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp41_ = self->priv->new_album_entry;
#line 1668 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			gtk_widget_grab_focus (G_TYPE_CHECK_INSTANCE_CAST (_tmp41_, gtk_widget_get_type (), GtkWidget));
#line 10497 "GalleryConnector.c"
		}
	}
#line 1671 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_publishing_options_pane_update_publish_button_sensitivity (self);
#line 1672 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_publishing_options_pane_update_pixel_entry_sensitivity (self);
#line 1641 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (last_album);
#line 10506 "GalleryConnector.c"
}


static GtkWidget* publishing_gallery3_publishing_options_pane_real_get_widget (SpitPublishingDialogPane* base) {
	PublishingGallery3PublishingOptionsPane * self;
	GtkWidget* result = NULL;
	GtkGrid* _tmp0_ = NULL;
	GtkWidget* _tmp1_ = NULL;
#line 1675 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_GALLERY3_TYPE_PUBLISHING_OPTIONS_PANE, PublishingGallery3PublishingOptionsPane);
#line 1676 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->pane_widget;
#line 1676 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_widget_get_type (), GtkWidget));
#line 1676 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp1_;
#line 1676 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 10525 "GalleryConnector.c"
}


static SpitPublishingDialogPaneGeometryOptions publishing_gallery3_publishing_options_pane_real_get_preferred_geometry (SpitPublishingDialogPane* base) {
	PublishingGallery3PublishingOptionsPane * self;
	SpitPublishingDialogPaneGeometryOptions result = 0;
#line 1679 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_GALLERY3_TYPE_PUBLISHING_OPTIONS_PANE, PublishingGallery3PublishingOptionsPane);
#line 1680 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = SPIT_PUBLISHING_DIALOG_PANE_GEOMETRY_OPTIONS_NONE;
#line 1680 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 10538 "GalleryConnector.c"
}


static void publishing_gallery3_publishing_options_pane_real_on_pane_installed (SpitPublishingDialogPane* base) {
	PublishingGallery3PublishingOptionsPane * self;
#line 1683 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_GALLERY3_TYPE_PUBLISHING_OPTIONS_PANE, PublishingGallery3PublishingOptionsPane);
#line 1684 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_publishing_options_pane_installed (self);
#line 10548 "GalleryConnector.c"
}


static void publishing_gallery3_publishing_options_pane_real_on_pane_uninstalled (SpitPublishingDialogPane* base) {
	PublishingGallery3PublishingOptionsPane * self;
#line 1687 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_GALLERY3_TYPE_PUBLISHING_OPTIONS_PANE, PublishingGallery3PublishingOptionsPane);
#line 10556 "GalleryConnector.c"
}


static void g_cclosure_user_marshal_VOID__PUBLISHING_GALLERY3_PUBLISHING_PARAMETERS (GClosure * closure, GValue * return_value, guint n_param_values, const GValue * param_values, gpointer invocation_hint, gpointer marshal_data) {
	typedef void (*GMarshalFunc_VOID__PUBLISHING_GALLERY3_PUBLISHING_PARAMETERS) (gpointer data1, gpointer arg_1, gpointer data2);
	register GMarshalFunc_VOID__PUBLISHING_GALLERY3_PUBLISHING_PARAMETERS callback;
	register GCClosure * cc;
	register gpointer data1;
	register gpointer data2;
	cc = (GCClosure *) closure;
#line 1499 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (n_param_values == 2);
#line 1499 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (G_CCLOSURE_SWAP_DATA (closure)) {
#line 1499 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		data1 = closure->data;
#line 1499 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		data2 = param_values->data[0].v_pointer;
#line 10575 "GalleryConnector.c"
	} else {
#line 1499 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		data1 = param_values->data[0].v_pointer;
#line 1499 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		data2 = closure->data;
#line 10581 "GalleryConnector.c"
	}
#line 1499 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	callback = (GMarshalFunc_VOID__PUBLISHING_GALLERY3_PUBLISHING_PARAMETERS) (marshal_data ? marshal_data : cc->callback);
#line 1499 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	callback (data1, publishing_gallery3_value_get_publishing_parameters (param_values + 1), data2);
#line 10587 "GalleryConnector.c"
}


static void publishing_gallery3_publishing_options_pane_class_init (PublishingGallery3PublishingOptionsPaneClass * klass) {
#line 1499 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_publishing_options_pane_parent_class = g_type_class_peek_parent (klass);
#line 1499 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_type_class_add_private (klass, sizeof (PublishingGallery3PublishingOptionsPanePrivate));
#line 1499 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	G_OBJECT_CLASS (klass)->finalize = publishing_gallery3_publishing_options_pane_finalize;
#line 1499 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_new ("publish", PUBLISHING_GALLERY3_TYPE_PUBLISHING_OPTIONS_PANE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_user_marshal_VOID__PUBLISHING_GALLERY3_PUBLISHING_PARAMETERS, G_TYPE_NONE, 1, PUBLISHING_GALLERY3_TYPE_PUBLISHING_PARAMETERS);
#line 1499 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_new ("logout", PUBLISHING_GALLERY3_TYPE_PUBLISHING_OPTIONS_PANE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
#line 10602 "GalleryConnector.c"
}


static void publishing_gallery3_publishing_options_pane_spit_publishing_dialog_pane_interface_init (SpitPublishingDialogPaneIface * iface) {
#line 1499 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_publishing_options_pane_spit_publishing_dialog_pane_parent_iface = g_type_interface_peek_parent (iface);
#line 1499 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	iface->get_widget = (GtkWidget* (*)(SpitPublishingDialogPane*)) publishing_gallery3_publishing_options_pane_real_get_widget;
#line 1499 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	iface->get_preferred_geometry = (SpitPublishingDialogPaneGeometryOptions (*)(SpitPublishingDialogPane*)) publishing_gallery3_publishing_options_pane_real_get_preferred_geometry;
#line 1499 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	iface->on_pane_installed = (void (*)(SpitPublishingDialogPane*)) publishing_gallery3_publishing_options_pane_real_on_pane_installed;
#line 1499 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	iface->on_pane_uninstalled = (void (*)(SpitPublishingDialogPane*)) publishing_gallery3_publishing_options_pane_real_on_pane_uninstalled;
#line 10617 "GalleryConnector.c"
}


static void publishing_gallery3_publishing_options_pane_instance_init (PublishingGallery3PublishingOptionsPane * self) {
#line 1499 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv = PUBLISHING_GALLERY3_PUBLISHING_OPTIONS_PANE_GET_PRIVATE (self);
#line 1503 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->builder = NULL;
#line 1505 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->pane_widget = NULL;
#line 1506 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->title_label = NULL;
#line 1507 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->use_existing_radio = NULL;
#line 1508 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->existing_albums_combo = NULL;
#line 1509 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->create_new_radio = NULL;
#line 1510 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->new_album_entry = NULL;
#line 1511 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->scaling_combo = NULL;
#line 1512 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->pixels = NULL;
#line 1513 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->strip_metadata_check = NULL;
#line 1514 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->publish_button = NULL;
#line 1515 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->logout_button = NULL;
#line 10648 "GalleryConnector.c"
}


static void publishing_gallery3_publishing_options_pane_finalize (GObject* obj) {
	PublishingGallery3PublishingOptionsPane * self;
#line 1499 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_GALLERY3_TYPE_PUBLISHING_OPTIONS_PANE, PublishingGallery3PublishingOptionsPane);
#line 1503 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->builder);
#line 1505 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->pane_widget);
#line 1506 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->title_label);
#line 1507 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->use_existing_radio);
#line 1508 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->existing_albums_combo);
#line 1509 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->create_new_radio);
#line 1510 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->new_album_entry);
#line 1511 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->scaling_combo);
#line 1512 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->pixels);
#line 1513 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->strip_metadata_check);
#line 1514 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->publish_button);
#line 1515 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->logout_button);
#line 1517 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->albums = (_vala_array_free (self->priv->albums, self->priv->albums_length1, (GDestroyNotify) publishing_gallery3_album_unref), NULL);
#line 1499 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	G_OBJECT_CLASS (publishing_gallery3_publishing_options_pane_parent_class)->finalize (obj);
#line 10684 "GalleryConnector.c"
}


GType publishing_gallery3_publishing_options_pane_get_type (void) {
	static volatile gsize publishing_gallery3_publishing_options_pane_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_gallery3_publishing_options_pane_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingGallery3PublishingOptionsPaneClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_gallery3_publishing_options_pane_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingGallery3PublishingOptionsPane), 0, (GInstanceInitFunc) publishing_gallery3_publishing_options_pane_instance_init, NULL };
		static const GInterfaceInfo spit_publishing_dialog_pane_info = { (GInterfaceInitFunc) publishing_gallery3_publishing_options_pane_spit_publishing_dialog_pane_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType publishing_gallery3_publishing_options_pane_type_id;
		publishing_gallery3_publishing_options_pane_type_id = g_type_register_static (G_TYPE_OBJECT, "PublishingGallery3PublishingOptionsPane", &g_define_type_info, 0);
		g_type_add_interface_static (publishing_gallery3_publishing_options_pane_type_id, SPIT_PUBLISHING_TYPE_DIALOG_PANE, &spit_publishing_dialog_pane_info);
		g_once_init_leave (&publishing_gallery3_publishing_options_pane_type_id__volatile, publishing_gallery3_publishing_options_pane_type_id);
	}
	return publishing_gallery3_publishing_options_pane_type_id__volatile;
}


static PublishingGallery3PublishingParameters* publishing_gallery3_publishing_parameters_construct (GType object_type) {
	PublishingGallery3PublishingParameters* self = NULL;
#line 1710 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = (PublishingGallery3PublishingParameters*) g_type_create_instance (object_type);
#line 1710 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return self;
#line 10708 "GalleryConnector.c"
}


static PublishingGallery3PublishingParameters* publishing_gallery3_publishing_parameters_new (void) {
#line 1710 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return publishing_gallery3_publishing_parameters_construct (PUBLISHING_GALLERY3_TYPE_PUBLISHING_PARAMETERS);
#line 10715 "GalleryConnector.c"
}


static gchar* string_delimit (const gchar* self, const gchar* delimiters, gchar new_delimiter) {
	gchar* result = NULL;
	gchar* _result_ = NULL;
	gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	gchar _tmp3_ = '\0';
#line 1215 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1215 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	g_return_val_if_fail (delimiters != NULL, NULL);
#line 1216 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp0_ = g_strdup (self);
#line 1216 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_result_ = _tmp0_;
#line 1217 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp1_ = _result_;
#line 1217 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp2_ = delimiters;
#line 1217 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp3_ = new_delimiter;
#line 1217 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	g_strdelimit (_tmp1_, _tmp2_, _tmp3_);
#line 1218 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	result = _result_;
#line 1218 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	return result;
#line 10746 "GalleryConnector.c"
}


PublishingGallery3PublishingParameters* publishing_gallery3_publishing_parameters_construct_to_new_album (GType object_type, const gchar* album_title) {
	PublishingGallery3PublishingParameters* self = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
#line 1713 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (album_title != NULL, NULL);
#line 1713 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = (PublishingGallery3PublishingParameters*) g_type_create_instance (object_type);
#line 1714 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = album_title;
#line 1714 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = string_delimit (_tmp0_, " ", '-');
#line 1714 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = _tmp1_;
#line 1714 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_publishing_parameters_set_album_name (self, _tmp2_);
#line 1714 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (_tmp2_);
#line 1716 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp3_ = album_title;
#line 1716 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_publishing_parameters_set_album_title (self, _tmp3_);
#line 1713 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return self;
#line 10776 "GalleryConnector.c"
}


PublishingGallery3PublishingParameters* publishing_gallery3_publishing_parameters_new_to_new_album (const gchar* album_title) {
#line 1713 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return publishing_gallery3_publishing_parameters_construct_to_new_album (PUBLISHING_GALLERY3_TYPE_PUBLISHING_PARAMETERS, album_title);
#line 10783 "GalleryConnector.c"
}


PublishingGallery3PublishingParameters* publishing_gallery3_publishing_parameters_construct_to_existing_album (GType object_type, const gchar* album_path) {
	PublishingGallery3PublishingParameters* self = NULL;
	const gchar* _tmp0_ = NULL;
#line 1719 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (album_path != NULL, NULL);
#line 1719 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = (PublishingGallery3PublishingParameters*) g_type_create_instance (object_type);
#line 1720 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = album_path;
#line 1720 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_publishing_parameters_set_album_path (self, _tmp0_);
#line 1719 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return self;
#line 10800 "GalleryConnector.c"
}


PublishingGallery3PublishingParameters* publishing_gallery3_publishing_parameters_new_to_existing_album (const gchar* album_path) {
#line 1719 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return publishing_gallery3_publishing_parameters_construct_to_existing_album (PUBLISHING_GALLERY3_TYPE_PUBLISHING_PARAMETERS, album_path);
#line 10807 "GalleryConnector.c"
}


gboolean publishing_gallery3_publishing_parameters_is_to_new_album (PublishingGallery3PublishingParameters* self) {
	gboolean result = FALSE;
	const gchar* _tmp0_ = NULL;
#line 1723 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_PUBLISHING_PARAMETERS (self), FALSE);
#line 1724 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->_album_name;
#line 1724 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = g_strcmp0 (_tmp0_, "") != 0;
#line 1724 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 10822 "GalleryConnector.c"
}


const gchar* publishing_gallery3_publishing_parameters_get_album_title (PublishingGallery3PublishingParameters* self) {
	const gchar* result;
	gboolean _tmp0_ = FALSE;
	const gchar* _tmp1_ = NULL;
#line 1698 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_PUBLISHING_PARAMETERS (self), NULL);
#line 1699 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = publishing_gallery3_publishing_parameters_is_to_new_album (self);
#line 1699 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_vala_assert (_tmp0_, "is_to_new_album()");
#line 1700 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = self->priv->_album_title;
#line 1700 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp1_;
#line 1700 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 10842 "GalleryConnector.c"
}


static void publishing_gallery3_publishing_parameters_set_album_title (PublishingGallery3PublishingParameters* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 1702 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_PUBLISHING_PARAMETERS (self));
#line 1702 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = value;
#line 1702 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 1702 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->_album_title);
#line 1702 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_album_title = _tmp1_;
#line 10859 "GalleryConnector.c"
}


const gchar* publishing_gallery3_publishing_parameters_get_album_name (PublishingGallery3PublishingParameters* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
#line 1704 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_PUBLISHING_PARAMETERS (self), NULL);
#line 1704 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->_album_name;
#line 1704 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp0_;
#line 1704 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 10874 "GalleryConnector.c"
}


static void publishing_gallery3_publishing_parameters_set_album_name (PublishingGallery3PublishingParameters* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 1704 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_PUBLISHING_PARAMETERS (self));
#line 1704 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = value;
#line 1704 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 1704 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->_album_name);
#line 1704 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_album_name = _tmp1_;
#line 10891 "GalleryConnector.c"
}


const gchar* publishing_gallery3_publishing_parameters_get_album_path (PublishingGallery3PublishingParameters* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
#line 1705 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_PUBLISHING_PARAMETERS (self), NULL);
#line 1705 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->_album_path;
#line 1705 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp0_;
#line 1705 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 10906 "GalleryConnector.c"
}


void publishing_gallery3_publishing_parameters_set_album_path (PublishingGallery3PublishingParameters* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 1705 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_PUBLISHING_PARAMETERS (self));
#line 1705 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = value;
#line 1705 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 1705 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->_album_path);
#line 1705 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_album_path = _tmp1_;
#line 10923 "GalleryConnector.c"
}


const gchar* publishing_gallery3_publishing_parameters_get_entity_title (PublishingGallery3PublishingParameters* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
#line 1706 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_PUBLISHING_PARAMETERS (self), NULL);
#line 1706 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->_entity_title;
#line 1706 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp0_;
#line 1706 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 10938 "GalleryConnector.c"
}


static void publishing_gallery3_publishing_parameters_set_entity_title (PublishingGallery3PublishingParameters* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 1706 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_PUBLISHING_PARAMETERS (self));
#line 1706 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = value;
#line 1706 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 1706 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->_entity_title);
#line 1706 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_entity_title = _tmp1_;
#line 10955 "GalleryConnector.c"
}


gint publishing_gallery3_publishing_parameters_get_photo_major_axis_size (PublishingGallery3PublishingParameters* self) {
	gint result;
	gint _tmp0_ = 0;
#line 1707 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_PUBLISHING_PARAMETERS (self), 0);
#line 1707 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->_photo_major_axis_size;
#line 1707 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp0_;
#line 1707 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 10970 "GalleryConnector.c"
}


void publishing_gallery3_publishing_parameters_set_photo_major_axis_size (PublishingGallery3PublishingParameters* self, gint value) {
	gint _tmp0_ = 0;
#line 1707 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_PUBLISHING_PARAMETERS (self));
#line 1707 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = value;
#line 1707 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_photo_major_axis_size = _tmp0_;
#line 10982 "GalleryConnector.c"
}


gboolean publishing_gallery3_publishing_parameters_get_strip_metadata (PublishingGallery3PublishingParameters* self) {
	gboolean result;
	gboolean _tmp0_ = FALSE;
#line 1708 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_PUBLISHING_PARAMETERS (self), FALSE);
#line 1708 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->_strip_metadata;
#line 1708 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp0_;
#line 1708 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 10997 "GalleryConnector.c"
}


void publishing_gallery3_publishing_parameters_set_strip_metadata (PublishingGallery3PublishingParameters* self, gboolean value) {
	gboolean _tmp0_ = FALSE;
#line 1708 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_PUBLISHING_PARAMETERS (self));
#line 1708 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = value;
#line 1708 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_strip_metadata = _tmp0_;
#line 11009 "GalleryConnector.c"
}


static void publishing_gallery3_value_publishing_parameters_init (GValue* value) {
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	value->data[0].v_pointer = NULL;
#line 11016 "GalleryConnector.c"
}


static void publishing_gallery3_value_publishing_parameters_free_value (GValue* value) {
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (value->data[0].v_pointer) {
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_gallery3_publishing_parameters_unref (value->data[0].v_pointer);
#line 11025 "GalleryConnector.c"
	}
}


static void publishing_gallery3_value_publishing_parameters_copy_value (const GValue* src_value, GValue* dest_value) {
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (src_value->data[0].v_pointer) {
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		dest_value->data[0].v_pointer = publishing_gallery3_publishing_parameters_ref (src_value->data[0].v_pointer);
#line 11035 "GalleryConnector.c"
	} else {
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		dest_value->data[0].v_pointer = NULL;
#line 11039 "GalleryConnector.c"
	}
}


static gpointer publishing_gallery3_value_publishing_parameters_peek_pointer (const GValue* value) {
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return value->data[0].v_pointer;
#line 11047 "GalleryConnector.c"
}


static gchar* publishing_gallery3_value_publishing_parameters_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (collect_values[0].v_pointer) {
#line 11054 "GalleryConnector.c"
		PublishingGallery3PublishingParameters* object;
		object = collect_values[0].v_pointer;
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		if (object->parent_instance.g_class == NULL) {
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 11061 "GalleryConnector.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 11065 "GalleryConnector.c"
		}
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		value->data[0].v_pointer = publishing_gallery3_publishing_parameters_ref (object);
#line 11069 "GalleryConnector.c"
	} else {
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		value->data[0].v_pointer = NULL;
#line 11073 "GalleryConnector.c"
	}
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return NULL;
#line 11077 "GalleryConnector.c"
}


static gchar* publishing_gallery3_value_publishing_parameters_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	PublishingGallery3PublishingParameters** object_p;
	object_p = collect_values[0].v_pointer;
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (!object_p) {
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 11088 "GalleryConnector.c"
	}
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (!value->data[0].v_pointer) {
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		*object_p = NULL;
#line 11094 "GalleryConnector.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		*object_p = value->data[0].v_pointer;
#line 11098 "GalleryConnector.c"
	} else {
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		*object_p = publishing_gallery3_publishing_parameters_ref (value->data[0].v_pointer);
#line 11102 "GalleryConnector.c"
	}
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return NULL;
#line 11106 "GalleryConnector.c"
}


GParamSpec* publishing_gallery3_param_spec_publishing_parameters (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
	PublishingGallery3ParamSpecPublishingParameters* spec;
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (g_type_is_a (object_type, PUBLISHING_GALLERY3_TYPE_PUBLISHING_PARAMETERS), NULL);
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return G_PARAM_SPEC (spec);
#line 11120 "GalleryConnector.c"
}


gpointer publishing_gallery3_value_get_publishing_parameters (const GValue* value) {
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_GALLERY3_TYPE_PUBLISHING_PARAMETERS), NULL);
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return value->data[0].v_pointer;
#line 11129 "GalleryConnector.c"
}


void publishing_gallery3_value_set_publishing_parameters (GValue* value, gpointer v_object) {
	PublishingGallery3PublishingParameters* old;
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_GALLERY3_TYPE_PUBLISHING_PARAMETERS));
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	old = value->data[0].v_pointer;
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (v_object) {
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PUBLISHING_GALLERY3_TYPE_PUBLISHING_PARAMETERS));
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		value->data[0].v_pointer = v_object;
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_gallery3_publishing_parameters_ref (value->data[0].v_pointer);
#line 11149 "GalleryConnector.c"
	} else {
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		value->data[0].v_pointer = NULL;
#line 11153 "GalleryConnector.c"
	}
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (old) {
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_gallery3_publishing_parameters_unref (old);
#line 11159 "GalleryConnector.c"
	}
}


void publishing_gallery3_value_take_publishing_parameters (GValue* value, gpointer v_object) {
	PublishingGallery3PublishingParameters* old;
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_GALLERY3_TYPE_PUBLISHING_PARAMETERS));
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	old = value->data[0].v_pointer;
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (v_object) {
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PUBLISHING_GALLERY3_TYPE_PUBLISHING_PARAMETERS));
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		value->data[0].v_pointer = v_object;
#line 11178 "GalleryConnector.c"
	} else {
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		value->data[0].v_pointer = NULL;
#line 11182 "GalleryConnector.c"
	}
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (old) {
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_gallery3_publishing_parameters_unref (old);
#line 11188 "GalleryConnector.c"
	}
}


static void publishing_gallery3_publishing_parameters_class_init (PublishingGallery3PublishingParametersClass * klass) {
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_publishing_parameters_parent_class = g_type_class_peek_parent (klass);
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	((PublishingGallery3PublishingParametersClass *) klass)->finalize = publishing_gallery3_publishing_parameters_finalize;
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_type_class_add_private (klass, sizeof (PublishingGallery3PublishingParametersPrivate));
#line 11200 "GalleryConnector.c"
}


static void publishing_gallery3_publishing_parameters_instance_init (PublishingGallery3PublishingParameters * self) {
	gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv = PUBLISHING_GALLERY3_PUBLISHING_PARAMETERS_GET_PRIVATE (self);
#line 1694 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = g_strdup ("");
#line 1694 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_album_title = _tmp0_;
#line 1704 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = g_strdup ("");
#line 1704 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_album_name = _tmp1_;
#line 1705 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = g_strdup ("");
#line 1705 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_album_path = _tmp2_;
#line 1706 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp3_ = g_strdup ("");
#line 1706 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_entity_title = _tmp3_;
#line 1707 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_photo_major_axis_size = -1;
#line 1708 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_strip_metadata = FALSE;
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->ref_count = 1;
#line 11233 "GalleryConnector.c"
}


static void publishing_gallery3_publishing_parameters_finalize (PublishingGallery3PublishingParameters* obj) {
	PublishingGallery3PublishingParameters * self;
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_GALLERY3_TYPE_PUBLISHING_PARAMETERS, PublishingGallery3PublishingParameters);
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_handlers_destroy (self);
#line 1694 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->_album_title);
#line 1704 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->_album_name);
#line 1705 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->_album_path);
#line 1706 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->_entity_title);
#line 11251 "GalleryConnector.c"
}


GType publishing_gallery3_publishing_parameters_get_type (void) {
	static volatile gsize publishing_gallery3_publishing_parameters_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_gallery3_publishing_parameters_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { publishing_gallery3_value_publishing_parameters_init, publishing_gallery3_value_publishing_parameters_free_value, publishing_gallery3_value_publishing_parameters_copy_value, publishing_gallery3_value_publishing_parameters_peek_pointer, "p", publishing_gallery3_value_publishing_parameters_collect_value, "p", publishing_gallery3_value_publishing_parameters_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (PublishingGallery3PublishingParametersClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_gallery3_publishing_parameters_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingGallery3PublishingParameters), 0, (GInstanceInitFunc) publishing_gallery3_publishing_parameters_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType publishing_gallery3_publishing_parameters_type_id;
		publishing_gallery3_publishing_parameters_type_id = g_type_register_fundamental (g_type_fundamental_next (), "PublishingGallery3PublishingParameters", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&publishing_gallery3_publishing_parameters_type_id__volatile, publishing_gallery3_publishing_parameters_type_id);
	}
	return publishing_gallery3_publishing_parameters_type_id__volatile;
}


gpointer publishing_gallery3_publishing_parameters_ref (gpointer instance) {
	PublishingGallery3PublishingParameters* self;
	self = instance;
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_atomic_int_inc (&self->ref_count);
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return instance;
#line 11276 "GalleryConnector.c"
}


void publishing_gallery3_publishing_parameters_unref (gpointer instance) {
	PublishingGallery3PublishingParameters* self;
	self = instance;
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		PUBLISHING_GALLERY3_PUBLISHING_PARAMETERS_GET_CLASS (self)->finalize (self);
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 11289 "GalleryConnector.c"
	}
}


gchar* publishing_gallery3_credentials_pane_mode_to_string (PublishingGallery3CredentialsPaneMode self) {
	gchar* result = NULL;
#line 1735 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	switch (self) {
#line 1735 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		case PUBLISHING_GALLERY3_CREDENTIALS_PANE_MODE_INTRO:
#line 11300 "GalleryConnector.c"
		{
			gchar* _tmp0_ = NULL;
#line 1737 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp0_ = g_strdup ("INTRO");
#line 1737 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			result = _tmp0_;
#line 1737 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			return result;
#line 11309 "GalleryConnector.c"
		}
#line 1735 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		case PUBLISHING_GALLERY3_CREDENTIALS_PANE_MODE_FAILED_RETRY:
#line 11313 "GalleryConnector.c"
		{
			gchar* _tmp1_ = NULL;
#line 1740 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp1_ = g_strdup ("FAILED_RETRY");
#line 1740 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			result = _tmp1_;
#line 1740 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			return result;
#line 11322 "GalleryConnector.c"
		}
#line 1735 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		case PUBLISHING_GALLERY3_CREDENTIALS_PANE_MODE_NOT_GALLERY_URL:
#line 11326 "GalleryConnector.c"
		{
			gchar* _tmp2_ = NULL;
#line 1743 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp2_ = g_strdup ("NOT_GALLERY_URL");
#line 1743 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			result = _tmp2_;
#line 1743 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			return result;
#line 11335 "GalleryConnector.c"
		}
		default:
		{
#line 1746 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_error ("GalleryConnector.vala:1746: unrecognized CredentialsPane.Mode enumerat" \
"ion value");
#line 11341 "GalleryConnector.c"
		}
	}
}


GType publishing_gallery3_credentials_pane_mode_get_type (void) {
	static volatile gsize publishing_gallery3_credentials_pane_mode_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_gallery3_credentials_pane_mode_type_id__volatile)) {
		static const GEnumValue values[] = {{PUBLISHING_GALLERY3_CREDENTIALS_PANE_MODE_INTRO, "PUBLISHING_GALLERY3_CREDENTIALS_PANE_MODE_INTRO", "intro"}, {PUBLISHING_GALLERY3_CREDENTIALS_PANE_MODE_FAILED_RETRY, "PUBLISHING_GALLERY3_CREDENTIALS_PANE_MODE_FAILED_RETRY", "failed-retry"}, {PUBLISHING_GALLERY3_CREDENTIALS_PANE_MODE_NOT_GALLERY_URL, "PUBLISHING_GALLERY3_CREDENTIALS_PANE_MODE_NOT_GALLERY_URL", "not-gallery-url"}, {0, NULL, NULL}};
		GType publishing_gallery3_credentials_pane_mode_type_id;
		publishing_gallery3_credentials_pane_mode_type_id = g_enum_register_static ("PublishingGallery3CredentialsPaneMode", values);
		g_once_init_leave (&publishing_gallery3_credentials_pane_mode_type_id__volatile, publishing_gallery3_credentials_pane_mode_type_id);
	}
	return publishing_gallery3_credentials_pane_mode_type_id__volatile;
}


PublishingGallery3CredentialsPane* publishing_gallery3_credentials_pane_construct (GType object_type, SpitPublishingPluginHost* host, PublishingGallery3CredentialsPaneMode mode, const gchar* url, const gchar* username, const gchar* key) {
	PublishingGallery3CredentialsPane * self = NULL;
	GtkBuilder* builder = NULL;
	GtkBuilder* _tmp0_ = NULL;
	SpitPublishingPluginHost* _tmp10_ = NULL;
	PublishingGallery3CredentialsPaneMode _tmp11_ = 0;
	const gchar* _tmp12_ = NULL;
	const gchar* _tmp13_ = NULL;
	const gchar* _tmp14_ = NULL;
	GtkBuilder* _tmp15_ = NULL;
	PublishingGallery3CredentialsGrid* _tmp16_ = NULL;
	PublishingGallery3CredentialsGrid* _tmp17_ = NULL;
	GtkGrid* _tmp18_ = NULL;
	GtkGrid* _tmp19_ = NULL;
	GtkWidget* _tmp20_ = NULL;
	GError * _inner_error_ = NULL;
#line 1758 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (SPIT_PUBLISHING_IS_PLUGIN_HOST (host), NULL);
#line 1758 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = (PublishingGallery3CredentialsPane*) g_object_new (object_type, NULL);
#line 1763 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = gtk_builder_new ();
#line 1763 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	builder = _tmp0_;
#line 11383 "GalleryConnector.c"
	{
		GtkBuilder* _tmp1_ = NULL;
#line 1766 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp1_ = builder;
#line 1766 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		gtk_builder_add_from_resource (_tmp1_, PLUGIN_RESOURCE_PATH "/gallery3_authentication_pane.ui", &_inner_error_);
#line 1766 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 11392 "GalleryConnector.c"
			goto __catch15_g_error;
		}
	}
	goto __finally15;
	__catch15_g_error:
	{
		GError* e = NULL;
		GError* _tmp2_ = NULL;
		const gchar* _tmp3_ = NULL;
		SpitPublishingPluginHost* _tmp4_ = NULL;
		const gchar* _tmp5_ = NULL;
		gchar* _tmp6_ = NULL;
		gchar* _tmp7_ = NULL;
		GError* _tmp8_ = NULL;
		GError* _tmp9_ = NULL;
#line 1765 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		e = _inner_error_;
#line 1765 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_inner_error_ = NULL;
#line 1770 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp2_ = e;
#line 1770 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp3_ = _tmp2_->message;
#line 1770 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_warning ("GalleryConnector.vala:1770: Could not parse UI file! Error: %s.", _tmp3_);
#line 1771 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp4_ = host;
#line 1771 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp5_ = _ ("A file required for publishing is unavailable. Publishing to %s can't " \
"continue.");
#line 1771 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp6_ = g_strdup_printf (_tmp5_, PUBLISHING_GALLERY3_SERVICE_NAME);
#line 1771 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp7_ = _tmp6_;
#line 1771 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp8_ = g_error_new_literal (SPIT_PUBLISHING_PUBLISHING_ERROR, SPIT_PUBLISHING_PUBLISHING_ERROR_LOCAL_FILE_ERROR, _tmp7_);
#line 1771 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp9_ = _tmp8_;
#line 1771 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		spit_publishing_plugin_host_post_error (_tmp4_, _tmp9_);
#line 1771 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_error_free0 (_tmp9_);
#line 1771 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_free0 (_tmp7_);
#line 1778 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_error_free0 (e);
#line 1778 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_object_unref0 (builder);
#line 1778 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return self;
#line 11442 "GalleryConnector.c"
	}
	__finally15:
#line 1765 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1765 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_object_unref0 (builder);
#line 1765 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1765 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_clear_error (&_inner_error_);
#line 1765 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return NULL;
#line 11455 "GalleryConnector.c"
	}
#line 1781 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp10_ = host;
#line 1781 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp11_ = mode;
#line 1781 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp12_ = url;
#line 1781 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp13_ = username;
#line 1781 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp14_ = key;
#line 1781 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp15_ = builder;
#line 1781 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp16_ = publishing_gallery3_credentials_grid_new (_tmp10_, _tmp11_, _tmp12_, _tmp13_, _tmp14_, _tmp15_);
#line 1781 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->frame);
#line 1781 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->frame = _tmp16_;
#line 1782 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp17_ = self->priv->frame;
#line 1782 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp18_ = publishing_gallery3_credentials_grid_get_pane_widget (_tmp17_);
#line 1782 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp19_ = _tmp18_;
#line 1782 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp20_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp19_, gtk_widget_get_type ()) ? ((GtkWidget*) _tmp19_) : NULL);
#line 1782 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->grid_widget);
#line 1782 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->grid_widget = _tmp20_;
#line 1758 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (builder);
#line 1758 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return self;
#line 11491 "GalleryConnector.c"
}


PublishingGallery3CredentialsPane* publishing_gallery3_credentials_pane_new (SpitPublishingPluginHost* host, PublishingGallery3CredentialsPaneMode mode, const gchar* url, const gchar* username, const gchar* key) {
#line 1758 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return publishing_gallery3_credentials_pane_construct (PUBLISHING_GALLERY3_TYPE_CREDENTIALS_PANE, host, mode, url, username, key);
#line 11498 "GalleryConnector.c"
}


void publishing_gallery3_credentials_pane_notify_go_back (PublishingGallery3CredentialsPane* self) {
#line 1785 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_CREDENTIALS_PANE (self));
#line 1786 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_emit_by_name (self, "go-back");
#line 11507 "GalleryConnector.c"
}


void publishing_gallery3_credentials_pane_notify_login (PublishingGallery3CredentialsPane* self, const gchar* url, const gchar* uname, const gchar* password, const gchar* key) {
	const gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
#line 1789 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_CREDENTIALS_PANE (self));
#line 1789 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (url != NULL);
#line 1789 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (uname != NULL);
#line 1789 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (password != NULL);
#line 1789 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (key != NULL);
#line 1791 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = url;
#line 1791 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = uname;
#line 1791 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = password;
#line 1791 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp3_ = key;
#line 1791 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_emit_by_name (self, "login", _tmp0_, _tmp1_, _tmp2_, _tmp3_);
#line 11536 "GalleryConnector.c"
}


static GtkWidget* publishing_gallery3_credentials_pane_real_get_widget (SpitPublishingDialogPane* base) {
	PublishingGallery3CredentialsPane * self;
	GtkWidget* result = NULL;
	GtkWidget* _tmp0_ = NULL;
	GtkWidget* _tmp1_ = NULL;
	GtkWidget* _tmp2_ = NULL;
#line 1794 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_GALLERY3_TYPE_CREDENTIALS_PANE, PublishingGallery3CredentialsPane);
#line 1795 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->grid_widget;
#line 1795 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_vala_assert (NULL != _tmp0_, "null != grid_widget");
#line 1796 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = self->priv->grid_widget;
#line 1796 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 1796 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp2_;
#line 1796 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 11560 "GalleryConnector.c"
}


static SpitPublishingDialogPaneGeometryOptions publishing_gallery3_credentials_pane_real_get_preferred_geometry (SpitPublishingDialogPane* base) {
	PublishingGallery3CredentialsPane * self;
	SpitPublishingDialogPaneGeometryOptions result = 0;
#line 1799 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_GALLERY3_TYPE_CREDENTIALS_PANE, PublishingGallery3CredentialsPane);
#line 1800 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = SPIT_PUBLISHING_DIALOG_PANE_GEOMETRY_OPTIONS_NONE;
#line 1800 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 11573 "GalleryConnector.c"
}


static void _publishing_gallery3_credentials_pane_notify_go_back_publishing_gallery3_credentials_grid_go_back (PublishingGallery3CredentialsGrid* _sender, gpointer self) {
#line 1804 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_credentials_pane_notify_go_back ((PublishingGallery3CredentialsPane*) self);
#line 11580 "GalleryConnector.c"
}


static void _publishing_gallery3_credentials_pane_notify_login_publishing_gallery3_credentials_grid_login (PublishingGallery3CredentialsGrid* _sender, const gchar* url, const gchar* username, const gchar* password, const gchar* key, gpointer self) {
#line 1805 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_credentials_pane_notify_login ((PublishingGallery3CredentialsPane*) self, url, username, password, key);
#line 11587 "GalleryConnector.c"
}


static void publishing_gallery3_credentials_pane_real_on_pane_installed (SpitPublishingDialogPane* base) {
	PublishingGallery3CredentialsPane * self;
	PublishingGallery3CredentialsGrid* _tmp0_ = NULL;
	PublishingGallery3CredentialsGrid* _tmp1_ = NULL;
	PublishingGallery3CredentialsGrid* _tmp2_ = NULL;
#line 1803 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_GALLERY3_TYPE_CREDENTIALS_PANE, PublishingGallery3CredentialsPane);
#line 1804 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->frame;
#line 1804 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_connect_object (_tmp0_, "go-back", (GCallback) _publishing_gallery3_credentials_pane_notify_go_back_publishing_gallery3_credentials_grid_go_back, self, 0);
#line 1805 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = self->priv->frame;
#line 1805 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_connect_object (_tmp1_, "login", (GCallback) _publishing_gallery3_credentials_pane_notify_login_publishing_gallery3_credentials_grid_login, self, 0);
#line 1807 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = self->priv->frame;
#line 1807 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_credentials_grid_installed (_tmp2_);
#line 11610 "GalleryConnector.c"
}


static void publishing_gallery3_credentials_pane_real_on_pane_uninstalled (SpitPublishingDialogPane* base) {
	PublishingGallery3CredentialsPane * self;
	PublishingGallery3CredentialsGrid* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
	PublishingGallery3CredentialsGrid* _tmp2_ = NULL;
	guint _tmp3_ = 0U;
#line 1810 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_GALLERY3_TYPE_CREDENTIALS_PANE, PublishingGallery3CredentialsPane);
#line 1811 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->frame;
#line 1811 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_parse_name ("go-back", PUBLISHING_GALLERY3_TYPE_CREDENTIALS_GRID, &_tmp1_, NULL, FALSE);
#line 1811 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_gallery3_credentials_pane_notify_go_back_publishing_gallery3_credentials_grid_go_back, self);
#line 1812 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = self->priv->frame;
#line 1812 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_parse_name ("login", PUBLISHING_GALLERY3_TYPE_CREDENTIALS_GRID, &_tmp3_, NULL, FALSE);
#line 1812 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_handlers_disconnect_matched (_tmp2_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _publishing_gallery3_credentials_pane_notify_login_publishing_gallery3_credentials_grid_login, self);
#line 11634 "GalleryConnector.c"
}


static void g_cclosure_user_marshal_VOID__STRING_STRING_STRING_STRING (GClosure * closure, GValue * return_value, guint n_param_values, const GValue * param_values, gpointer invocation_hint, gpointer marshal_data) {
	typedef void (*GMarshalFunc_VOID__STRING_STRING_STRING_STRING) (gpointer data1, const char* arg_1, const char* arg_2, const char* arg_3, const char* arg_4, gpointer data2);
	register GMarshalFunc_VOID__STRING_STRING_STRING_STRING callback;
	register GCClosure * cc;
	register gpointer data1;
	register gpointer data2;
	cc = (GCClosure *) closure;
#line 1728 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (n_param_values == 5);
#line 1728 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (G_CCLOSURE_SWAP_DATA (closure)) {
#line 1728 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		data1 = closure->data;
#line 1728 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		data2 = param_values->data[0].v_pointer;
#line 11653 "GalleryConnector.c"
	} else {
#line 1728 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		data1 = param_values->data[0].v_pointer;
#line 1728 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		data2 = closure->data;
#line 11659 "GalleryConnector.c"
	}
#line 1728 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	callback = (GMarshalFunc_VOID__STRING_STRING_STRING_STRING) (marshal_data ? marshal_data : cc->callback);
#line 1728 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	callback (data1, g_value_get_string (param_values + 1), g_value_get_string (param_values + 2), g_value_get_string (param_values + 3), g_value_get_string (param_values + 4), data2);
#line 11665 "GalleryConnector.c"
}


static void publishing_gallery3_credentials_pane_class_init (PublishingGallery3CredentialsPaneClass * klass) {
#line 1728 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_credentials_pane_parent_class = g_type_class_peek_parent (klass);
#line 1728 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_type_class_add_private (klass, sizeof (PublishingGallery3CredentialsPanePrivate));
#line 1728 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	G_OBJECT_CLASS (klass)->finalize = publishing_gallery3_credentials_pane_finalize;
#line 1728 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_new ("go_back", PUBLISHING_GALLERY3_TYPE_CREDENTIALS_PANE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
#line 1728 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_new ("login", PUBLISHING_GALLERY3_TYPE_CREDENTIALS_PANE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_user_marshal_VOID__STRING_STRING_STRING_STRING, G_TYPE_NONE, 4, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING);
#line 11680 "GalleryConnector.c"
}


static void publishing_gallery3_credentials_pane_spit_publishing_dialog_pane_interface_init (SpitPublishingDialogPaneIface * iface) {
#line 1728 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_credentials_pane_spit_publishing_dialog_pane_parent_iface = g_type_interface_peek_parent (iface);
#line 1728 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	iface->get_widget = (GtkWidget* (*)(SpitPublishingDialogPane*)) publishing_gallery3_credentials_pane_real_get_widget;
#line 1728 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	iface->get_preferred_geometry = (SpitPublishingDialogPaneGeometryOptions (*)(SpitPublishingDialogPane*)) publishing_gallery3_credentials_pane_real_get_preferred_geometry;
#line 1728 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	iface->on_pane_installed = (void (*)(SpitPublishingDialogPane*)) publishing_gallery3_credentials_pane_real_on_pane_installed;
#line 1728 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	iface->on_pane_uninstalled = (void (*)(SpitPublishingDialogPane*)) publishing_gallery3_credentials_pane_real_on_pane_uninstalled;
#line 11695 "GalleryConnector.c"
}


static void publishing_gallery3_credentials_pane_instance_init (PublishingGallery3CredentialsPane * self) {
#line 1728 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv = PUBLISHING_GALLERY3_CREDENTIALS_PANE_GET_PRIVATE (self);
#line 1751 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->frame = NULL;
#line 1752 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->grid_widget = NULL;
#line 11706 "GalleryConnector.c"
}


static void publishing_gallery3_credentials_pane_finalize (GObject* obj) {
	PublishingGallery3CredentialsPane * self;
#line 1728 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_GALLERY3_TYPE_CREDENTIALS_PANE, PublishingGallery3CredentialsPane);
#line 1751 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->frame);
#line 1752 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->grid_widget);
#line 1728 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	G_OBJECT_CLASS (publishing_gallery3_credentials_pane_parent_class)->finalize (obj);
#line 11720 "GalleryConnector.c"
}


GType publishing_gallery3_credentials_pane_get_type (void) {
	static volatile gsize publishing_gallery3_credentials_pane_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_gallery3_credentials_pane_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingGallery3CredentialsPaneClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_gallery3_credentials_pane_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingGallery3CredentialsPane), 0, (GInstanceInitFunc) publishing_gallery3_credentials_pane_instance_init, NULL };
		static const GInterfaceInfo spit_publishing_dialog_pane_info = { (GInterfaceInitFunc) publishing_gallery3_credentials_pane_spit_publishing_dialog_pane_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType publishing_gallery3_credentials_pane_type_id;
		publishing_gallery3_credentials_pane_type_id = g_type_register_static (G_TYPE_OBJECT, "PublishingGallery3CredentialsPane", &g_define_type_info, 0);
		g_type_add_interface_static (publishing_gallery3_credentials_pane_type_id, SPIT_PUBLISHING_TYPE_DIALOG_PANE, &spit_publishing_dialog_pane_info);
		g_once_init_leave (&publishing_gallery3_credentials_pane_type_id__volatile, publishing_gallery3_credentials_pane_type_id);
	}
	return publishing_gallery3_credentials_pane_type_id__volatile;
}


static void _publishing_gallery3_credentials_grid_on_url_or_username_changed_gtk_editable_changed (GtkEditable* _sender, gpointer self) {
#line 1890 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_credentials_grid_on_url_or_username_changed ((PublishingGallery3CredentialsGrid*) self);
#line 11741 "GalleryConnector.c"
}


static void _publishing_gallery3_credentials_grid_on_go_back_button_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 1906 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_credentials_grid_on_go_back_button_clicked ((PublishingGallery3CredentialsGrid*) self);
#line 11748 "GalleryConnector.c"
}


static void _publishing_gallery3_credentials_grid_on_login_button_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 1907 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_credentials_grid_on_login_button_clicked ((PublishingGallery3CredentialsGrid*) self);
#line 11755 "GalleryConnector.c"
}


PublishingGallery3CredentialsGrid* publishing_gallery3_credentials_grid_construct (GType object_type, SpitPublishingPluginHost* host, PublishingGallery3CredentialsPaneMode mode, const gchar* url, const gchar* username, const gchar* key, GtkBuilder* builder) {
	PublishingGallery3CredentialsGrid * self = NULL;
	SpitPublishingPluginHost* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	GtkBuilder* _tmp7_ = NULL;
	GtkBuilder* _tmp8_ = NULL;
	GtkBuilder* _tmp9_ = NULL;
	GtkBuilder* _tmp10_ = NULL;
	GSList* _tmp11_ = NULL;
	GSList* _tmp12_ = NULL;
	guint _tmp13_ = 0U;
	GtkBuilder* _tmp14_ = NULL;
	GObject* _tmp15_ = NULL;
	GtkBuilder* _tmp16_ = NULL;
	GObject* _tmp17_ = NULL;
	GtkLabel* _tmp18_ = NULL;
	GtkBuilder* _tmp19_ = NULL;
	GObject* _tmp20_ = NULL;
	GtkEntry* _tmp21_ = NULL;
	GtkBuilder* _tmp22_ = NULL;
	GObject* _tmp23_ = NULL;
	GtkEntry* _tmp24_ = NULL;
	GtkBuilder* _tmp25_ = NULL;
	GObject* _tmp26_ = NULL;
	GtkEntry* _tmp27_ = NULL;
	GtkBuilder* _tmp28_ = NULL;
	GObject* _tmp29_ = NULL;
	GtkEntry* _tmp30_ = NULL;
	GtkBuilder* _tmp31_ = NULL;
	GObject* _tmp32_ = NULL;
	GtkButton* _tmp33_ = NULL;
	GtkBuilder* _tmp34_ = NULL;
	GObject* _tmp35_ = NULL;
	GtkButton* _tmp36_ = NULL;
	PublishingGallery3CredentialsPaneMode _tmp37_ = 0;
	const gchar* _tmp47_ = NULL;
	GtkEntry* _tmp51_ = NULL;
	const gchar* _tmp52_ = NULL;
	GtkEntry* _tmp56_ = NULL;
	const gchar* _tmp57_ = NULL;
	GtkEntry* _tmp61_ = NULL;
	GtkButton* _tmp62_ = NULL;
	GtkButton* _tmp63_ = NULL;
	gboolean _tmp64_ = FALSE;
	const gchar* _tmp65_ = NULL;
	GtkButton* _tmp67_ = NULL;
#line 1840 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (SPIT_PUBLISHING_IS_PLUGIN_HOST (host), NULL);
#line 1840 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (GTK_IS_BUILDER (builder), NULL);
#line 1840 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = (PublishingGallery3CredentialsGrid*) g_object_new (object_type, NULL);
#line 1845 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = host;
#line 1845 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->host = _tmp0_;
#line 1846 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = url;
#line 1846 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = g_strdup (_tmp1_);
#line 1846 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->url);
#line 1846 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->url = _tmp2_;
#line 1847 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp3_ = key;
#line 1847 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp4_ = g_strdup (_tmp3_);
#line 1847 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->key);
#line 1847 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->key = _tmp4_;
#line 1848 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp5_ = username;
#line 1848 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp6_ = g_strdup (_tmp5_);
#line 1848 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->username);
#line 1848 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->username = _tmp6_;
#line 1850 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp7_ = builder;
#line 1850 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp8_ = _g_object_ref0 (_tmp7_);
#line 1850 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->builder);
#line 1850 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->builder = _tmp8_;
#line 1851 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp9_ = builder;
#line 1851 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_vala_assert (_tmp9_ != NULL, "builder != null");
#line 1852 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp10_ = builder;
#line 1852 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp11_ = gtk_builder_get_objects (_tmp10_);
#line 1852 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp12_ = _tmp11_;
#line 1852 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp13_ = g_slist_length (_tmp12_);
#line 1852 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_vala_assert (_tmp13_ > ((guint) 0), "builder.get_objects().length() > 0");
#line 1852 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_slist_free0 (_tmp12_);
#line 1855 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp14_ = builder;
#line 1855 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp15_ = gtk_builder_get_object (_tmp14_, "gallery3_auth_pane_widget");
#line 1855 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_credentials_grid_set_pane_widget (self, G_TYPE_CHECK_INSTANCE_TYPE (_tmp15_, gtk_grid_get_type ()) ? ((GtkGrid*) _tmp15_) : NULL);
#line 1856 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp16_ = builder;
#line 1856 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp17_ = gtk_builder_get_object (_tmp16_, "intro_message_label");
#line 1856 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp18_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp17_, gtk_label_get_type ()) ? ((GtkLabel*) _tmp17_) : NULL);
#line 1856 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->intro_message_label);
#line 1856 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->intro_message_label = _tmp18_;
#line 1857 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp19_ = builder;
#line 1857 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp20_ = gtk_builder_get_object (_tmp19_, "url_entry");
#line 1857 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp21_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp20_, gtk_entry_get_type ()) ? ((GtkEntry*) _tmp20_) : NULL);
#line 1857 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->url_entry);
#line 1857 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->url_entry = _tmp21_;
#line 1858 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp22_ = builder;
#line 1858 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp23_ = gtk_builder_get_object (_tmp22_, "username_entry");
#line 1858 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp24_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp23_, gtk_entry_get_type ()) ? ((GtkEntry*) _tmp23_) : NULL);
#line 1858 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->username_entry);
#line 1858 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->username_entry = _tmp24_;
#line 1859 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp25_ = builder;
#line 1859 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp26_ = gtk_builder_get_object (_tmp25_, "key_entry");
#line 1859 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp27_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp26_, gtk_entry_get_type ()) ? ((GtkEntry*) _tmp26_) : NULL);
#line 1859 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->key_entry);
#line 1859 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->key_entry = _tmp27_;
#line 1860 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp28_ = builder;
#line 1860 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp29_ = gtk_builder_get_object (_tmp28_, "password_entry");
#line 1860 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp30_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp29_, gtk_entry_get_type ()) ? ((GtkEntry*) _tmp29_) : NULL);
#line 1860 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->password_entry);
#line 1860 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->password_entry = _tmp30_;
#line 1861 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp31_ = builder;
#line 1861 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp32_ = gtk_builder_get_object (_tmp31_, "go_back_button");
#line 1861 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp33_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp32_, gtk_button_get_type ()) ? ((GtkButton*) _tmp32_) : NULL);
#line 1861 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->go_back_button);
#line 1861 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->go_back_button = _tmp33_;
#line 1862 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp34_ = builder;
#line 1862 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp35_ = gtk_builder_get_object (_tmp34_, "login_button");
#line 1862 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp36_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp35_, gtk_button_get_type ()) ? ((GtkButton*) _tmp35_) : NULL);
#line 1862 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->login_button);
#line 1862 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->login_button = _tmp36_;
#line 1865 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp37_ = mode;
#line 1865 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	switch (_tmp37_) {
#line 1865 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		case PUBLISHING_GALLERY3_CREDENTIALS_PANE_MODE_INTRO:
#line 11950 "GalleryConnector.c"
		{
			GtkLabel* _tmp38_ = NULL;
#line 1867 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp38_ = self->priv->intro_message_label;
#line 1867 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			gtk_label_set_markup (_tmp38_, PUBLISHING_GALLERY3_CREDENTIALS_GRID_INTRO_MESSAGE);
#line 1868 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			break;
#line 11959 "GalleryConnector.c"
		}
#line 1865 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		case PUBLISHING_GALLERY3_CREDENTIALS_PANE_MODE_FAILED_RETRY:
#line 11963 "GalleryConnector.c"
		{
			GtkLabel* _tmp39_ = NULL;
			const gchar* _tmp40_ = NULL;
			gchar* _tmp41_ = NULL;
			gchar* _tmp42_ = NULL;
#line 1871 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp39_ = self->priv->intro_message_label;
#line 1871 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp40_ = _ ("Unrecognized User");
#line 1871 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp41_ = g_strdup_printf ("<b>%s</b>\n\n%s", _tmp40_, PUBLISHING_GALLERY3_CREDENTIALS_GRID_FAILED_RETRY_MESSAGE);
#line 1871 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp42_ = _tmp41_;
#line 1871 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			gtk_label_set_markup (_tmp39_, _tmp42_);
#line 1871 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_g_free0 (_tmp42_);
#line 1873 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			break;
#line 11983 "GalleryConnector.c"
		}
#line 1865 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		case PUBLISHING_GALLERY3_CREDENTIALS_PANE_MODE_NOT_GALLERY_URL:
#line 11987 "GalleryConnector.c"
		{
			GtkLabel* _tmp43_ = NULL;
			const gchar* _tmp44_ = NULL;
			gchar* _tmp45_ = NULL;
			gchar* _tmp46_ = NULL;
#line 1876 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp43_ = self->priv->intro_message_label;
#line 1876 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp44_ = _ (PUBLISHING_GALLERY3_SERVICE_NAME " Site Not Found");
#line 1876 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp45_ = g_strdup_printf ("<b>%s</b>\n\n%s", _tmp44_, PUBLISHING_GALLERY3_CREDENTIALS_GRID_NOT_GALLERY_URL_MESSAGE);
#line 1876 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp46_ = _tmp45_;
#line 1876 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			gtk_label_set_markup (_tmp43_, _tmp46_);
#line 1876 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_g_free0 (_tmp46_);
#line 1879 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			break;
#line 12007 "GalleryConnector.c"
		}
		default:
		{
#line 1882 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_error ("GalleryConnector.vala:1882: Invalid CredentialsPane mode");
#line 12013 "GalleryConnector.c"
		}
	}
#line 1886 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp47_ = url;
#line 1886 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (_tmp47_ != NULL) {
#line 12020 "GalleryConnector.c"
		GtkEntry* _tmp48_ = NULL;
		const gchar* _tmp49_ = NULL;
		GtkEntry* _tmp50_ = NULL;
#line 1887 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp48_ = self->priv->url_entry;
#line 1887 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp49_ = url;
#line 1887 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		gtk_entry_set_text (_tmp48_, _tmp49_);
#line 1888 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp50_ = self->priv->username_entry;
#line 1888 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		gtk_widget_grab_focus (G_TYPE_CHECK_INSTANCE_CAST (_tmp50_, gtk_widget_get_type (), GtkWidget));
#line 12034 "GalleryConnector.c"
	}
#line 1890 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp51_ = self->priv->url_entry;
#line 1890 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp51_, GTK_TYPE_EDITABLE, GtkEditable), "changed", (GCallback) _publishing_gallery3_credentials_grid_on_url_or_username_changed_gtk_editable_changed, self, 0);
#line 1892 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp52_ = username;
#line 1892 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (_tmp52_ != NULL) {
#line 12044 "GalleryConnector.c"
		GtkEntry* _tmp53_ = NULL;
		const gchar* _tmp54_ = NULL;
		GtkEntry* _tmp55_ = NULL;
#line 1893 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp53_ = self->priv->username_entry;
#line 1893 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp54_ = username;
#line 1893 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		gtk_entry_set_text (_tmp53_, _tmp54_);
#line 1894 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp55_ = self->priv->password_entry;
#line 1894 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		gtk_widget_grab_focus (G_TYPE_CHECK_INSTANCE_CAST (_tmp55_, gtk_widget_get_type (), GtkWidget));
#line 12058 "GalleryConnector.c"
	}
#line 1896 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp56_ = self->priv->username_entry;
#line 1896 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp56_, GTK_TYPE_EDITABLE, GtkEditable), "changed", (GCallback) _publishing_gallery3_credentials_grid_on_url_or_username_changed_gtk_editable_changed, self, 0);
#line 1899 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp57_ = key;
#line 1899 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (_tmp57_ != NULL) {
#line 12068 "GalleryConnector.c"
		GtkEntry* _tmp58_ = NULL;
		const gchar* _tmp59_ = NULL;
		GtkEntry* _tmp60_ = NULL;
#line 1900 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp58_ = self->priv->key_entry;
#line 1900 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp59_ = key;
#line 1900 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		gtk_entry_set_text (_tmp58_, _tmp59_);
#line 1901 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp60_ = self->priv->key_entry;
#line 1901 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		gtk_widget_grab_focus (G_TYPE_CHECK_INSTANCE_CAST (_tmp60_, gtk_widget_get_type (), GtkWidget));
#line 12082 "GalleryConnector.c"
	}
#line 1903 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp61_ = self->priv->key_entry;
#line 1903 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp61_, GTK_TYPE_EDITABLE, GtkEditable), "changed", (GCallback) _publishing_gallery3_credentials_grid_on_url_or_username_changed_gtk_editable_changed, self, 0);
#line 1906 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp62_ = self->priv->go_back_button;
#line 1906 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_connect_object (_tmp62_, "clicked", (GCallback) _publishing_gallery3_credentials_grid_on_go_back_button_clicked_gtk_button_clicked, self, 0);
#line 1907 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp63_ = self->priv->login_button;
#line 1907 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_connect_object (_tmp63_, "clicked", (GCallback) _publishing_gallery3_credentials_grid_on_login_button_clicked_gtk_button_clicked, self, 0);
#line 1908 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp65_ = url;
#line 1908 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (_tmp65_ != NULL) {
#line 12100 "GalleryConnector.c"
		const gchar* _tmp66_ = NULL;
#line 1908 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp66_ = username;
#line 1908 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp64_ = _tmp66_ != NULL;
#line 12106 "GalleryConnector.c"
	} else {
#line 1908 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp64_ = FALSE;
#line 12110 "GalleryConnector.c"
	}
#line 1908 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp67_ = self->priv->login_button;
#line 1908 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp67_, gtk_widget_get_type (), GtkWidget), _tmp64_);
#line 1840 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return self;
#line 12118 "GalleryConnector.c"
}


PublishingGallery3CredentialsGrid* publishing_gallery3_credentials_grid_new (SpitPublishingPluginHost* host, PublishingGallery3CredentialsPaneMode mode, const gchar* url, const gchar* username, const gchar* key, GtkBuilder* builder) {
#line 1840 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return publishing_gallery3_credentials_grid_construct (PUBLISHING_GALLERY3_TYPE_CREDENTIALS_GRID, host, mode, url, username, key, builder);
#line 12125 "GalleryConnector.c"
}


static void publishing_gallery3_credentials_grid_on_login_button_clicked (PublishingGallery3CredentialsGrid* self) {
	GtkEntry* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	GtkEntry* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	GtkEntry* _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
	GtkEntry* _tmp6_ = NULL;
	const gchar* _tmp7_ = NULL;
#line 1911 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_CREDENTIALS_GRID (self));
#line 1912 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->url_entry;
#line 1912 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = gtk_entry_get_text (_tmp0_);
#line 1912 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = self->priv->username_entry;
#line 1912 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp3_ = gtk_entry_get_text (_tmp2_);
#line 1912 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp4_ = self->priv->password_entry;
#line 1912 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp5_ = gtk_entry_get_text (_tmp4_);
#line 1912 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp6_ = self->priv->key_entry;
#line 1912 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp7_ = gtk_entry_get_text (_tmp6_);
#line 1912 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_emit_by_name (self, "login", _tmp1_, _tmp3_, _tmp5_, _tmp7_);
#line 12158 "GalleryConnector.c"
}


static void publishing_gallery3_credentials_grid_on_go_back_button_clicked (PublishingGallery3CredentialsGrid* self) {
#line 1916 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_CREDENTIALS_GRID (self));
#line 1917 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_emit_by_name (self, "go-back");
#line 12167 "GalleryConnector.c"
}


static void publishing_gallery3_credentials_grid_on_url_or_username_changed (PublishingGallery3CredentialsGrid* self) {
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	GtkEntry* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	GtkButton* _tmp8_ = NULL;
#line 1920 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_CREDENTIALS_GRID (self));
#line 1922 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = self->priv->url_entry;
#line 1922 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp3_ = gtk_entry_get_text (_tmp2_);
#line 1922 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (g_strcmp0 (_tmp3_, "") != 0) {
#line 12185 "GalleryConnector.c"
		GtkEntry* _tmp4_ = NULL;
		const gchar* _tmp5_ = NULL;
#line 1923 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp4_ = self->priv->username_entry;
#line 1923 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp5_ = gtk_entry_get_text (_tmp4_);
#line 1923 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp1_ = g_strcmp0 (_tmp5_, "") != 0;
#line 12194 "GalleryConnector.c"
	} else {
#line 1922 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp1_ = FALSE;
#line 12198 "GalleryConnector.c"
	}
#line 1922 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (_tmp1_) {
#line 1922 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp0_ = TRUE;
#line 12204 "GalleryConnector.c"
	} else {
		GtkEntry* _tmp6_ = NULL;
		const gchar* _tmp7_ = NULL;
#line 1924 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp6_ = self->priv->key_entry;
#line 1924 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp7_ = gtk_entry_get_text (_tmp6_);
#line 1924 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp0_ = g_strcmp0 (_tmp7_, "") != 0;
#line 12214 "GalleryConnector.c"
	}
#line 1921 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp8_ = self->priv->login_button;
#line 1921 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, gtk_widget_get_type (), GtkWidget), _tmp0_);
#line 12220 "GalleryConnector.c"
}


void publishing_gallery3_credentials_grid_installed (PublishingGallery3CredentialsGrid* self) {
	SpitPublishingPluginHost* _tmp0_ = NULL;
	SpitPublishingPluginHost* _tmp1_ = NULL;
	GtkButton* _tmp2_ = NULL;
#line 1927 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_CREDENTIALS_GRID (self));
#line 1928 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->host;
#line 1928 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	spit_publishing_plugin_host_set_service_locked (_tmp0_, FALSE);
#line 1931 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = self->priv->host;
#line 1931 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = self->priv->login_button;
#line 1931 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	spit_publishing_plugin_host_set_dialog_default_widget (_tmp1_, G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, gtk_widget_get_type (), GtkWidget));
#line 12240 "GalleryConnector.c"
}


GtkGrid* publishing_gallery3_credentials_grid_get_pane_widget (PublishingGallery3CredentialsGrid* self) {
	GtkGrid* result;
	GtkGrid* _tmp0_ = NULL;
#line 1821 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_CREDENTIALS_GRID (self), NULL);
#line 1821 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->_pane_widget;
#line 1821 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp0_;
#line 1821 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 12255 "GalleryConnector.c"
}


static void publishing_gallery3_credentials_grid_set_pane_widget (PublishingGallery3CredentialsGrid* self, GtkGrid* value) {
	GtkGrid* _tmp0_ = NULL;
	GtkGrid* _tmp1_ = NULL;
#line 1821 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_CREDENTIALS_GRID (self));
#line 1821 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = value;
#line 1821 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 1821 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->_pane_widget);
#line 1821 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_pane_widget = _tmp1_;
#line 1821 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_object_notify ((GObject *) self, "pane-widget");
#line 12274 "GalleryConnector.c"
}


static void publishing_gallery3_credentials_grid_class_init (PublishingGallery3CredentialsGridClass * klass) {
#line 1816 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_credentials_grid_parent_class = g_type_class_peek_parent (klass);
#line 1816 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_type_class_add_private (klass, sizeof (PublishingGallery3CredentialsGridPrivate));
#line 1816 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_publishing_gallery3_credentials_grid_get_property;
#line 1816 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_publishing_gallery3_credentials_grid_set_property;
#line 1816 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	G_OBJECT_CLASS (klass)->finalize = publishing_gallery3_credentials_grid_finalize;
#line 1816 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), PUBLISHING_GALLERY3_CREDENTIALS_GRID_PANE_WIDGET, g_param_spec_object ("pane-widget", "pane-widget", "pane-widget", gtk_grid_get_type (), G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 1816 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_new ("go_back", PUBLISHING_GALLERY3_TYPE_CREDENTIALS_GRID, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
#line 1816 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_new ("login", PUBLISHING_GALLERY3_TYPE_CREDENTIALS_GRID, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_user_marshal_VOID__STRING_STRING_STRING_STRING, G_TYPE_NONE, 4, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING);
#line 12295 "GalleryConnector.c"
}


static void publishing_gallery3_credentials_grid_instance_init (PublishingGallery3CredentialsGrid * self) {
#line 1816 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv = PUBLISHING_GALLERY3_CREDENTIALS_GRID_GET_PRIVATE (self);
#line 1821 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_pane_widget = NULL;
#line 1823 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->host = NULL;
#line 1824 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->builder = NULL;
#line 1825 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->intro_message_label = NULL;
#line 1826 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->url_entry = NULL;
#line 1827 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->username_entry = NULL;
#line 1828 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->password_entry = NULL;
#line 1829 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->key_entry = NULL;
#line 1830 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->login_button = NULL;
#line 1831 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->go_back_button = NULL;
#line 1832 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->url = NULL;
#line 1833 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->username = NULL;
#line 1834 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->key = NULL;
#line 12328 "GalleryConnector.c"
}


static void publishing_gallery3_credentials_grid_finalize (GObject* obj) {
	PublishingGallery3CredentialsGrid * self;
#line 1816 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_GALLERY3_TYPE_CREDENTIALS_GRID, PublishingGallery3CredentialsGrid);
#line 1821 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->_pane_widget);
#line 1824 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->builder);
#line 1825 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->intro_message_label);
#line 1826 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->url_entry);
#line 1827 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->username_entry);
#line 1828 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->password_entry);
#line 1829 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->key_entry);
#line 1830 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->login_button);
#line 1831 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->go_back_button);
#line 1832 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->url);
#line 1833 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->username);
#line 1834 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->key);
#line 1816 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	G_OBJECT_CLASS (publishing_gallery3_credentials_grid_parent_class)->finalize (obj);
#line 12362 "GalleryConnector.c"
}


GType publishing_gallery3_credentials_grid_get_type (void) {
	static volatile gsize publishing_gallery3_credentials_grid_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_gallery3_credentials_grid_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingGallery3CredentialsGridClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_gallery3_credentials_grid_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingGallery3CredentialsGrid), 0, (GInstanceInitFunc) publishing_gallery3_credentials_grid_instance_init, NULL };
		GType publishing_gallery3_credentials_grid_type_id;
		publishing_gallery3_credentials_grid_type_id = g_type_register_static (G_TYPE_OBJECT, "PublishingGallery3CredentialsGrid", &g_define_type_info, 0);
		g_once_init_leave (&publishing_gallery3_credentials_grid_type_id__volatile, publishing_gallery3_credentials_grid_type_id);
	}
	return publishing_gallery3_credentials_grid_type_id__volatile;
}


static void _vala_publishing_gallery3_credentials_grid_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	PublishingGallery3CredentialsGrid * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, PUBLISHING_GALLERY3_TYPE_CREDENTIALS_GRID, PublishingGallery3CredentialsGrid);
#line 1816 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	switch (property_id) {
#line 1816 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		case PUBLISHING_GALLERY3_CREDENTIALS_GRID_PANE_WIDGET:
#line 1816 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_value_set_object (value, publishing_gallery3_credentials_grid_get_pane_widget (self));
#line 1816 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		break;
#line 12389 "GalleryConnector.c"
		default:
#line 1816 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 1816 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		break;
#line 12395 "GalleryConnector.c"
	}
}


static void _vala_publishing_gallery3_credentials_grid_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	PublishingGallery3CredentialsGrid * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, PUBLISHING_GALLERY3_TYPE_CREDENTIALS_GRID, PublishingGallery3CredentialsGrid);
#line 1816 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	switch (property_id) {
#line 1816 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		case PUBLISHING_GALLERY3_CREDENTIALS_GRID_PANE_WIDGET:
#line 1816 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_gallery3_credentials_grid_set_pane_widget (self, g_value_get_object (value));
#line 1816 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		break;
#line 12411 "GalleryConnector.c"
		default:
#line 1816 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 1816 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		break;
#line 12417 "GalleryConnector.c"
	}
}


PublishingGallery3Session* publishing_gallery3_session_construct (GType object_type) {
	PublishingGallery3Session* self = NULL;
#line 1942 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = (PublishingGallery3Session*) publishing_rest_support_session_construct (object_type, NULL);
#line 1942 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return self;
#line 12428 "GalleryConnector.c"
}


PublishingGallery3Session* publishing_gallery3_session_new (void) {
#line 1942 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return publishing_gallery3_session_construct (PUBLISHING_GALLERY3_TYPE_SESSION);
#line 12435 "GalleryConnector.c"
}


static gboolean publishing_gallery3_session_real_is_authenticated (PublishingRESTSupportSession* base) {
	PublishingGallery3Session * self;
	gboolean result = FALSE;
	const gchar* _tmp0_ = NULL;
#line 1945 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_GALLERY3_TYPE_SESSION, PublishingGallery3Session);
#line 1946 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->_key;
#line 1946 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = NULL != _tmp0_;
#line 1946 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 12451 "GalleryConnector.c"
}


void publishing_gallery3_session_authenticate (PublishingGallery3Session* self, const gchar* gallery_url, const gchar* username, const gchar* key) {
	const gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
#line 1949 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_SESSION (self));
#line 1949 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (gallery_url != NULL);
#line 1949 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (username != NULL);
#line 1949 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (key != NULL);
#line 1950 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = gallery_url;
#line 1950 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_session_set_url (self, _tmp0_);
#line 1951 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = username;
#line 1951 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_session_set_username (self, _tmp1_);
#line 1952 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = key;
#line 1952 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_session_set_key (self, _tmp2_);
#line 1954 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_rest_support_session_notify_authenticated (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession));
#line 12481 "GalleryConnector.c"
}


void publishing_gallery3_session_deauthenticate (PublishingGallery3Session* self) {
#line 1957 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_SESSION (self));
#line 1958 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_session_set_url (self, NULL);
#line 1959 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_session_set_username (self, NULL);
#line 1960 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_session_set_key (self, NULL);
#line 12494 "GalleryConnector.c"
}


const gchar* publishing_gallery3_session_get_url (PublishingGallery3Session* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
#line 1938 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_SESSION (self), NULL);
#line 1938 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->_url;
#line 1938 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp0_;
#line 1938 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 12509 "GalleryConnector.c"
}


static void publishing_gallery3_session_set_url (PublishingGallery3Session* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 1938 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_SESSION (self));
#line 1938 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = value;
#line 1938 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 1938 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->_url);
#line 1938 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_url = _tmp1_;
#line 12526 "GalleryConnector.c"
}


const gchar* publishing_gallery3_session_get_username (PublishingGallery3Session* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
#line 1939 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_SESSION (self), NULL);
#line 1939 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->_username;
#line 1939 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp0_;
#line 1939 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 12541 "GalleryConnector.c"
}


static void publishing_gallery3_session_set_username (PublishingGallery3Session* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 1939 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_SESSION (self));
#line 1939 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = value;
#line 1939 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 1939 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->_username);
#line 1939 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_username = _tmp1_;
#line 12558 "GalleryConnector.c"
}


const gchar* publishing_gallery3_session_get_key (PublishingGallery3Session* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
#line 1940 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_SESSION (self), NULL);
#line 1940 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->_key;
#line 1940 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp0_;
#line 1940 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 12573 "GalleryConnector.c"
}


static void publishing_gallery3_session_set_key (PublishingGallery3Session* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 1940 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_SESSION (self));
#line 1940 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = value;
#line 1940 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 1940 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->_key);
#line 1940 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_key = _tmp1_;
#line 12590 "GalleryConnector.c"
}


static void publishing_gallery3_session_class_init (PublishingGallery3SessionClass * klass) {
#line 1935 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_session_parent_class = g_type_class_peek_parent (klass);
#line 1935 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	((PublishingRESTSupportSessionClass *) klass)->finalize = publishing_gallery3_session_finalize;
#line 1935 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_type_class_add_private (klass, sizeof (PublishingGallery3SessionPrivate));
#line 1935 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	((PublishingRESTSupportSessionClass *) klass)->is_authenticated = publishing_gallery3_session_real_is_authenticated;
#line 12603 "GalleryConnector.c"
}


static void publishing_gallery3_session_instance_init (PublishingGallery3Session * self) {
#line 1935 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv = PUBLISHING_GALLERY3_SESSION_GET_PRIVATE (self);
#line 1938 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_url = NULL;
#line 1939 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_username = NULL;
#line 1940 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_key = NULL;
#line 12616 "GalleryConnector.c"
}


static void publishing_gallery3_session_finalize (PublishingRESTSupportSession* obj) {
	PublishingGallery3Session * self;
#line 1935 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_GALLERY3_TYPE_SESSION, PublishingGallery3Session);
#line 1938 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->_url);
#line 1939 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->_username);
#line 1940 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->_key);
#line 1935 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	PUBLISHING_REST_SUPPORT_SESSION_CLASS (publishing_gallery3_session_parent_class)->finalize (obj);
#line 12632 "GalleryConnector.c"
}


GType publishing_gallery3_session_get_type (void) {
	static volatile gsize publishing_gallery3_session_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_gallery3_session_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingGallery3SessionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_gallery3_session_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingGallery3Session), 0, (GInstanceInitFunc) publishing_gallery3_session_instance_init, NULL };
		GType publishing_gallery3_session_type_id;
		publishing_gallery3_session_type_id = g_type_register_static (PUBLISHING_REST_SUPPORT_TYPE_SESSION, "PublishingGallery3Session", &g_define_type_info, 0);
		g_once_init_leave (&publishing_gallery3_session_type_id__volatile, publishing_gallery3_session_type_id);
	}
	return publishing_gallery3_session_type_id__volatile;
}


PublishingGallery3Uploader* publishing_gallery3_uploader_construct (GType object_type, PublishingGallery3Session* session, SpitPublishingPublishable** publishables, int publishables_length1, PublishingGallery3PublishingParameters* parameters) {
	PublishingGallery3Uploader* self = NULL;
	PublishingGallery3Session* _tmp0_ = NULL;
	SpitPublishingPublishable** _tmp1_ = NULL;
	gint _tmp1__length1 = 0;
	PublishingGallery3PublishingParameters* _tmp2_ = NULL;
	PublishingGallery3PublishingParameters* _tmp3_ = NULL;
#line 1990 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_SESSION (session), NULL);
#line 1990 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_PUBLISHING_PARAMETERS (parameters), NULL);
#line 1994 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = session;
#line 1994 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = publishables;
#line 1994 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1__length1 = publishables_length1;
#line 1994 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = (PublishingGallery3Uploader*) publishing_rest_support_batch_uploader_construct (object_type, G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession), _tmp1_, _tmp1__length1);
#line 1996 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = parameters;
#line 1996 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp3_ = _publishing_gallery3_publishing_parameters_ref0 (_tmp2_);
#line 1996 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_publishing_gallery3_publishing_parameters_unref0 (self->priv->parameters);
#line 1996 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->parameters = _tmp3_;
#line 1990 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return self;
#line 12677 "GalleryConnector.c"
}


PublishingGallery3Uploader* publishing_gallery3_uploader_new (PublishingGallery3Session* session, SpitPublishingPublishable** publishables, int publishables_length1, PublishingGallery3PublishingParameters* parameters) {
#line 1990 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return publishing_gallery3_uploader_construct (PUBLISHING_GALLERY3_TYPE_UPLOADER, session, publishables, publishables_length1, parameters);
#line 12684 "GalleryConnector.c"
}


static gpointer _publishing_rest_support_transaction_ref0 (gpointer self) {
#line 2011 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return self ? publishing_rest_support_transaction_ref (self) : NULL;
#line 12691 "GalleryConnector.c"
}


static PublishingRESTSupportTransaction* publishing_gallery3_uploader_real_create_transaction (PublishingRESTSupportBatchUploader* base, SpitPublishingPublishable* publishable) {
	PublishingGallery3Uploader * self;
	PublishingRESTSupportTransaction* result = NULL;
	SpitPublishingPublishable* p = NULL;
	SpitPublishingPublishable* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	SpitPublishingPublisherMediaType _tmp2_ = 0;
	PublishingRESTSupportSession* _tmp3_ = NULL;
	PublishingGallery3Session* _tmp4_ = NULL;
	PublishingGallery3PublishingParameters* _tmp5_ = NULL;
	PublishingGallery3GalleryUploadTransaction* _tmp6_ = NULL;
	PublishingRESTSupportTransaction* _tmp7_ = NULL;
	PublishingRESTSupportTransaction* _tmp8_ = NULL;
#line 2000 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_GALLERY3_TYPE_UPLOADER, PublishingGallery3Uploader);
#line 2000 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (SPIT_PUBLISHING_IS_PUBLISHABLE (publishable), NULL);
#line 2003 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = publishing_rest_support_batch_uploader_get_current_publishable (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, PublishingRESTSupportBatchUploader));
#line 2003 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	p = _tmp0_;
#line 2004 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = spit_publishing_publishable_get_param_string (p, SPIT_PUBLISHING_PUBLISHABLE_PARAM_STRING_BASENAME);
#line 2004 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->_current_publishable_name);
#line 2004 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_current_publishable_name = _tmp1_;
#line 2006 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = spit_publishing_publishable_get_media_type (p);
#line 2006 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_current_media_type = _tmp2_;
#line 2008 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp3_ = publishing_rest_support_batch_uploader_get_session (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, PublishingRESTSupportBatchUploader));
#line 2008 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp4_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, PUBLISHING_GALLERY3_TYPE_SESSION, PublishingGallery3Session);
#line 2008 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp5_ = self->priv->parameters;
#line 2008 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp6_ = publishing_gallery3_gallery_upload_transaction_new (_tmp4_, _tmp5_, p);
#line 2008 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_publishing_rest_support_transaction_unref0 (self->priv->_current_transaction);
#line 2008 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_current_transaction = G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction);
#line 2008 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_publishing_rest_support_session_unref0 (_tmp4_);
#line 2011 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp7_ = self->priv->_current_transaction;
#line 2011 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp8_ = _publishing_rest_support_transaction_ref0 (_tmp7_);
#line 2011 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp8_;
#line 2011 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (p);
#line 2011 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 12750 "GalleryConnector.c"
}


const gchar* publishing_gallery3_uploader_get_current_publishable_name (PublishingGallery3Uploader* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
#line 1974 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_UPLOADER (self), NULL);
#line 1975 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->_current_publishable_name;
#line 1975 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp0_;
#line 1975 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 12765 "GalleryConnector.c"
}


guint publishing_gallery3_uploader_get_status_code (PublishingGallery3Uploader* self) {
	guint result;
	PublishingRESTSupportTransaction* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
#line 1979 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_UPLOADER (self), 0U);
#line 1980 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->_current_transaction;
#line 1980 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = publishing_rest_support_transaction_get_status_code (_tmp0_);
#line 1980 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp1_;
#line 1980 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 12783 "GalleryConnector.c"
}


SpitPublishingPublisherMediaType publishing_gallery3_uploader_get_current_publishable_type (PublishingGallery3Uploader* self) {
	SpitPublishingPublisherMediaType result;
	SpitPublishingPublisherMediaType _tmp0_ = 0;
#line 1985 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_UPLOADER (self), 0);
#line 1986 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->_current_media_type;
#line 1986 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp0_;
#line 1986 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 12798 "GalleryConnector.c"
}


static void publishing_gallery3_uploader_class_init (PublishingGallery3UploaderClass * klass) {
#line 1965 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_uploader_parent_class = g_type_class_peek_parent (klass);
#line 1965 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	((PublishingRESTSupportBatchUploaderClass *) klass)->finalize = publishing_gallery3_uploader_finalize;
#line 1965 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_type_class_add_private (klass, sizeof (PublishingGallery3UploaderPrivate));
#line 1965 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	((PublishingRESTSupportBatchUploaderClass *) klass)->create_transaction = publishing_gallery3_uploader_real_create_transaction;
#line 12811 "GalleryConnector.c"
}


static void publishing_gallery3_uploader_instance_init (PublishingGallery3Uploader * self) {
#line 1965 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv = PUBLISHING_GALLERY3_UPLOADER_GET_PRIVATE (self);
#line 12818 "GalleryConnector.c"
}


static void publishing_gallery3_uploader_finalize (PublishingRESTSupportBatchUploader* obj) {
	PublishingGallery3Uploader * self;
#line 1965 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_GALLERY3_TYPE_UPLOADER, PublishingGallery3Uploader);
#line 1967 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_publishing_gallery3_publishing_parameters_unref0 (self->priv->parameters);
#line 1968 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->_current_publishable_name);
#line 1970 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_publishing_rest_support_transaction_unref0 (self->priv->_current_transaction);
#line 1965 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	PUBLISHING_REST_SUPPORT_BATCH_UPLOADER_CLASS (publishing_gallery3_uploader_parent_class)->finalize (obj);
#line 12834 "GalleryConnector.c"
}


GType publishing_gallery3_uploader_get_type (void) {
	static volatile gsize publishing_gallery3_uploader_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_gallery3_uploader_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingGallery3UploaderClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_gallery3_uploader_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingGallery3Uploader), 0, (GInstanceInitFunc) publishing_gallery3_uploader_instance_init, NULL };
		GType publishing_gallery3_uploader_type_id;
		publishing_gallery3_uploader_type_id = g_type_register_static (PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, "PublishingGallery3Uploader", &g_define_type_info, 0);
		g_once_init_leave (&publishing_gallery3_uploader_type_id__volatile, publishing_gallery3_uploader_type_id);
	}
	return publishing_gallery3_uploader_type_id__volatile;
}


static gint string_last_index_of (const gchar* self, const gchar* needle, gint start_index) {
	gint result = 0;
	gchar* _result_ = NULL;
	gint _tmp0_ = 0;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
#line 997 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, 0);
#line 997 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	g_return_val_if_fail (needle != NULL, 0);
#line 998 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp0_ = start_index;
#line 998 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp1_ = needle;
#line 998 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp2_ = g_strrstr (((gchar*) self) + _tmp0_, (gchar*) _tmp1_);
#line 998 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_result_ = _tmp2_;
#line 1000 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp3_ = _result_;
#line 1000 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	if (_tmp3_ != NULL) {
#line 12873 "GalleryConnector.c"
		gchar* _tmp4_ = NULL;
#line 1001 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp4_ = _result_;
#line 1001 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		result = (gint) (_tmp4_ - ((gchar*) self));
#line 1001 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		return result;
#line 12881 "GalleryConnector.c"
	} else {
#line 1003 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		result = -1;
#line 1003 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		return result;
#line 12887 "GalleryConnector.c"
	}
}


gchar* publishing_gallery3_strip_session_url (const gchar* url) {
	gchar* result = NULL;
	const gchar* _tmp0_ = NULL;
	gint item_loc = 0;
	const gchar* _tmp1_ = NULL;
	gint _tmp2_ = 0;
	const gchar* _tmp4_ = NULL;
	gint _tmp5_ = 0;
	gint _tmp6_ = 0;
	gchar* _tmp7_ = NULL;
#line 2017 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (url != NULL, NULL);
#line 2020 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = url;
#line 2020 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_debug ("GalleryConnector.vala:2020: Searching for \"%s\" in \"%s\"", PUBLISHING_GALLERY3_REST_PATH, _tmp0_);
#line 2022 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = url;
#line 2022 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = string_last_index_of (_tmp1_, PUBLISHING_GALLERY3_REST_PATH, 0);
#line 2022 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	item_loc = _tmp2_;
#line 2025 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (-1 == item_loc) {
#line 12916 "GalleryConnector.c"
		const gchar* _tmp3_ = NULL;
#line 2026 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp3_ = url;
#line 2026 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_error ("Did not find \"%s\" in the base of the new item " "URL \"%s\"", PUBLISHING_GALLERY3_REST_PATH, _tmp3_);
#line 12922 "GalleryConnector.c"
	}
#line 2029 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp4_ = url;
#line 2029 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp5_ = strlen (PUBLISHING_GALLERY3_REST_PATH);
#line 2029 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp6_ = _tmp5_;
#line 2029 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp7_ = string_substring (_tmp4_, (glong) (item_loc + _tmp6_), (glong) -1);
#line 2029 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp7_;
#line 2029 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 12936 "GalleryConnector.c"
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}



