/* LibraryWindow.c generated by valac 0.32.1, the Vala compiler
 * generated from LibraryWindow.vala, do not modify */

/* Copyright 2016 Software Freedom Conservancy Inc.
 *
 * This software is licensed under the GNU Lesser General Public License
 * (version 2.1 or later).  See the COPYING file in this distribution.
 */

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <stdlib.h>
#include <string.h>
#include <gee.h>
#include <gdk/gdk.h>
#include <gio/gio.h>
#include <glib/gi18n-lib.h>
#include <gphoto2/gphoto2-camera.h>
#include <gphoto.h>
#include <float.h>
#include <math.h>
#include <cairo.h>
#include <gdk-pixbuf/gdk-pixbuf.h>


#define TYPE_PAGE_WINDOW (page_window_get_type ())
#define PAGE_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PAGE_WINDOW, PageWindow))
#define PAGE_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PAGE_WINDOW, PageWindowClass))
#define IS_PAGE_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PAGE_WINDOW))
#define IS_PAGE_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PAGE_WINDOW))
#define PAGE_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PAGE_WINDOW, PageWindowClass))

typedef struct _PageWindow PageWindow;
typedef struct _PageWindowClass PageWindowClass;
typedef struct _PageWindowPrivate PageWindowPrivate;

#define TYPE_PAGE (page_get_type ())
#define PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PAGE, Page))
#define PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PAGE, PageClass))
#define IS_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PAGE))
#define IS_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PAGE))
#define PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PAGE, PageClass))

typedef struct _Page Page;
typedef struct _PageClass PageClass;

#define TYPE_APP_WINDOW (app_window_get_type ())
#define APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_APP_WINDOW, AppWindow))
#define APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_APP_WINDOW, AppWindowClass))
#define IS_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_APP_WINDOW))
#define IS_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_APP_WINDOW))
#define APP_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_APP_WINDOW, AppWindowClass))

typedef struct _AppWindow AppWindow;
typedef struct _AppWindowClass AppWindowClass;
typedef struct _AppWindowPrivate AppWindowPrivate;

#define TYPE_DIMENSIONS (dimensions_get_type ())
typedef struct _Dimensions Dimensions;

#define TYPE_LIBRARY_WINDOW (library_window_get_type ())
#define LIBRARY_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_LIBRARY_WINDOW, LibraryWindow))
#define LIBRARY_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_LIBRARY_WINDOW, LibraryWindowClass))
#define IS_LIBRARY_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_LIBRARY_WINDOW))
#define IS_LIBRARY_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_LIBRARY_WINDOW))
#define LIBRARY_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_LIBRARY_WINDOW, LibraryWindowClass))

typedef struct _LibraryWindow LibraryWindow;
typedef struct _LibraryWindowClass LibraryWindowClass;
typedef struct _LibraryWindowPrivate LibraryWindowPrivate;

#define TYPE_ONE_SHOT_SCHEDULER (one_shot_scheduler_get_type ())
#define ONE_SHOT_SCHEDULER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_ONE_SHOT_SCHEDULER, OneShotScheduler))
#define ONE_SHOT_SCHEDULER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_ONE_SHOT_SCHEDULER, OneShotSchedulerClass))
#define IS_ONE_SHOT_SCHEDULER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_ONE_SHOT_SCHEDULER))
#define IS_ONE_SHOT_SCHEDULER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_ONE_SHOT_SCHEDULER))
#define ONE_SHOT_SCHEDULER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_ONE_SHOT_SCHEDULER, OneShotSchedulerClass))

typedef struct _OneShotScheduler OneShotScheduler;
typedef struct _OneShotSchedulerClass OneShotSchedulerClass;

#define SIDEBAR_TYPE_TREE (sidebar_tree_get_type ())
#define SIDEBAR_TREE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_TREE, SidebarTree))
#define SIDEBAR_TREE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SIDEBAR_TYPE_TREE, SidebarTreeClass))
#define SIDEBAR_IS_TREE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_TREE))
#define SIDEBAR_IS_TREE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SIDEBAR_TYPE_TREE))
#define SIDEBAR_TREE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SIDEBAR_TYPE_TREE, SidebarTreeClass))

typedef struct _SidebarTree SidebarTree;
typedef struct _SidebarTreeClass SidebarTreeClass;

#define SIDEBAR_TYPE_BRANCH (sidebar_branch_get_type ())
#define SIDEBAR_BRANCH(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_BRANCH, SidebarBranch))
#define SIDEBAR_BRANCH_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SIDEBAR_TYPE_BRANCH, SidebarBranchClass))
#define SIDEBAR_IS_BRANCH(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_BRANCH))
#define SIDEBAR_IS_BRANCH_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SIDEBAR_TYPE_BRANCH))
#define SIDEBAR_BRANCH_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SIDEBAR_TYPE_BRANCH, SidebarBranchClass))

typedef struct _SidebarBranch SidebarBranch;
typedef struct _SidebarBranchClass SidebarBranchClass;

#define LIBRARY_TYPE_BRANCH (library_branch_get_type ())
#define LIBRARY_BRANCH(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), LIBRARY_TYPE_BRANCH, LibraryBranch))
#define LIBRARY_BRANCH_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), LIBRARY_TYPE_BRANCH, LibraryBranchClass))
#define LIBRARY_IS_BRANCH(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), LIBRARY_TYPE_BRANCH))
#define LIBRARY_IS_BRANCH_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), LIBRARY_TYPE_BRANCH))
#define LIBRARY_BRANCH_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), LIBRARY_TYPE_BRANCH, LibraryBranchClass))

typedef struct _LibraryBranch LibraryBranch;
typedef struct _LibraryBranchClass LibraryBranchClass;

#define TAGS_TYPE_BRANCH (tags_branch_get_type ())
#define TAGS_BRANCH(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TAGS_TYPE_BRANCH, TagsBranch))
#define TAGS_BRANCH_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TAGS_TYPE_BRANCH, TagsBranchClass))
#define TAGS_IS_BRANCH(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TAGS_TYPE_BRANCH))
#define TAGS_IS_BRANCH_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TAGS_TYPE_BRANCH))
#define TAGS_BRANCH_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TAGS_TYPE_BRANCH, TagsBranchClass))

typedef struct _TagsBranch TagsBranch;
typedef struct _TagsBranchClass TagsBranchClass;

#define FOLDERS_TYPE_BRANCH (folders_branch_get_type ())
#define FOLDERS_BRANCH(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), FOLDERS_TYPE_BRANCH, FoldersBranch))
#define FOLDERS_BRANCH_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), FOLDERS_TYPE_BRANCH, FoldersBranchClass))
#define FOLDERS_IS_BRANCH(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), FOLDERS_TYPE_BRANCH))
#define FOLDERS_IS_BRANCH_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), FOLDERS_TYPE_BRANCH))
#define FOLDERS_BRANCH_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), FOLDERS_TYPE_BRANCH, FoldersBranchClass))

typedef struct _FoldersBranch FoldersBranch;
typedef struct _FoldersBranchClass FoldersBranchClass;

#define EVENTS_TYPE_BRANCH (events_branch_get_type ())
#define EVENTS_BRANCH(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), EVENTS_TYPE_BRANCH, EventsBranch))
#define EVENTS_BRANCH_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), EVENTS_TYPE_BRANCH, EventsBranchClass))
#define EVENTS_IS_BRANCH(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), EVENTS_TYPE_BRANCH))
#define EVENTS_IS_BRANCH_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), EVENTS_TYPE_BRANCH))
#define EVENTS_BRANCH_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), EVENTS_TYPE_BRANCH, EventsBranchClass))

typedef struct _EventsBranch EventsBranch;
typedef struct _EventsBranchClass EventsBranchClass;

#define CAMERA_TYPE_BRANCH (camera_branch_get_type ())
#define CAMERA_BRANCH(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CAMERA_TYPE_BRANCH, CameraBranch))
#define CAMERA_BRANCH_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), CAMERA_TYPE_BRANCH, CameraBranchClass))
#define CAMERA_IS_BRANCH(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CAMERA_TYPE_BRANCH))
#define CAMERA_IS_BRANCH_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CAMERA_TYPE_BRANCH))
#define CAMERA_BRANCH_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), CAMERA_TYPE_BRANCH, CameraBranchClass))

typedef struct _CameraBranch CameraBranch;
typedef struct _CameraBranchClass CameraBranchClass;

#define SEARCHES_TYPE_BRANCH (searches_branch_get_type ())
#define SEARCHES_BRANCH(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SEARCHES_TYPE_BRANCH, SearchesBranch))
#define SEARCHES_BRANCH_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SEARCHES_TYPE_BRANCH, SearchesBranchClass))
#define SEARCHES_IS_BRANCH(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SEARCHES_TYPE_BRANCH))
#define SEARCHES_IS_BRANCH_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SEARCHES_TYPE_BRANCH))
#define SEARCHES_BRANCH_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SEARCHES_TYPE_BRANCH, SearchesBranchClass))

typedef struct _SearchesBranch SearchesBranch;
typedef struct _SearchesBranchClass SearchesBranchClass;

#define SIDEBAR_TYPE_ENTRY (sidebar_entry_get_type ())
#define SIDEBAR_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_ENTRY, SidebarEntry))
#define SIDEBAR_IS_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_ENTRY))
#define SIDEBAR_ENTRY_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), SIDEBAR_TYPE_ENTRY, SidebarEntryIface))

typedef struct _SidebarEntry SidebarEntry;
typedef struct _SidebarEntryIface SidebarEntryIface;

#define TYPE_SINGLE_PHOTO_PAGE (single_photo_page_get_type ())
#define SINGLE_PHOTO_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SINGLE_PHOTO_PAGE, SinglePhotoPage))
#define SINGLE_PHOTO_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SINGLE_PHOTO_PAGE, SinglePhotoPageClass))
#define IS_SINGLE_PHOTO_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SINGLE_PHOTO_PAGE))
#define IS_SINGLE_PHOTO_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SINGLE_PHOTO_PAGE))
#define SINGLE_PHOTO_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SINGLE_PHOTO_PAGE, SinglePhotoPageClass))

typedef struct _SinglePhotoPage SinglePhotoPage;
typedef struct _SinglePhotoPageClass SinglePhotoPageClass;

#define TYPE_EDITING_HOST_PAGE (editing_host_page_get_type ())
#define EDITING_HOST_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_EDITING_HOST_PAGE, EditingHostPage))
#define EDITING_HOST_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_EDITING_HOST_PAGE, EditingHostPageClass))
#define IS_EDITING_HOST_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_EDITING_HOST_PAGE))
#define IS_EDITING_HOST_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_EDITING_HOST_PAGE))
#define EDITING_HOST_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_EDITING_HOST_PAGE, EditingHostPageClass))

typedef struct _EditingHostPage EditingHostPage;
typedef struct _EditingHostPageClass EditingHostPageClass;

#define TYPE_LIBRARY_PHOTO_PAGE (library_photo_page_get_type ())
#define LIBRARY_PHOTO_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_LIBRARY_PHOTO_PAGE, LibraryPhotoPage))
#define LIBRARY_PHOTO_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_LIBRARY_PHOTO_PAGE, LibraryPhotoPageClass))
#define IS_LIBRARY_PHOTO_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_LIBRARY_PHOTO_PAGE))
#define IS_LIBRARY_PHOTO_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_LIBRARY_PHOTO_PAGE))
#define LIBRARY_PHOTO_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_LIBRARY_PHOTO_PAGE, LibraryPhotoPageClass))

typedef struct _LibraryPhotoPage LibraryPhotoPage;
typedef struct _LibraryPhotoPageClass LibraryPhotoPageClass;

#define TYPE_SEARCH_FILTER_ACTIONS (search_filter_actions_get_type ())
#define SEARCH_FILTER_ACTIONS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SEARCH_FILTER_ACTIONS, SearchFilterActions))
#define SEARCH_FILTER_ACTIONS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SEARCH_FILTER_ACTIONS, SearchFilterActionsClass))
#define IS_SEARCH_FILTER_ACTIONS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SEARCH_FILTER_ACTIONS))
#define IS_SEARCH_FILTER_ACTIONS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SEARCH_FILTER_ACTIONS))
#define SEARCH_FILTER_ACTIONS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SEARCH_FILTER_ACTIONS, SearchFilterActionsClass))

typedef struct _SearchFilterActions SearchFilterActions;
typedef struct _SearchFilterActionsClass SearchFilterActionsClass;

#define TYPE_SEARCH_FILTER_TOOLBAR (search_filter_toolbar_get_type ())
#define SEARCH_FILTER_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SEARCH_FILTER_TOOLBAR, SearchFilterToolbar))
#define SEARCH_FILTER_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SEARCH_FILTER_TOOLBAR, SearchFilterToolbarClass))
#define IS_SEARCH_FILTER_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SEARCH_FILTER_TOOLBAR))
#define IS_SEARCH_FILTER_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SEARCH_FILTER_TOOLBAR))
#define SEARCH_FILTER_TOOLBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SEARCH_FILTER_TOOLBAR, SearchFilterToolbarClass))

typedef struct _SearchFilterToolbar SearchFilterToolbar;
typedef struct _SearchFilterToolbarClass SearchFilterToolbarClass;

#define TYPE_PROPERTIES (properties_get_type ())
#define PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PROPERTIES, Properties))
#define PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PROPERTIES, PropertiesClass))
#define IS_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PROPERTIES))
#define IS_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PROPERTIES))
#define PROPERTIES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PROPERTIES, PropertiesClass))

typedef struct _Properties Properties;
typedef struct _PropertiesClass PropertiesClass;

#define TYPE_BASIC_PROPERTIES (basic_properties_get_type ())
#define BASIC_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_BASIC_PROPERTIES, BasicProperties))
#define BASIC_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_BASIC_PROPERTIES, BasicPropertiesClass))
#define IS_BASIC_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_BASIC_PROPERTIES))
#define IS_BASIC_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_BASIC_PROPERTIES))
#define BASIC_PROPERTIES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_BASIC_PROPERTIES, BasicPropertiesClass))

typedef struct _BasicProperties BasicProperties;
typedef struct _BasicPropertiesClass BasicPropertiesClass;

#define TYPE_EXTENDED_PROPERTIES_WINDOW (extended_properties_window_get_type ())
#define EXTENDED_PROPERTIES_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_EXTENDED_PROPERTIES_WINDOW, ExtendedPropertiesWindow))
#define EXTENDED_PROPERTIES_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_EXTENDED_PROPERTIES_WINDOW, ExtendedPropertiesWindowClass))
#define IS_EXTENDED_PROPERTIES_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_EXTENDED_PROPERTIES_WINDOW))
#define IS_EXTENDED_PROPERTIES_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_EXTENDED_PROPERTIES_WINDOW))
#define EXTENDED_PROPERTIES_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_EXTENDED_PROPERTIES_WINDOW, ExtendedPropertiesWindowClass))

typedef struct _ExtendedPropertiesWindow ExtendedPropertiesWindow;
typedef struct _ExtendedPropertiesWindowClass ExtendedPropertiesWindowClass;

#define SIDEBAR_TYPE_SELECTABLE_ENTRY (sidebar_selectable_entry_get_type ())
#define SIDEBAR_SELECTABLE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_SELECTABLE_ENTRY, SidebarSelectableEntry))
#define SIDEBAR_IS_SELECTABLE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_SELECTABLE_ENTRY))
#define SIDEBAR_SELECTABLE_ENTRY_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), SIDEBAR_TYPE_SELECTABLE_ENTRY, SidebarSelectableEntryIface))

typedef struct _SidebarSelectableEntry SidebarSelectableEntry;
typedef struct _SidebarSelectableEntryIface SidebarSelectableEntryIface;

#define SIDEBAR_TYPE_PAGE_REPRESENTATIVE (sidebar_page_representative_get_type ())
#define SIDEBAR_PAGE_REPRESENTATIVE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_PAGE_REPRESENTATIVE, SidebarPageRepresentative))
#define SIDEBAR_IS_PAGE_REPRESENTATIVE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_PAGE_REPRESENTATIVE))
#define SIDEBAR_PAGE_REPRESENTATIVE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), SIDEBAR_TYPE_PAGE_REPRESENTATIVE, SidebarPageRepresentativeIface))

typedef struct _SidebarPageRepresentative SidebarPageRepresentative;
typedef struct _SidebarPageRepresentativeIface SidebarPageRepresentativeIface;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define TYPE_DATA_COLLECTION (data_collection_get_type ())
#define DATA_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATA_COLLECTION, DataCollection))
#define DATA_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATA_COLLECTION, DataCollectionClass))
#define IS_DATA_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATA_COLLECTION))
#define IS_DATA_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATA_COLLECTION))
#define DATA_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATA_COLLECTION, DataCollectionClass))

typedef struct _DataCollection DataCollection;
typedef struct _DataCollectionClass DataCollectionClass;

#define TYPE_SOURCE_COLLECTION (source_collection_get_type ())
#define SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SOURCE_COLLECTION, SourceCollection))
#define SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SOURCE_COLLECTION, SourceCollectionClass))
#define IS_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SOURCE_COLLECTION))
#define IS_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SOURCE_COLLECTION))
#define SOURCE_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SOURCE_COLLECTION, SourceCollectionClass))

typedef struct _SourceCollection SourceCollection;
typedef struct _SourceCollectionClass SourceCollectionClass;

#define TYPE_DATABASE_SOURCE_COLLECTION (database_source_collection_get_type ())
#define DATABASE_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATABASE_SOURCE_COLLECTION, DatabaseSourceCollection))
#define DATABASE_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATABASE_SOURCE_COLLECTION, DatabaseSourceCollectionClass))
#define IS_DATABASE_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATABASE_SOURCE_COLLECTION))
#define IS_DATABASE_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATABASE_SOURCE_COLLECTION))
#define DATABASE_SOURCE_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATABASE_SOURCE_COLLECTION, DatabaseSourceCollectionClass))

typedef struct _DatabaseSourceCollection DatabaseSourceCollection;
typedef struct _DatabaseSourceCollectionClass DatabaseSourceCollectionClass;

#define TYPE_MEDIA_SOURCE_COLLECTION (media_source_collection_get_type ())
#define MEDIA_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollection))
#define MEDIA_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollectionClass))
#define IS_MEDIA_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MEDIA_SOURCE_COLLECTION))
#define IS_MEDIA_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MEDIA_SOURCE_COLLECTION))
#define MEDIA_SOURCE_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollectionClass))

typedef struct _MediaSourceCollection MediaSourceCollection;
typedef struct _MediaSourceCollectionClass MediaSourceCollectionClass;

#define TYPE_MEDIA_COLLECTION_REGISTRY (media_collection_registry_get_type ())
#define MEDIA_COLLECTION_REGISTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MEDIA_COLLECTION_REGISTRY, MediaCollectionRegistry))
#define MEDIA_COLLECTION_REGISTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MEDIA_COLLECTION_REGISTRY, MediaCollectionRegistryClass))
#define IS_MEDIA_COLLECTION_REGISTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MEDIA_COLLECTION_REGISTRY))
#define IS_MEDIA_COLLECTION_REGISTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MEDIA_COLLECTION_REGISTRY))
#define MEDIA_COLLECTION_REGISTRY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MEDIA_COLLECTION_REGISTRY, MediaCollectionRegistryClass))

typedef struct _MediaCollectionRegistry MediaCollectionRegistry;
typedef struct _MediaCollectionRegistryClass MediaCollectionRegistryClass;
#define _media_collection_registry_unref0(var) ((var == NULL) ? NULL : (var = (media_collection_registry_unref (var), NULL)))

#define TYPE_DATA_OBJECT (data_object_get_type ())
#define DATA_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATA_OBJECT, DataObject))
#define DATA_OBJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATA_OBJECT, DataObjectClass))
#define IS_DATA_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATA_OBJECT))
#define IS_DATA_OBJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATA_OBJECT))
#define DATA_OBJECT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATA_OBJECT, DataObjectClass))

typedef struct _DataObject DataObject;
typedef struct _DataObjectClass DataObjectClass;

#define TYPE_DATA_SOURCE (data_source_get_type ())
#define DATA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATA_SOURCE, DataSource))
#define DATA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATA_SOURCE, DataSourceClass))
#define IS_DATA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATA_SOURCE))
#define IS_DATA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATA_SOURCE))
#define DATA_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATA_SOURCE, DataSourceClass))

typedef struct _DataSource DataSource;
typedef struct _DataSourceClass DataSourceClass;

#define TYPE_THUMBNAIL_SOURCE (thumbnail_source_get_type ())
#define THUMBNAIL_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_THUMBNAIL_SOURCE, ThumbnailSource))
#define THUMBNAIL_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_THUMBNAIL_SOURCE, ThumbnailSourceClass))
#define IS_THUMBNAIL_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_THUMBNAIL_SOURCE))
#define IS_THUMBNAIL_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_THUMBNAIL_SOURCE))
#define THUMBNAIL_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_THUMBNAIL_SOURCE, ThumbnailSourceClass))

typedef struct _ThumbnailSource ThumbnailSource;
typedef struct _ThumbnailSourceClass ThumbnailSourceClass;

#define TYPE_MEDIA_SOURCE (media_source_get_type ())
#define MEDIA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MEDIA_SOURCE, MediaSource))
#define MEDIA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MEDIA_SOURCE, MediaSourceClass))
#define IS_MEDIA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MEDIA_SOURCE))
#define IS_MEDIA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MEDIA_SOURCE))
#define MEDIA_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MEDIA_SOURCE, MediaSourceClass))

typedef struct _MediaSource MediaSource;
typedef struct _MediaSourceClass MediaSourceClass;

#define TYPE_ALTERATION (alteration_get_type ())
#define ALTERATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_ALTERATION, Alteration))
#define ALTERATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_ALTERATION, AlterationClass))
#define IS_ALTERATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_ALTERATION))
#define IS_ALTERATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_ALTERATION))
#define ALTERATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_ALTERATION, AlterationClass))

typedef struct _Alteration Alteration;
typedef struct _AlterationClass AlterationClass;
#define _data_collection_unref0(var) ((var == NULL) ? NULL : (var = (data_collection_unref (var), NULL)))

#define TYPE_METADATA_WRITER (metadata_writer_get_type ())
#define METADATA_WRITER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_METADATA_WRITER, MetadataWriter))
#define METADATA_WRITER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_METADATA_WRITER, MetadataWriterClass))
#define IS_METADATA_WRITER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_METADATA_WRITER))
#define IS_METADATA_WRITER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_METADATA_WRITER))
#define METADATA_WRITER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_METADATA_WRITER, MetadataWriterClass))

typedef struct _MetadataWriter MetadataWriter;
typedef struct _MetadataWriterClass MetadataWriterClass;

#define TYPE_DIRECTORY_MONITOR (directory_monitor_get_type ())
#define DIRECTORY_MONITOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DIRECTORY_MONITOR, DirectoryMonitor))
#define DIRECTORY_MONITOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DIRECTORY_MONITOR, DirectoryMonitorClass))
#define IS_DIRECTORY_MONITOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DIRECTORY_MONITOR))
#define IS_DIRECTORY_MONITOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DIRECTORY_MONITOR))
#define DIRECTORY_MONITOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DIRECTORY_MONITOR, DirectoryMonitorClass))

typedef struct _DirectoryMonitor DirectoryMonitor;
typedef struct _DirectoryMonitorClass DirectoryMonitorClass;

#define TYPE_LIBRARY_MONITOR (library_monitor_get_type ())
#define LIBRARY_MONITOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_LIBRARY_MONITOR, LibraryMonitor))
#define LIBRARY_MONITOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_LIBRARY_MONITOR, LibraryMonitorClass))
#define IS_LIBRARY_MONITOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_LIBRARY_MONITOR))
#define IS_LIBRARY_MONITOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_LIBRARY_MONITOR))
#define LIBRARY_MONITOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_LIBRARY_MONITOR, LibraryMonitorClass))

typedef struct _LibraryMonitor LibraryMonitor;
typedef struct _LibraryMonitorClass LibraryMonitorClass;

#define TYPE_LIBRARY_MONITOR_POOL (library_monitor_pool_get_type ())
#define LIBRARY_MONITOR_POOL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_LIBRARY_MONITOR_POOL, LibraryMonitorPool))
#define LIBRARY_MONITOR_POOL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_LIBRARY_MONITOR_POOL, LibraryMonitorPoolClass))
#define IS_LIBRARY_MONITOR_POOL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_LIBRARY_MONITOR_POOL))
#define IS_LIBRARY_MONITOR_POOL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_LIBRARY_MONITOR_POOL))
#define LIBRARY_MONITOR_POOL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_LIBRARY_MONITOR_POOL, LibraryMonitorPoolClass))

typedef struct _LibraryMonitorPool LibraryMonitorPool;
typedef struct _LibraryMonitorPoolClass LibraryMonitorPoolClass;
#define _library_monitor_pool_unref0(var) ((var == NULL) ? NULL : (var = (library_monitor_pool_unref (var), NULL)))

#define TYPE_CAMERA_TABLE (camera_table_get_type ())
#define CAMERA_TABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_CAMERA_TABLE, CameraTable))
#define CAMERA_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_CAMERA_TABLE, CameraTableClass))
#define IS_CAMERA_TABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_CAMERA_TABLE))
#define IS_CAMERA_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_CAMERA_TABLE))
#define CAMERA_TABLE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_CAMERA_TABLE, CameraTableClass))

typedef struct _CameraTable CameraTable;
typedef struct _CameraTableClass CameraTableClass;

#define TYPE_DISCOVERED_CAMERA (discovered_camera_get_type ())
#define DISCOVERED_CAMERA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DISCOVERED_CAMERA, DiscoveredCamera))
#define DISCOVERED_CAMERA_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DISCOVERED_CAMERA, DiscoveredCameraClass))
#define IS_DISCOVERED_CAMERA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DISCOVERED_CAMERA))
#define IS_DISCOVERED_CAMERA_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DISCOVERED_CAMERA))
#define DISCOVERED_CAMERA_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DISCOVERED_CAMERA, DiscoveredCameraClass))

typedef struct _DiscoveredCamera DiscoveredCamera;
typedef struct _DiscoveredCameraClass DiscoveredCameraClass;
#define _camera_table_unref0(var) ((var == NULL) ? NULL : (var = (camera_table_unref (var), NULL)))

#define LIBRARY_WINDOW_TYPE_SIDEBAR_ROOT_POSITION (library_window_sidebar_root_position_get_type ())

#define LIBRARY_WINDOW_TYPE_TARGET_TYPE (library_window_target_type_get_type ())
#define _g_free0(var) (var = (g_free (var), NULL))
#define _one_shot_scheduler_unref0(var) ((var == NULL) ? NULL : (var = (one_shot_scheduler_unref (var), NULL)))
#define _search_filter_actions_unref0(var) ((var == NULL) ? NULL : (var = (search_filter_actions_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))

#define SIDEBAR_TYPE_SIMPLE_PAGE_ENTRY (sidebar_simple_page_entry_get_type ())
#define SIDEBAR_SIMPLE_PAGE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_SIMPLE_PAGE_ENTRY, SidebarSimplePageEntry))
#define SIDEBAR_SIMPLE_PAGE_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SIDEBAR_TYPE_SIMPLE_PAGE_ENTRY, SidebarSimplePageEntryClass))
#define SIDEBAR_IS_SIMPLE_PAGE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_SIMPLE_PAGE_ENTRY))
#define SIDEBAR_IS_SIMPLE_PAGE_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SIDEBAR_TYPE_SIMPLE_PAGE_ENTRY))
#define SIDEBAR_SIMPLE_PAGE_ENTRY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SIDEBAR_TYPE_SIMPLE_PAGE_ENTRY, SidebarSimplePageEntryClass))

typedef struct _SidebarSimplePageEntry SidebarSimplePageEntry;
typedef struct _SidebarSimplePageEntryClass SidebarSimplePageEntryClass;

#define LIBRARY_TYPE_PHOTOS_ENTRY (library_photos_entry_get_type ())
#define LIBRARY_PHOTOS_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), LIBRARY_TYPE_PHOTOS_ENTRY, LibraryPhotosEntry))
#define LIBRARY_PHOTOS_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), LIBRARY_TYPE_PHOTOS_ENTRY, LibraryPhotosEntryClass))
#define LIBRARY_IS_PHOTOS_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), LIBRARY_TYPE_PHOTOS_ENTRY))
#define LIBRARY_IS_PHOTOS_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), LIBRARY_TYPE_PHOTOS_ENTRY))
#define LIBRARY_PHOTOS_ENTRY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), LIBRARY_TYPE_PHOTOS_ENTRY, LibraryPhotosEntryClass))

typedef struct _LibraryPhotosEntry LibraryPhotosEntry;
typedef struct _LibraryPhotosEntryClass LibraryPhotosEntryClass;

#define TYPE_VIEW_COLLECTION (view_collection_get_type ())
#define VIEW_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_VIEW_COLLECTION, ViewCollection))
#define VIEW_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_VIEW_COLLECTION, ViewCollectionClass))
#define IS_VIEW_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_VIEW_COLLECTION))
#define IS_VIEW_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_VIEW_COLLECTION))
#define VIEW_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_VIEW_COLLECTION, ViewCollectionClass))

typedef struct _ViewCollection ViewCollection;
typedef struct _ViewCollectionClass ViewCollectionClass;

#define TYPE_VIEW_FILTER (view_filter_get_type ())
#define VIEW_FILTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_VIEW_FILTER, ViewFilter))
#define VIEW_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_VIEW_FILTER, ViewFilterClass))
#define IS_VIEW_FILTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_VIEW_FILTER))
#define IS_VIEW_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_VIEW_FILTER))
#define VIEW_FILTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_VIEW_FILTER, ViewFilterClass))

typedef struct _ViewFilter ViewFilter;
typedef struct _ViewFilterClass ViewFilterClass;

#define TYPE_CHECKERBOARD_PAGE (checkerboard_page_get_type ())
#define CHECKERBOARD_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_CHECKERBOARD_PAGE, CheckerboardPage))
#define CHECKERBOARD_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_CHECKERBOARD_PAGE, CheckerboardPageClass))
#define IS_CHECKERBOARD_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_CHECKERBOARD_PAGE))
#define IS_CHECKERBOARD_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_CHECKERBOARD_PAGE))
#define CHECKERBOARD_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_CHECKERBOARD_PAGE, CheckerboardPageClass))

typedef struct _CheckerboardPage CheckerboardPage;
typedef struct _CheckerboardPageClass CheckerboardPageClass;

#define TYPE_TAG (tag_get_type ())
#define TAG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_TAG, Tag))
#define TAG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_TAG, TagClass))
#define IS_TAG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_TAG))
#define IS_TAG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_TAG))
#define TAG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_TAG, TagClass))

typedef struct _Tag Tag;
typedef struct _TagClass TagClass;

#define TAGS_TYPE_SIDEBAR_ENTRY (tags_sidebar_entry_get_type ())
#define TAGS_SIDEBAR_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TAGS_TYPE_SIDEBAR_ENTRY, TagsSidebarEntry))
#define TAGS_SIDEBAR_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TAGS_TYPE_SIDEBAR_ENTRY, TagsSidebarEntryClass))
#define TAGS_IS_SIDEBAR_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TAGS_TYPE_SIDEBAR_ENTRY))
#define TAGS_IS_SIDEBAR_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TAGS_TYPE_SIDEBAR_ENTRY))
#define TAGS_SIDEBAR_ENTRY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TAGS_TYPE_SIDEBAR_ENTRY, TagsSidebarEntryClass))

typedef struct _TagsSidebarEntry TagsSidebarEntry;
typedef struct _TagsSidebarEntryClass TagsSidebarEntryClass;

#define TYPE_EVENT_SOURCE (event_source_get_type ())
#define EVENT_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_EVENT_SOURCE, EventSource))
#define EVENT_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_EVENT_SOURCE, EventSourceClass))
#define IS_EVENT_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_EVENT_SOURCE))
#define IS_EVENT_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_EVENT_SOURCE))
#define EVENT_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_EVENT_SOURCE, EventSourceClass))

typedef struct _EventSource EventSource;
typedef struct _EventSourceClass EventSourceClass;

#define TYPE_EVENT (event_get_type ())
#define EVENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_EVENT, Event))
#define EVENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_EVENT, EventClass))
#define IS_EVENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_EVENT))
#define IS_EVENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_EVENT))
#define EVENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_EVENT, EventClass))

typedef struct _Event Event;
typedef struct _EventClass EventClass;

#define EVENTS_TYPE_EVENT_ENTRY (events_event_entry_get_type ())
#define EVENTS_EVENT_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), EVENTS_TYPE_EVENT_ENTRY, EventsEventEntry))
#define EVENTS_EVENT_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), EVENTS_TYPE_EVENT_ENTRY, EventsEventEntryClass))
#define EVENTS_IS_EVENT_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), EVENTS_TYPE_EVENT_ENTRY))
#define EVENTS_IS_EVENT_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), EVENTS_TYPE_EVENT_ENTRY))
#define EVENTS_EVENT_ENTRY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), EVENTS_TYPE_EVENT_ENTRY, EventsEventEntryClass))

typedef struct _EventsEventEntry EventsEventEntry;
typedef struct _EventsEventEntryClass EventsEventEntryClass;

#define TYPE_SAVED_SEARCH (saved_search_get_type ())
#define SAVED_SEARCH(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SAVED_SEARCH, SavedSearch))
#define SAVED_SEARCH_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SAVED_SEARCH, SavedSearchClass))
#define IS_SAVED_SEARCH(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SAVED_SEARCH))
#define IS_SAVED_SEARCH_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SAVED_SEARCH))
#define SAVED_SEARCH_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SAVED_SEARCH, SavedSearchClass))

typedef struct _SavedSearch SavedSearch;
typedef struct _SavedSearchClass SavedSearchClass;

#define SEARCHES_TYPE_SIDEBAR_ENTRY (searches_sidebar_entry_get_type ())
#define SEARCHES_SIDEBAR_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SEARCHES_TYPE_SIDEBAR_ENTRY, SearchesSidebarEntry))
#define SEARCHES_SIDEBAR_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SEARCHES_TYPE_SIDEBAR_ENTRY, SearchesSidebarEntryClass))
#define SEARCHES_IS_SIDEBAR_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SEARCHES_TYPE_SIDEBAR_ENTRY))
#define SEARCHES_IS_SIDEBAR_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SEARCHES_TYPE_SIDEBAR_ENTRY))
#define SEARCHES_SIDEBAR_ENTRY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SEARCHES_TYPE_SIDEBAR_ENTRY, SearchesSidebarEntryClass))

typedef struct _SearchesSidebarEntry SearchesSidebarEntry;
typedef struct _SearchesSidebarEntryClass SearchesSidebarEntryClass;

#define TYPE_CONFIGURATION_FACADE (configuration_facade_get_type ())
#define CONFIGURATION_FACADE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_CONFIGURATION_FACADE, ConfigurationFacade))
#define CONFIGURATION_FACADE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_CONFIGURATION_FACADE, ConfigurationFacadeClass))
#define IS_CONFIGURATION_FACADE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_CONFIGURATION_FACADE))
#define IS_CONFIGURATION_FACADE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_CONFIGURATION_FACADE))
#define CONFIGURATION_FACADE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_CONFIGURATION_FACADE, ConfigurationFacadeClass))

typedef struct _ConfigurationFacade ConfigurationFacade;
typedef struct _ConfigurationFacadeClass ConfigurationFacadeClass;

#define CONFIG_TYPE_FACADE (config_facade_get_type ())
#define CONFIG_FACADE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CONFIG_TYPE_FACADE, ConfigFacade))
#define CONFIG_FACADE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), CONFIG_TYPE_FACADE, ConfigFacadeClass))
#define CONFIG_IS_FACADE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CONFIG_TYPE_FACADE))
#define CONFIG_IS_FACADE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CONFIG_TYPE_FACADE))
#define CONFIG_FACADE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), CONFIG_TYPE_FACADE, ConfigFacadeClass))

typedef struct _ConfigFacade ConfigFacade;
typedef struct _ConfigFacadeClass ConfigFacadeClass;

#define TYPE_MEDIA_PAGE (media_page_get_type ())
#define MEDIA_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MEDIA_PAGE, MediaPage))
#define MEDIA_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MEDIA_PAGE, MediaPageClass))
#define IS_MEDIA_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MEDIA_PAGE))
#define IS_MEDIA_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MEDIA_PAGE))
#define MEDIA_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MEDIA_PAGE, MediaPageClass))

typedef struct _MediaPage MediaPage;
typedef struct _MediaPageClass MediaPageClass;

#define TYPE_COLLECTION_PAGE (collection_page_get_type ())
#define COLLECTION_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_COLLECTION_PAGE, CollectionPage))
#define COLLECTION_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_COLLECTION_PAGE, CollectionPageClass))
#define IS_COLLECTION_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_COLLECTION_PAGE))
#define IS_COLLECTION_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_COLLECTION_PAGE))
#define COLLECTION_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_COLLECTION_PAGE, CollectionPageClass))

typedef struct _CollectionPage CollectionPage;
typedef struct _CollectionPageClass CollectionPageClass;

#define TYPE_PHOTO_SOURCE (photo_source_get_type ())
#define PHOTO_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PHOTO_SOURCE, PhotoSource))
#define PHOTO_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PHOTO_SOURCE, PhotoSourceClass))
#define IS_PHOTO_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PHOTO_SOURCE))
#define IS_PHOTO_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PHOTO_SOURCE))
#define PHOTO_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PHOTO_SOURCE, PhotoSourceClass))

typedef struct _PhotoSource PhotoSource;
typedef struct _PhotoSourceClass PhotoSourceClass;

#define TYPE_PHOTO (photo_get_type ())
#define PHOTO(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PHOTO, Photo))
#define PHOTO_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PHOTO, PhotoClass))
#define IS_PHOTO(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PHOTO))
#define IS_PHOTO_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PHOTO))
#define PHOTO_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PHOTO, PhotoClass))

typedef struct _Photo Photo;
typedef struct _PhotoClass PhotoClass;

#define TYPE_LIBRARY_PHOTO (library_photo_get_type ())
#define LIBRARY_PHOTO(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_LIBRARY_PHOTO, LibraryPhoto))
#define LIBRARY_PHOTO_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_LIBRARY_PHOTO, LibraryPhotoClass))
#define IS_LIBRARY_PHOTO(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_LIBRARY_PHOTO))
#define IS_LIBRARY_PHOTO_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_LIBRARY_PHOTO))
#define LIBRARY_PHOTO_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_LIBRARY_PHOTO, LibraryPhotoClass))

typedef struct _LibraryPhoto LibraryPhoto;
typedef struct _LibraryPhotoClass LibraryPhotoClass;

#define TYPE_EVENTS_DIRECTORY_PAGE (events_directory_page_get_type ())
#define EVENTS_DIRECTORY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_EVENTS_DIRECTORY_PAGE, EventsDirectoryPage))
#define EVENTS_DIRECTORY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_EVENTS_DIRECTORY_PAGE, EventsDirectoryPageClass))
#define IS_EVENTS_DIRECTORY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_EVENTS_DIRECTORY_PAGE))
#define IS_EVENTS_DIRECTORY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_EVENTS_DIRECTORY_PAGE))
#define EVENTS_DIRECTORY_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_EVENTS_DIRECTORY_PAGE, EventsDirectoryPageClass))

typedef struct _EventsDirectoryPage EventsDirectoryPage;
typedef struct _EventsDirectoryPageClass EventsDirectoryPageClass;

#define TYPE_DATA_VIEW (data_view_get_type ())
#define DATA_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATA_VIEW, DataView))
#define DATA_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATA_VIEW, DataViewClass))
#define IS_DATA_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATA_VIEW))
#define IS_DATA_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATA_VIEW))
#define DATA_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATA_VIEW, DataViewClass))

typedef struct _DataView DataView;
typedef struct _DataViewClass DataViewClass;

#define TYPE_EVENT_PAGE (event_page_get_type ())
#define EVENT_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_EVENT_PAGE, EventPage))
#define EVENT_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_EVENT_PAGE, EventPageClass))
#define IS_EVENT_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_EVENT_PAGE))
#define IS_EVENT_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_EVENT_PAGE))
#define EVENT_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_EVENT_PAGE, EventPageClass))

typedef struct _EventPage EventPage;
typedef struct _EventPageClass EventPageClass;

#define LIBRARY_WINDOW_TYPE_FULLSCREEN_PHOTO_PAGE (library_window_fullscreen_photo_page_get_type ())
#define LIBRARY_WINDOW_FULLSCREEN_PHOTO_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), LIBRARY_WINDOW_TYPE_FULLSCREEN_PHOTO_PAGE, LibraryWindowFullscreenPhotoPage))
#define LIBRARY_WINDOW_FULLSCREEN_PHOTO_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), LIBRARY_WINDOW_TYPE_FULLSCREEN_PHOTO_PAGE, LibraryWindowFullscreenPhotoPageClass))
#define LIBRARY_WINDOW_IS_FULLSCREEN_PHOTO_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), LIBRARY_WINDOW_TYPE_FULLSCREEN_PHOTO_PAGE))
#define LIBRARY_WINDOW_IS_FULLSCREEN_PHOTO_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), LIBRARY_WINDOW_TYPE_FULLSCREEN_PHOTO_PAGE))
#define LIBRARY_WINDOW_FULLSCREEN_PHOTO_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), LIBRARY_WINDOW_TYPE_FULLSCREEN_PHOTO_PAGE, LibraryWindowFullscreenPhotoPageClass))

typedef struct _LibraryWindowFullscreenPhotoPage LibraryWindowFullscreenPhotoPage;
typedef struct _LibraryWindowFullscreenPhotoPageClass LibraryWindowFullscreenPhotoPageClass;
#define __g_slist_free__g_free0_0(var) ((var == NULL) ? NULL : (var = (_g_slist_free__g_free0_ (var), NULL)))

#define DATA_IMPORTS_UI_TYPE_DATA_IMPORTS_DIALOG (data_imports_ui_data_imports_dialog_get_type ())
#define DATA_IMPORTS_UI_DATA_IMPORTS_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATA_IMPORTS_UI_TYPE_DATA_IMPORTS_DIALOG, DataImportsUIDataImportsDialog))
#define DATA_IMPORTS_UI_DATA_IMPORTS_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DATA_IMPORTS_UI_TYPE_DATA_IMPORTS_DIALOG, DataImportsUIDataImportsDialogClass))
#define DATA_IMPORTS_UI_IS_DATA_IMPORTS_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATA_IMPORTS_UI_TYPE_DATA_IMPORTS_DIALOG))
#define DATA_IMPORTS_UI_IS_DATA_IMPORTS_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DATA_IMPORTS_UI_TYPE_DATA_IMPORTS_DIALOG))
#define DATA_IMPORTS_UI_DATA_IMPORTS_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DATA_IMPORTS_UI_TYPE_DATA_IMPORTS_DIALOG, DataImportsUIDataImportsDialogClass))

typedef struct _DataImportsUIDataImportsDialog DataImportsUIDataImportsDialog;
typedef struct _DataImportsUIDataImportsDialogClass DataImportsUIDataImportsDialogClass;

#define TYPE_LIBRARY_PHOTO_SOURCE_COLLECTION (library_photo_source_collection_get_type ())
#define LIBRARY_PHOTO_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_LIBRARY_PHOTO_SOURCE_COLLECTION, LibraryPhotoSourceCollection))
#define LIBRARY_PHOTO_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_LIBRARY_PHOTO_SOURCE_COLLECTION, LibraryPhotoSourceCollectionClass))
#define IS_LIBRARY_PHOTO_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_LIBRARY_PHOTO_SOURCE_COLLECTION))
#define IS_LIBRARY_PHOTO_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_LIBRARY_PHOTO_SOURCE_COLLECTION))
#define LIBRARY_PHOTO_SOURCE_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_LIBRARY_PHOTO_SOURCE_COLLECTION, LibraryPhotoSourceCollectionClass))

typedef struct _LibraryPhotoSourceCollection LibraryPhotoSourceCollection;
typedef struct _LibraryPhotoSourceCollectionClass LibraryPhotoSourceCollectionClass;

#define TYPE_VIDEO_SOURCE_COLLECTION (video_source_collection_get_type ())
#define VIDEO_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_VIDEO_SOURCE_COLLECTION, VideoSourceCollection))
#define VIDEO_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_VIDEO_SOURCE_COLLECTION, VideoSourceCollectionClass))
#define IS_VIDEO_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_VIDEO_SOURCE_COLLECTION))
#define IS_VIDEO_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_VIDEO_SOURCE_COLLECTION))
#define VIDEO_SOURCE_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_VIDEO_SOURCE_COLLECTION, VideoSourceCollectionClass))

typedef struct _VideoSourceCollection VideoSourceCollection;
typedef struct _VideoSourceCollectionClass VideoSourceCollectionClass;

#define TYPE_COMMAND_MANAGER (command_manager_get_type ())
#define COMMAND_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_COMMAND_MANAGER, CommandManager))
#define COMMAND_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_COMMAND_MANAGER, CommandManagerClass))
#define IS_COMMAND_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_COMMAND_MANAGER))
#define IS_COMMAND_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_COMMAND_MANAGER))
#define COMMAND_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_COMMAND_MANAGER, CommandManagerClass))

typedef struct _CommandManager CommandManager;
typedef struct _CommandManagerClass CommandManagerClass;
#define _command_manager_unref0(var) ((var == NULL) ? NULL : (var = (command_manager_unref (var), NULL)))

#define TYPE_SAVED_SEARCH_DIALOG (saved_search_dialog_get_type ())
#define SAVED_SEARCH_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SAVED_SEARCH_DIALOG, SavedSearchDialog))
#define SAVED_SEARCH_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SAVED_SEARCH_DIALOG, SavedSearchDialogClass))
#define IS_SAVED_SEARCH_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SAVED_SEARCH_DIALOG))
#define IS_SAVED_SEARCH_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SAVED_SEARCH_DIALOG))
#define SAVED_SEARCH_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SAVED_SEARCH_DIALOG, SavedSearchDialogClass))

typedef struct _SavedSearchDialog SavedSearchDialog;
typedef struct _SavedSearchDialogClass SavedSearchDialogClass;
#define _saved_search_dialog_unref0(var) ((var == NULL) ? NULL : (var = (saved_search_dialog_unref (var), NULL)))

#define TYPE_BATCH_IMPORT (batch_import_get_type ())
#define BATCH_IMPORT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_BATCH_IMPORT, BatchImport))
#define BATCH_IMPORT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_BATCH_IMPORT, BatchImportClass))
#define IS_BATCH_IMPORT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_BATCH_IMPORT))
#define IS_BATCH_IMPORT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_BATCH_IMPORT))
#define BATCH_IMPORT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_BATCH_IMPORT, BatchImportClass))

typedef struct _BatchImport BatchImport;
typedef struct _BatchImportClass BatchImportClass;

#define LIBRARY_TYPE_HIDEABLE_PAGE_ENTRY (library_hideable_page_entry_get_type ())
#define LIBRARY_HIDEABLE_PAGE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), LIBRARY_TYPE_HIDEABLE_PAGE_ENTRY, LibraryHideablePageEntry))
#define LIBRARY_HIDEABLE_PAGE_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), LIBRARY_TYPE_HIDEABLE_PAGE_ENTRY, LibraryHideablePageEntryClass))
#define LIBRARY_IS_HIDEABLE_PAGE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), LIBRARY_TYPE_HIDEABLE_PAGE_ENTRY))
#define LIBRARY_IS_HIDEABLE_PAGE_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), LIBRARY_TYPE_HIDEABLE_PAGE_ENTRY))
#define LIBRARY_HIDEABLE_PAGE_ENTRY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), LIBRARY_TYPE_HIDEABLE_PAGE_ENTRY, LibraryHideablePageEntryClass))

typedef struct _LibraryHideablePageEntry LibraryHideablePageEntry;
typedef struct _LibraryHideablePageEntryClass LibraryHideablePageEntryClass;

#define LIBRARY_TYPE_IMPORT_QUEUE_SIDEBAR_ENTRY (library_import_queue_sidebar_entry_get_type ())
#define LIBRARY_IMPORT_QUEUE_SIDEBAR_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), LIBRARY_TYPE_IMPORT_QUEUE_SIDEBAR_ENTRY, LibraryImportQueueSidebarEntry))
#define LIBRARY_IMPORT_QUEUE_SIDEBAR_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), LIBRARY_TYPE_IMPORT_QUEUE_SIDEBAR_ENTRY, LibraryImportQueueSidebarEntryClass))
#define LIBRARY_IS_IMPORT_QUEUE_SIDEBAR_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), LIBRARY_TYPE_IMPORT_QUEUE_SIDEBAR_ENTRY))
#define LIBRARY_IS_IMPORT_QUEUE_SIDEBAR_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), LIBRARY_TYPE_IMPORT_QUEUE_SIDEBAR_ENTRY))
#define LIBRARY_IMPORT_QUEUE_SIDEBAR_ENTRY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), LIBRARY_TYPE_IMPORT_QUEUE_SIDEBAR_ENTRY, LibraryImportQueueSidebarEntryClass))

typedef struct _LibraryImportQueueSidebarEntry LibraryImportQueueSidebarEntry;
typedef struct _LibraryImportQueueSidebarEntryClass LibraryImportQueueSidebarEntryClass;

#define TYPE_IMPORT_MANIFEST (import_manifest_get_type ())
#define IMPORT_MANIFEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_IMPORT_MANIFEST, ImportManifest))
#define IMPORT_MANIFEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_IMPORT_MANIFEST, ImportManifestClass))
#define IS_IMPORT_MANIFEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_IMPORT_MANIFEST))
#define IS_IMPORT_MANIFEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_IMPORT_MANIFEST))
#define IMPORT_MANIFEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_IMPORT_MANIFEST, ImportManifestClass))

typedef struct _ImportManifest ImportManifest;
typedef struct _ImportManifestClass ImportManifestClass;

#define IMPORT_UI_TYPE_QUESTION_PARAMS (import_ui_question_params_get_type ())
#define IMPORT_UI_QUESTION_PARAMS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), IMPORT_UI_TYPE_QUESTION_PARAMS, ImportUIQuestionParams))
#define IMPORT_UI_QUESTION_PARAMS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), IMPORT_UI_TYPE_QUESTION_PARAMS, ImportUIQuestionParamsClass))
#define IMPORT_UI_IS_QUESTION_PARAMS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), IMPORT_UI_TYPE_QUESTION_PARAMS))
#define IMPORT_UI_IS_QUESTION_PARAMS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), IMPORT_UI_TYPE_QUESTION_PARAMS))
#define IMPORT_UI_QUESTION_PARAMS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), IMPORT_UI_TYPE_QUESTION_PARAMS, ImportUIQuestionParamsClass))

typedef struct _ImportUIQuestionParams ImportUIQuestionParams;
typedef struct _ImportUIQuestionParamsClass ImportUIQuestionParamsClass;

#define TYPE_BATCH_IMPORT_JOB (batch_import_job_get_type ())
#define BATCH_IMPORT_JOB(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_BATCH_IMPORT_JOB, BatchImportJob))
#define BATCH_IMPORT_JOB_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_BATCH_IMPORT_JOB, BatchImportJobClass))
#define IS_BATCH_IMPORT_JOB(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_BATCH_IMPORT_JOB))
#define IS_BATCH_IMPORT_JOB_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_BATCH_IMPORT_JOB))
#define BATCH_IMPORT_JOB_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_BATCH_IMPORT_JOB, BatchImportJobClass))

typedef struct _BatchImportJob BatchImportJob;
typedef struct _BatchImportJobClass BatchImportJobClass;

#define TYPE_FILE_IMPORT_JOB (file_import_job_get_type ())
#define FILE_IMPORT_JOB(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_FILE_IMPORT_JOB, FileImportJob))
#define FILE_IMPORT_JOB_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_FILE_IMPORT_JOB, FileImportJobClass))
#define IS_FILE_IMPORT_JOB(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_FILE_IMPORT_JOB))
#define IS_FILE_IMPORT_JOB_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_FILE_IMPORT_JOB))
#define FILE_IMPORT_JOB_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_FILE_IMPORT_JOB, FileImportJobClass))

typedef struct _FileImportJob FileImportJob;
typedef struct _FileImportJobClass FileImportJobClass;
#define _batch_import_job_unref0(var) ((var == NULL) ? NULL : (var = (batch_import_job_unref (var), NULL)))

#define TYPE_BATCH_IMPORT_ROLL (batch_import_roll_get_type ())
#define BATCH_IMPORT_ROLL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_BATCH_IMPORT_ROLL, BatchImportRoll))
#define BATCH_IMPORT_ROLL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_BATCH_IMPORT_ROLL, BatchImportRollClass))
#define IS_BATCH_IMPORT_ROLL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_BATCH_IMPORT_ROLL))
#define IS_BATCH_IMPORT_ROLL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_BATCH_IMPORT_ROLL))
#define BATCH_IMPORT_ROLL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_BATCH_IMPORT_ROLL, BatchImportRollClass))

typedef struct _BatchImportRoll BatchImportRoll;
typedef struct _BatchImportRollClass BatchImportRollClass;

#define CAMERA_TYPE_SIDEBAR_ENTRY (camera_sidebar_entry_get_type ())
#define CAMERA_SIDEBAR_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CAMERA_TYPE_SIDEBAR_ENTRY, CameraSidebarEntry))
#define CAMERA_SIDEBAR_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), CAMERA_TYPE_SIDEBAR_ENTRY, CameraSidebarEntryClass))
#define CAMERA_IS_SIDEBAR_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CAMERA_TYPE_SIDEBAR_ENTRY))
#define CAMERA_IS_SIDEBAR_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CAMERA_TYPE_SIDEBAR_ENTRY))
#define CAMERA_SIDEBAR_ENTRY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), CAMERA_TYPE_SIDEBAR_ENTRY, CameraSidebarEntryClass))

typedef struct _CameraSidebarEntry CameraSidebarEntry;
typedef struct _CameraSidebarEntryClass CameraSidebarEntryClass;

#define TYPE_IMPORT_PAGE (import_page_get_type ())
#define IMPORT_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_IMPORT_PAGE, ImportPage))
#define IMPORT_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_IMPORT_PAGE, ImportPageClass))
#define IS_IMPORT_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_IMPORT_PAGE))
#define IS_IMPORT_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_IMPORT_PAGE))
#define IMPORT_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_IMPORT_PAGE, ImportPageClass))

typedef struct _ImportPage ImportPage;
typedef struct _ImportPageClass ImportPageClass;
typedef struct _DiscoveredCameraPrivate DiscoveredCameraPrivate;

#define SIDEBAR_TYPE_EXPANDABLE_ENTRY (sidebar_expandable_entry_get_type ())
#define SIDEBAR_EXPANDABLE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_EXPANDABLE_ENTRY, SidebarExpandableEntry))
#define SIDEBAR_IS_EXPANDABLE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_EXPANDABLE_ENTRY))
#define SIDEBAR_EXPANDABLE_ENTRY_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), SIDEBAR_TYPE_EXPANDABLE_ENTRY, SidebarExpandableEntryIface))

typedef struct _SidebarExpandableEntry SidebarExpandableEntry;
typedef struct _SidebarExpandableEntryIface SidebarExpandableEntryIface;

#define TYPE_SEARCH_VIEW_FILTER (search_view_filter_get_type ())
#define SEARCH_VIEW_FILTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SEARCH_VIEW_FILTER, SearchViewFilter))
#define SEARCH_VIEW_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SEARCH_VIEW_FILTER, SearchViewFilterClass))
#define IS_SEARCH_VIEW_FILTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SEARCH_VIEW_FILTER))
#define IS_SEARCH_VIEW_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SEARCH_VIEW_FILTER))
#define SEARCH_VIEW_FILTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SEARCH_VIEW_FILTER, SearchViewFilterClass))

typedef struct _SearchViewFilter SearchViewFilter;
typedef struct _SearchViewFilterClass SearchViewFilterClass;
#define _view_filter_unref0(var) ((var == NULL) ? NULL : (var = (view_filter_unref (var), NULL)))

#define TYPE_DISABLED_VIEW_FILTER (disabled_view_filter_get_type ())
#define DISABLED_VIEW_FILTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DISABLED_VIEW_FILTER, DisabledViewFilter))
#define DISABLED_VIEW_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DISABLED_VIEW_FILTER, DisabledViewFilterClass))
#define IS_DISABLED_VIEW_FILTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DISABLED_VIEW_FILTER))
#define IS_DISABLED_VIEW_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DISABLED_VIEW_FILTER))
#define DISABLED_VIEW_FILTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DISABLED_VIEW_FILTER, DisabledViewFilterClass))

typedef struct _DisabledViewFilter DisabledViewFilter;
typedef struct _DisabledViewFilterClass DisabledViewFilterClass;

#define LIBRARY_TYPE_LAST_IMPORT_SIDEBAR_ENTRY (library_last_import_sidebar_entry_get_type ())
#define LIBRARY_LAST_IMPORT_SIDEBAR_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), LIBRARY_TYPE_LAST_IMPORT_SIDEBAR_ENTRY, LibraryLastImportSidebarEntry))
#define LIBRARY_LAST_IMPORT_SIDEBAR_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), LIBRARY_TYPE_LAST_IMPORT_SIDEBAR_ENTRY, LibraryLastImportSidebarEntryClass))
#define LIBRARY_IS_LAST_IMPORT_SIDEBAR_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), LIBRARY_TYPE_LAST_IMPORT_SIDEBAR_ENTRY))
#define LIBRARY_IS_LAST_IMPORT_SIDEBAR_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), LIBRARY_TYPE_LAST_IMPORT_SIDEBAR_ENTRY))
#define LIBRARY_LAST_IMPORT_SIDEBAR_ENTRY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), LIBRARY_TYPE_LAST_IMPORT_SIDEBAR_ENTRY, LibraryLastImportSidebarEntryClass))

typedef struct _LibraryLastImportSidebarEntry LibraryLastImportSidebarEntry;
typedef struct _LibraryLastImportSidebarEntryClass LibraryLastImportSidebarEntryClass;

#define EVENTS_TYPE_DIRECTORY_ENTRY (events_directory_entry_get_type ())
#define EVENTS_DIRECTORY_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), EVENTS_TYPE_DIRECTORY_ENTRY, EventsDirectoryEntry))
#define EVENTS_DIRECTORY_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), EVENTS_TYPE_DIRECTORY_ENTRY, EventsDirectoryEntryClass))
#define EVENTS_IS_DIRECTORY_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), EVENTS_TYPE_DIRECTORY_ENTRY))
#define EVENTS_IS_DIRECTORY_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), EVENTS_TYPE_DIRECTORY_ENTRY))
#define EVENTS_DIRECTORY_ENTRY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), EVENTS_TYPE_DIRECTORY_ENTRY, EventsDirectoryEntryClass))

typedef struct _EventsDirectoryEntry EventsDirectoryEntry;
typedef struct _EventsDirectoryEntryClass EventsDirectoryEntryClass;

#define EVENTS_TYPE_MASTER_DIRECTORY_ENTRY (events_master_directory_entry_get_type ())
#define EVENTS_MASTER_DIRECTORY_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), EVENTS_TYPE_MASTER_DIRECTORY_ENTRY, EventsMasterDirectoryEntry))
#define EVENTS_MASTER_DIRECTORY_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), EVENTS_TYPE_MASTER_DIRECTORY_ENTRY, EventsMasterDirectoryEntryClass))
#define EVENTS_IS_MASTER_DIRECTORY_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), EVENTS_TYPE_MASTER_DIRECTORY_ENTRY))
#define EVENTS_IS_MASTER_DIRECTORY_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), EVENTS_TYPE_MASTER_DIRECTORY_ENTRY))
#define EVENTS_MASTER_DIRECTORY_ENTRY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), EVENTS_TYPE_MASTER_DIRECTORY_ENTRY, EventsMasterDirectoryEntryClass))

typedef struct _EventsMasterDirectoryEntry EventsMasterDirectoryEntry;
typedef struct _EventsMasterDirectoryEntryClass EventsMasterDirectoryEntryClass;
#define _g_regex_unref0(var) ((var == NULL) ? NULL : (var = (g_regex_unref (var), NULL)))
typedef struct _PagePrivate PagePrivate;

#define TYPE_FULLSCREEN_WINDOW (fullscreen_window_get_type ())
#define FULLSCREEN_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_FULLSCREEN_WINDOW, FullscreenWindow))
#define FULLSCREEN_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_FULLSCREEN_WINDOW, FullscreenWindowClass))
#define IS_FULLSCREEN_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_FULLSCREEN_WINDOW))
#define IS_FULLSCREEN_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_FULLSCREEN_WINDOW))
#define FULLSCREEN_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_FULLSCREEN_WINDOW, FullscreenWindowClass))

typedef struct _FullscreenWindow FullscreenWindow;
typedef struct _FullscreenWindowClass FullscreenWindowClass;

#define TYPE_INJECTION_GROUP (injection_group_get_type ())
#define INJECTION_GROUP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_INJECTION_GROUP, InjectionGroup))
#define INJECTION_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_INJECTION_GROUP, InjectionGroupClass))
#define IS_INJECTION_GROUP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_INJECTION_GROUP))
#define IS_INJECTION_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_INJECTION_GROUP))
#define INJECTION_GROUP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_INJECTION_GROUP, InjectionGroupClass))

typedef struct _InjectionGroup InjectionGroup;
typedef struct _InjectionGroupClass InjectionGroupClass;
typedef struct _SinglePhotoPagePrivate SinglePhotoPagePrivate;

#define TYPE_ZOOM_BUFFER (zoom_buffer_get_type ())
#define ZOOM_BUFFER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_ZOOM_BUFFER, ZoomBuffer))
#define ZOOM_BUFFER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_ZOOM_BUFFER, ZoomBufferClass))
#define IS_ZOOM_BUFFER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_ZOOM_BUFFER))
#define IS_ZOOM_BUFFER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_ZOOM_BUFFER))
#define ZOOM_BUFFER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_ZOOM_BUFFER, ZoomBufferClass))

typedef struct _ZoomBuffer ZoomBuffer;
typedef struct _ZoomBufferClass ZoomBufferClass;

#define SINGLE_PHOTO_PAGE_TYPE_UPDATE_REASON (single_photo_page_update_reason_get_type ())
typedef struct _EditingHostPagePrivate EditingHostPagePrivate;
typedef struct _LibraryPhotoPagePrivate LibraryPhotoPagePrivate;

#define TYPE_RAW_DEVELOPER (raw_developer_get_type ())
typedef struct _LibraryWindowFullscreenPhotoPagePrivate LibraryWindowFullscreenPhotoPagePrivate;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _PageWindow {
	GtkWindow parent_instance;
	PageWindowPrivate * priv;
	GtkUIManager* ui;
};

struct _PageWindowClass {
	GtkWindowClass parent_class;
	void (*switched_pages) (PageWindow* self, Page* old_page, Page* new_page);
	void (*set_current_page) (PageWindow* self, Page* page);
	void (*clear_current_page) (PageWindow* self);
};

struct _Dimensions {
	gint width;
	gint height;
};

struct _AppWindow {
	PageWindow parent_instance;
	AppWindowPrivate * priv;
	GtkActionGroup** common_action_groups;
	gint common_action_groups_length1;
	gboolean maximized;
	Dimensions dimensions;
	gint pos_x;
	gint pos_y;
};

struct _AppWindowClass {
	PageWindowClass parent_class;
	void (*on_fullscreen) (AppWindow* self);
	gchar* (*get_app_role) (AppWindow* self);
	void (*on_quit) (AppWindow* self);
	GtkActionGroup** (*create_common_action_groups) (AppWindow* self, int* result_length1);
	void (*replace_common_placeholders) (AppWindow* self, GtkUIManager* ui);
	void (*update_common_action_availability) (AppWindow* self, Page* old_page, Page* new_page);
	void (*update_common_actions) (AppWindow* self, Page* page, gint selected_count, gint count);
};

struct _LibraryWindow {
	AppWindow parent_instance;
	LibraryWindowPrivate * priv;
};

struct _LibraryWindowClass {
	AppWindowClass parent_class;
};

struct _SidebarEntryIface {
	GTypeInterface parent_iface;
	gchar* (*get_sidebar_name) (SidebarEntry* self);
	gchar* (*get_sidebar_tooltip) (SidebarEntry* self);
	gchar* (*get_sidebar_icon) (SidebarEntry* self);
	gchar* (*to_string) (SidebarEntry* self);
	void (*grafted) (SidebarEntry* self, SidebarTree* tree);
	void (*pruned) (SidebarEntry* self, SidebarTree* tree);
};

struct _LibraryWindowPrivate {
	gchar* import_dir;
	GtkPaned* sidebar_paned;
	GtkPaned* client_paned;
	GtkFrame* bottom_frame;
	GtkActionGroup* common_action_group;
	OneShotScheduler* properties_scheduler;
	gboolean notify_library_is_home_dir;
	SidebarTree* sidebar_tree;
	LibraryBranch* library_branch;
	TagsBranch* tags_branch;
	FoldersBranch* folders_branch;
	EventsBranch* events_branch;
	CameraBranch* camera_branch;
	SearchesBranch* saved_search_branch;
	gboolean page_switching_enabled;
	GeeHashMap* page_map;
	LibraryPhotoPage* photo_page;
	gboolean is_search_toolbar_visible;
	SearchFilterActions* search_actions;
	SearchFilterToolbar* search_toolbar;
	GtkBox* top_section;
	GtkFrame* background_progress_frame;
	GtkProgressBar* background_progress_bar;
	gboolean background_progress_displayed;
	BasicProperties* basic_properties;
	ExtendedPropertiesWindow* extended_properties;
	GtkStack* stack;
	GtkBox* layout;
	GtkBox* right_vbox;
	gint current_progress_priority;
	guint background_progress_pulse_id;
};

struct _SidebarSelectableEntryIface {
	GTypeInterface parent_iface;
};

struct _SidebarPageRepresentativeIface {
	GTypeInterface parent_iface;
	gboolean (*has_page) (SidebarPageRepresentative* self);
	Page* (*get_page) (SidebarPageRepresentative* self);
};

typedef enum  {
	LIBRARY_WINDOW_SIDEBAR_ROOT_POSITION_LIBRARY,
	LIBRARY_WINDOW_SIDEBAR_ROOT_POSITION_CAMERAS,
	LIBRARY_WINDOW_SIDEBAR_ROOT_POSITION_SAVED_SEARCH,
	LIBRARY_WINDOW_SIDEBAR_ROOT_POSITION_EVENTS,
	LIBRARY_WINDOW_SIDEBAR_ROOT_POSITION_FOLDERS,
	LIBRARY_WINDOW_SIDEBAR_ROOT_POSITION_TAGS
} LibraryWindowSidebarRootPosition;

typedef enum  {
	LIBRARY_WINDOW_TARGET_TYPE_URI_LIST,
	LIBRARY_WINDOW_TARGET_TYPE_MEDIA_LIST,
	LIBRARY_WINDOW_TARGET_TYPE_TAG_PATH
} LibraryWindowTargetType;

typedef gboolean (*ProgressMonitor) (guint64 current, guint64 total, gboolean do_event_loop, void* user_data);
typedef void (*SidebarTreeExternalDropHandler) (GdkDragContext* context, SidebarEntry* entry, GtkSelectionData* data, guint info, guint time, void* user_data);
typedef void (*OneShotCallback) (void* user_data);
typedef void (*BatchImportImportReporter) (ImportManifest* manifest, BatchImportRoll* import_roll, void* user_data);
struct _DiscoveredCamera {
	GTypeInstance parent_instance;
	volatile int ref_count;
	DiscoveredCameraPrivate * priv;
	Camera* gcamera;
	gchar* uri;
	gchar* display_name;
	gchar* icon;
};

struct _DiscoveredCameraClass {
	GTypeClass parent_class;
	void (*finalize) (DiscoveredCamera *self);
};

struct _SidebarExpandableEntryIface {
	GTypeInterface parent_iface;
	gboolean (*expand_on_select) (SidebarExpandableEntry* self);
};

struct _Page {
	GtkScrolledWindow parent_instance;
	PagePrivate * priv;
	GtkUIManager* ui;
	GtkToolbar* toolbar;
	gboolean in_view;
};

struct _PageClass {
	GtkScrolledWindowClass parent_class;
	void (*set_page_name) (Page* self, const gchar* page_name);
	void (*set_container) (Page* self, GtkWindow* container);
	void (*clear_container) (Page* self);
	GtkMenuBar* (*get_menubar) (Page* self);
	GtkWidget* (*get_page_ui_widget) (Page* self, const gchar* path);
	GtkToolbar* (*get_toolbar) (Page* self);
	GtkMenu* (*get_page_context_menu) (Page* self);
	void (*switching_from) (Page* self);
	void (*switched_to) (Page* self);
	void (*ready) (Page* self);
	void (*switching_to_fullscreen) (Page* self, FullscreenWindow* fsw);
	void (*returning_from_fullscreen) (Page* self, FullscreenWindow* fsw);
	void (*init_collect_ui_filenames) (Page* self, GeeList* ui_filenames);
	GtkActionEntry* (*init_collect_action_entries) (Page* self, int* result_length1);
	GtkToggleActionEntry* (*init_collect_toggle_action_entries) (Page* self, int* result_length1);
	void (*register_radio_actions) (Page* self, GtkActionGroup* action_group);
	InjectionGroup** (*init_collect_injection_groups) (Page* self, int* result_length1);
	void (*init_actions) (Page* self, gint selected_count, gint count);
	void (*update_actions) (Page* self, gint selected_count, gint count);
	gboolean (*source_drag_failed) (Page* self, GdkDragContext* context, GtkDragResult drag_result);
	gboolean (*on_left_click) (Page* self, GdkEventButton* event);
	gboolean (*on_middle_click) (Page* self, GdkEventButton* event);
	gboolean (*on_right_click) (Page* self, GdkEventButton* event);
	gboolean (*on_left_released) (Page* self, GdkEventButton* event);
	gboolean (*on_middle_released) (Page* self, GdkEventButton* event);
	gboolean (*on_right_released) (Page* self, GdkEventButton* event);
	gboolean (*on_ctrl_pressed) (Page* self, GdkEventKey* event);
	gboolean (*on_ctrl_released) (Page* self, GdkEventKey* event);
	gboolean (*on_alt_pressed) (Page* self, GdkEventKey* event);
	gboolean (*on_alt_released) (Page* self, GdkEventKey* event);
	gboolean (*on_shift_pressed) (Page* self, GdkEventKey* event);
	gboolean (*on_shift_released) (Page* self, GdkEventKey* event);
	gboolean (*on_super_pressed) (Page* self, GdkEventKey* event);
	gboolean (*on_super_released) (Page* self, GdkEventKey* event);
	gboolean (*on_app_key_pressed) (Page* self, GdkEventKey* event);
	gboolean (*on_app_key_released) (Page* self, GdkEventKey* event);
	void (*on_move) (Page* self, GdkRectangle* rect);
	void (*on_move_start) (Page* self, GdkRectangle* rect);
	void (*on_move_finished) (Page* self, GdkRectangle* rect);
	void (*on_resize) (Page* self, GdkRectangle* rect);
	void (*on_resize_start) (Page* self, GdkRectangle* rect);
	void (*on_resize_finished) (Page* self, GdkRectangle* rect);
	gboolean (*on_configure) (Page* self, GdkEventConfigure* event, GdkRectangle* rect);
	gboolean (*on_motion) (Page* self, GdkEventMotion* event, gint x, gint y, GdkModifierType mask);
	gboolean (*on_leave_notify_event) (Page* self);
	gboolean (*on_mousewheel_up) (Page* self, GdkEventScroll* event);
	gboolean (*on_mousewheel_down) (Page* self, GdkEventScroll* event);
	gboolean (*on_mousewheel_left) (Page* self, GdkEventScroll* event);
	gboolean (*on_mousewheel_right) (Page* self, GdkEventScroll* event);
	gboolean (*on_context_keypress) (Page* self);
	gboolean (*on_context_buttonpress) (Page* self, GdkEventButton* event);
	gboolean (*on_context_invoked) (Page* self);
	void (*set_page_cursor) (Page* self, GdkCursorType cursor_type);
};

typedef enum  {
	SINGLE_PHOTO_PAGE_UPDATE_REASON_NEW_PIXBUF,
	SINGLE_PHOTO_PAGE_UPDATE_REASON_QUALITY_IMPROVEMENT,
	SINGLE_PHOTO_PAGE_UPDATE_REASON_RESIZED_CANVAS
} SinglePhotoPageUpdateReason;

struct _SinglePhotoPage {
	Page parent_instance;
	SinglePhotoPagePrivate * priv;
	GtkDrawingArea* canvas;
	GtkViewport* viewport;
};

struct _SinglePhotoPageClass {
	PageClass parent_class;
	gboolean (*is_zoom_supported) (SinglePhotoPage* self);
	void (*cancel_zoom) (SinglePhotoPage* self);
	void (*save_zoom_state) (SinglePhotoPage* self);
	void (*restore_zoom_state) (SinglePhotoPage* self);
	ZoomBuffer* (*get_zoom_buffer) (SinglePhotoPage* self);
	void (*new_surface) (SinglePhotoPage* self, cairo_t* ctx, Dimensions* ctx_dim);
	void (*updated_pixbuf) (SinglePhotoPage* self, GdkPixbuf* pixbuf, SinglePhotoPageUpdateReason reason, Dimensions* old_dim);
	void (*paint) (SinglePhotoPage* self, cairo_t* ctx, Dimensions* ctx_dim);
	void (*on_previous_photo) (SinglePhotoPage* self);
	void (*on_next_photo) (SinglePhotoPage* self);
};

struct _EditingHostPage {
	SinglePhotoPage parent_instance;
	EditingHostPagePrivate * priv;
};

struct _EditingHostPageClass {
	SinglePhotoPageClass parent_class;
	gboolean (*on_zoom_slider_key_press) (EditingHostPage* self, GdkEventKey* event);
	void (*on_increase_size) (EditingHostPage* self);
	void (*on_decrease_size) (EditingHostPage* self);
	void (*photo_changing) (EditingHostPage* self, Photo* new_photo);
	DataView* (*create_photo_view) (EditingHostPage* self, DataSource* source);
	void (*update_ui) (EditingHostPage* self, gboolean missing);
	void (*notify_photo_backing_missing) (EditingHostPage* self, Photo* photo, gboolean missing);
	gboolean (*confirm_replace_photo) (EditingHostPage* self, Photo* old_photo, Photo* new_photo);
	gboolean (*on_double_click) (EditingHostPage* self, GdkEventButton* event);
	GdkPixbuf* (*get_bottom_left_trinket) (EditingHostPage* self, gint scale);
	GdkPixbuf* (*get_top_left_trinket) (EditingHostPage* self, gint scale);
	GdkPixbuf* (*get_top_right_trinket) (EditingHostPage* self, gint scale);
	GdkPixbuf* (*get_bottom_right_trinket) (EditingHostPage* self, gint scale);
};

typedef enum  {
	RAW_DEVELOPER_SHOTWELL = 0,
	RAW_DEVELOPER_CAMERA,
	RAW_DEVELOPER_EMBEDDED
} RawDeveloper;

struct _LibraryPhotoPage {
	EditingHostPage parent_instance;
	LibraryPhotoPagePrivate * priv;
};

struct _LibraryPhotoPageClass {
	EditingHostPageClass parent_class;
	void (*developer_changed) (LibraryPhotoPage* self, RawDeveloper rd);
};

struct _LibraryWindowFullscreenPhotoPage {
	LibraryPhotoPage parent_instance;
	LibraryWindowFullscreenPhotoPagePrivate * priv;
};

struct _LibraryWindowFullscreenPhotoPageClass {
	LibraryPhotoPageClass parent_class;
};

struct _LibraryWindowFullscreenPhotoPagePrivate {
	CollectionPage* collection;
	Photo* start;
	ViewCollection* view;
};


static gpointer library_window_parent_class = NULL;
static GeeHashSet* library_window_initial_camera_uris;
static GeeHashSet* library_window_initial_camera_uris = NULL;
extern AppWindow* app_window_instance;
extern LibraryPhotoSourceCollection* library_photo_global;
extern VideoSourceCollection* video_global;
static gpointer library_window_fullscreen_photo_page_parent_class = NULL;

GType page_window_get_type (void) G_GNUC_CONST;
GType page_get_type (void) G_GNUC_CONST;
GType app_window_get_type (void) G_GNUC_CONST;
GType dimensions_get_type (void) G_GNUC_CONST;
Dimensions* dimensions_dup (const Dimensions* self);
void dimensions_free (Dimensions* self);
GType library_window_get_type (void) G_GNUC_CONST;
gpointer one_shot_scheduler_ref (gpointer instance);
void one_shot_scheduler_unref (gpointer instance);
GParamSpec* param_spec_one_shot_scheduler (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_one_shot_scheduler (GValue* value, gpointer v_object);
void value_take_one_shot_scheduler (GValue* value, gpointer v_object);
gpointer value_get_one_shot_scheduler (const GValue* value);
GType one_shot_scheduler_get_type (void) G_GNUC_CONST;
GType sidebar_tree_get_type (void) G_GNUC_CONST;
GType sidebar_branch_get_type (void) G_GNUC_CONST;
GType library_branch_get_type (void) G_GNUC_CONST;
GType tags_branch_get_type (void) G_GNUC_CONST;
GType folders_branch_get_type (void) G_GNUC_CONST;
GType events_branch_get_type (void) G_GNUC_CONST;
GType camera_branch_get_type (void) G_GNUC_CONST;
GType searches_branch_get_type (void) G_GNUC_CONST;
GType sidebar_entry_get_type (void) G_GNUC_CONST;
GType single_photo_page_get_type (void) G_GNUC_CONST;
GType editing_host_page_get_type (void) G_GNUC_CONST;
GType library_photo_page_get_type (void) G_GNUC_CONST;
gpointer search_filter_actions_ref (gpointer instance);
void search_filter_actions_unref (gpointer instance);
GParamSpec* param_spec_search_filter_actions (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_search_filter_actions (GValue* value, gpointer v_object);
void value_take_search_filter_actions (GValue* value, gpointer v_object);
gpointer value_get_search_filter_actions (const GValue* value);
GType search_filter_actions_get_type (void) G_GNUC_CONST;
GType search_filter_toolbar_get_type (void) G_GNUC_CONST;
GType properties_get_type (void) G_GNUC_CONST;
GType basic_properties_get_type (void) G_GNUC_CONST;
GType extended_properties_window_get_type (void) G_GNUC_CONST;
#define LIBRARY_WINDOW_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_LIBRARY_WINDOW, LibraryWindowPrivate))
enum  {
	LIBRARY_WINDOW_DUMMY_PROPERTY
};
GType sidebar_selectable_entry_get_type (void) G_GNUC_CONST;
GType sidebar_page_representative_get_type (void) G_GNUC_CONST;
static void library_window_on_page_created (LibraryWindow* self, SidebarPageRepresentative* entry, Page* page);
static void _library_window_on_page_created_sidebar_tree_page_created (SidebarTree* _sender, SidebarPageRepresentative* entry, Page* page, gpointer self);
static void library_window_on_destroying_page (LibraryWindow* self, SidebarPageRepresentative* entry, Page* page);
static void _library_window_on_destroying_page_sidebar_tree_destroying_page (SidebarTree* _sender, SidebarPageRepresentative* entry, Page* page, gpointer self);
static void library_window_on_sidebar_entry_selected (LibraryWindow* self, SidebarSelectableEntry* selectable);
static void _library_window_on_sidebar_entry_selected_sidebar_tree_entry_selected (SidebarTree* _sender, SidebarSelectableEntry* selectable, gpointer self);
static void library_window_on_sidebar_selected_entry_removed (LibraryWindow* self, SidebarSelectableEntry* selectable);
static void _library_window_on_sidebar_selected_entry_removed_sidebar_tree_selected_entry_removed (SidebarTree* _sender, SidebarSelectableEntry* removed, gpointer self);
static void library_window_unsubscribe_from_basic_information (LibraryWindow* self, Page* page);
Page* page_window_get_current_page (PageWindow* self);
static void library_window_hide_extended_properties (LibraryWindow* self);
static void _library_window_hide_extended_properties_gtk_widget_hide (GtkWidget* _sender, gpointer self);
static void library_window_show_extended_properties (LibraryWindow* self);
static void _library_window_show_extended_properties_gtk_widget_show (GtkWidget* _sender, gpointer self);
gpointer data_collection_ref (gpointer instance);
void data_collection_unref (gpointer instance);
GParamSpec* param_spec_data_collection (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_data_collection (GValue* value, gpointer v_object);
void value_take_data_collection (GValue* value, gpointer v_object);
gpointer value_get_data_collection (const GValue* value);
GType data_collection_get_type (void) G_GNUC_CONST;
GType source_collection_get_type (void) G_GNUC_CONST;
GType database_source_collection_get_type (void) G_GNUC_CONST;
GType media_source_collection_get_type (void) G_GNUC_CONST;
gpointer media_collection_registry_ref (gpointer instance);
void media_collection_registry_unref (gpointer instance);
GParamSpec* param_spec_media_collection_registry (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_media_collection_registry (GValue* value, gpointer v_object);
void value_take_media_collection_registry (GValue* value, gpointer v_object);
gpointer value_get_media_collection_registry (const GValue* value);
GType media_collection_registry_get_type (void) G_GNUC_CONST;
MediaCollectionRegistry* media_collection_registry_get_instance (void);
GeeCollection* media_collection_registry_get_all (MediaCollectionRegistry* self);
static void library_window_on_trashcan_contents_altered (LibraryWindow* self);
GType data_object_get_type (void) G_GNUC_CONST;
GType data_source_get_type (void) G_GNUC_CONST;
GType thumbnail_source_get_type (void) G_GNUC_CONST;
GType media_source_get_type (void) G_GNUC_CONST;
static void _library_window_on_trashcan_contents_altered_media_source_collection_trashcan_contents_altered (MediaSourceCollection* _sender, GeeCollection* added, GeeCollection* removed, gpointer self);
static void library_window_on_media_altered (LibraryWindow* self);
gpointer alteration_ref (gpointer instance);
void alteration_unref (gpointer instance);
GParamSpec* param_spec_alteration (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_alteration (GValue* value, gpointer v_object);
void value_take_alteration (GValue* value, gpointer v_object);
gpointer value_get_alteration (const GValue* value);
GType alteration_get_type (void) G_GNUC_CONST;
static void _library_window_on_media_altered_data_collection_items_altered (DataCollection* _sender, GeeMap* items, gpointer self);
GType metadata_writer_get_type (void) G_GNUC_CONST;
MetadataWriter* metadata_writer_get_instance (void);
static void library_window_on_metadata_writer_progress (LibraryWindow* self, guint completed, guint total);
static void _library_window_on_metadata_writer_progress_metadata_writer_progress (MetadataWriter* _sender, guint completed, guint total, gpointer self);
GType directory_monitor_get_type (void) G_GNUC_CONST;
GType library_monitor_get_type (void) G_GNUC_CONST;
gpointer library_monitor_pool_ref (gpointer instance);
void library_monitor_pool_unref (gpointer instance);
GParamSpec* param_spec_library_monitor_pool (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_library_monitor_pool (GValue* value, gpointer v_object);
void value_take_library_monitor_pool (GValue* value, gpointer v_object);
gpointer value_get_library_monitor_pool (const GValue* value);
GType library_monitor_pool_get_type (void) G_GNUC_CONST;
LibraryMonitorPool* library_monitor_pool_get_instance (void);
LibraryMonitor* library_monitor_pool_get_monitor (LibraryMonitorPool* self);
static void library_window_on_library_monitor_destroyed (LibraryWindow* self, LibraryMonitor* monitor);
static void library_window_on_library_monitor_installed (LibraryWindow* self, LibraryMonitor* monitor);
static void _library_window_on_library_monitor_installed_library_monitor_pool_monitor_installed (LibraryMonitorPool* _sender, LibraryMonitor* monitor, gpointer self);
static void _library_window_on_library_monitor_destroyed_library_monitor_pool_monitor_destroyed (LibraryMonitorPool* _sender, LibraryMonitor* monitor, gpointer self);
gpointer camera_table_ref (gpointer instance);
void camera_table_unref (gpointer instance);
GParamSpec* param_spec_camera_table (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_camera_table (GValue* value, gpointer v_object);
void value_take_camera_table (GValue* value, gpointer v_object);
gpointer value_get_camera_table (const GValue* value);
GType camera_table_get_type (void) G_GNUC_CONST;
CameraTable* camera_table_get_instance (void);
gpointer discovered_camera_ref (gpointer instance);
void discovered_camera_unref (gpointer instance);
GParamSpec* param_spec_discovered_camera (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_discovered_camera (GValue* value, gpointer v_object);
void value_take_discovered_camera (GValue* value, gpointer v_object);
gpointer value_get_discovered_camera (const GValue* value);
GType discovered_camera_get_type (void) G_GNUC_CONST;
static void library_window_on_camera_added (LibraryWindow* self, DiscoveredCamera* camera);
static void _library_window_on_camera_added_camera_table_camera_added (CameraTable* _sender, DiscoveredCamera* camera, gpointer self);
static GType library_window_sidebar_root_position_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
GType library_window_target_type_get_type (void) G_GNUC_CONST;
LibraryBranch* library_branch_new (void);
LibraryBranch* library_branch_construct (GType object_type);
TagsBranch* tags_branch_new (void);
TagsBranch* tags_branch_construct (GType object_type);
FoldersBranch* folders_branch_new (void);
FoldersBranch* folders_branch_construct (GType object_type);
EventsBranch* events_branch_new (void);
EventsBranch* events_branch_construct (GType object_type);
CameraBranch* camera_branch_new (void);
CameraBranch* camera_branch_construct (GType object_type);
SearchesBranch* searches_branch_new (void);
SearchesBranch* searches_branch_construct (GType object_type);
SearchFilterActions* search_filter_actions_new (void);
SearchFilterActions* search_filter_actions_construct (GType object_type);
BasicProperties* basic_properties_new (void);
BasicProperties* basic_properties_construct (GType object_type);
#define LIBRARY_WINDOW_SIDEBAR_MIN_WIDTH 120
#define LIBRARY_WINDOW_SORT_EVENTS_ORDER_ASCENDING 0
#define LIBRARY_WINDOW_SORT_EVENTS_ORDER_DESCENDING 1
#define LIBRARY_WINDOW_BACKGROUND_PROGRESS_PULSE_MSEC 250
#define LIBRARY_WINDOW_MIN_PROGRESS_BAR_FILES 20
#define LIBRARY_WINDOW_STARTUP_SCAN_PROGRESS_PRIORITY 35
#define LIBRARY_WINDOW_REALTIME_UPDATE_PROGRESS_PRIORITY 40
#define LIBRARY_WINDOW_REALTIME_IMPORT_PROGRESS_PRIORITY 50
#define LIBRARY_WINDOW_METADATA_WRITER_PROGRESS_PRIORITY 30
#define LIBRARY_WINDOW_TAG_PATH_MIME_TYPE "shotwell/tag-path"
#define LIBRARY_WINDOW_MEDIA_LIST_MIME_TYPE "shotwell/media-id-atom"
LibraryWindow* library_window_new (ProgressMonitor progress_monitor, void* progress_monitor_target);
LibraryWindow* library_window_construct (GType object_type, ProgressMonitor progress_monitor, void* progress_monitor_target);
AppWindow* app_window_construct (GType object_type);
static void library_window_external_drop_handler (LibraryWindow* self, GdkDragContext* context, SidebarEntry* entry, GtkSelectionData* data, guint info, guint time);
static void _library_window_external_drop_handler_sidebar_tree_external_drop_handler (GdkDragContext* context, SidebarEntry* entry, GtkSelectionData* data, guint info, guint time, gpointer self);
SidebarTree* sidebar_tree_new (GtkTargetEntry* target_entries, int target_entries_length1, GdkDragAction actions, SidebarTreeExternalDropHandler drop_handler, void* drop_handler_target);
SidebarTree* sidebar_tree_construct (GType object_type, GtkTargetEntry* target_entries, int target_entries_length1, GdkDragAction actions, SidebarTreeExternalDropHandler drop_handler, void* drop_handler_target);
void sidebar_tree_graft (SidebarTree* self, SidebarBranch* branch, gint position);
ExtendedPropertiesWindow* extended_properties_window_new (GtkWindow* owner);
ExtendedPropertiesWindow* extended_properties_window_construct (GType object_type, GtkWindow* owner);
static void library_window_on_update_properties_now (LibraryWindow* self);
static void _library_window_on_update_properties_now_one_shot_callback (gpointer self);
OneShotScheduler* one_shot_scheduler_new (const gchar* name, OneShotCallback callback, void* callback_target);
OneShotScheduler* one_shot_scheduler_construct (GType object_type, const gchar* name, OneShotCallback callback, void* callback_target);
SearchFilterToolbar* search_filter_toolbar_new (SearchFilterActions* actions);
SearchFilterToolbar* search_filter_toolbar_construct (GType object_type, SearchFilterActions* actions);
GFile* resources_get_ui (const gchar* filename);
static void library_window_create_layout (LibraryWindow* self, Page* start_page);
GType sidebar_simple_page_entry_get_type (void) G_GNUC_CONST;
GType library_photos_entry_get_type (void) G_GNUC_CONST;
LibraryPhotosEntry* library_branch_get_photos_entry (LibraryBranch* self);
Page* sidebar_page_representative_get_page (SidebarPageRepresentative* self);
static void library_window_load_configuration (LibraryWindow* self);
GFile* directory_monitor_get_root (DirectoryMonitor* self);
static void library_window_on_library_monitor_discovery_started (LibraryWindow* self);
static void _library_window_on_library_monitor_discovery_started_directory_monitor_discovery_started (DirectoryMonitor* _sender, gpointer self);
static void library_window_on_library_monitor_discovery_completed (LibraryWindow* self);
static void _library_window_on_library_monitor_discovery_completed_directory_monitor_discovery_completed (DirectoryMonitor* _sender, gpointer self);
static void _library_window_on_library_monitor_discovery_completed_directory_monitor_closed (DirectoryMonitor* _sender, gpointer self);
static void library_window_on_library_monitor_auto_update_progress (LibraryWindow* self, gint completed_files, gint total_files);
static void _library_window_on_library_monitor_auto_update_progress_library_monitor_auto_update_progress (LibraryMonitor* _sender, gint completed_files, gint total_files, gpointer self);
static void library_window_on_library_monitor_auto_import_preparing (LibraryWindow* self);
static void _library_window_on_library_monitor_auto_import_preparing_library_monitor_auto_import_preparing (LibraryMonitor* _sender, gpointer self);
static void library_window_on_library_monitor_auto_import_progress (LibraryWindow* self, guint64 completed_bytes, guint64 total_bytes);
static void _library_window_on_library_monitor_auto_import_progress_library_monitor_auto_import_progress (LibraryMonitor* _sender, guint64 completed_bytes, guint64 total_bytes, gpointer self);
static GtkActionEntry* library_window_create_common_actions (LibraryWindow* self, int* result_length1);
#define RESOURCES_IMPORT "shotwell-import"
#define TRANSLATABLE "translatable"
static void library_window_on_file_import (LibraryWindow* self);
static void _library_window_on_file_import_gtk_action_callback (GtkAction* action, gpointer self);
static void _vala_array_add61 (GtkActionEntry** array, int* length, int* size, const GtkActionEntry* value);
static void library_window_on_external_library_import (LibraryWindow* self);
static void _library_window_on_external_library_import_gtk_action_callback (GtkAction* action, gpointer self);
static void _vala_array_add62 (GtkActionEntry** array, int* length, int* size, const GtkActionEntry* value);
static void _vala_array_add63 (GtkActionEntry** array, int* length, int* size, const GtkActionEntry* value);
#define RESOURCES_PREFERENCES_LABEL _ ("_Preferences")
static void library_window_on_preferences (LibraryWindow* self);
static void _library_window_on_preferences_gtk_action_callback (GtkAction* action, gpointer self);
#define RESOURCES_PREFERENCES_MENU _ ("_Preferences")
static void _vala_array_add64 (GtkActionEntry** array, int* length, int* size, const GtkActionEntry* value);
static void library_window_on_empty_trash (LibraryWindow* self);
static void _library_window_on_empty_trash_gtk_action_callback (GtkAction* action, gpointer self);
static void _vala_array_add65 (GtkActionEntry** array, int* length, int* size, const GtkActionEntry* value);
static void library_window_on_jump_to_event (LibraryWindow* self);
static void _library_window_on_jump_to_event_gtk_action_callback (GtkAction* action, gpointer self);
static void _vala_array_add66 (GtkActionEntry** array, int* length, int* size, const GtkActionEntry* value);
static void library_window_on_find (LibraryWindow* self);
static void _library_window_on_find_gtk_action_callback (GtkAction* action, gpointer self);
static void _vala_array_add67 (GtkActionEntry** array, int* length, int* size, const GtkActionEntry* value);
#define RESOURCES_FILTER_PHOTOS_MENU _ ("_Filter Photos")
static void _vala_array_add68 (GtkActionEntry** array, int* length, int* size, const GtkActionEntry* value);
static void library_window_on_new_search (LibraryWindow* self);
static void _library_window_on_new_search_gtk_action_callback (GtkAction* action, gpointer self);
static void _vala_array_add69 (GtkActionEntry** array, int* length, int* size, const GtkActionEntry* value);
static void _vala_array_add70 (GtkActionEntry** array, int* length, int* size, const GtkActionEntry* value);
static void _vala_array_add71 (GtkActionEntry** array, int* length, int* size, const GtkActionEntry* value);
static void _vala_array_add72 (GtkActionEntry** array, int* length, int* size, const GtkActionEntry* value);
static void _vala_array_add73 (GtkActionEntry** array, int* length, int* size, const GtkActionEntry* value);
static void _vala_array_add74 (GtkActionEntry** array, int* length, int* size, const GtkActionEntry* value);
static void _vala_array_add75 (GtkActionEntry** array, int* length, int* size, const GtkActionEntry* value);
static void _vala_array_add76 (GtkActionEntry** array, int* length, int* size, const GtkActionEntry* value);
static void _vala_array_add77 (GtkActionEntry** array, int* length, int* size, const GtkActionEntry* value);
static GtkToggleActionEntry* library_window_create_common_toggle_actions (LibraryWindow* self, int* result_length1);
static void library_window_on_display_basic_properties (LibraryWindow* self, GtkAction* action);
static void _library_window_on_display_basic_properties_gtk_action_callback (GtkAction* action, gpointer self);
static void _vala_array_add78 (GtkToggleActionEntry** array, int* length, int* size, const GtkToggleActionEntry* value);
static void library_window_on_display_extended_properties (LibraryWindow* self, GtkAction* action);
static void _library_window_on_display_extended_properties_gtk_action_callback (GtkAction* action, gpointer self);
static void _vala_array_add79 (GtkToggleActionEntry** array, int* length, int* size, const GtkToggleActionEntry* value);
static void library_window_on_display_searchbar (LibraryWindow* self, GtkAction* action);
static void _library_window_on_display_searchbar_gtk_action_callback (GtkAction* action, gpointer self);
static void _vala_array_add80 (GtkToggleActionEntry** array, int* length, int* size, const GtkToggleActionEntry* value);
static void library_window_on_display_sidebar (LibraryWindow* self, GtkAction* action);
static void _library_window_on_display_sidebar_gtk_action_callback (GtkAction* action, gpointer self);
static gboolean library_window_is_sidebar_visible (LibraryWindow* self);
static void _vala_array_add81 (GtkToggleActionEntry** array, int* length, int* size, const GtkToggleActionEntry* value);
static void library_window_on_display_toolbar (LibraryWindow* self, GtkAction* action);
static void _library_window_on_display_toolbar_gtk_action_callback (GtkAction* action, gpointer self);
static gboolean library_window_is_toolbar_visible (LibraryWindow* self);
static void _vala_array_add82 (GtkToggleActionEntry** array, int* length, int* size, const GtkToggleActionEntry* value);
static void library_window_add_common_radio_actions (LibraryWindow* self, GtkActionGroup* group);
#define RESOURCES_SORT_ASCENDING_LABEL _ ("Sort _Ascending")
static void _vala_array_add83 (GtkRadioActionEntry** array, int* length, int* size, const GtkRadioActionEntry* value);
#define RESOURCES_SORT_DESCENDING_LABEL _ ("Sort _Descending")
static void _vala_array_add84 (GtkRadioActionEntry** array, int* length, int* size, const GtkRadioActionEntry* value);
static void library_window_on_events_sort_changed (LibraryWindow* self, GtkAction* action, GtkAction* c);
static void _library_window_on_events_sort_changed_gtk_radio_action_callback (GtkAction* action, GtkAction* current, gpointer self);
static GtkActionGroup** library_window_real_create_common_action_groups (AppWindow* base, int* result_length1);
GtkActionGroup** app_window_create_common_action_groups (AppWindow* self, int* result_length1);
#define RESOURCES_FIND_LABEL _ ("Find")
static void _vala_array_add85 (GtkActionGroup*** array, int* length, int* size, GtkActionGroup* value);
GtkActionGroup* search_filter_actions_get_action_group (SearchFilterActions* self);
static void _vala_array_add86 (GtkActionGroup*** array, int* length, int* size, GtkActionGroup* value);
static void library_window_real_replace_common_placeholders (AppWindow* base, GtkUIManager* ui);
void app_window_replace_common_placeholders (AppWindow* self, GtkUIManager* ui);
static void library_window_real_switched_pages (PageWindow* base, Page* old_page, Page* new_page);
void page_window_switched_pages (PageWindow* self, Page* old_page, Page* new_page);
GType view_collection_get_type (void) G_GNUC_CONST;
ViewCollection* page_get_view (Page* self);
gpointer view_filter_ref (gpointer instance);
void view_filter_unref (gpointer instance);
GParamSpec* param_spec_view_filter (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_view_filter (GValue* value, gpointer v_object);
void value_take_view_filter (GValue* value, gpointer v_object);
gpointer value_get_view_filter (const GValue* value);
GType view_filter_get_type (void) G_GNUC_CONST;
static void library_window_on_view_filter_installed (LibraryWindow* self, ViewFilter* filter);
static void _library_window_on_view_filter_installed_view_collection_view_filter_installed (ViewCollection* _sender, ViewFilter* filer, gpointer self);
static void library_window_on_view_filter_removed (LibraryWindow* self, ViewFilter* filter);
static void _library_window_on_view_filter_removed_view_collection_view_filter_removed (ViewCollection* _sender, ViewFilter* filer, gpointer self);
void search_filter_actions_monitor_page_contents (SearchFilterActions* self, Page* old_page, Page* new_page);
static void library_window_on_view_filter_refreshed (LibraryWindow* self);
static void _library_window_on_view_filter_refreshed_view_filter_refresh (ViewFilter* _sender, gpointer self);
gboolean view_collection_are_items_filtered_out (ViewCollection* self);
GtkAction* app_window_get_common_action (AppWindow* self, const gchar* name);
static void library_window_real_show_all (GtkWidget* base);
GtkAction* page_get_common_action (Page* self, const gchar* name, gboolean log_warning);
GType checkerboard_page_get_type (void) G_GNUC_CONST;
static void library_window_init_view_filter (LibraryWindow* self, CheckerboardPage* page);
static void library_window_toggle_search_bar (LibraryWindow* self, gboolean show, CheckerboardPage* page);
static gboolean library_window_should_show_search_bar (LibraryWindow* self);
static void library_window_set_sidebar_visible (LibraryWindow* self, gboolean visible);
LibraryWindow* library_window_get_app (void);
gboolean library_window_is_mount_uri_supported (const gchar* uri);
static gchar* library_window_real_get_app_role (AppWindow* base);
#define RESOURCES_APP_LIBRARY_ROLE _ ("Photo Manager")
GType tag_get_type (void) G_GNUC_CONST;
void library_window_rename_tag_in_sidebar (LibraryWindow* self, Tag* tag);
GType tags_sidebar_entry_get_type (void) G_GNUC_CONST;
TagsSidebarEntry* tags_branch_get_entry_for_tag (TagsBranch* self, Tag* tag);
gboolean sidebar_tree_rename_entry_in_place (SidebarTree* self, SidebarEntry* entry);
GType event_source_get_type (void) G_GNUC_CONST;
GType event_get_type (void) G_GNUC_CONST;
void library_window_rename_event_in_sidebar (LibraryWindow* self, Event* event);
GType events_event_entry_get_type (void) G_GNUC_CONST;
EventsEventEntry* events_branch_get_entry_for_event (EventsBranch* self, Event* event);
GType saved_search_get_type (void) G_GNUC_CONST;
void library_window_rename_search_in_sidebar (LibraryWindow* self, SavedSearch* search);
GType searches_sidebar_entry_get_type (void) G_GNUC_CONST;
SearchesSidebarEntry* searches_branch_get_entry_for_saved_search (SearchesBranch* self, SavedSearch* search);
static void library_window_real_on_quit (AppWindow* base);
GType configuration_facade_get_type (void) G_GNUC_CONST;
GType config_facade_get_type (void) G_GNUC_CONST;
ConfigFacade* config_facade_get_instance (void);
void configuration_facade_set_library_window_state (ConfigurationFacade* self, gboolean maximize, Dimensions* dimensions);
void configuration_facade_set_sidebar_position (ConfigurationFacade* self, gint position);
void app_window_on_quit (AppWindow* self);
GType media_page_get_type (void) G_GNUC_CONST;
GType collection_page_get_type (void) G_GNUC_CONST;
GType photo_source_get_type (void) G_GNUC_CONST;
GType photo_get_type (void) G_GNUC_CONST;
static Photo* library_window_get_start_fullscreen_photo (LibraryWindow* self, CollectionPage* page);
gint view_collection_get_selected_count (ViewCollection* self);
GeeList* view_collection_get_selected_sources_of_type (ViewCollection* self, GType t);
GType library_photo_get_type (void) G_GNUC_CONST;
GeeList* view_collection_get_sources_of_type (ViewCollection* self, GType t);
static gboolean library_window_get_fullscreen_photo (LibraryWindow* self, Page* page, CollectionPage** collection, Photo** start, ViewCollection** view_collection);
GType events_directory_page_get_type (void) G_GNUC_CONST;
gint data_collection_get_count (DataCollection* self);
DataObject* data_collection_get_at (DataCollection* self, gint index);
GType data_view_get_type (void) G_GNUC_CONST;
DataSource* data_view_get_source (DataView* self);
GType event_page_get_type (void) G_GNUC_CONST;
CollectionPage* library_photo_page_get_controller_page (LibraryPhotoPage* self);
gboolean editing_host_page_has_photo (EditingHostPage* self);
Photo* editing_host_page_get_photo (EditingHostPage* self);
static void library_window_real_on_fullscreen (AppWindow* base);
static GType library_window_fullscreen_photo_page_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
static LibraryWindowFullscreenPhotoPage* library_window_fullscreen_photo_page_new (CollectionPage* collection, Photo* start, ViewCollection* view);
static LibraryWindowFullscreenPhotoPage* library_window_fullscreen_photo_page_construct (GType object_type, CollectionPage* collection, Photo* start, ViewCollection* view);
void app_window_go_fullscreen (AppWindow* self, Page* page);
#define RESOURCES_CANCEL_LABEL _ ("_Cancel")
#define RESOURCES_OK_LABEL _ ("_OK")
gboolean app_dirs_is_in_import_dir (GFile* file);
GtkResponseType copy_files_dialog (void);
static void library_window_dispatch_import_jobs (LibraryWindow* self, GSList* uris, const gchar* job_name, gboolean copy_to_library);
static void _g_free0_ (gpointer var);
static void _g_slist_free__g_free0_ (GSList* self);
GType data_imports_ui_data_imports_dialog_get_type (void) G_GNUC_CONST;
DataImportsUIDataImportsDialog* data_imports_ui_data_imports_dialog_get_or_create_instance (void);
static void library_window_real_update_common_action_availability (AppWindow* base, Page* old_page, Page* new_page);
void app_window_update_common_action_availability (AppWindow* self, Page* old_page, Page* new_page);
void app_window_set_common_action_sensitive (AppWindow* self, const gchar* name, gboolean sensitive);
static void library_window_real_update_common_actions (AppWindow* base, Page* page, gint selected_count, gint count);
static gboolean library_window_can_empty_trash (LibraryWindow* self);
void app_window_set_common_action_visible (AppWindow* self, const gchar* name, gboolean visible);
static gboolean library_window_can_jump_to_event (LibraryWindow* self);
void app_window_update_common_actions (AppWindow* self, Page* page, gint selected_count, gint count);
GType library_photo_source_collection_get_type (void) G_GNUC_CONST;
gint media_source_collection_get_trashcan_count (MediaSourceCollection* self);
GType video_source_collection_get_type (void) G_GNUC_CONST;
GeeCollection* media_source_collection_get_trashcan_contents (MediaSourceCollection* self);
void remove_from_app (GeeCollection* sources, const gchar* dialog_title, const gchar* progress_dialog_text);
gpointer command_manager_ref (gpointer instance);
void command_manager_unref (gpointer instance);
GParamSpec* param_spec_command_manager (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_command_manager (GValue* value, gpointer v_object);
void value_take_command_manager (GValue* value, gpointer v_object);
gpointer value_get_command_manager (const GValue* value);
GType command_manager_get_type (void) G_GNUC_CONST;
CommandManager* app_window_get_command_manager (void);
void command_manager_reset (CommandManager* self);
SavedSearchDialog* saved_search_dialog_new (void);
SavedSearchDialog* saved_search_dialog_construct (GType object_type);
gpointer saved_search_dialog_ref (gpointer instance);
void saved_search_dialog_unref (gpointer instance);
GParamSpec* param_spec_saved_search_dialog (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_saved_search_dialog (GValue* value, gpointer v_object);
void value_take_saved_search_dialog (GValue* value, gpointer v_object);
gpointer value_get_saved_search_dialog (const GValue* value);
GType saved_search_dialog_get_type (void) G_GNUC_CONST;
void saved_search_dialog_show (SavedSearchDialog* self);
DataSource* view_collection_get_selected_source_at (ViewCollection* self, gint index);
Event* media_source_get_event (MediaSource* self);
void library_window_switch_to_event (LibraryWindow* self, Event* event);
void search_filter_toolbar_take_focus (SearchFilterToolbar* self);
static void library_window_on_clear_search (LibraryWindow* self);
void search_filter_actions_reset (SearchFilterActions* self);
gint library_window_get_events_sort (LibraryWindow* self);
void configuration_facade_set_events_sort_ascending (ConfigurationFacade* self, gboolean sort);
void preferences_dialog_show (void);
void properties_update_properties (Properties* self, Page* page);
void configuration_facade_set_display_basic_properties (ConfigurationFacade* self, gboolean display);
void extended_properties_window_update_properties (ExtendedPropertiesWindow* self, Page* page);
void configuration_facade_set_display_search_bar (ConfigurationFacade* self, gboolean display);
void library_window_show_search_bar (LibraryWindow* self, gboolean display);
void configuration_facade_set_display_sidebar (ConfigurationFacade* self, gboolean display);
gboolean configuration_facade_get_display_sidebar (ConfigurationFacade* self);
static void library_window_set_toolbar_visible (LibraryWindow* self, gboolean visible);
GtkToolbar* page_get_toolbar (Page* self);
void configuration_facade_set_display_toolbar (ConfigurationFacade* self, gboolean display);
gboolean configuration_facade_get_display_toolbar (ConfigurationFacade* self);
static void library_window_sync_extended_properties (LibraryWindow* self, gboolean show);
void configuration_facade_set_display_extended_properties (ConfigurationFacade* self, gboolean display);
GType batch_import_get_type (void) G_GNUC_CONST;
void library_window_enqueue_batch_import (LibraryWindow* self, BatchImport* batch_import, gboolean allow_user_cancel);
GType library_hideable_page_entry_get_type (void) G_GNUC_CONST;
GType library_import_queue_sidebar_entry_get_type (void) G_GNUC_CONST;
LibraryImportQueueSidebarEntry* library_branch_get_import_queue_entry (LibraryBranch* self);
void library_import_queue_sidebar_entry_enqueue_and_schedule (LibraryImportQueueSidebarEntry* self, BatchImport* batch_import, gboolean allow_user_cancel);
gpointer import_manifest_ref (gpointer instance);
void import_manifest_unref (gpointer instance);
GParamSpec* param_spec_import_manifest (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_import_manifest (GValue* value, gpointer v_object);
void value_take_import_manifest (GValue* value, gpointer v_object);
gpointer value_get_import_manifest (const GValue* value);
GType import_manifest_get_type (void) G_GNUC_CONST;
static void library_window_import_reporter (LibraryWindow* self, ImportManifest* manifest);
gpointer import_ui_question_params_ref (gpointer instance);
void import_ui_question_params_unref (gpointer instance);
GParamSpec* import_ui_param_spec_question_params (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void import_ui_value_set_question_params (GValue* value, gpointer v_object);
void import_ui_value_take_question_params (GValue* value, gpointer v_object);
gpointer import_ui_value_get_question_params (const GValue* value);
GType import_ui_question_params_get_type (void) G_GNUC_CONST;
gboolean import_ui_report_manifest (ImportManifest* manifest, gboolean show_dest_id, ImportUIQuestionParams* question);
GFile* app_dirs_get_import_dir (void);
GtkResponseType app_window_affirm_cancel_question (const gchar* message, const gchar* affirmative, const gchar* title, GtkWindow* parent);
AppWindow* app_window_get_instance (void);
gpointer batch_import_job_ref (gpointer instance);
void batch_import_job_unref (gpointer instance);
GParamSpec* param_spec_batch_import_job (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_batch_import_job (GValue* value, gpointer v_object);
void value_take_batch_import_job (GValue* value, gpointer v_object);
gpointer value_get_batch_import_job (const GValue* value);
GType batch_import_job_get_type (void) G_GNUC_CONST;
GType file_import_job_get_type (void) G_GNUC_CONST;
void app_window_error_message (const gchar* message, GtkWindow* parent);
FileImportJob* file_import_job_new (GFile* file_or_dir, gboolean copy_to_library);
FileImportJob* file_import_job_construct (GType object_type, GFile* file_or_dir, gboolean copy_to_library);
gpointer batch_import_roll_ref (gpointer instance);
void batch_import_roll_unref (gpointer instance);
GParamSpec* param_spec_batch_import_roll (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_batch_import_roll (GValue* value, gpointer v_object);
void value_take_batch_import_roll (GValue* value, gpointer v_object);
gpointer value_get_batch_import_roll (const GValue* value);
GType batch_import_roll_get_type (void) G_GNUC_CONST;
static void _library_window_import_reporter_batch_import_import_reporter (ImportManifest* manifest, BatchImportRoll* import_roll, gpointer self);
BatchImport* batch_import_new (GeeIterable* jobs, const gchar* name, BatchImportImportReporter reporter, void* reporter_target, GeeArrayList* prefailed, GeeArrayList* pre_already_imported, GCancellable* cancellable, BatchImportRoll* import_roll, ImportManifest* skip_manifest);
BatchImport* batch_import_construct (GType object_type, GeeIterable* jobs, const gchar* name, BatchImportImportReporter reporter, void* reporter_target, GeeArrayList* prefailed, GeeArrayList* pre_already_imported, GCancellable* cancellable, BatchImportRoll* import_roll, ImportManifest* skip_manifest);
void library_window_switch_to_import_queue_page (LibraryWindow* self);
static GdkDragAction library_window_get_drag_action (LibraryWindow* self);
static gboolean library_window_real_drag_motion (GtkWidget* base, GdkDragContext* context, gint x, gint y, guint time);
static void library_window_real_drag_data_received (GtkWidget* base, GdkDragContext* context, gint x, gint y, GtkSelectionData* selection_data, guint info, guint time);
void library_window_switch_to_library_page (LibraryWindow* self);
void library_window_switch_to_page (LibraryWindow* self, Page* page);
void library_window_switch_to_tag (LibraryWindow* self, Tag* tag);
void library_window_switch_to_saved_search (LibraryWindow* self, SavedSearch* search);
void library_window_switch_to_photo_page (LibraryWindow* self, CollectionPage* controller, Photo* current);
DataView* view_collection_get_view_for_source (ViewCollection* self, DataSource* source);
LibraryPhotoPage* library_photo_page_new (void);
LibraryPhotoPage* library_photo_page_construct (GType object_type);
void library_window_add_to_stack (LibraryWindow* self, Page* page);
void spin_event_loop (void);
void library_photo_page_display_for_collection (LibraryPhotoPage* self, CollectionPage* return_page, Photo* photo, ViewCollection* view);
GType camera_sidebar_entry_get_type (void) G_GNUC_CONST;
CameraSidebarEntry* camera_branch_get_entry_for_camera (CameraBranch* self, DiscoveredCamera* camera);
GType import_page_get_type (void) G_GNUC_CONST;
gboolean import_page_unmount_camera (ImportPage* self, GMount* mount);
static void library_window_remove_from_stack (LibraryWindow* self, Page* page);
gboolean configuration_facade_get_display_basic_properties (ConfigurationFacade* self);
gboolean configuration_facade_get_display_extended_properties (ConfigurationFacade* self);
gboolean configuration_facade_get_display_search_bar (ConfigurationFacade* self);
gboolean configuration_facade_get_events_sort_ascending (ConfigurationFacade* self);
static void library_window_start_pulse_background_progress_bar (LibraryWindow* self, const gchar* label, gint priority);
static void library_window_stop_pulse_background_progress_bar (LibraryWindow* self, gint priority, gboolean clear);
static void library_window_show_background_progress_bar (LibraryWindow* self);
static gboolean library_window_on_pulse_background_progress_bar (LibraryWindow* self);
static gboolean _library_window_on_pulse_background_progress_bar_gsource_func (gpointer self);
static void library_window_clear_background_progress_bar (LibraryWindow* self, gint priority);
static void library_window_update_background_progress_bar (LibraryWindow* self, const gchar* label, gint priority, gdouble count, gdouble total);
static void library_window_hide_background_progress_bar (LibraryWindow* self);
gint configuration_facade_get_sidebar_position (ConfigurationFacade* self);
gint library_window_get_PAGE_MIN_WIDTH (void);
static void library_window_real_set_current_page (PageWindow* base, Page* page);
void library_window_set_page_switching_enabled (LibraryWindow* self, gboolean should_enable);
void page_switching_from (Page* self);
void sidebar_tree_enable_editing (SidebarTree* self);
void page_window_set_current_page (PageWindow* self, Page* page);
void sidebar_tree_disable_editing (SidebarTree* self);
GType sidebar_expandable_entry_get_type (void) G_GNUC_CONST;
gboolean sidebar_expandable_entry_expand_on_select (SidebarExpandableEntry* self);
gboolean sidebar_tree_expand_to_entry (SidebarTree* self, SidebarEntry* entry);
gboolean sidebar_tree_place_cursor (SidebarTree* self, SidebarEntry* entry, gboolean mask_signal);
static void library_window_on_update_properties (LibraryWindow* self);
static void library_window_subscribe_for_basic_information (LibraryWindow* self, Page* page);
void page_switched_to (Page* self);
void page_ready (Page* self);
GType search_view_filter_get_type (void) G_GNUC_CONST;
void search_filter_toolbar_set_view_filter (SearchFilterToolbar* self, SearchViewFilter* search_filter);
SearchViewFilter* checkerboard_page_get_search_view_filter (CheckerboardPage* self);
void view_collection_install_view_filter (ViewCollection* self, ViewFilter* f);
DisabledViewFilter* disabled_view_filter_new (void);
DisabledViewFilter* disabled_view_filter_construct (GType object_type);
GType disabled_view_filter_get_type (void) G_GNUC_CONST;
GType library_last_import_sidebar_entry_get_type (void) G_GNUC_CONST;
LibraryLastImportSidebarEntry* library_branch_get_last_imported_entry (LibraryBranch* self);
gboolean library_hideable_page_entry_get_visible (LibraryHideablePageEntry* self);
gboolean sidebar_branch_get_show_branch (SidebarBranch* self);
GType events_directory_entry_get_type (void) G_GNUC_CONST;
GType events_master_directory_entry_get_type (void) G_GNUC_CONST;
EventsMasterDirectoryEntry* events_branch_get_master_entry (EventsBranch* self);
static void _library_window_on_update_properties_view_collection_items_state_changed (ViewCollection* _sender, GeeIterable* changed, gpointer self);
static void _library_window_on_update_properties_data_collection_items_altered (DataCollection* _sender, GeeMap* items, gpointer self);
static void _library_window_on_update_properties_data_collection_contents_altered (DataCollection* _sender, GeeIterable* added, GeeIterable* removed, gpointer self);
static void _library_window_on_update_properties_view_collection_items_visibility_changed (ViewCollection* _sender, GeeCollection* changed, gpointer self);
void one_shot_scheduler_at_idle (OneShotScheduler* self);
void library_window_mounted_camera_shell_notification (LibraryWindow* self, const gchar* uri, gboolean at_startup);
gchar* camera_table_get_port_uri (const gchar* port);
gboolean is_string_empty (const gchar* s);
static gboolean library_window_real_key_press_event (GtkWidget* base, GdkEventKey* event);
gboolean sidebar_tree_is_keypress_interpreted (SidebarTree* self, GdkEventKey* event);
gint thumbnail_get_MAX_SCALE (void);
#define CHECKERBOARD_LAYOUT_COLUMN_GUTTER_PADDING 24
GType fullscreen_window_get_type (void) G_GNUC_CONST;
gpointer injection_group_ref (gpointer instance);
void injection_group_unref (gpointer instance);
GParamSpec* param_spec_injection_group (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_injection_group (GValue* value, gpointer v_object);
void value_take_injection_group (GValue* value, gpointer v_object);
gpointer value_get_injection_group (const GValue* value);
GType injection_group_get_type (void) G_GNUC_CONST;
GType zoom_buffer_get_type (void) G_GNUC_CONST;
GType single_photo_page_update_reason_get_type (void) G_GNUC_CONST;
GType raw_developer_get_type (void) G_GNUC_CONST;
#define LIBRARY_WINDOW_FULLSCREEN_PHOTO_PAGE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), LIBRARY_WINDOW_TYPE_FULLSCREEN_PHOTO_PAGE, LibraryWindowFullscreenPhotoPagePrivate))
enum  {
	LIBRARY_WINDOW_FULLSCREEN_PHOTO_PAGE_DUMMY_PROPERTY
};
static void library_window_fullscreen_photo_page_real_switched_to (Page* base);
static void library_window_fullscreen_photo_page_real_init_collect_ui_filenames (Page* base, GeeList* ui_filenames);
static void library_window_fullscreen_photo_page_finalize (GObject* obj);
static void library_window_finalize (GObject* obj);
static void _vala_library_window_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
static gint _vala_array_length (gpointer array);

static const gchar* LIBRARY_WINDOW_SUPPORTED_MOUNT_SCHEMES[3] = {"gphoto2:", "disk:", "file:"};
const GtkTargetEntry LIBRARY_WINDOW_DND_TARGET_ENTRIES[3] = {{"text/uri-list", (guint) GTK_TARGET_OTHER_APP, (guint) LIBRARY_WINDOW_TARGET_TYPE_URI_LIST}, {LIBRARY_WINDOW_MEDIA_LIST_MIME_TYPE, (guint) GTK_TARGET_SAME_APP, (guint) LIBRARY_WINDOW_TARGET_TYPE_MEDIA_LIST}, {LIBRARY_WINDOW_TAG_PATH_MIME_TYPE, (guint) GTK_TARGET_SAME_WIDGET, (guint) LIBRARY_WINDOW_TARGET_TYPE_TAG_PATH}};

static void _library_window_on_page_created_sidebar_tree_page_created (SidebarTree* _sender, SidebarPageRepresentative* entry, Page* page, gpointer self) {
#line 231 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_window_on_page_created ((LibraryWindow*) self, entry, page);
#line 1775 "LibraryWindow.c"
}


static void _library_window_on_destroying_page_sidebar_tree_destroying_page (SidebarTree* _sender, SidebarPageRepresentative* entry, Page* page, gpointer self) {
#line 232 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_window_on_destroying_page ((LibraryWindow*) self, entry, page);
#line 1782 "LibraryWindow.c"
}


static void _library_window_on_sidebar_entry_selected_sidebar_tree_entry_selected (SidebarTree* _sender, SidebarSelectableEntry* selectable, gpointer self) {
#line 233 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_window_on_sidebar_entry_selected ((LibraryWindow*) self, selectable);
#line 1789 "LibraryWindow.c"
}


static void _library_window_on_sidebar_selected_entry_removed_sidebar_tree_selected_entry_removed (SidebarTree* _sender, SidebarSelectableEntry* removed, gpointer self) {
#line 234 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_window_on_sidebar_selected_entry_removed ((LibraryWindow*) self, removed);
#line 1796 "LibraryWindow.c"
}


static void _library_window_hide_extended_properties_gtk_widget_hide (GtkWidget* _sender, gpointer self) {
#line 238 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_window_hide_extended_properties ((LibraryWindow*) self);
#line 1803 "LibraryWindow.c"
}


static void _library_window_show_extended_properties_gtk_widget_show (GtkWidget* _sender, gpointer self) {
#line 239 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_window_show_extended_properties ((LibraryWindow*) self);
#line 1810 "LibraryWindow.c"
}


static void _library_window_on_trashcan_contents_altered_media_source_collection_trashcan_contents_altered (MediaSourceCollection* _sender, GeeCollection* added, GeeCollection* removed, gpointer self) {
#line 242 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_window_on_trashcan_contents_altered ((LibraryWindow*) self);
#line 1817 "LibraryWindow.c"
}


static void _library_window_on_media_altered_data_collection_items_altered (DataCollection* _sender, GeeMap* items, gpointer self) {
#line 243 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_window_on_media_altered ((LibraryWindow*) self);
#line 1824 "LibraryWindow.c"
}


static void _library_window_on_metadata_writer_progress_metadata_writer_progress (MetadataWriter* _sender, guint completed, guint total, gpointer self) {
#line 246 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_window_on_metadata_writer_progress ((LibraryWindow*) self, completed, total);
#line 1831 "LibraryWindow.c"
}


static void _library_window_on_library_monitor_installed_library_monitor_pool_monitor_installed (LibraryMonitorPool* _sender, LibraryMonitor* monitor, gpointer self) {
#line 252 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_window_on_library_monitor_installed ((LibraryWindow*) self, monitor);
#line 1838 "LibraryWindow.c"
}


static void _library_window_on_library_monitor_destroyed_library_monitor_pool_monitor_destroyed (LibraryMonitorPool* _sender, LibraryMonitor* monitor, gpointer self) {
#line 253 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_window_on_library_monitor_destroyed ((LibraryWindow*) self, monitor);
#line 1845 "LibraryWindow.c"
}


static void _library_window_on_camera_added_camera_table_camera_added (CameraTable* _sender, DiscoveredCamera* camera, gpointer self) {
#line 255 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_window_on_camera_added ((LibraryWindow*) self, camera);
#line 1852 "LibraryWindow.c"
}


static GType library_window_sidebar_root_position_get_type (void) {
	static volatile gsize library_window_sidebar_root_position_type_id__volatile = 0;
	if (g_once_init_enter (&library_window_sidebar_root_position_type_id__volatile)) {
		static const GEnumValue values[] = {{LIBRARY_WINDOW_SIDEBAR_ROOT_POSITION_LIBRARY, "LIBRARY_WINDOW_SIDEBAR_ROOT_POSITION_LIBRARY", "library"}, {LIBRARY_WINDOW_SIDEBAR_ROOT_POSITION_CAMERAS, "LIBRARY_WINDOW_SIDEBAR_ROOT_POSITION_CAMERAS", "cameras"}, {LIBRARY_WINDOW_SIDEBAR_ROOT_POSITION_SAVED_SEARCH, "LIBRARY_WINDOW_SIDEBAR_ROOT_POSITION_SAVED_SEARCH", "saved-search"}, {LIBRARY_WINDOW_SIDEBAR_ROOT_POSITION_EVENTS, "LIBRARY_WINDOW_SIDEBAR_ROOT_POSITION_EVENTS", "events"}, {LIBRARY_WINDOW_SIDEBAR_ROOT_POSITION_FOLDERS, "LIBRARY_WINDOW_SIDEBAR_ROOT_POSITION_FOLDERS", "folders"}, {LIBRARY_WINDOW_SIDEBAR_ROOT_POSITION_TAGS, "LIBRARY_WINDOW_SIDEBAR_ROOT_POSITION_TAGS", "tags"}, {0, NULL, NULL}};
		GType library_window_sidebar_root_position_type_id;
		library_window_sidebar_root_position_type_id = g_enum_register_static ("LibraryWindowSidebarRootPosition", values);
		g_once_init_leave (&library_window_sidebar_root_position_type_id__volatile, library_window_sidebar_root_position_type_id);
	}
	return library_window_sidebar_root_position_type_id__volatile;
}


GType library_window_target_type_get_type (void) {
	static volatile gsize library_window_target_type_type_id__volatile = 0;
	if (g_once_init_enter (&library_window_target_type_type_id__volatile)) {
		static const GEnumValue values[] = {{LIBRARY_WINDOW_TARGET_TYPE_URI_LIST, "LIBRARY_WINDOW_TARGET_TYPE_URI_LIST", "uri-list"}, {LIBRARY_WINDOW_TARGET_TYPE_MEDIA_LIST, "LIBRARY_WINDOW_TARGET_TYPE_MEDIA_LIST", "media-list"}, {LIBRARY_WINDOW_TARGET_TYPE_TAG_PATH, "LIBRARY_WINDOW_TARGET_TYPE_TAG_PATH", "tag-path"}, {0, NULL, NULL}};
		GType library_window_target_type_type_id;
		library_window_target_type_type_id = g_enum_register_static ("LibraryWindowTargetType", values);
		g_once_init_leave (&library_window_target_type_type_id__volatile, library_window_target_type_type_id);
	}
	return library_window_target_type_type_id__volatile;
}


static void _library_window_external_drop_handler_sidebar_tree_external_drop_handler (GdkDragContext* context, SidebarEntry* entry, GtkSelectionData* data, guint info, guint time, gpointer self) {
#line 153 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_window_external_drop_handler ((LibraryWindow*) self, context, entry, data, info, time);
#line 1883 "LibraryWindow.c"
}


static void _library_window_on_update_properties_now_one_shot_callback (gpointer self) {
#line 173 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_window_on_update_properties_now ((LibraryWindow*) self);
#line 1890 "LibraryWindow.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 186 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	return self ? g_object_ref (self) : NULL;
#line 1897 "LibraryWindow.c"
}


LibraryWindow* library_window_construct (GType object_type, ProgressMonitor progress_monitor, void* progress_monitor_target) {
	LibraryWindow * self = NULL;
	SidebarTree* _tmp0_ = NULL;
	SidebarTree* _tmp1_ = NULL;
	SidebarTree* _tmp2_ = NULL;
	SidebarTree* _tmp3_ = NULL;
	SidebarTree* _tmp4_ = NULL;
	SidebarTree* _tmp5_ = NULL;
	LibraryBranch* _tmp6_ = NULL;
	SidebarTree* _tmp7_ = NULL;
	TagsBranch* _tmp8_ = NULL;
	SidebarTree* _tmp9_ = NULL;
	FoldersBranch* _tmp10_ = NULL;
	SidebarTree* _tmp11_ = NULL;
	EventsBranch* _tmp12_ = NULL;
	SidebarTree* _tmp13_ = NULL;
	CameraBranch* _tmp14_ = NULL;
	SidebarTree* _tmp15_ = NULL;
	SearchesBranch* _tmp16_ = NULL;
	ExtendedPropertiesWindow* _tmp17_ = NULL;
	ExtendedPropertiesWindow* _tmp18_ = NULL;
	ExtendedPropertiesWindow* _tmp19_ = NULL;
	OneShotScheduler* _tmp20_ = NULL;
	SearchFilterActions* _tmp21_ = NULL;
	SearchFilterToolbar* _tmp22_ = NULL;
	GtkMenuBar* menubar = NULL;
	GtkUIManager* _tmp28_ = NULL;
	GtkWidget* _tmp29_ = NULL;
	GtkMenuBar* _tmp30_ = NULL;
	GtkBox* _tmp31_ = NULL;
	GtkMenuBar* _tmp32_ = NULL;
	GtkMenuBar* _tmp33_ = NULL;
	LibraryBranch* _tmp34_ = NULL;
	LibraryPhotosEntry* _tmp35_ = NULL;
	LibraryPhotosEntry* _tmp36_ = NULL;
	Page* _tmp37_ = NULL;
	Page* _tmp38_ = NULL;
	GtkTargetEntry* main_window_dnd_targets = NULL;
	GtkTargetEntry _tmp51_ = {0};
	GtkTargetEntry _tmp52_ = {0};
	GtkTargetEntry* _tmp53_ = NULL;
	gint main_window_dnd_targets_length1 = 0;
	gint _main_window_dnd_targets_size_ = 0;
	GtkTargetEntry* _tmp54_ = NULL;
	gint _tmp54__length1 = 0;
	MetadataWriter* _tmp55_ = NULL;
	MetadataWriter* _tmp56_ = NULL;
	LibraryMonitor* monitor = NULL;
	LibraryMonitorPool* _tmp57_ = NULL;
	LibraryMonitorPool* _tmp58_ = NULL;
	LibraryMonitor* _tmp59_ = NULL;
	LibraryMonitor* _tmp60_ = NULL;
	LibraryMonitor* _tmp61_ = NULL;
	LibraryMonitorPool* _tmp63_ = NULL;
	LibraryMonitorPool* _tmp64_ = NULL;
	LibraryMonitorPool* _tmp65_ = NULL;
	LibraryMonitorPool* _tmp66_ = NULL;
	CameraTable* _tmp67_ = NULL;
	CameraTable* _tmp68_ = NULL;
	GtkProgressBar* _tmp69_ = NULL;
	GError * _inner_error_ = NULL;
#line 151 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	self = (LibraryWindow*) app_window_construct (object_type);
#line 153 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = sidebar_tree_new (LIBRARY_WINDOW_DND_TARGET_ENTRIES, G_N_ELEMENTS (LIBRARY_WINDOW_DND_TARGET_ENTRIES), GDK_ACTION_ASK, _library_window_external_drop_handler_sidebar_tree_external_drop_handler, self);
#line 153 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_object_ref_sink (_tmp0_);
#line 153 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (self->priv->sidebar_tree);
#line 153 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	self->priv->sidebar_tree = _tmp0_;
#line 156 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_ = self->priv->sidebar_tree;
#line 156 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_signal_connect_object (_tmp1_, "page-created", (GCallback) _library_window_on_page_created_sidebar_tree_page_created, self, 0);
#line 157 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp2_ = self->priv->sidebar_tree;
#line 157 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_signal_connect_object (_tmp2_, "destroying-page", (GCallback) _library_window_on_destroying_page_sidebar_tree_destroying_page, self, 0);
#line 158 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp3_ = self->priv->sidebar_tree;
#line 158 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_signal_connect_object (_tmp3_, "entry-selected", (GCallback) _library_window_on_sidebar_entry_selected_sidebar_tree_entry_selected, self, 0);
#line 159 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp4_ = self->priv->sidebar_tree;
#line 159 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_signal_connect_object (_tmp4_, "selected-entry-removed", (GCallback) _library_window_on_sidebar_selected_entry_removed_sidebar_tree_selected_entry_removed, self, 0);
#line 161 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp5_ = self->priv->sidebar_tree;
#line 161 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp6_ = self->priv->library_branch;
#line 161 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	sidebar_tree_graft (_tmp5_, G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, SIDEBAR_TYPE_BRANCH, SidebarBranch), (gint) LIBRARY_WINDOW_SIDEBAR_ROOT_POSITION_LIBRARY);
#line 162 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp7_ = self->priv->sidebar_tree;
#line 162 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp8_ = self->priv->tags_branch;
#line 162 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	sidebar_tree_graft (_tmp7_, G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, SIDEBAR_TYPE_BRANCH, SidebarBranch), (gint) LIBRARY_WINDOW_SIDEBAR_ROOT_POSITION_TAGS);
#line 163 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp9_ = self->priv->sidebar_tree;
#line 163 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp10_ = self->priv->folders_branch;
#line 163 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	sidebar_tree_graft (_tmp9_, G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, SIDEBAR_TYPE_BRANCH, SidebarBranch), (gint) LIBRARY_WINDOW_SIDEBAR_ROOT_POSITION_FOLDERS);
#line 164 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp11_ = self->priv->sidebar_tree;
#line 164 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp12_ = self->priv->events_branch;
#line 164 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	sidebar_tree_graft (_tmp11_, G_TYPE_CHECK_INSTANCE_CAST (_tmp12_, SIDEBAR_TYPE_BRANCH, SidebarBranch), (gint) LIBRARY_WINDOW_SIDEBAR_ROOT_POSITION_EVENTS);
#line 165 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp13_ = self->priv->sidebar_tree;
#line 165 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp14_ = self->priv->camera_branch;
#line 165 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	sidebar_tree_graft (_tmp13_, G_TYPE_CHECK_INSTANCE_CAST (_tmp14_, SIDEBAR_TYPE_BRANCH, SidebarBranch), (gint) LIBRARY_WINDOW_SIDEBAR_ROOT_POSITION_CAMERAS);
#line 166 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp15_ = self->priv->sidebar_tree;
#line 166 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp16_ = self->priv->saved_search_branch;
#line 166 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	sidebar_tree_graft (_tmp15_, G_TYPE_CHECK_INSTANCE_CAST (_tmp16_, SIDEBAR_TYPE_BRANCH, SidebarBranch), (gint) LIBRARY_WINDOW_SIDEBAR_ROOT_POSITION_SAVED_SEARCH);
#line 169 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp17_ = extended_properties_window_new (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow));
#line 169 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_object_ref_sink (_tmp17_);
#line 169 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (self->priv->extended_properties);
#line 169 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	self->priv->extended_properties = _tmp17_;
#line 170 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp18_ = self->priv->extended_properties;
#line 170 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp18_, gtk_widget_get_type (), GtkWidget), "hide", (GCallback) _library_window_hide_extended_properties_gtk_widget_hide, self, 0);
#line 171 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp19_ = self->priv->extended_properties;
#line 171 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp19_, gtk_widget_get_type (), GtkWidget), "show", (GCallback) _library_window_show_extended_properties_gtk_widget_show, self, 0);
#line 173 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp20_ = one_shot_scheduler_new ("LibraryWindow properties", _library_window_on_update_properties_now_one_shot_callback, self);
#line 173 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_one_shot_scheduler_unref0 (self->priv->properties_scheduler);
#line 173 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	self->priv->properties_scheduler = _tmp20_;
#line 177 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp21_ = self->priv->search_actions;
#line 177 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp22_ = search_filter_toolbar_new (_tmp21_);
#line 177 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_object_ref_sink (_tmp22_);
#line 177 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (self->priv->search_toolbar);
#line 177 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	self->priv->search_toolbar = _tmp22_;
#line 2056 "LibraryWindow.c"
	{
		GFile* ui_file = NULL;
		GFile* _tmp23_ = NULL;
		GtkUIManager* _tmp24_ = NULL;
		gchar* _tmp25_ = NULL;
		gchar* _tmp26_ = NULL;
#line 180 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp23_ = resources_get_ui ("top.ui");
#line 180 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		ui_file = _tmp23_;
#line 181 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp24_ = G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE_WINDOW, PageWindow)->ui;
#line 181 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp25_ = g_file_get_path (ui_file);
#line 181 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp26_ = _tmp25_;
#line 181 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		gtk_ui_manager_add_ui_from_file (_tmp24_, _tmp26_, &_inner_error_);
#line 181 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_free0 (_tmp26_);
#line 181 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 181 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_g_object_unref0 (ui_file);
#line 2081 "LibraryWindow.c"
			goto __catch38_g_error;
		}
#line 179 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_object_unref0 (ui_file);
#line 2086 "LibraryWindow.c"
	}
	goto __finally38;
	__catch38_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp27_ = NULL;
#line 179 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		e = _inner_error_;
#line 179 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_inner_error_ = NULL;
#line 183 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp27_ = e->message;
#line 183 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		g_error ("LibraryWindow.vala:183: %s", _tmp27_);
#line 179 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_error_free0 (e);
#line 2103 "LibraryWindow.c"
	}
	__finally38:
#line 179 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 179 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 179 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		g_clear_error (&_inner_error_);
#line 179 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		return NULL;
#line 2114 "LibraryWindow.c"
	}
#line 186 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp28_ = G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE_WINDOW, PageWindow)->ui;
#line 186 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp29_ = gtk_ui_manager_get_widget (_tmp28_, "/MenuBar");
#line 186 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp30_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp29_, gtk_menu_bar_get_type ()) ? ((GtkMenuBar*) _tmp29_) : NULL);
#line 186 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	menubar = _tmp30_;
#line 187 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp31_ = self->priv->layout;
#line 187 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp32_ = menubar;
#line 187 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	gtk_container_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp31_, gtk_container_get_type (), GtkContainer), G_TYPE_CHECK_INSTANCE_CAST (_tmp32_, gtk_widget_get_type (), GtkWidget));
#line 191 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp33_ = menubar;
#line 191 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	gtk_widget_set_no_show_all (G_TYPE_CHECK_INSTANCE_CAST (_tmp33_, gtk_widget_get_type (), GtkWidget), TRUE);
#line 194 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp34_ = self->priv->library_branch;
#line 194 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp35_ = library_branch_get_photos_entry (_tmp34_);
#line 194 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp36_ = _tmp35_;
#line 194 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp37_ = sidebar_page_representative_get_page (G_TYPE_CHECK_INSTANCE_CAST (_tmp36_, SIDEBAR_TYPE_PAGE_REPRESENTATIVE, SidebarPageRepresentative));
#line 194 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp38_ = _tmp37_;
#line 194 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_window_create_layout (self, _tmp38_);
#line 194 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (_tmp38_);
#line 197 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_window_load_configuration (self);
#line 2150 "LibraryWindow.c"
	{
		GeeIterator* _media_sources_it = NULL;
		MediaCollectionRegistry* _tmp39_ = NULL;
		MediaCollectionRegistry* _tmp40_ = NULL;
		GeeCollection* _tmp41_ = NULL;
		GeeCollection* _tmp42_ = NULL;
		GeeIterator* _tmp43_ = NULL;
		GeeIterator* _tmp44_ = NULL;
#line 199 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp39_ = media_collection_registry_get_instance ();
#line 199 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp40_ = _tmp39_;
#line 199 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp41_ = media_collection_registry_get_all (_tmp40_);
#line 199 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp42_ = _tmp41_;
#line 199 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp43_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp42_, GEE_TYPE_ITERABLE, GeeIterable));
#line 199 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp44_ = _tmp43_;
#line 199 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_object_unref0 (_tmp42_);
#line 199 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_media_collection_registry_unref0 (_tmp40_);
#line 199 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_media_sources_it = _tmp44_;
#line 199 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		while (TRUE) {
#line 2179 "LibraryWindow.c"
			GeeIterator* _tmp45_ = NULL;
			gboolean _tmp46_ = FALSE;
			MediaSourceCollection* media_sources = NULL;
			GeeIterator* _tmp47_ = NULL;
			gpointer _tmp48_ = NULL;
			MediaSourceCollection* _tmp49_ = NULL;
			MediaSourceCollection* _tmp50_ = NULL;
#line 199 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_tmp45_ = _media_sources_it;
#line 199 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_tmp46_ = gee_iterator_next (_tmp45_);
#line 199 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			if (!_tmp46_) {
#line 199 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				break;
#line 2195 "LibraryWindow.c"
			}
#line 199 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_tmp47_ = _media_sources_it;
#line 199 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_tmp48_ = gee_iterator_get (_tmp47_);
#line 199 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			media_sources = (MediaSourceCollection*) _tmp48_;
#line 200 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_tmp49_ = media_sources;
#line 200 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			g_signal_connect_object (_tmp49_, "trashcan-contents-altered", (GCallback) _library_window_on_trashcan_contents_altered_media_source_collection_trashcan_contents_altered, self, 0);
#line 201 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_tmp50_ = media_sources;
#line 201 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp50_, TYPE_DATA_COLLECTION, DataCollection), "items-altered", (GCallback) _library_window_on_media_altered_data_collection_items_altered, self, 0);
#line 199 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_data_collection_unref0 (media_sources);
#line 2213 "LibraryWindow.c"
		}
#line 199 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_object_unref0 (_media_sources_it);
#line 2217 "LibraryWindow.c"
	}
#line 206 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp51_ = LIBRARY_WINDOW_DND_TARGET_ENTRIES[LIBRARY_WINDOW_TARGET_TYPE_URI_LIST];
#line 206 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp52_ = LIBRARY_WINDOW_DND_TARGET_ENTRIES[LIBRARY_WINDOW_TARGET_TYPE_MEDIA_LIST];
#line 206 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp53_ = g_new0 (GtkTargetEntry, 2);
#line 206 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp53_[0] = _tmp51_;
#line 206 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp53_[1] = _tmp52_;
#line 206 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	main_window_dnd_targets = _tmp53_;
#line 206 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	main_window_dnd_targets_length1 = 2;
#line 206 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_main_window_dnd_targets_size_ = main_window_dnd_targets_length1;
#line 212 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp54_ = main_window_dnd_targets;
#line 212 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp54__length1 = main_window_dnd_targets_length1;
#line 212 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	gtk_drag_dest_set (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget), GTK_DEST_DEFAULT_ALL, _tmp54_, _tmp54__length1, (GDK_ACTION_COPY | GDK_ACTION_LINK) | GDK_ACTION_ASK);
#line 215 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp55_ = metadata_writer_get_instance ();
#line 215 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp56_ = _tmp55_;
#line 215 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_signal_connect_object (_tmp56_, "progress", (GCallback) _library_window_on_metadata_writer_progress_metadata_writer_progress, self, 0);
#line 215 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (_tmp56_);
#line 217 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp57_ = library_monitor_pool_get_instance ();
#line 217 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp58_ = _tmp57_;
#line 217 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp59_ = library_monitor_pool_get_monitor (_tmp58_);
#line 217 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp60_ = _tmp59_;
#line 217 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_library_monitor_pool_unref0 (_tmp58_);
#line 217 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	monitor = _tmp60_;
#line 218 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp61_ = monitor;
#line 218 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp61_ != NULL) {
#line 2265 "LibraryWindow.c"
		LibraryMonitor* _tmp62_ = NULL;
#line 219 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp62_ = monitor;
#line 219 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		library_window_on_library_monitor_installed (self, _tmp62_);
#line 2271 "LibraryWindow.c"
	}
#line 221 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp63_ = library_monitor_pool_get_instance ();
#line 221 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp64_ = _tmp63_;
#line 221 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_signal_connect_object (_tmp64_, "monitor-installed", (GCallback) _library_window_on_library_monitor_installed_library_monitor_pool_monitor_installed, self, 0);
#line 221 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_library_monitor_pool_unref0 (_tmp64_);
#line 222 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp65_ = library_monitor_pool_get_instance ();
#line 222 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp66_ = _tmp65_;
#line 222 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_signal_connect_object (_tmp66_, "monitor-destroyed", (GCallback) _library_window_on_library_monitor_destroyed_library_monitor_pool_monitor_destroyed, self, 0);
#line 222 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_library_monitor_pool_unref0 (_tmp66_);
#line 224 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp67_ = camera_table_get_instance ();
#line 224 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp68_ = _tmp67_;
#line 224 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_signal_connect_object (_tmp68_, "camera-added", (GCallback) _library_window_on_camera_added_camera_table_camera_added, self, 0);
#line 224 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_camera_table_unref0 (_tmp68_);
#line 226 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp69_ = self->priv->background_progress_bar;
#line 226 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	gtk_progress_bar_set_show_text (_tmp69_, TRUE);
#line 151 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (monitor);
#line 151 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	main_window_dnd_targets = (g_free (main_window_dnd_targets), NULL);
#line 151 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (menubar);
#line 151 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	return self;
#line 2309 "LibraryWindow.c"
}


LibraryWindow* library_window_new (ProgressMonitor progress_monitor, void* progress_monitor_target) {
#line 151 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	return library_window_construct (TYPE_LIBRARY_WINDOW, progress_monitor, progress_monitor_target);
#line 2316 "LibraryWindow.c"
}


static void _library_window_on_library_monitor_discovery_started_directory_monitor_discovery_started (DirectoryMonitor* _sender, gpointer self) {
#line 261 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_window_on_library_monitor_discovery_started ((LibraryWindow*) self);
#line 2323 "LibraryWindow.c"
}


static void _library_window_on_library_monitor_discovery_completed_directory_monitor_discovery_completed (DirectoryMonitor* _sender, gpointer self) {
#line 262 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_window_on_library_monitor_discovery_completed ((LibraryWindow*) self);
#line 2330 "LibraryWindow.c"
}


static void _library_window_on_library_monitor_discovery_completed_directory_monitor_closed (DirectoryMonitor* _sender, gpointer self) {
#line 263 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_window_on_library_monitor_discovery_completed ((LibraryWindow*) self);
#line 2337 "LibraryWindow.c"
}


static void _library_window_on_library_monitor_auto_update_progress_library_monitor_auto_update_progress (LibraryMonitor* _sender, gint completed_files, gint total_files, gpointer self) {
#line 264 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_window_on_library_monitor_auto_update_progress ((LibraryWindow*) self, completed_files, total_files);
#line 2344 "LibraryWindow.c"
}


static void _library_window_on_library_monitor_auto_import_preparing_library_monitor_auto_import_preparing (LibraryMonitor* _sender, gpointer self) {
#line 265 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_window_on_library_monitor_auto_import_preparing ((LibraryWindow*) self);
#line 2351 "LibraryWindow.c"
}


static void _library_window_on_library_monitor_auto_import_progress_library_monitor_auto_import_progress (LibraryMonitor* _sender, guint64 completed_bytes, guint64 total_bytes, gpointer self) {
#line 266 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_window_on_library_monitor_auto_import_progress ((LibraryWindow*) self, completed_bytes, total_bytes);
#line 2358 "LibraryWindow.c"
}


static void library_window_on_library_monitor_installed (LibraryWindow* self, LibraryMonitor* monitor) {
	LibraryMonitor* _tmp0_ = NULL;
	GFile* _tmp1_ = NULL;
	GFile* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	LibraryMonitor* _tmp5_ = NULL;
	LibraryMonitor* _tmp6_ = NULL;
	LibraryMonitor* _tmp7_ = NULL;
	LibraryMonitor* _tmp8_ = NULL;
	LibraryMonitor* _tmp9_ = NULL;
	LibraryMonitor* _tmp10_ = NULL;
#line 258 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_LIBRARY_WINDOW (self));
#line 258 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_LIBRARY_MONITOR (monitor));
#line 259 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = monitor;
#line 259 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_ = directory_monitor_get_root (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, TYPE_DIRECTORY_MONITOR, DirectoryMonitor));
#line 259 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp2_ = _tmp1_;
#line 259 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp3_ = g_file_get_path (_tmp2_);
#line 259 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp4_ = _tmp3_;
#line 259 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_debug ("LibraryWindow.vala:259: on_library_monitor_installed: %s", _tmp4_);
#line 259 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_free0 (_tmp4_);
#line 259 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (_tmp2_);
#line 261 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp5_ = monitor;
#line 261 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, TYPE_DIRECTORY_MONITOR, DirectoryMonitor), "discovery-started", (GCallback) _library_window_on_library_monitor_discovery_started_directory_monitor_discovery_started, self, 0);
#line 262 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp6_ = monitor;
#line 262 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, TYPE_DIRECTORY_MONITOR, DirectoryMonitor), "discovery-completed", (GCallback) _library_window_on_library_monitor_discovery_completed_directory_monitor_discovery_completed, self, 0);
#line 263 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp7_ = monitor;
#line 263 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, TYPE_DIRECTORY_MONITOR, DirectoryMonitor), "closed", (GCallback) _library_window_on_library_monitor_discovery_completed_directory_monitor_closed, self, 0);
#line 264 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp8_ = monitor;
#line 264 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_signal_connect_object (_tmp8_, "auto-update-progress", (GCallback) _library_window_on_library_monitor_auto_update_progress_library_monitor_auto_update_progress, self, 0);
#line 265 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp9_ = monitor;
#line 265 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_signal_connect_object (_tmp9_, "auto-import-preparing", (GCallback) _library_window_on_library_monitor_auto_import_preparing_library_monitor_auto_import_preparing, self, 0);
#line 266 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp10_ = monitor;
#line 266 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_signal_connect_object (_tmp10_, "auto-import-progress", (GCallback) _library_window_on_library_monitor_auto_import_progress_library_monitor_auto_import_progress, self, 0);
#line 2418 "LibraryWindow.c"
}


static void library_window_on_library_monitor_destroyed (LibraryWindow* self, LibraryMonitor* monitor) {
	LibraryMonitor* _tmp0_ = NULL;
	GFile* _tmp1_ = NULL;
	GFile* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	LibraryMonitor* _tmp5_ = NULL;
	guint _tmp6_ = 0U;
	LibraryMonitor* _tmp7_ = NULL;
	guint _tmp8_ = 0U;
	LibraryMonitor* _tmp9_ = NULL;
	guint _tmp10_ = 0U;
	LibraryMonitor* _tmp11_ = NULL;
	guint _tmp12_ = 0U;
	LibraryMonitor* _tmp13_ = NULL;
	guint _tmp14_ = 0U;
	LibraryMonitor* _tmp15_ = NULL;
	guint _tmp16_ = 0U;
#line 269 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_LIBRARY_WINDOW (self));
#line 269 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_LIBRARY_MONITOR (monitor));
#line 270 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = monitor;
#line 270 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_ = directory_monitor_get_root (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, TYPE_DIRECTORY_MONITOR, DirectoryMonitor));
#line 270 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp2_ = _tmp1_;
#line 270 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp3_ = g_file_get_path (_tmp2_);
#line 270 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp4_ = _tmp3_;
#line 270 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_debug ("LibraryWindow.vala:270: on_library_monitor_destroyed: %s", _tmp4_);
#line 270 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_free0 (_tmp4_);
#line 270 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (_tmp2_);
#line 272 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp5_ = monitor;
#line 272 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_signal_parse_name ("discovery-started", TYPE_DIRECTORY_MONITOR, &_tmp6_, NULL, FALSE);
#line 272 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_signal_handlers_disconnect_matched (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, TYPE_DIRECTORY_MONITOR, DirectoryMonitor), G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp6_, 0, NULL, (GCallback) _library_window_on_library_monitor_discovery_started_directory_monitor_discovery_started, self);
#line 273 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp7_ = monitor;
#line 273 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_signal_parse_name ("discovery-completed", TYPE_DIRECTORY_MONITOR, &_tmp8_, NULL, FALSE);
#line 273 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_signal_handlers_disconnect_matched (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, TYPE_DIRECTORY_MONITOR, DirectoryMonitor), G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp8_, 0, NULL, (GCallback) _library_window_on_library_monitor_discovery_completed_directory_monitor_discovery_completed, self);
#line 274 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp9_ = monitor;
#line 274 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_signal_parse_name ("closed", TYPE_DIRECTORY_MONITOR, &_tmp10_, NULL, FALSE);
#line 274 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_signal_handlers_disconnect_matched (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, TYPE_DIRECTORY_MONITOR, DirectoryMonitor), G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp10_, 0, NULL, (GCallback) _library_window_on_library_monitor_discovery_completed_directory_monitor_closed, self);
#line 275 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp11_ = monitor;
#line 275 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_signal_parse_name ("auto-update-progress", TYPE_LIBRARY_MONITOR, &_tmp12_, NULL, FALSE);
#line 275 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_signal_handlers_disconnect_matched (_tmp11_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp12_, 0, NULL, (GCallback) _library_window_on_library_monitor_auto_update_progress_library_monitor_auto_update_progress, self);
#line 276 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp13_ = monitor;
#line 276 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_signal_parse_name ("auto-import-preparing", TYPE_LIBRARY_MONITOR, &_tmp14_, NULL, FALSE);
#line 276 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_signal_handlers_disconnect_matched (_tmp13_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp14_, 0, NULL, (GCallback) _library_window_on_library_monitor_auto_import_preparing_library_monitor_auto_import_preparing, self);
#line 277 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp15_ = monitor;
#line 277 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_signal_parse_name ("auto-import-progress", TYPE_LIBRARY_MONITOR, &_tmp16_, NULL, FALSE);
#line 277 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_signal_handlers_disconnect_matched (_tmp15_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp16_, 0, NULL, (GCallback) _library_window_on_library_monitor_auto_import_progress_library_monitor_auto_import_progress, self);
#line 2496 "LibraryWindow.c"
}


static void _library_window_on_file_import_gtk_action_callback (GtkAction* action, gpointer self) {
#line 283 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_window_on_file_import ((LibraryWindow*) self);
#line 2503 "LibraryWindow.c"
}


static void _vala_array_add61 (GtkActionEntry** array, int* length, int* size, const GtkActionEntry* value) {
#line 287 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if ((*length) == (*size)) {
#line 287 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 287 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		*array = g_renew (GtkActionEntry, *array, *size);
#line 2514 "LibraryWindow.c"
	}
#line 287 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	(*array)[(*length)++] = *value;
#line 2518 "LibraryWindow.c"
}


static void _library_window_on_external_library_import_gtk_action_callback (GtkAction* action, gpointer self) {
#line 289 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_window_on_external_library_import ((LibraryWindow*) self);
#line 2525 "LibraryWindow.c"
}


static void _vala_array_add62 (GtkActionEntry** array, int* length, int* size, const GtkActionEntry* value) {
#line 294 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if ((*length) == (*size)) {
#line 294 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 294 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		*array = g_renew (GtkActionEntry, *array, *size);
#line 2536 "LibraryWindow.c"
	}
#line 294 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	(*array)[(*length)++] = *value;
#line 2540 "LibraryWindow.c"
}


static void _vala_array_add63 (GtkActionEntry** array, int* length, int* size, const GtkActionEntry* value) {
#line 298 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if ((*length) == (*size)) {
#line 298 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 298 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		*array = g_renew (GtkActionEntry, *array, *size);
#line 2551 "LibraryWindow.c"
	}
#line 298 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	(*array)[(*length)++] = *value;
#line 2555 "LibraryWindow.c"
}


static void _library_window_on_preferences_gtk_action_callback (GtkAction* action, gpointer self) {
#line 300 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_window_on_preferences ((LibraryWindow*) self);
#line 2562 "LibraryWindow.c"
}


static void _vala_array_add64 (GtkActionEntry** array, int* length, int* size, const GtkActionEntry* value) {
#line 303 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if ((*length) == (*size)) {
#line 303 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 303 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		*array = g_renew (GtkActionEntry, *array, *size);
#line 2573 "LibraryWindow.c"
	}
#line 303 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	(*array)[(*length)++] = *value;
#line 2577 "LibraryWindow.c"
}


static void _library_window_on_empty_trash_gtk_action_callback (GtkAction* action, gpointer self) {
#line 305 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_window_on_empty_trash ((LibraryWindow*) self);
#line 2584 "LibraryWindow.c"
}


static void _vala_array_add65 (GtkActionEntry** array, int* length, int* size, const GtkActionEntry* value) {
#line 309 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if ((*length) == (*size)) {
#line 309 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 309 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		*array = g_renew (GtkActionEntry, *array, *size);
#line 2595 "LibraryWindow.c"
	}
#line 309 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	(*array)[(*length)++] = *value;
#line 2599 "LibraryWindow.c"
}


static void _library_window_on_jump_to_event_gtk_action_callback (GtkAction* action, gpointer self) {
#line 311 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_window_on_jump_to_event ((LibraryWindow*) self);
#line 2606 "LibraryWindow.c"
}


static void _vala_array_add66 (GtkActionEntry** array, int* length, int* size, const GtkActionEntry* value) {
#line 314 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if ((*length) == (*size)) {
#line 314 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 314 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		*array = g_renew (GtkActionEntry, *array, *size);
#line 2617 "LibraryWindow.c"
	}
#line 314 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	(*array)[(*length)++] = *value;
#line 2621 "LibraryWindow.c"
}


static void _library_window_on_find_gtk_action_callback (GtkAction* action, gpointer self) {
#line 316 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_window_on_find ((LibraryWindow*) self);
#line 2628 "LibraryWindow.c"
}


static void _vala_array_add67 (GtkActionEntry** array, int* length, int* size, const GtkActionEntry* value) {
#line 319 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if ((*length) == (*size)) {
#line 319 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 319 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		*array = g_renew (GtkActionEntry, *array, *size);
#line 2639 "LibraryWindow.c"
	}
#line 319 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	(*array)[(*length)++] = *value;
#line 2643 "LibraryWindow.c"
}


static void _vala_array_add68 (GtkActionEntry** array, int* length, int* size, const GtkActionEntry* value) {
#line 325 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if ((*length) == (*size)) {
#line 325 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 325 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		*array = g_renew (GtkActionEntry, *array, *size);
#line 2654 "LibraryWindow.c"
	}
#line 325 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	(*array)[(*length)++] = *value;
#line 2658 "LibraryWindow.c"
}


static void _library_window_on_new_search_gtk_action_callback (GtkAction* action, gpointer self) {
#line 327 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_window_on_new_search ((LibraryWindow*) self);
#line 2665 "LibraryWindow.c"
}


static void _vala_array_add69 (GtkActionEntry** array, int* length, int* size, const GtkActionEntry* value) {
#line 330 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if ((*length) == (*size)) {
#line 330 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 330 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		*array = g_renew (GtkActionEntry, *array, *size);
#line 2676 "LibraryWindow.c"
	}
#line 330 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	(*array)[(*length)++] = *value;
#line 2680 "LibraryWindow.c"
}


static void _vala_array_add70 (GtkActionEntry** array, int* length, int* size, const GtkActionEntry* value) {
#line 336 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if ((*length) == (*size)) {
#line 336 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 336 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		*array = g_renew (GtkActionEntry, *array, *size);
#line 2691 "LibraryWindow.c"
	}
#line 336 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	(*array)[(*length)++] = *value;
#line 2695 "LibraryWindow.c"
}


static void _vala_array_add71 (GtkActionEntry** array, int* length, int* size, const GtkActionEntry* value) {
#line 340 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if ((*length) == (*size)) {
#line 340 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 340 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		*array = g_renew (GtkActionEntry, *array, *size);
#line 2706 "LibraryWindow.c"
	}
#line 340 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	(*array)[(*length)++] = *value;
#line 2710 "LibraryWindow.c"
}


static void _vala_array_add72 (GtkActionEntry** array, int* length, int* size, const GtkActionEntry* value) {
#line 344 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if ((*length) == (*size)) {
#line 344 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 344 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		*array = g_renew (GtkActionEntry, *array, *size);
#line 2721 "LibraryWindow.c"
	}
#line 344 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	(*array)[(*length)++] = *value;
#line 2725 "LibraryWindow.c"
}


static void _vala_array_add73 (GtkActionEntry** array, int* length, int* size, const GtkActionEntry* value) {
#line 348 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if ((*length) == (*size)) {
#line 348 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 348 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		*array = g_renew (GtkActionEntry, *array, *size);
#line 2736 "LibraryWindow.c"
	}
#line 348 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	(*array)[(*length)++] = *value;
#line 2740 "LibraryWindow.c"
}


static void _vala_array_add74 (GtkActionEntry** array, int* length, int* size, const GtkActionEntry* value) {
#line 352 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if ((*length) == (*size)) {
#line 352 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 352 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		*array = g_renew (GtkActionEntry, *array, *size);
#line 2751 "LibraryWindow.c"
	}
#line 352 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	(*array)[(*length)++] = *value;
#line 2755 "LibraryWindow.c"
}


static void _vala_array_add75 (GtkActionEntry** array, int* length, int* size, const GtkActionEntry* value) {
#line 356 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if ((*length) == (*size)) {
#line 356 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 356 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		*array = g_renew (GtkActionEntry, *array, *size);
#line 2766 "LibraryWindow.c"
	}
#line 356 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	(*array)[(*length)++] = *value;
#line 2770 "LibraryWindow.c"
}


static void _vala_array_add76 (GtkActionEntry** array, int* length, int* size, const GtkActionEntry* value) {
#line 360 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if ((*length) == (*size)) {
#line 360 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 360 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		*array = g_renew (GtkActionEntry, *array, *size);
#line 2781 "LibraryWindow.c"
	}
#line 360 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	(*array)[(*length)++] = *value;
#line 2785 "LibraryWindow.c"
}


static void _vala_array_add77 (GtkActionEntry** array, int* length, int* size, const GtkActionEntry* value) {
#line 364 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if ((*length) == (*size)) {
#line 364 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 364 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		*array = g_renew (GtkActionEntry, *array, *size);
#line 2796 "LibraryWindow.c"
	}
#line 364 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	(*array)[(*length)++] = *value;
#line 2800 "LibraryWindow.c"
}


static GtkActionEntry* library_window_create_common_actions (LibraryWindow* self, int* result_length1) {
	GtkActionEntry* result = NULL;
	GtkActionEntry* actions = NULL;
	GtkActionEntry* _tmp0_ = NULL;
	gint actions_length1 = 0;
	gint _actions_size_ = 0;
	GtkActionEntry import = {0};
	GtkActionEntry _tmp1_ = {0};
	const gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	GtkActionEntry* _tmp4_ = NULL;
	gint _tmp4__length1 = 0;
	GtkActionEntry _tmp5_ = {0};
	GtkActionEntry import_from_external = {0};
	GtkActionEntry _tmp6_ = {0};
	const gchar* _tmp7_ = NULL;
	GtkActionEntry* _tmp8_ = NULL;
	gint _tmp8__length1 = 0;
	GtkActionEntry _tmp9_ = {0};
	GtkActionEntry sort = {0};
	GtkActionEntry _tmp10_ = {0};
	const gchar* _tmp11_ = NULL;
	GtkActionEntry* _tmp12_ = NULL;
	gint _tmp12__length1 = 0;
	GtkActionEntry _tmp13_ = {0};
	GtkActionEntry preferences = {0};
	GtkActionEntry _tmp14_ = {0};
	GtkActionEntry* _tmp15_ = NULL;
	gint _tmp15__length1 = 0;
	GtkActionEntry _tmp16_ = {0};
	GtkActionEntry empty = {0};
	GtkActionEntry _tmp17_ = {0};
	const gchar* _tmp18_ = NULL;
	const gchar* _tmp19_ = NULL;
	GtkActionEntry* _tmp20_ = NULL;
	gint _tmp20__length1 = 0;
	GtkActionEntry _tmp21_ = {0};
	GtkActionEntry jump_to_event = {0};
	GtkActionEntry _tmp22_ = {0};
	const gchar* _tmp23_ = NULL;
	GtkActionEntry* _tmp24_ = NULL;
	gint _tmp24__length1 = 0;
	GtkActionEntry _tmp25_ = {0};
	GtkActionEntry find = {0};
	GtkActionEntry _tmp26_ = {0};
	const gchar* _tmp27_ = NULL;
	const gchar* _tmp28_ = NULL;
	GtkActionEntry* _tmp29_ = NULL;
	gint _tmp29__length1 = 0;
	GtkActionEntry _tmp30_ = {0};
	GtkActionEntry filter_photos = {0};
	GtkActionEntry _tmp31_ = {0};
	GtkActionEntry* _tmp32_ = NULL;
	gint _tmp32__length1 = 0;
	GtkActionEntry _tmp33_ = {0};
	GtkActionEntry new_search = {0};
	GtkActionEntry _tmp34_ = {0};
	const gchar* _tmp35_ = NULL;
	GtkActionEntry* _tmp36_ = NULL;
	gint _tmp36__length1 = 0;
	GtkActionEntry _tmp37_ = {0};
	GtkActionEntry file = {0};
	GtkActionEntry _tmp38_ = {0};
	const gchar* _tmp39_ = NULL;
	GtkActionEntry* _tmp40_ = NULL;
	gint _tmp40__length1 = 0;
	GtkActionEntry _tmp41_ = {0};
	GtkActionEntry edit = {0};
	GtkActionEntry _tmp42_ = {0};
	const gchar* _tmp43_ = NULL;
	GtkActionEntry* _tmp44_ = NULL;
	gint _tmp44__length1 = 0;
	GtkActionEntry _tmp45_ = {0};
	GtkActionEntry view = {0};
	GtkActionEntry _tmp46_ = {0};
	const gchar* _tmp47_ = NULL;
	GtkActionEntry* _tmp48_ = NULL;
	gint _tmp48__length1 = 0;
	GtkActionEntry _tmp49_ = {0};
	GtkActionEntry photo = {0};
	GtkActionEntry _tmp50_ = {0};
	const gchar* _tmp51_ = NULL;
	GtkActionEntry* _tmp52_ = NULL;
	gint _tmp52__length1 = 0;
	GtkActionEntry _tmp53_ = {0};
	GtkActionEntry photos = {0};
	GtkActionEntry _tmp54_ = {0};
	const gchar* _tmp55_ = NULL;
	GtkActionEntry* _tmp56_ = NULL;
	gint _tmp56__length1 = 0;
	GtkActionEntry _tmp57_ = {0};
	GtkActionEntry event = {0};
	GtkActionEntry _tmp58_ = {0};
	const gchar* _tmp59_ = NULL;
	GtkActionEntry* _tmp60_ = NULL;
	gint _tmp60__length1 = 0;
	GtkActionEntry _tmp61_ = {0};
	GtkActionEntry tags = {0};
	GtkActionEntry _tmp62_ = {0};
	const gchar* _tmp63_ = NULL;
	GtkActionEntry* _tmp64_ = NULL;
	gint _tmp64__length1 = 0;
	GtkActionEntry _tmp65_ = {0};
	GtkActionEntry help = {0};
	GtkActionEntry _tmp66_ = {0};
	const gchar* _tmp67_ = NULL;
	GtkActionEntry* _tmp68_ = NULL;
	gint _tmp68__length1 = 0;
	GtkActionEntry _tmp69_ = {0};
	GtkActionEntry* _tmp70_ = NULL;
	gint _tmp70__length1 = 0;
#line 280 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_val_if_fail (IS_LIBRARY_WINDOW (self), NULL);
#line 281 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = g_new0 (GtkActionEntry, 0);
#line 281 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	actions = _tmp0_;
#line 281 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	actions_length1 = 0;
#line 281 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_actions_size_ = actions_length1;
#line 283 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_.name = "CommonFileImport";
#line 283 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_.stock_id = RESOURCES_IMPORT;
#line 283 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_.label = TRANSLATABLE;
#line 283 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_.accelerator = "<Ctrl>I";
#line 283 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_.tooltip = TRANSLATABLE;
#line 283 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_.callback = (GCallback) _library_window_on_file_import_gtk_action_callback;
#line 283 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	import = _tmp1_;
#line 285 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp2_ = _ ("_Import From Folder...");
#line 285 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	import.label = _tmp2_;
#line 286 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp3_ = _ ("Import photos from disk to library");
#line 286 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	import.tooltip = _tmp3_;
#line 287 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp4_ = actions;
#line 287 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp4__length1 = actions_length1;
#line 287 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp5_ = import;
#line 287 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_vala_array_add61 (&actions, &actions_length1, &_actions_size_, &_tmp5_);
#line 289 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp6_.name = "ExternalLibraryImport";
#line 289 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp6_.stock_id = RESOURCES_IMPORT;
#line 289 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp6_.label = TRANSLATABLE;
#line 289 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp6_.accelerator = NULL;
#line 289 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp6_.tooltip = TRANSLATABLE;
#line 289 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp6_.callback = (GCallback) _library_window_on_external_library_import_gtk_action_callback;
#line 289 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	import_from_external = _tmp6_;
#line 293 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp7_ = _ ("Import From _Application...");
#line 293 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	import_from_external.label = _tmp7_;
#line 294 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp8_ = actions;
#line 294 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp8__length1 = actions_length1;
#line 294 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp9_ = import_from_external;
#line 294 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_vala_array_add62 (&actions, &actions_length1, &_actions_size_, &_tmp9_);
#line 296 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp10_.name = "CommonSortEvents";
#line 296 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp10_.stock_id = NULL;
#line 296 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp10_.label = TRANSLATABLE;
#line 296 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp10_.accelerator = NULL;
#line 296 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp10_.tooltip = NULL;
#line 296 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp10_.callback = (GCallback) NULL;
#line 296 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	sort = _tmp10_;
#line 297 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp11_ = _ ("Sort _Events");
#line 297 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	sort.label = _tmp11_;
#line 298 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp12_ = actions;
#line 298 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp12__length1 = actions_length1;
#line 298 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp13_ = sort;
#line 298 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_vala_array_add63 (&actions, &actions_length1, &_actions_size_, &_tmp13_);
#line 300 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp14_.name = "CommonPreferences";
#line 300 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp14_.stock_id = RESOURCES_PREFERENCES_LABEL;
#line 300 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp14_.label = TRANSLATABLE;
#line 300 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp14_.accelerator = NULL;
#line 300 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp14_.tooltip = TRANSLATABLE;
#line 300 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp14_.callback = (GCallback) _library_window_on_preferences_gtk_action_callback;
#line 300 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	preferences = _tmp14_;
#line 302 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	preferences.label = RESOURCES_PREFERENCES_MENU;
#line 303 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp15_ = actions;
#line 303 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp15__length1 = actions_length1;
#line 303 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp16_ = preferences;
#line 303 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_vala_array_add64 (&actions, &actions_length1, &_actions_size_, &_tmp16_);
#line 305 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp17_.name = "CommonEmptyTrash";
#line 305 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp17_.stock_id = NULL;
#line 305 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp17_.label = TRANSLATABLE;
#line 305 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp17_.accelerator = NULL;
#line 305 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp17_.tooltip = NULL;
#line 305 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp17_.callback = (GCallback) _library_window_on_empty_trash_gtk_action_callback;
#line 305 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	empty = _tmp17_;
#line 307 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp18_ = _ ("Empty T_rash");
#line 307 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	empty.label = _tmp18_;
#line 308 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp19_ = _ ("Delete all photos in the trash");
#line 308 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	empty.tooltip = _tmp19_;
#line 309 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp20_ = actions;
#line 309 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp20__length1 = actions_length1;
#line 309 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp21_ = empty;
#line 309 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_vala_array_add65 (&actions, &actions_length1, &_actions_size_, &_tmp21_);
#line 311 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp22_.name = "CommonJumpToEvent";
#line 311 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp22_.stock_id = NULL;
#line 311 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp22_.label = TRANSLATABLE;
#line 311 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp22_.accelerator = NULL;
#line 311 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp22_.tooltip = TRANSLATABLE;
#line 311 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp22_.callback = (GCallback) _library_window_on_jump_to_event_gtk_action_callback;
#line 311 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	jump_to_event = _tmp22_;
#line 313 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp23_ = _ ("View Eve_nt for Photo");
#line 313 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	jump_to_event.label = _tmp23_;
#line 314 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp24_ = actions;
#line 314 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp24__length1 = actions_length1;
#line 314 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp25_ = jump_to_event;
#line 314 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_vala_array_add66 (&actions, &actions_length1, &_actions_size_, &_tmp25_);
#line 316 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp26_.name = "CommonFind";
#line 316 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp26_.stock_id = NULL;
#line 316 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp26_.label = TRANSLATABLE;
#line 316 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp26_.accelerator = NULL;
#line 316 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp26_.tooltip = NULL;
#line 316 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp26_.callback = (GCallback) _library_window_on_find_gtk_action_callback;
#line 316 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	find = _tmp26_;
#line 317 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp27_ = _ ("_Find");
#line 317 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	find.label = _tmp27_;
#line 318 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp28_ = _ ("Find photos and videos by search criteria");
#line 318 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	find.tooltip = _tmp28_;
#line 319 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp29_ = actions;
#line 319 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp29__length1 = actions_length1;
#line 319 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp30_ = find;
#line 319 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_vala_array_add67 (&actions, &actions_length1, &_actions_size_, &_tmp30_);
#line 323 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp31_.name = "CommonFilterPhotos";
#line 323 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp31_.stock_id = NULL;
#line 323 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp31_.label = TRANSLATABLE;
#line 323 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp31_.accelerator = NULL;
#line 323 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp31_.tooltip = NULL;
#line 323 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp31_.callback = (GCallback) NULL;
#line 323 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	filter_photos = _tmp31_;
#line 324 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	filter_photos.label = RESOURCES_FILTER_PHOTOS_MENU;
#line 325 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp32_ = actions;
#line 325 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp32__length1 = actions_length1;
#line 325 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp33_ = filter_photos;
#line 325 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_vala_array_add68 (&actions, &actions_length1, &_actions_size_, &_tmp33_);
#line 327 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp34_.name = "CommonNewSearch";
#line 327 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp34_.stock_id = NULL;
#line 327 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp34_.label = TRANSLATABLE;
#line 327 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp34_.accelerator = "<Ctrl>S";
#line 327 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp34_.tooltip = NULL;
#line 327 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp34_.callback = (GCallback) _library_window_on_new_search_gtk_action_callback;
#line 327 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	new_search = _tmp34_;
#line 329 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp35_ = _ ("Ne_w Saved Search...");
#line 329 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	new_search.label = _tmp35_;
#line 330 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp36_ = actions;
#line 330 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp36__length1 = actions_length1;
#line 330 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp37_ = new_search;
#line 330 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_vala_array_add69 (&actions, &actions_length1, &_actions_size_, &_tmp37_);
#line 334 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp38_.name = "FileMenu";
#line 334 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp38_.stock_id = NULL;
#line 334 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp38_.label = TRANSLATABLE;
#line 334 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp38_.accelerator = NULL;
#line 334 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp38_.tooltip = NULL;
#line 334 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp38_.callback = (GCallback) NULL;
#line 334 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	file = _tmp38_;
#line 335 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp39_ = _ ("_File");
#line 335 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	file.label = _tmp39_;
#line 336 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp40_ = actions;
#line 336 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp40__length1 = actions_length1;
#line 336 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp41_ = file;
#line 336 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_vala_array_add70 (&actions, &actions_length1, &_actions_size_, &_tmp41_);
#line 338 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp42_.name = "EditMenu";
#line 338 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp42_.stock_id = NULL;
#line 338 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp42_.label = TRANSLATABLE;
#line 338 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp42_.accelerator = NULL;
#line 338 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp42_.tooltip = NULL;
#line 338 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp42_.callback = (GCallback) NULL;
#line 338 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	edit = _tmp42_;
#line 339 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp43_ = _ ("_Edit");
#line 339 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	edit.label = _tmp43_;
#line 340 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp44_ = actions;
#line 340 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp44__length1 = actions_length1;
#line 340 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp45_ = edit;
#line 340 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_vala_array_add71 (&actions, &actions_length1, &_actions_size_, &_tmp45_);
#line 342 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp46_.name = "ViewMenu";
#line 342 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp46_.stock_id = NULL;
#line 342 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp46_.label = TRANSLATABLE;
#line 342 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp46_.accelerator = NULL;
#line 342 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp46_.tooltip = NULL;
#line 342 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp46_.callback = (GCallback) NULL;
#line 342 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	view = _tmp46_;
#line 343 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp47_ = _ ("_View");
#line 343 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	view.label = _tmp47_;
#line 344 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp48_ = actions;
#line 344 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp48__length1 = actions_length1;
#line 344 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp49_ = view;
#line 344 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_vala_array_add72 (&actions, &actions_length1, &_actions_size_, &_tmp49_);
#line 346 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp50_.name = "PhotoMenu";
#line 346 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp50_.stock_id = NULL;
#line 346 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp50_.label = TRANSLATABLE;
#line 346 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp50_.accelerator = NULL;
#line 346 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp50_.tooltip = NULL;
#line 346 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp50_.callback = (GCallback) NULL;
#line 346 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	photo = _tmp50_;
#line 347 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp51_ = _ ("_Photo");
#line 347 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	photo.label = _tmp51_;
#line 348 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp52_ = actions;
#line 348 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp52__length1 = actions_length1;
#line 348 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp53_ = photo;
#line 348 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_vala_array_add73 (&actions, &actions_length1, &_actions_size_, &_tmp53_);
#line 350 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp54_.name = "PhotosMenu";
#line 350 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp54_.stock_id = NULL;
#line 350 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp54_.label = TRANSLATABLE;
#line 350 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp54_.accelerator = NULL;
#line 350 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp54_.tooltip = NULL;
#line 350 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp54_.callback = (GCallback) NULL;
#line 350 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	photos = _tmp54_;
#line 351 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp55_ = _ ("_Photos");
#line 351 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	photos.label = _tmp55_;
#line 352 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp56_ = actions;
#line 352 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp56__length1 = actions_length1;
#line 352 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp57_ = photos;
#line 352 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_vala_array_add74 (&actions, &actions_length1, &_actions_size_, &_tmp57_);
#line 354 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp58_.name = "EventsMenu";
#line 354 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp58_.stock_id = NULL;
#line 354 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp58_.label = TRANSLATABLE;
#line 354 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp58_.accelerator = NULL;
#line 354 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp58_.tooltip = NULL;
#line 354 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp58_.callback = (GCallback) NULL;
#line 354 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	event = _tmp58_;
#line 355 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp59_ = _ ("Even_ts");
#line 355 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	event.label = _tmp59_;
#line 356 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp60_ = actions;
#line 356 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp60__length1 = actions_length1;
#line 356 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp61_ = event;
#line 356 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_vala_array_add75 (&actions, &actions_length1, &_actions_size_, &_tmp61_);
#line 358 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp62_.name = "TagsMenu";
#line 358 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp62_.stock_id = NULL;
#line 358 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp62_.label = TRANSLATABLE;
#line 358 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp62_.accelerator = NULL;
#line 358 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp62_.tooltip = NULL;
#line 358 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp62_.callback = (GCallback) NULL;
#line 358 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	tags = _tmp62_;
#line 359 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp63_ = _ ("Ta_gs");
#line 359 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	tags.label = _tmp63_;
#line 360 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp64_ = actions;
#line 360 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp64__length1 = actions_length1;
#line 360 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp65_ = tags;
#line 360 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_vala_array_add76 (&actions, &actions_length1, &_actions_size_, &_tmp65_);
#line 362 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp66_.name = "HelpMenu";
#line 362 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp66_.stock_id = NULL;
#line 362 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp66_.label = TRANSLATABLE;
#line 362 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp66_.accelerator = NULL;
#line 362 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp66_.tooltip = NULL;
#line 362 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp66_.callback = (GCallback) NULL;
#line 362 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	help = _tmp66_;
#line 363 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp67_ = _ ("_Help");
#line 363 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	help.label = _tmp67_;
#line 364 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp68_ = actions;
#line 364 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp68__length1 = actions_length1;
#line 364 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp69_ = help;
#line 364 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_vala_array_add77 (&actions, &actions_length1, &_actions_size_, &_tmp69_);
#line 366 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp70_ = actions;
#line 366 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp70__length1 = actions_length1;
#line 366 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (result_length1) {
#line 366 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		*result_length1 = _tmp70__length1;
#line 3383 "LibraryWindow.c"
	}
#line 366 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	result = _tmp70_;
#line 366 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	return result;
#line 3389 "LibraryWindow.c"
}


static void _library_window_on_display_basic_properties_gtk_action_callback (GtkAction* action, gpointer self) {
#line 372 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_window_on_display_basic_properties ((LibraryWindow*) self, action);
#line 3396 "LibraryWindow.c"
}


static void _vala_array_add78 (GtkToggleActionEntry** array, int* length, int* size, const GtkToggleActionEntry* value) {
#line 376 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if ((*length) == (*size)) {
#line 376 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 376 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		*array = g_renew (GtkToggleActionEntry, *array, *size);
#line 3407 "LibraryWindow.c"
	}
#line 376 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	(*array)[(*length)++] = *value;
#line 3411 "LibraryWindow.c"
}


static void _library_window_on_display_extended_properties_gtk_action_callback (GtkAction* action, gpointer self) {
#line 378 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_window_on_display_extended_properties ((LibraryWindow*) self, action);
#line 3418 "LibraryWindow.c"
}


static void _vala_array_add79 (GtkToggleActionEntry** array, int* length, int* size, const GtkToggleActionEntry* value) {
#line 382 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if ((*length) == (*size)) {
#line 382 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 382 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		*array = g_renew (GtkToggleActionEntry, *array, *size);
#line 3429 "LibraryWindow.c"
	}
#line 382 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	(*array)[(*length)++] = *value;
#line 3433 "LibraryWindow.c"
}


static void _library_window_on_display_searchbar_gtk_action_callback (GtkAction* action, gpointer self) {
#line 384 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_window_on_display_searchbar ((LibraryWindow*) self, action);
#line 3440 "LibraryWindow.c"
}


static void _vala_array_add80 (GtkToggleActionEntry** array, int* length, int* size, const GtkToggleActionEntry* value) {
#line 388 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if ((*length) == (*size)) {
#line 388 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 388 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		*array = g_renew (GtkToggleActionEntry, *array, *size);
#line 3451 "LibraryWindow.c"
	}
#line 388 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	(*array)[(*length)++] = *value;
#line 3455 "LibraryWindow.c"
}


static void _library_window_on_display_sidebar_gtk_action_callback (GtkAction* action, gpointer self) {
#line 390 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_window_on_display_sidebar ((LibraryWindow*) self, action);
#line 3462 "LibraryWindow.c"
}


static void _vala_array_add81 (GtkToggleActionEntry** array, int* length, int* size, const GtkToggleActionEntry* value) {
#line 394 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if ((*length) == (*size)) {
#line 394 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 394 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		*array = g_renew (GtkToggleActionEntry, *array, *size);
#line 3473 "LibraryWindow.c"
	}
#line 394 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	(*array)[(*length)++] = *value;
#line 3477 "LibraryWindow.c"
}


static void _library_window_on_display_toolbar_gtk_action_callback (GtkAction* action, gpointer self) {
#line 396 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_window_on_display_toolbar ((LibraryWindow*) self, action);
#line 3484 "LibraryWindow.c"
}


static void _vala_array_add82 (GtkToggleActionEntry** array, int* length, int* size, const GtkToggleActionEntry* value) {
#line 400 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if ((*length) == (*size)) {
#line 400 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 400 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		*array = g_renew (GtkToggleActionEntry, *array, *size);
#line 3495 "LibraryWindow.c"
	}
#line 400 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	(*array)[(*length)++] = *value;
#line 3499 "LibraryWindow.c"
}


static GtkToggleActionEntry* library_window_create_common_toggle_actions (LibraryWindow* self, int* result_length1) {
	GtkToggleActionEntry* result = NULL;
	GtkToggleActionEntry* actions = NULL;
	GtkToggleActionEntry* _tmp0_ = NULL;
	gint actions_length1 = 0;
	gint _actions_size_ = 0;
	GtkToggleActionEntry basic_props = {0};
	GtkToggleActionEntry _tmp1_ = {0};
	const gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	GtkToggleActionEntry* _tmp4_ = NULL;
	gint _tmp4__length1 = 0;
	GtkToggleActionEntry _tmp5_ = {0};
	GtkToggleActionEntry extended_props = {0};
	GtkToggleActionEntry _tmp6_ = {0};
	const gchar* _tmp7_ = NULL;
	const gchar* _tmp8_ = NULL;
	GtkToggleActionEntry* _tmp9_ = NULL;
	gint _tmp9__length1 = 0;
	GtkToggleActionEntry _tmp10_ = {0};
	GtkToggleActionEntry searchbar = {0};
	gboolean _tmp11_ = FALSE;
	GtkToggleActionEntry _tmp12_ = {0};
	const gchar* _tmp13_ = NULL;
	const gchar* _tmp14_ = NULL;
	GtkToggleActionEntry* _tmp15_ = NULL;
	gint _tmp15__length1 = 0;
	GtkToggleActionEntry _tmp16_ = {0};
	GtkToggleActionEntry sidebar = {0};
	gboolean _tmp17_ = FALSE;
	GtkToggleActionEntry _tmp18_ = {0};
	const gchar* _tmp19_ = NULL;
	const gchar* _tmp20_ = NULL;
	GtkToggleActionEntry* _tmp21_ = NULL;
	gint _tmp21__length1 = 0;
	GtkToggleActionEntry _tmp22_ = {0};
	GtkToggleActionEntry toolbar = {0};
	gboolean _tmp23_ = FALSE;
	GtkToggleActionEntry _tmp24_ = {0};
	const gchar* _tmp25_ = NULL;
	const gchar* _tmp26_ = NULL;
	GtkToggleActionEntry* _tmp27_ = NULL;
	gint _tmp27__length1 = 0;
	GtkToggleActionEntry _tmp28_ = {0};
	GtkToggleActionEntry* _tmp29_ = NULL;
	gint _tmp29__length1 = 0;
#line 369 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_val_if_fail (IS_LIBRARY_WINDOW (self), NULL);
#line 370 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = g_new0 (GtkToggleActionEntry, 0);
#line 370 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	actions = _tmp0_;
#line 370 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	actions_length1 = 0;
#line 370 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_actions_size_ = actions_length1;
#line 372 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_.name = "CommonDisplayBasicProperties";
#line 372 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_.stock_id = NULL;
#line 372 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_.label = TRANSLATABLE;
#line 372 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_.accelerator = "<Ctrl><Shift>I";
#line 372 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_.tooltip = TRANSLATABLE;
#line 372 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_.callback = (GCallback) _library_window_on_display_basic_properties_gtk_action_callback;
#line 372 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_.is_active = FALSE;
#line 372 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	basic_props = _tmp1_;
#line 374 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp2_ = _ ("_Basic Information");
#line 374 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	basic_props.label = _tmp2_;
#line 375 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp3_ = _ ("Display basic information for the selection");
#line 375 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	basic_props.tooltip = _tmp3_;
#line 376 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp4_ = actions;
#line 376 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp4__length1 = actions_length1;
#line 376 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp5_ = basic_props;
#line 376 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_vala_array_add78 (&actions, &actions_length1, &_actions_size_, &_tmp5_);
#line 378 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp6_.name = "CommonDisplayExtendedProperties";
#line 378 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp6_.stock_id = NULL;
#line 378 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp6_.label = TRANSLATABLE;
#line 378 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp6_.accelerator = "<Ctrl><Shift>X";
#line 378 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp6_.tooltip = TRANSLATABLE;
#line 378 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp6_.callback = (GCallback) _library_window_on_display_extended_properties_gtk_action_callback;
#line 378 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp6_.is_active = FALSE;
#line 378 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	extended_props = _tmp6_;
#line 380 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp7_ = _ ("E_xtended Information");
#line 380 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	extended_props.label = _tmp7_;
#line 381 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp8_ = _ ("Display extended information for the selection");
#line 381 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	extended_props.tooltip = _tmp8_;
#line 382 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp9_ = actions;
#line 382 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp9__length1 = actions_length1;
#line 382 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp10_ = extended_props;
#line 382 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_vala_array_add79 (&actions, &actions_length1, &_actions_size_, &_tmp10_);
#line 384 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp11_ = self->priv->is_search_toolbar_visible;
#line 384 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp12_.name = "CommonDisplaySearchbar";
#line 384 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp12_.stock_id = "edit-find";
#line 384 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp12_.label = TRANSLATABLE;
#line 384 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp12_.accelerator = "F8";
#line 384 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp12_.tooltip = TRANSLATABLE;
#line 384 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp12_.callback = (GCallback) _library_window_on_display_searchbar_gtk_action_callback;
#line 384 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp12_.is_active = _tmp11_;
#line 384 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	searchbar = _tmp12_;
#line 386 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp13_ = _ ("_Search Bar");
#line 386 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	searchbar.label = _tmp13_;
#line 387 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp14_ = _ ("Display the search bar");
#line 387 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	searchbar.tooltip = _tmp14_;
#line 388 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp15_ = actions;
#line 388 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp15__length1 = actions_length1;
#line 388 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp16_ = searchbar;
#line 388 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_vala_array_add80 (&actions, &actions_length1, &_actions_size_, &_tmp16_);
#line 390 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp17_ = library_window_is_sidebar_visible (self);
#line 390 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp18_.name = "CommonDisplaySidebar";
#line 390 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp18_.stock_id = NULL;
#line 390 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp18_.label = TRANSLATABLE;
#line 390 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp18_.accelerator = "F9";
#line 390 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp18_.tooltip = TRANSLATABLE;
#line 390 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp18_.callback = (GCallback) _library_window_on_display_sidebar_gtk_action_callback;
#line 390 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp18_.is_active = _tmp17_;
#line 390 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	sidebar = _tmp18_;
#line 392 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp19_ = _ ("S_idebar");
#line 392 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	sidebar.label = _tmp19_;
#line 393 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp20_ = _ ("Display the sidebar");
#line 393 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	sidebar.tooltip = _tmp20_;
#line 394 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp21_ = actions;
#line 394 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp21__length1 = actions_length1;
#line 394 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp22_ = sidebar;
#line 394 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_vala_array_add81 (&actions, &actions_length1, &_actions_size_, &_tmp22_);
#line 396 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp23_ = library_window_is_toolbar_visible (self);
#line 396 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp24_.name = "CommonDisplayToolbar";
#line 396 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp24_.stock_id = NULL;
#line 396 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp24_.label = TRANSLATABLE;
#line 396 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp24_.accelerator = "<Ctrl>F9";
#line 396 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp24_.tooltip = TRANSLATABLE;
#line 396 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp24_.callback = (GCallback) _library_window_on_display_toolbar_gtk_action_callback;
#line 396 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp24_.is_active = _tmp23_;
#line 396 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	toolbar = _tmp24_;
#line 398 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp25_ = _ ("T_oolbar");
#line 398 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	toolbar.label = _tmp25_;
#line 399 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp26_ = _ ("Display the tool bar");
#line 399 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	toolbar.tooltip = _tmp26_;
#line 400 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp27_ = actions;
#line 400 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp27__length1 = actions_length1;
#line 400 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp28_ = toolbar;
#line 400 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_vala_array_add82 (&actions, &actions_length1, &_actions_size_, &_tmp28_);
#line 402 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp29_ = actions;
#line 402 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp29__length1 = actions_length1;
#line 402 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (result_length1) {
#line 402 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		*result_length1 = _tmp29__length1;
#line 3733 "LibraryWindow.c"
	}
#line 402 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	result = _tmp29_;
#line 402 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	return result;
#line 3739 "LibraryWindow.c"
}


static void _vala_array_add83 (GtkRadioActionEntry** array, int* length, int* size, const GtkRadioActionEntry* value) {
#line 413 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if ((*length) == (*size)) {
#line 413 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 413 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		*array = g_renew (GtkRadioActionEntry, *array, *size);
#line 3750 "LibraryWindow.c"
	}
#line 413 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	(*array)[(*length)++] = *value;
#line 3754 "LibraryWindow.c"
}


static void _vala_array_add84 (GtkRadioActionEntry** array, int* length, int* size, const GtkRadioActionEntry* value) {
#line 420 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if ((*length) == (*size)) {
#line 420 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 420 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		*array = g_renew (GtkRadioActionEntry, *array, *size);
#line 3765 "LibraryWindow.c"
	}
#line 420 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	(*array)[(*length)++] = *value;
#line 3769 "LibraryWindow.c"
}


static void _library_window_on_events_sort_changed_gtk_radio_action_callback (GtkAction* action, GtkAction* current, gpointer self) {
#line 422 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_window_on_events_sort_changed ((LibraryWindow*) self, action, current);
#line 3776 "LibraryWindow.c"
}


static void library_window_add_common_radio_actions (LibraryWindow* self, GtkActionGroup* group) {
	GtkRadioActionEntry* actions = NULL;
	GtkRadioActionEntry* _tmp0_ = NULL;
	gint actions_length1 = 0;
	gint _actions_size_ = 0;
	GtkRadioActionEntry ascending = {0};
	GtkRadioActionEntry _tmp1_ = {0};
	const gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	GtkRadioActionEntry* _tmp4_ = NULL;
	gint _tmp4__length1 = 0;
	GtkRadioActionEntry _tmp5_ = {0};
	GtkRadioActionEntry descending = {0};
	GtkRadioActionEntry _tmp6_ = {0};
	const gchar* _tmp7_ = NULL;
	const gchar* _tmp8_ = NULL;
	GtkRadioActionEntry* _tmp9_ = NULL;
	gint _tmp9__length1 = 0;
	GtkRadioActionEntry _tmp10_ = {0};
	GtkActionGroup* _tmp11_ = NULL;
	GtkRadioActionEntry* _tmp12_ = NULL;
	gint _tmp12__length1 = 0;
#line 405 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_LIBRARY_WINDOW (self));
#line 405 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (GTK_IS_ACTION_GROUP (group));
#line 406 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = g_new0 (GtkRadioActionEntry, 0);
#line 406 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	actions = _tmp0_;
#line 406 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	actions_length1 = 0;
#line 406 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_actions_size_ = actions_length1;
#line 408 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_.name = "CommonSortEventsAscending";
#line 408 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_.stock_id = RESOURCES_SORT_ASCENDING_LABEL;
#line 408 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_.label = TRANSLATABLE;
#line 408 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_.accelerator = NULL;
#line 408 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_.tooltip = TRANSLATABLE;
#line 408 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_.value = LIBRARY_WINDOW_SORT_EVENTS_ORDER_ASCENDING;
#line 408 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	ascending = _tmp1_;
#line 411 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp2_ = _ ("_Ascending");
#line 411 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	ascending.label = _tmp2_;
#line 412 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp3_ = _ ("Sort photos in an ascending order");
#line 412 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	ascending.tooltip = _tmp3_;
#line 413 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp4_ = actions;
#line 413 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp4__length1 = actions_length1;
#line 413 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp5_ = ascending;
#line 413 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_vala_array_add83 (&actions, &actions_length1, &_actions_size_, &_tmp5_);
#line 415 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp6_.name = "CommonSortEventsDescending";
#line 415 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp6_.stock_id = RESOURCES_SORT_DESCENDING_LABEL;
#line 415 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp6_.label = TRANSLATABLE;
#line 415 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp6_.accelerator = NULL;
#line 415 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp6_.tooltip = TRANSLATABLE;
#line 415 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp6_.value = LIBRARY_WINDOW_SORT_EVENTS_ORDER_DESCENDING;
#line 415 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	descending = _tmp6_;
#line 418 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp7_ = _ ("D_escending");
#line 418 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	descending.label = _tmp7_;
#line 419 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp8_ = _ ("Sort photos in a descending order");
#line 419 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	descending.tooltip = _tmp8_;
#line 420 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp9_ = actions;
#line 420 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp9__length1 = actions_length1;
#line 420 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp10_ = descending;
#line 420 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_vala_array_add84 (&actions, &actions_length1, &_actions_size_, &_tmp10_);
#line 422 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp11_ = group;
#line 422 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp12_ = actions;
#line 422 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp12__length1 = actions_length1;
#line 422 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	gtk_action_group_add_radio_actions (_tmp11_, _tmp12_, _tmp12__length1, LIBRARY_WINDOW_SORT_EVENTS_ORDER_ASCENDING, (GCallback) _library_window_on_events_sort_changed_gtk_radio_action_callback, self);
#line 405 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	actions = (g_free (actions), NULL);
#line 3884 "LibraryWindow.c"
}


static void _vala_array_add85 (GtkActionGroup*** array, int* length, int* size, GtkActionGroup* value) {
#line 438 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if ((*length) == (*size)) {
#line 438 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 438 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		*array = g_renew (GtkActionGroup*, *array, (*size) + 1);
#line 3895 "LibraryWindow.c"
	}
#line 438 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	(*array)[(*length)++] = value;
#line 438 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	(*array)[*length] = NULL;
#line 3901 "LibraryWindow.c"
}


static void _vala_array_add86 (GtkActionGroup*** array, int* length, int* size, GtkActionGroup* value) {
#line 439 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if ((*length) == (*size)) {
#line 439 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 439 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		*array = g_renew (GtkActionGroup*, *array, (*size) + 1);
#line 3912 "LibraryWindow.c"
	}
#line 439 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	(*array)[(*length)++] = value;
#line 439 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	(*array)[*length] = NULL;
#line 3918 "LibraryWindow.c"
}


static GtkActionGroup** library_window_real_create_common_action_groups (AppWindow* base, int* result_length1) {
	LibraryWindow * self;
	GtkActionGroup** result = NULL;
	GtkActionGroup** groups = NULL;
	gint _tmp0_ = 0;
	GtkActionGroup** _tmp1_ = NULL;
	gint groups_length1 = 0;
	gint _groups_size_ = 0;
	GtkActionGroup* _tmp2_ = NULL;
	gint _tmp3_ = 0;
	GtkActionEntry* _tmp4_ = NULL;
	GtkActionEntry* _tmp5_ = NULL;
	gint _tmp5__length1 = 0;
	GtkActionGroup* _tmp6_ = NULL;
	gint _tmp7_ = 0;
	GtkToggleActionEntry* _tmp8_ = NULL;
	GtkToggleActionEntry* _tmp9_ = NULL;
	gint _tmp9__length1 = 0;
	GtkActionGroup* _tmp10_ = NULL;
	GtkAction* action = NULL;
	GtkActionGroup* _tmp11_ = NULL;
	GtkAction* _tmp12_ = NULL;
	GtkAction* _tmp13_ = NULL;
	GtkAction* _tmp14_ = NULL;
	GtkActionGroup** _tmp17_ = NULL;
	gint _tmp17__length1 = 0;
	GtkActionGroup* _tmp18_ = NULL;
	GtkActionGroup* _tmp19_ = NULL;
	GtkActionGroup** _tmp20_ = NULL;
	gint _tmp20__length1 = 0;
	SearchFilterActions* _tmp21_ = NULL;
	GtkActionGroup* _tmp22_ = NULL;
	GtkActionGroup** _tmp23_ = NULL;
	gint _tmp23__length1 = 0;
#line 425 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_LIBRARY_WINDOW, LibraryWindow);
#line 426 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_ = APP_WINDOW_CLASS (library_window_parent_class)->create_common_action_groups (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_APP_WINDOW, AppWindow), &_tmp0_);
#line 426 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	groups = _tmp1_;
#line 426 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	groups_length1 = _tmp0_;
#line 426 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_groups_size_ = groups_length1;
#line 428 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp2_ = self->priv->common_action_group;
#line 428 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp4_ = library_window_create_common_actions (self, &_tmp3_);
#line 428 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp5_ = _tmp4_;
#line 428 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp5__length1 = _tmp3_;
#line 428 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	gtk_action_group_add_actions (_tmp2_, _tmp5_, _tmp3_, self);
#line 428 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp5_ = (g_free (_tmp5_), NULL);
#line 429 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp6_ = self->priv->common_action_group;
#line 429 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp8_ = library_window_create_common_toggle_actions (self, &_tmp7_);
#line 429 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp9_ = _tmp8_;
#line 429 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp9__length1 = _tmp7_;
#line 429 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	gtk_action_group_add_toggle_actions (_tmp6_, _tmp9_, _tmp7_, self);
#line 429 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp9_ = (g_free (_tmp9_), NULL);
#line 430 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp10_ = self->priv->common_action_group;
#line 430 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_window_add_common_radio_actions (self, _tmp10_);
#line 432 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp11_ = self->priv->common_action_group;
#line 432 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp12_ = gtk_action_group_get_action (_tmp11_, "CommonDisplaySearchbar");
#line 432 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp13_ = _g_object_ref0 (_tmp12_);
#line 432 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	action = _tmp13_;
#line 433 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp14_ = action;
#line 433 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp14_ != NULL) {
#line 4006 "LibraryWindow.c"
		GtkAction* _tmp15_ = NULL;
		GtkAction* _tmp16_ = NULL;
#line 434 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp15_ = action;
#line 434 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		gtk_action_set_short_label (_tmp15_, RESOURCES_FIND_LABEL);
#line 435 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp16_ = action;
#line 435 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		gtk_action_set_is_important (_tmp16_, TRUE);
#line 4017 "LibraryWindow.c"
	}
#line 438 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp17_ = groups;
#line 438 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp17__length1 = groups_length1;
#line 438 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp18_ = self->priv->common_action_group;
#line 438 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp19_ = _g_object_ref0 (_tmp18_);
#line 438 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_vala_array_add85 (&groups, &groups_length1, &_groups_size_, _tmp19_);
#line 439 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp20_ = groups;
#line 439 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp20__length1 = groups_length1;
#line 439 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp21_ = self->priv->search_actions;
#line 439 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp22_ = search_filter_actions_get_action_group (_tmp21_);
#line 439 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_vala_array_add86 (&groups, &groups_length1, &_groups_size_, _tmp22_);
#line 441 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp23_ = groups;
#line 441 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp23__length1 = groups_length1;
#line 441 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (result_length1) {
#line 441 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		*result_length1 = _tmp23__length1;
#line 4047 "LibraryWindow.c"
	}
#line 441 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	result = _tmp23_;
#line 441 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (action);
#line 441 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	return result;
#line 4055 "LibraryWindow.c"
}


static void library_window_real_replace_common_placeholders (AppWindow* base, GtkUIManager* ui) {
	LibraryWindow * self;
	GtkUIManager* _tmp0_ = NULL;
#line 444 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_LIBRARY_WINDOW, LibraryWindow);
#line 444 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (GTK_IS_UI_MANAGER (ui));
#line 445 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = ui;
#line 445 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	APP_WINDOW_CLASS (library_window_parent_class)->replace_common_placeholders (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_APP_WINDOW, AppWindow), _tmp0_);
#line 4070 "LibraryWindow.c"
}


static void _library_window_on_view_filter_installed_view_collection_view_filter_installed (ViewCollection* _sender, ViewFilter* filer, gpointer self) {
#line 453 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_window_on_view_filter_installed ((LibraryWindow*) self, filer);
#line 4077 "LibraryWindow.c"
}


static void _library_window_on_view_filter_removed_view_collection_view_filter_removed (ViewCollection* _sender, ViewFilter* filer, gpointer self) {
#line 454 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_window_on_view_filter_removed ((LibraryWindow*) self, filer);
#line 4084 "LibraryWindow.c"
}


static void library_window_real_switched_pages (PageWindow* base, Page* old_page, Page* new_page) {
	LibraryWindow * self;
	Page* _tmp0_ = NULL;
	Page* _tmp1_ = NULL;
	Page* _tmp2_ = NULL;
	Page* _tmp11_ = NULL;
	SearchFilterActions* _tmp18_ = NULL;
	Page* _tmp19_ = NULL;
	Page* _tmp20_ = NULL;
#line 448 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_LIBRARY_WINDOW, LibraryWindow);
#line 448 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail ((old_page == NULL) || IS_PAGE (old_page));
#line 448 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail ((new_page == NULL) || IS_PAGE (new_page));
#line 449 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = old_page;
#line 449 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_ = new_page;
#line 449 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	PAGE_WINDOW_CLASS (library_window_parent_class)->switched_pages (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_APP_WINDOW, AppWindow), TYPE_PAGE_WINDOW, PageWindow), _tmp0_, _tmp1_);
#line 452 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp2_ = old_page;
#line 452 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp2_ != NULL) {
#line 4113 "LibraryWindow.c"
		Page* _tmp3_ = NULL;
		ViewCollection* _tmp4_ = NULL;
		ViewCollection* _tmp5_ = NULL;
		guint _tmp6_ = 0U;
		Page* _tmp7_ = NULL;
		ViewCollection* _tmp8_ = NULL;
		ViewCollection* _tmp9_ = NULL;
		guint _tmp10_ = 0U;
#line 453 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp3_ = old_page;
#line 453 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp4_ = page_get_view (_tmp3_);
#line 453 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp5_ = _tmp4_;
#line 453 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		g_signal_parse_name ("view-filter-installed", TYPE_VIEW_COLLECTION, &_tmp6_, NULL, FALSE);
#line 453 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		g_signal_handlers_disconnect_matched (_tmp5_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp6_, 0, NULL, (GCallback) _library_window_on_view_filter_installed_view_collection_view_filter_installed, self);
#line 453 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_data_collection_unref0 (_tmp5_);
#line 454 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp7_ = old_page;
#line 454 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp8_ = page_get_view (_tmp7_);
#line 454 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp9_ = _tmp8_;
#line 454 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		g_signal_parse_name ("view-filter-removed", TYPE_VIEW_COLLECTION, &_tmp10_, NULL, FALSE);
#line 454 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		g_signal_handlers_disconnect_matched (_tmp9_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp10_, 0, NULL, (GCallback) _library_window_on_view_filter_removed_view_collection_view_filter_removed, self);
#line 454 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_data_collection_unref0 (_tmp9_);
#line 4146 "LibraryWindow.c"
	}
#line 457 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp11_ = new_page;
#line 457 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp11_ != NULL) {
#line 4152 "LibraryWindow.c"
		Page* _tmp12_ = NULL;
		ViewCollection* _tmp13_ = NULL;
		ViewCollection* _tmp14_ = NULL;
		Page* _tmp15_ = NULL;
		ViewCollection* _tmp16_ = NULL;
		ViewCollection* _tmp17_ = NULL;
#line 458 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp12_ = new_page;
#line 458 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp13_ = page_get_view (_tmp12_);
#line 458 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp14_ = _tmp13_;
#line 458 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		g_signal_connect_object (_tmp14_, "view-filter-installed", (GCallback) _library_window_on_view_filter_installed_view_collection_view_filter_installed, self, 0);
#line 458 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_data_collection_unref0 (_tmp14_);
#line 459 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp15_ = new_page;
#line 459 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp16_ = page_get_view (_tmp15_);
#line 459 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp17_ = _tmp16_;
#line 459 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		g_signal_connect_object (_tmp17_, "view-filter-removed", (GCallback) _library_window_on_view_filter_removed_view_collection_view_filter_removed, self, 0);
#line 459 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_data_collection_unref0 (_tmp17_);
#line 4179 "LibraryWindow.c"
	}
#line 462 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp18_ = self->priv->search_actions;
#line 462 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp19_ = old_page;
#line 462 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp20_ = new_page;
#line 462 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	search_filter_actions_monitor_page_contents (_tmp18_, _tmp19_, _tmp20_);
#line 4189 "LibraryWindow.c"
}


static void _library_window_on_view_filter_refreshed_view_filter_refresh (ViewFilter* _sender, gpointer self) {
#line 466 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_window_on_view_filter_refreshed ((LibraryWindow*) self);
#line 4196 "LibraryWindow.c"
}


static void library_window_on_view_filter_installed (LibraryWindow* self, ViewFilter* filter) {
	ViewFilter* _tmp0_ = NULL;
#line 465 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_LIBRARY_WINDOW (self));
#line 465 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_VIEW_FILTER (filter));
#line 466 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = filter;
#line 466 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_signal_connect_object (_tmp0_, "refresh", (GCallback) _library_window_on_view_filter_refreshed_view_filter_refresh, self, 0);
#line 4210 "LibraryWindow.c"
}


static void library_window_on_view_filter_removed (LibraryWindow* self, ViewFilter* filter) {
	ViewFilter* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
#line 469 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_LIBRARY_WINDOW (self));
#line 469 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_VIEW_FILTER (filter));
#line 470 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = filter;
#line 470 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_signal_parse_name ("refresh", TYPE_VIEW_FILTER, &_tmp1_, NULL, FALSE);
#line 470 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _library_window_on_view_filter_refreshed_view_filter_refresh, self);
#line 4227 "LibraryWindow.c"
}


static void library_window_on_view_filter_refreshed (LibraryWindow* self) {
	Page* _tmp0_ = NULL;
	Page* _tmp1_ = NULL;
	ViewCollection* _tmp2_ = NULL;
	ViewCollection* _tmp3_ = NULL;
	gboolean _tmp4_ = FALSE;
	gboolean _tmp5_ = FALSE;
	GtkToggleAction* display_searchbar = NULL;
	GtkAction* _tmp6_ = NULL;
	GtkToggleAction* _tmp7_ = NULL;
	GtkToggleAction* _tmp8_ = NULL;
#line 473 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_LIBRARY_WINDOW (self));
#line 476 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = page_window_get_current_page (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE_WINDOW, PageWindow));
#line 476 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_ = _tmp0_;
#line 476 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp2_ = page_get_view (_tmp1_);
#line 476 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp3_ = _tmp2_;
#line 476 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp4_ = view_collection_are_items_filtered_out (_tmp3_);
#line 476 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp5_ = !_tmp4_;
#line 476 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_data_collection_unref0 (_tmp3_);
#line 476 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (_tmp1_);
#line 476 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp5_) {
#line 477 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		return;
#line 4264 "LibraryWindow.c"
	}
#line 480 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp6_ = app_window_get_common_action (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_APP_WINDOW, AppWindow), "CommonDisplaySearchbar");
#line 480 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp7_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp6_, gtk_toggle_action_get_type ()) ? ((GtkToggleAction*) _tmp6_) : NULL;
#line 480 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp7_ == NULL) {
#line 480 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_object_unref0 (_tmp6_);
#line 4274 "LibraryWindow.c"
	}
#line 480 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	display_searchbar = _tmp7_;
#line 482 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp8_ = display_searchbar;
#line 482 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp8_ != NULL) {
#line 4282 "LibraryWindow.c"
		GtkToggleAction* _tmp9_ = NULL;
#line 483 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp9_ = display_searchbar;
#line 483 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		gtk_toggle_action_set_active (_tmp9_, TRUE);
#line 4288 "LibraryWindow.c"
	}
#line 473 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (display_searchbar);
#line 4292 "LibraryWindow.c"
}


static void library_window_real_show_all (GtkWidget* base) {
	LibraryWindow * self;
	GtkToggleAction* basic_properties_action = NULL;
	Page* _tmp0_ = NULL;
	Page* _tmp1_ = NULL;
	GtkAction* _tmp2_ = NULL;
	GtkToggleAction* _tmp3_ = NULL;
	GtkToggleAction* _tmp4_ = NULL;
	GtkToggleAction* _tmp5_ = NULL;
	GtkToggleAction* _tmp6_ = NULL;
	gboolean _tmp7_ = FALSE;
	GtkToggleAction* searchbar_action = NULL;
	Page* _tmp9_ = NULL;
	Page* _tmp10_ = NULL;
	GtkAction* _tmp11_ = NULL;
	GtkToggleAction* _tmp12_ = NULL;
	GtkToggleAction* _tmp13_ = NULL;
	GtkToggleAction* _tmp14_ = NULL;
	CheckerboardPage* current_page = NULL;
	Page* _tmp15_ = NULL;
	CheckerboardPage* _tmp16_ = NULL;
	CheckerboardPage* _tmp17_ = NULL;
	gboolean _tmp19_ = FALSE;
	CheckerboardPage* _tmp20_ = NULL;
	gboolean _tmp21_ = FALSE;
#line 487 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_LIBRARY_WINDOW, LibraryWindow);
#line 488 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	GTK_WIDGET_CLASS (library_window_parent_class)->show_all (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_APP_WINDOW, AppWindow), gtk_widget_get_type (), GtkWidget));
#line 490 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = page_window_get_current_page (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE_WINDOW, PageWindow));
#line 490 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_ = _tmp0_;
#line 490 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp2_ = page_get_common_action (_tmp1_, "CommonDisplayBasicProperties", TRUE);
#line 490 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp3_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp2_, gtk_toggle_action_get_type ()) ? ((GtkToggleAction*) _tmp2_) : NULL;
#line 490 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp3_ == NULL) {
#line 490 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_object_unref0 (_tmp2_);
#line 4337 "LibraryWindow.c"
	}
#line 490 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp4_ = _tmp3_;
#line 490 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (_tmp1_);
#line 490 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	basic_properties_action = _tmp4_;
#line 492 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp5_ = basic_properties_action;
#line 492 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_vala_assert (_tmp5_ != NULL, "basic_properties_action != null");
#line 494 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp6_ = basic_properties_action;
#line 494 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp7_ = gtk_toggle_action_get_active (_tmp6_);
#line 494 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (!_tmp7_) {
#line 4355 "LibraryWindow.c"
		GtkFrame* _tmp8_ = NULL;
#line 495 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp8_ = self->priv->bottom_frame;
#line 495 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		gtk_widget_hide (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, gtk_widget_get_type (), GtkWidget));
#line 4361 "LibraryWindow.c"
	}
#line 497 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp9_ = page_window_get_current_page (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE_WINDOW, PageWindow));
#line 497 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp10_ = _tmp9_;
#line 497 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp11_ = page_get_common_action (_tmp10_, "CommonDisplaySearchbar", TRUE);
#line 497 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp12_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp11_, gtk_toggle_action_get_type ()) ? ((GtkToggleAction*) _tmp11_) : NULL;
#line 497 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp12_ == NULL) {
#line 497 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_object_unref0 (_tmp11_);
#line 4375 "LibraryWindow.c"
	}
#line 497 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp13_ = _tmp12_;
#line 497 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (_tmp10_);
#line 497 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	searchbar_action = _tmp13_;
#line 499 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp14_ = searchbar_action;
#line 499 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_vala_assert (_tmp14_ != NULL, "searchbar_action != null");
#line 502 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp15_ = page_window_get_current_page (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE_WINDOW, PageWindow));
#line 502 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp16_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp15_, TYPE_CHECKERBOARD_PAGE) ? ((CheckerboardPage*) _tmp15_) : NULL;
#line 502 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp16_ == NULL) {
#line 502 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_object_unref0 (_tmp15_);
#line 4395 "LibraryWindow.c"
	}
#line 502 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	current_page = _tmp16_;
#line 503 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp17_ = current_page;
#line 503 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp17_ != NULL) {
#line 4403 "LibraryWindow.c"
		CheckerboardPage* _tmp18_ = NULL;
#line 504 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp18_ = current_page;
#line 504 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		library_window_init_view_filter (self, _tmp18_);
#line 4409 "LibraryWindow.c"
	}
#line 506 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp19_ = library_window_should_show_search_bar (self);
#line 506 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp20_ = current_page;
#line 506 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_window_toggle_search_bar (self, _tmp19_, _tmp20_);
#line 509 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp21_ = library_window_is_sidebar_visible (self);
#line 509 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_window_set_sidebar_visible (self, _tmp21_);
#line 487 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (current_page);
#line 487 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (searchbar_action);
#line 487 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (basic_properties_action);
#line 4427 "LibraryWindow.c"
}


LibraryWindow* library_window_get_app (void) {
	LibraryWindow* result = NULL;
	AppWindow* _tmp0_ = NULL;
	AppWindow* _tmp1_ = NULL;
	LibraryWindow* _tmp2_ = NULL;
#line 513 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = app_window_instance;
#line 513 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, TYPE_LIBRARY_WINDOW), "instance is LibraryWindow");
#line 515 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_ = app_window_instance;
#line 515 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp2_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, TYPE_LIBRARY_WINDOW, LibraryWindow));
#line 515 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	result = _tmp2_;
#line 515 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	return result;
#line 4448 "LibraryWindow.c"
}


gboolean library_window_is_mount_uri_supported (const gchar* uri) {
	gboolean result = FALSE;
#line 519 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_val_if_fail (uri != NULL, FALSE);
#line 4456 "LibraryWindow.c"
	{
		const gchar** scheme_collection = NULL;
		gint scheme_collection_length1 = 0;
		gint _scheme_collection_size_ = 0;
		gint scheme_it = 0;
#line 520 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		scheme_collection = LIBRARY_WINDOW_SUPPORTED_MOUNT_SCHEMES;
#line 520 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		scheme_collection_length1 = G_N_ELEMENTS (LIBRARY_WINDOW_SUPPORTED_MOUNT_SCHEMES);
#line 520 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		for (scheme_it = 0; scheme_it < G_N_ELEMENTS (LIBRARY_WINDOW_SUPPORTED_MOUNT_SCHEMES); scheme_it = scheme_it + 1) {
#line 4468 "LibraryWindow.c"
			gchar* _tmp0_ = NULL;
			gchar* scheme = NULL;
#line 520 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_tmp0_ = g_strdup (scheme_collection[scheme_it]);
#line 520 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			scheme = _tmp0_;
#line 4475 "LibraryWindow.c"
			{
				const gchar* _tmp1_ = NULL;
				const gchar* _tmp2_ = NULL;
				gboolean _tmp3_ = FALSE;
#line 521 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				_tmp1_ = uri;
#line 521 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				_tmp2_ = scheme;
#line 521 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				_tmp3_ = g_str_has_prefix (_tmp1_, _tmp2_);
#line 521 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				if (_tmp3_) {
#line 522 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
					result = TRUE;
#line 522 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
					_g_free0 (scheme);
#line 522 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
					return result;
#line 4494 "LibraryWindow.c"
				}
#line 520 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				_g_free0 (scheme);
#line 4498 "LibraryWindow.c"
			}
		}
	}
#line 525 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	result = FALSE;
#line 525 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	return result;
#line 4506 "LibraryWindow.c"
}


static gchar* library_window_real_get_app_role (AppWindow* base) {
	LibraryWindow * self;
	gchar* result = NULL;
	gchar* _tmp0_ = NULL;
#line 528 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_LIBRARY_WINDOW, LibraryWindow);
#line 529 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = g_strdup (RESOURCES_APP_LIBRARY_ROLE);
#line 529 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	result = _tmp0_;
#line 529 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	return result;
#line 4522 "LibraryWindow.c"
}


void library_window_rename_tag_in_sidebar (LibraryWindow* self, Tag* tag) {
	TagsSidebarEntry* entry = NULL;
	TagsBranch* _tmp0_ = NULL;
	Tag* _tmp1_ = NULL;
	TagsSidebarEntry* _tmp2_ = NULL;
	TagsSidebarEntry* _tmp3_ = NULL;
#line 532 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_LIBRARY_WINDOW (self));
#line 532 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_TAG (tag));
#line 533 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = self->priv->tags_branch;
#line 533 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_ = tag;
#line 533 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp2_ = tags_branch_get_entry_for_tag (_tmp0_, _tmp1_);
#line 533 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	entry = _tmp2_;
#line 534 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp3_ = entry;
#line 534 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp3_ != NULL) {
#line 4548 "LibraryWindow.c"
		SidebarTree* _tmp4_ = NULL;
		TagsSidebarEntry* _tmp5_ = NULL;
#line 535 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp4_ = self->priv->sidebar_tree;
#line 535 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp5_ = entry;
#line 535 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		sidebar_tree_rename_entry_in_place (_tmp4_, G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, SIDEBAR_TYPE_ENTRY, SidebarEntry));
#line 4557 "LibraryWindow.c"
	} else {
#line 537 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		g_debug ("LibraryWindow.vala:537: No tag entry found for rename");
#line 4561 "LibraryWindow.c"
	}
#line 532 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (entry);
#line 4565 "LibraryWindow.c"
}


void library_window_rename_event_in_sidebar (LibraryWindow* self, Event* event) {
	EventsEventEntry* entry = NULL;
	EventsBranch* _tmp0_ = NULL;
	Event* _tmp1_ = NULL;
	EventsEventEntry* _tmp2_ = NULL;
	EventsEventEntry* _tmp3_ = NULL;
#line 540 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_LIBRARY_WINDOW (self));
#line 540 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_EVENT (event));
#line 541 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = self->priv->events_branch;
#line 541 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_ = event;
#line 541 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp2_ = events_branch_get_entry_for_event (_tmp0_, _tmp1_);
#line 541 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	entry = _tmp2_;
#line 542 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp3_ = entry;
#line 542 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp3_ != NULL) {
#line 4591 "LibraryWindow.c"
		SidebarTree* _tmp4_ = NULL;
		EventsEventEntry* _tmp5_ = NULL;
#line 543 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp4_ = self->priv->sidebar_tree;
#line 543 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp5_ = entry;
#line 543 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		sidebar_tree_rename_entry_in_place (_tmp4_, G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, SIDEBAR_TYPE_ENTRY, SidebarEntry));
#line 4600 "LibraryWindow.c"
	} else {
#line 545 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		g_debug ("LibraryWindow.vala:545: No event entry found for rename");
#line 4604 "LibraryWindow.c"
	}
#line 540 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (entry);
#line 4608 "LibraryWindow.c"
}


void library_window_rename_search_in_sidebar (LibraryWindow* self, SavedSearch* search) {
	SearchesSidebarEntry* entry = NULL;
	SearchesBranch* _tmp0_ = NULL;
	SavedSearch* _tmp1_ = NULL;
	SearchesSidebarEntry* _tmp2_ = NULL;
	SearchesSidebarEntry* _tmp3_ = NULL;
#line 548 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_LIBRARY_WINDOW (self));
#line 548 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_SAVED_SEARCH (search));
#line 549 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = self->priv->saved_search_branch;
#line 549 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_ = search;
#line 549 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp2_ = searches_branch_get_entry_for_saved_search (_tmp0_, _tmp1_);
#line 549 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	entry = _tmp2_;
#line 550 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp3_ = entry;
#line 550 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp3_ != NULL) {
#line 4634 "LibraryWindow.c"
		SidebarTree* _tmp4_ = NULL;
		SearchesSidebarEntry* _tmp5_ = NULL;
#line 551 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp4_ = self->priv->sidebar_tree;
#line 551 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp5_ = entry;
#line 551 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		sidebar_tree_rename_entry_in_place (_tmp4_, G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, SIDEBAR_TYPE_ENTRY, SidebarEntry));
#line 4643 "LibraryWindow.c"
	} else {
#line 553 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		g_debug ("LibraryWindow.vala:553: No search entry found for rename");
#line 4647 "LibraryWindow.c"
	}
#line 548 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (entry);
#line 4651 "LibraryWindow.c"
}


static void library_window_real_on_quit (AppWindow* base) {
	LibraryWindow * self;
	ConfigFacade* _tmp0_ = NULL;
	ConfigFacade* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	Dimensions _tmp3_ = {0};
	ConfigFacade* _tmp4_ = NULL;
	ConfigFacade* _tmp5_ = NULL;
	GtkPaned* _tmp6_ = NULL;
	gint _tmp7_ = 0;
	gint _tmp8_ = 0;
#line 556 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_LIBRARY_WINDOW, LibraryWindow);
#line 557 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = config_facade_get_instance ();
#line 557 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_ = _tmp0_;
#line 557 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp2_ = G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_APP_WINDOW, AppWindow)->maximized;
#line 557 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp3_ = G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_APP_WINDOW, AppWindow)->dimensions;
#line 557 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	configuration_facade_set_library_window_state (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade), _tmp2_, &_tmp3_);
#line 557 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (_tmp1_);
#line 559 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp4_ = config_facade_get_instance ();
#line 559 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp5_ = _tmp4_;
#line 559 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp6_ = self->priv->client_paned;
#line 559 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp7_ = gtk_paned_get_position (_tmp6_);
#line 559 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp8_ = _tmp7_;
#line 559 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	configuration_facade_set_sidebar_position (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade), _tmp8_);
#line 559 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (_tmp5_);
#line 561 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	APP_WINDOW_CLASS (library_window_parent_class)->on_quit (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_APP_WINDOW, AppWindow));
#line 4696 "LibraryWindow.c"
}


static Photo* library_window_get_start_fullscreen_photo (LibraryWindow* self, CollectionPage* page) {
	Photo* result = NULL;
	ViewCollection* view = NULL;
	CollectionPage* _tmp0_ = NULL;
	ViewCollection* _tmp1_ = NULL;
	GeeList* _tmp2_ = NULL;
	ViewCollection* _tmp3_ = NULL;
	gint _tmp4_ = 0;
	GeeList* sources = NULL;
	GeeList* _tmp9_ = NULL;
	Photo* _tmp10_ = NULL;
	gboolean _tmp11_ = FALSE;
	GeeList* _tmp12_ = NULL;
#line 564 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_val_if_fail (IS_LIBRARY_WINDOW (self), NULL);
#line 564 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_val_if_fail (IS_COLLECTION_PAGE (page), NULL);
#line 565 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = page;
#line 565 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, TYPE_PAGE, Page));
#line 565 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	view = _tmp1_;
#line 569 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp3_ = view;
#line 569 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp4_ = view_collection_get_selected_count (_tmp3_);
#line 569 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp4_ > 0) {
#line 4729 "LibraryWindow.c"
		ViewCollection* _tmp5_ = NULL;
		GeeList* _tmp6_ = NULL;
#line 570 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp5_ = view;
#line 570 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp6_ = view_collection_get_selected_sources_of_type (_tmp5_, TYPE_LIBRARY_PHOTO);
#line 570 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_object_unref0 (_tmp2_);
#line 570 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp2_ = _tmp6_;
#line 4740 "LibraryWindow.c"
	} else {
		ViewCollection* _tmp7_ = NULL;
		GeeList* _tmp8_ = NULL;
#line 571 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp7_ = view;
#line 571 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp8_ = view_collection_get_sources_of_type (_tmp7_, TYPE_LIBRARY_PHOTO);
#line 571 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_object_unref0 (_tmp2_);
#line 571 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp2_ = _tmp8_;
#line 4752 "LibraryWindow.c"
	}
#line 569 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp9_ = _g_object_ref0 (_tmp2_);
#line 569 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	sources = _tmp9_;
#line 573 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp12_ = sources;
#line 573 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp12_ != NULL) {
#line 4762 "LibraryWindow.c"
		GeeList* _tmp13_ = NULL;
		gint _tmp14_ = 0;
		gint _tmp15_ = 0;
#line 573 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp13_ = sources;
#line 573 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp14_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp13_, GEE_TYPE_COLLECTION, GeeCollection));
#line 573 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp15_ = _tmp14_;
#line 573 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp11_ = _tmp15_ != 0;
#line 4774 "LibraryWindow.c"
	} else {
#line 573 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp11_ = FALSE;
#line 4778 "LibraryWindow.c"
	}
#line 573 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp11_) {
#line 4782 "LibraryWindow.c"
		GeeList* _tmp16_ = NULL;
		gpointer _tmp17_ = NULL;
#line 574 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp16_ = sources;
#line 574 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp17_ = gee_list_get (_tmp16_, 0);
#line 574 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_object_unref0 (_tmp10_);
#line 574 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp10_ = G_TYPE_CHECK_INSTANCE_CAST ((DataSource*) _tmp17_, TYPE_PHOTO, Photo);
#line 4793 "LibraryWindow.c"
	} else {
#line 574 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_object_unref0 (_tmp10_);
#line 574 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp10_ = NULL;
#line 4799 "LibraryWindow.c"
	}
#line 573 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	result = _tmp10_;
#line 573 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (sources);
#line 573 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (_tmp2_);
#line 573 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_data_collection_unref0 (view);
#line 573 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	return result;
#line 4811 "LibraryWindow.c"
}


static gboolean library_window_get_fullscreen_photo (LibraryWindow* self, Page* page, CollectionPage** collection, Photo** start, ViewCollection** view_collection) {
	CollectionPage* _vala_collection = NULL;
	Photo* _vala_start = NULL;
	ViewCollection* _vala_view_collection = NULL;
	gboolean result = FALSE;
	Page* _tmp0_ = NULL;
	Page* _tmp8_ = NULL;
	Page* _tmp30_ = NULL;
#line 577 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_val_if_fail (IS_LIBRARY_WINDOW (self), FALSE);
#line 577 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_val_if_fail (IS_PAGE (page), FALSE);
#line 579 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (_vala_collection);
#line 579 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_vala_collection = NULL;
#line 580 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (_vala_start);
#line 580 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_vala_start = NULL;
#line 581 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_data_collection_unref0 (_vala_view_collection);
#line 581 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_vala_view_collection = NULL;
#line 584 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = page;
#line 584 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, TYPE_COLLECTION_PAGE)) {
#line 4843 "LibraryWindow.c"
		Page* _tmp1_ = NULL;
		CollectionPage* _tmp2_ = NULL;
		Photo* photo = NULL;
		CollectionPage* _tmp3_ = NULL;
		Photo* _tmp4_ = NULL;
		Photo* _tmp5_ = NULL;
		Photo* _tmp6_ = NULL;
		Photo* _tmp7_ = NULL;
#line 585 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp1_ = page;
#line 585 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp2_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, TYPE_COLLECTION_PAGE, CollectionPage));
#line 585 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_object_unref0 (_vala_collection);
#line 585 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_vala_collection = _tmp2_;
#line 586 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp3_ = _vala_collection;
#line 586 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp4_ = library_window_get_start_fullscreen_photo (self, _tmp3_);
#line 586 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		photo = _tmp4_;
#line 587 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp5_ = photo;
#line 587 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		if (_tmp5_ == NULL) {
#line 588 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			result = FALSE;
#line 588 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_g_object_unref0 (photo);
#line 588 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			if (collection) {
#line 588 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				*collection = _vala_collection;
#line 4878 "LibraryWindow.c"
			} else {
#line 588 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				_g_object_unref0 (_vala_collection);
#line 4882 "LibraryWindow.c"
			}
#line 588 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			if (start) {
#line 588 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				*start = _vala_start;
#line 4888 "LibraryWindow.c"
			} else {
#line 588 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				_g_object_unref0 (_vala_start);
#line 4892 "LibraryWindow.c"
			}
#line 588 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			if (view_collection) {
#line 588 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				*view_collection = _vala_view_collection;
#line 4898 "LibraryWindow.c"
			} else {
#line 588 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				_data_collection_unref0 (_vala_view_collection);
#line 4902 "LibraryWindow.c"
			}
#line 588 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			return result;
#line 4906 "LibraryWindow.c"
		}
#line 590 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp6_ = photo;
#line 590 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp7_ = _g_object_ref0 (_tmp6_);
#line 590 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_object_unref0 (_vala_start);
#line 590 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_vala_start = _tmp7_;
#line 591 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_data_collection_unref0 (_vala_view_collection);
#line 591 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_vala_view_collection = NULL;
#line 593 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		result = TRUE;
#line 593 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_object_unref0 (photo);
#line 593 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		if (collection) {
#line 593 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			*collection = _vala_collection;
#line 4928 "LibraryWindow.c"
		} else {
#line 593 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_g_object_unref0 (_vala_collection);
#line 4932 "LibraryWindow.c"
		}
#line 593 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		if (start) {
#line 593 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			*start = _vala_start;
#line 4938 "LibraryWindow.c"
		} else {
#line 593 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_g_object_unref0 (_vala_start);
#line 4942 "LibraryWindow.c"
		}
#line 593 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		if (view_collection) {
#line 593 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			*view_collection = _vala_view_collection;
#line 4948 "LibraryWindow.c"
		} else {
#line 593 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_data_collection_unref0 (_vala_view_collection);
#line 4952 "LibraryWindow.c"
		}
#line 593 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		return result;
#line 4956 "LibraryWindow.c"
	}
#line 596 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp8_ = page;
#line 596 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp8_, TYPE_EVENTS_DIRECTORY_PAGE)) {
#line 4962 "LibraryWindow.c"
		ViewCollection* view = NULL;
		Page* _tmp9_ = NULL;
		ViewCollection* _tmp10_ = NULL;
		ViewCollection* _tmp11_ = NULL;
		gint _tmp12_ = 0;
		Event* event = NULL;
		ViewCollection* _tmp13_ = NULL;
		DataObject* _tmp14_ = NULL;
		DataView* _tmp15_ = NULL;
		DataSource* _tmp16_ = NULL;
		Event* _tmp17_ = NULL;
		Event* _tmp18_ = NULL;
		EventsEventEntry* entry = NULL;
		EventsBranch* _tmp19_ = NULL;
		Event* _tmp20_ = NULL;
		EventsEventEntry* _tmp21_ = NULL;
		EventsEventEntry* _tmp22_ = NULL;
		EventsEventEntry* _tmp23_ = NULL;
		Page* _tmp24_ = NULL;
		Photo* photo = NULL;
		CollectionPage* _tmp25_ = NULL;
		Photo* _tmp26_ = NULL;
		Photo* _tmp27_ = NULL;
		Photo* _tmp28_ = NULL;
		Photo* _tmp29_ = NULL;
#line 597 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp9_ = page;
#line 597 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp10_ = page_get_view (_tmp9_);
#line 597 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		view = _tmp10_;
#line 598 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp11_ = view;
#line 598 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp12_ = data_collection_get_count (G_TYPE_CHECK_INSTANCE_CAST (_tmp11_, TYPE_DATA_COLLECTION, DataCollection));
#line 598 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		if (_tmp12_ == 0) {
#line 599 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			result = FALSE;
#line 599 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_data_collection_unref0 (view);
#line 599 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			if (collection) {
#line 599 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				*collection = _vala_collection;
#line 5008 "LibraryWindow.c"
			} else {
#line 599 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				_g_object_unref0 (_vala_collection);
#line 5012 "LibraryWindow.c"
			}
#line 599 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			if (start) {
#line 599 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				*start = _vala_start;
#line 5018 "LibraryWindow.c"
			} else {
#line 599 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				_g_object_unref0 (_vala_start);
#line 5022 "LibraryWindow.c"
			}
#line 599 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			if (view_collection) {
#line 599 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				*view_collection = _vala_view_collection;
#line 5028 "LibraryWindow.c"
			} else {
#line 599 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				_data_collection_unref0 (_vala_view_collection);
#line 5032 "LibraryWindow.c"
			}
#line 599 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			return result;
#line 5036 "LibraryWindow.c"
		}
#line 601 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp13_ = view;
#line 601 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp14_ = data_collection_get_at (G_TYPE_CHECK_INSTANCE_CAST (_tmp13_, TYPE_DATA_COLLECTION, DataCollection), 0);
#line 601 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp15_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp14_, TYPE_DATA_VIEW, DataView);
#line 601 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp16_ = data_view_get_source (_tmp15_);
#line 601 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp17_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp16_, TYPE_EVENT, Event);
#line 601 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_object_unref0 (_tmp15_);
#line 601 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		event = _tmp17_;
#line 602 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp18_ = event;
#line 602 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		if (_tmp18_ == NULL) {
#line 603 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			result = FALSE;
#line 603 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_g_object_unref0 (event);
#line 603 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_data_collection_unref0 (view);
#line 603 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			if (collection) {
#line 603 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				*collection = _vala_collection;
#line 5066 "LibraryWindow.c"
			} else {
#line 603 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				_g_object_unref0 (_vala_collection);
#line 5070 "LibraryWindow.c"
			}
#line 603 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			if (start) {
#line 603 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				*start = _vala_start;
#line 5076 "LibraryWindow.c"
			} else {
#line 603 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				_g_object_unref0 (_vala_start);
#line 5080 "LibraryWindow.c"
			}
#line 603 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			if (view_collection) {
#line 603 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				*view_collection = _vala_view_collection;
#line 5086 "LibraryWindow.c"
			} else {
#line 603 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				_data_collection_unref0 (_vala_view_collection);
#line 5090 "LibraryWindow.c"
			}
#line 603 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			return result;
#line 5094 "LibraryWindow.c"
		}
#line 605 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp19_ = self->priv->events_branch;
#line 605 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp20_ = event;
#line 605 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp21_ = events_branch_get_entry_for_event (_tmp19_, _tmp20_);
#line 605 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		entry = _tmp21_;
#line 606 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp22_ = entry;
#line 606 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		if (_tmp22_ == NULL) {
#line 607 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			result = FALSE;
#line 607 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_g_object_unref0 (entry);
#line 607 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_g_object_unref0 (event);
#line 607 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_data_collection_unref0 (view);
#line 607 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			if (collection) {
#line 607 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				*collection = _vala_collection;
#line 5120 "LibraryWindow.c"
			} else {
#line 607 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				_g_object_unref0 (_vala_collection);
#line 5124 "LibraryWindow.c"
			}
#line 607 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			if (start) {
#line 607 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				*start = _vala_start;
#line 5130 "LibraryWindow.c"
			} else {
#line 607 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				_g_object_unref0 (_vala_start);
#line 5134 "LibraryWindow.c"
			}
#line 607 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			if (view_collection) {
#line 607 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				*view_collection = _vala_view_collection;
#line 5140 "LibraryWindow.c"
			} else {
#line 607 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				_data_collection_unref0 (_vala_view_collection);
#line 5144 "LibraryWindow.c"
			}
#line 607 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			return result;
#line 5148 "LibraryWindow.c"
		}
#line 609 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp23_ = entry;
#line 609 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp24_ = sidebar_page_representative_get_page (G_TYPE_CHECK_INSTANCE_CAST (_tmp23_, SIDEBAR_TYPE_PAGE_REPRESENTATIVE, SidebarPageRepresentative));
#line 609 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_object_unref0 (_vala_collection);
#line 609 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_vala_collection = G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (_tmp24_, TYPE_EVENT_PAGE, EventPage), TYPE_COLLECTION_PAGE, CollectionPage);
#line 610 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp25_ = _vala_collection;
#line 610 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp26_ = library_window_get_start_fullscreen_photo (self, _tmp25_);
#line 610 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		photo = _tmp26_;
#line 611 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp27_ = photo;
#line 611 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		if (_tmp27_ == NULL) {
#line 612 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			result = FALSE;
#line 612 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_g_object_unref0 (photo);
#line 612 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_g_object_unref0 (entry);
#line 612 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_g_object_unref0 (event);
#line 612 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_data_collection_unref0 (view);
#line 612 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			if (collection) {
#line 612 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				*collection = _vala_collection;
#line 5182 "LibraryWindow.c"
			} else {
#line 612 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				_g_object_unref0 (_vala_collection);
#line 5186 "LibraryWindow.c"
			}
#line 612 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			if (start) {
#line 612 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				*start = _vala_start;
#line 5192 "LibraryWindow.c"
			} else {
#line 612 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				_g_object_unref0 (_vala_start);
#line 5196 "LibraryWindow.c"
			}
#line 612 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			if (view_collection) {
#line 612 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				*view_collection = _vala_view_collection;
#line 5202 "LibraryWindow.c"
			} else {
#line 612 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				_data_collection_unref0 (_vala_view_collection);
#line 5206 "LibraryWindow.c"
			}
#line 612 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			return result;
#line 5210 "LibraryWindow.c"
		}
#line 614 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp28_ = photo;
#line 614 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp29_ = _g_object_ref0 (_tmp28_);
#line 614 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_object_unref0 (_vala_start);
#line 614 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_vala_start = _tmp29_;
#line 615 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_data_collection_unref0 (_vala_view_collection);
#line 615 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_vala_view_collection = NULL;
#line 617 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		result = TRUE;
#line 617 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_object_unref0 (photo);
#line 617 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_object_unref0 (entry);
#line 617 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_object_unref0 (event);
#line 617 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_data_collection_unref0 (view);
#line 617 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		if (collection) {
#line 617 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			*collection = _vala_collection;
#line 5238 "LibraryWindow.c"
		} else {
#line 617 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_g_object_unref0 (_vala_collection);
#line 5242 "LibraryWindow.c"
		}
#line 617 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		if (start) {
#line 617 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			*start = _vala_start;
#line 5248 "LibraryWindow.c"
		} else {
#line 617 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_g_object_unref0 (_vala_start);
#line 5252 "LibraryWindow.c"
		}
#line 617 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		if (view_collection) {
#line 617 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			*view_collection = _vala_view_collection;
#line 5258 "LibraryWindow.c"
		} else {
#line 617 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_data_collection_unref0 (_vala_view_collection);
#line 5262 "LibraryWindow.c"
		}
#line 617 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		return result;
#line 5266 "LibraryWindow.c"
	}
#line 620 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp30_ = page;
#line 620 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp30_, TYPE_LIBRARY_PHOTO_PAGE)) {
#line 5272 "LibraryWindow.c"
		LibraryPhotoPage* photo_page = NULL;
		Page* _tmp31_ = NULL;
		LibraryPhotoPage* _tmp32_ = NULL;
		CollectionPage* controller = NULL;
		LibraryPhotoPage* _tmp33_ = NULL;
		CollectionPage* _tmp34_ = NULL;
		CollectionPage* _tmp35_ = NULL;
		LibraryPhotoPage* _tmp36_ = NULL;
		gboolean _tmp37_ = FALSE;
		CollectionPage* _tmp38_ = NULL;
		CollectionPage* _tmp39_ = NULL;
		LibraryPhotoPage* _tmp40_ = NULL;
		Photo* _tmp41_ = NULL;
		LibraryPhotoPage* _tmp42_ = NULL;
		ViewCollection* _tmp43_ = NULL;
#line 621 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp31_ = page;
#line 621 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp32_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp31_, TYPE_LIBRARY_PHOTO_PAGE, LibraryPhotoPage));
#line 621 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		photo_page = _tmp32_;
#line 623 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp33_ = photo_page;
#line 623 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp34_ = library_photo_page_get_controller_page (_tmp33_);
#line 623 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		controller = _tmp34_;
#line 624 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp35_ = controller;
#line 624 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		if (_tmp35_ == NULL) {
#line 625 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			result = FALSE;
#line 625 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_g_object_unref0 (controller);
#line 625 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_g_object_unref0 (photo_page);
#line 625 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			if (collection) {
#line 625 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				*collection = _vala_collection;
#line 5314 "LibraryWindow.c"
			} else {
#line 625 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				_g_object_unref0 (_vala_collection);
#line 5318 "LibraryWindow.c"
			}
#line 625 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			if (start) {
#line 625 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				*start = _vala_start;
#line 5324 "LibraryWindow.c"
			} else {
#line 625 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				_g_object_unref0 (_vala_start);
#line 5328 "LibraryWindow.c"
			}
#line 625 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			if (view_collection) {
#line 625 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				*view_collection = _vala_view_collection;
#line 5334 "LibraryWindow.c"
			} else {
#line 625 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				_data_collection_unref0 (_vala_view_collection);
#line 5338 "LibraryWindow.c"
			}
#line 625 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			return result;
#line 5342 "LibraryWindow.c"
		}
#line 627 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp36_ = photo_page;
#line 627 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp37_ = editing_host_page_has_photo (G_TYPE_CHECK_INSTANCE_CAST (_tmp36_, TYPE_EDITING_HOST_PAGE, EditingHostPage));
#line 627 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		if (!_tmp37_) {
#line 628 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			result = FALSE;
#line 628 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_g_object_unref0 (controller);
#line 628 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_g_object_unref0 (photo_page);
#line 628 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			if (collection) {
#line 628 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				*collection = _vala_collection;
#line 5360 "LibraryWindow.c"
			} else {
#line 628 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				_g_object_unref0 (_vala_collection);
#line 5364 "LibraryWindow.c"
			}
#line 628 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			if (start) {
#line 628 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				*start = _vala_start;
#line 5370 "LibraryWindow.c"
			} else {
#line 628 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				_g_object_unref0 (_vala_start);
#line 5374 "LibraryWindow.c"
			}
#line 628 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			if (view_collection) {
#line 628 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				*view_collection = _vala_view_collection;
#line 5380 "LibraryWindow.c"
			} else {
#line 628 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				_data_collection_unref0 (_vala_view_collection);
#line 5384 "LibraryWindow.c"
			}
#line 628 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			return result;
#line 5388 "LibraryWindow.c"
		}
#line 630 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp38_ = controller;
#line 630 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp39_ = _g_object_ref0 (_tmp38_);
#line 630 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_object_unref0 (_vala_collection);
#line 630 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_vala_collection = _tmp39_;
#line 631 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp40_ = photo_page;
#line 631 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp41_ = editing_host_page_get_photo (G_TYPE_CHECK_INSTANCE_CAST (_tmp40_, TYPE_EDITING_HOST_PAGE, EditingHostPage));
#line 631 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_object_unref0 (_vala_start);
#line 631 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_vala_start = _tmp41_;
#line 632 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp42_ = photo_page;
#line 632 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp43_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (_tmp42_, TYPE_PAGE, Page));
#line 632 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_data_collection_unref0 (_vala_view_collection);
#line 632 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_vala_view_collection = _tmp43_;
#line 634 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		result = TRUE;
#line 634 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_object_unref0 (controller);
#line 634 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_object_unref0 (photo_page);
#line 634 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		if (collection) {
#line 634 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			*collection = _vala_collection;
#line 5424 "LibraryWindow.c"
		} else {
#line 634 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_g_object_unref0 (_vala_collection);
#line 5428 "LibraryWindow.c"
		}
#line 634 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		if (start) {
#line 634 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			*start = _vala_start;
#line 5434 "LibraryWindow.c"
		} else {
#line 634 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_g_object_unref0 (_vala_start);
#line 5438 "LibraryWindow.c"
		}
#line 634 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		if (view_collection) {
#line 634 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			*view_collection = _vala_view_collection;
#line 5444 "LibraryWindow.c"
		} else {
#line 634 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_data_collection_unref0 (_vala_view_collection);
#line 5448 "LibraryWindow.c"
		}
#line 634 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		return result;
#line 5452 "LibraryWindow.c"
	}
#line 637 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	result = FALSE;
#line 637 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (collection) {
#line 637 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		*collection = _vala_collection;
#line 5460 "LibraryWindow.c"
	} else {
#line 637 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_object_unref0 (_vala_collection);
#line 5464 "LibraryWindow.c"
	}
#line 637 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (start) {
#line 637 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		*start = _vala_start;
#line 5470 "LibraryWindow.c"
	} else {
#line 637 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_object_unref0 (_vala_start);
#line 5474 "LibraryWindow.c"
	}
#line 637 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (view_collection) {
#line 637 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		*view_collection = _vala_view_collection;
#line 5480 "LibraryWindow.c"
	} else {
#line 637 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_data_collection_unref0 (_vala_view_collection);
#line 5484 "LibraryWindow.c"
	}
#line 637 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	return result;
#line 5488 "LibraryWindow.c"
}


static void library_window_real_on_fullscreen (AppWindow* base) {
	LibraryWindow * self;
	Page* current_page = NULL;
	Page* _tmp0_ = NULL;
	Page* _tmp1_ = NULL;
	CollectionPage* collection = NULL;
	Photo* start = NULL;
	ViewCollection* view = NULL;
	Page* _tmp2_ = NULL;
	CollectionPage* _tmp3_ = NULL;
	Photo* _tmp4_ = NULL;
	ViewCollection* _tmp5_ = NULL;
	gboolean _tmp6_ = FALSE;
	LibraryWindowFullscreenPhotoPage* fs_photo = NULL;
	CollectionPage* _tmp7_ = NULL;
	Photo* _tmp8_ = NULL;
	ViewCollection* _tmp9_ = NULL;
	LibraryWindowFullscreenPhotoPage* _tmp10_ = NULL;
	LibraryWindowFullscreenPhotoPage* _tmp11_ = NULL;
#line 640 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_LIBRARY_WINDOW, LibraryWindow);
#line 641 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = page_window_get_current_page (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE_WINDOW, PageWindow));
#line 641 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	current_page = _tmp0_;
#line 642 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_ = current_page;
#line 642 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp1_ == NULL) {
#line 643 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_object_unref0 (current_page);
#line 643 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		return;
#line 5525 "LibraryWindow.c"
	}
#line 647 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	view = NULL;
#line 648 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp2_ = current_page;
#line 648 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp6_ = library_window_get_fullscreen_photo (self, _tmp2_, &_tmp3_, &_tmp4_, &_tmp5_);
#line 648 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (collection);
#line 648 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	collection = _tmp3_;
#line 648 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (start);
#line 648 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	start = _tmp4_;
#line 648 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_data_collection_unref0 (view);
#line 648 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	view = _tmp5_;
#line 648 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (!_tmp6_) {
#line 649 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_data_collection_unref0 (view);
#line 649 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_object_unref0 (start);
#line 649 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_object_unref0 (collection);
#line 649 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_object_unref0 (current_page);
#line 649 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		return;
#line 5557 "LibraryWindow.c"
	}
#line 651 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp7_ = collection;
#line 651 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp8_ = start;
#line 651 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp9_ = view;
#line 651 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp10_ = library_window_fullscreen_photo_page_new (_tmp7_, _tmp8_, _tmp9_);
#line 651 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_object_ref_sink (_tmp10_);
#line 651 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	fs_photo = _tmp10_;
#line 653 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp11_ = fs_photo;
#line 653 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	app_window_go_fullscreen (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_APP_WINDOW, AppWindow), G_TYPE_CHECK_INSTANCE_CAST (_tmp11_, TYPE_PAGE, Page));
#line 640 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (fs_photo);
#line 640 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_data_collection_unref0 (view);
#line 640 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (start);
#line 640 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (collection);
#line 640 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (current_page);
#line 5585 "LibraryWindow.c"
}


static void _g_free0_ (gpointer var) {
#line 673 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	var = (g_free (var), NULL);
#line 5592 "LibraryWindow.c"
}


static void _g_slist_free__g_free0_ (GSList* self) {
#line 673 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_slist_foreach (self, (GFunc) _g_free0_, NULL);
#line 673 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_slist_free (self);
#line 5601 "LibraryWindow.c"
}


static void library_window_on_file_import (LibraryWindow* self) {
	GtkFileChooserDialog* import_dialog = NULL;
	const gchar* _tmp0_ = NULL;
	GtkFileChooserDialog* _tmp1_ = NULL;
	GtkFileChooserDialog* _tmp2_ = NULL;
	GtkFileChooserDialog* _tmp3_ = NULL;
	GtkFileChooserDialog* _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
	gint response = 0;
	GtkFileChooserDialog* _tmp6_ = NULL;
	gint _tmp7_ = 0;
	gint _tmp8_ = 0;
	GtkFileChooserDialog* _tmp23_ = NULL;
	gchar* _tmp24_ = NULL;
	GtkFileChooserDialog* _tmp25_ = NULL;
#line 656 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_LIBRARY_WINDOW (self));
#line 657 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = _ ("Import From Folder");
#line 657 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_ = (GtkFileChooserDialog*) gtk_file_chooser_dialog_new (_tmp0_, NULL, GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER, RESOURCES_CANCEL_LABEL, GTK_RESPONSE_CANCEL, RESOURCES_OK_LABEL, GTK_RESPONSE_OK, NULL);
#line 657 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_object_ref_sink (_tmp1_);
#line 657 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	import_dialog = _tmp1_;
#line 660 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp2_ = import_dialog;
#line 660 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	gtk_file_chooser_set_local_only (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, GTK_TYPE_FILE_CHOOSER, GtkFileChooser), FALSE);
#line 661 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp3_ = import_dialog;
#line 661 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	gtk_file_chooser_set_select_multiple (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, GTK_TYPE_FILE_CHOOSER, GtkFileChooser), TRUE);
#line 662 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp4_ = import_dialog;
#line 662 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp5_ = self->priv->import_dir;
#line 662 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	gtk_file_chooser_set_current_folder (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, GTK_TYPE_FILE_CHOOSER, GtkFileChooser), _tmp5_);
#line 664 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp6_ = import_dialog;
#line 664 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp7_ = gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, gtk_dialog_get_type (), GtkDialog));
#line 664 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	response = _tmp7_;
#line 666 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp8_ = response;
#line 666 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp8_ == ((gint) GTK_RESPONSE_OK)) {
#line 5654 "LibraryWindow.c"
		GtkResponseType _tmp9_ = 0;
		GtkFileChooserDialog* _tmp10_ = NULL;
		gchar* _tmp11_ = NULL;
		gchar* _tmp12_ = NULL;
		GFile* _tmp13_ = NULL;
		GFile* _tmp14_ = NULL;
		gboolean _tmp15_ = FALSE;
		gboolean _tmp16_ = FALSE;
		GtkResponseType copy_files_response = 0;
		GtkResponseType _tmp18_ = 0;
#line 669 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp10_ = import_dialog;
#line 669 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp11_ = gtk_file_chooser_get_uri (G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, GTK_TYPE_FILE_CHOOSER, GtkFileChooser));
#line 669 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp12_ = _tmp11_;
#line 669 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp13_ = g_file_new_for_uri (_tmp12_);
#line 669 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp14_ = _tmp13_;
#line 669 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp15_ = app_dirs_is_in_import_dir (_tmp14_);
#line 669 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp16_ = _tmp15_;
#line 669 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_object_unref0 (_tmp14_);
#line 669 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_free0 (_tmp12_);
#line 669 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		if (_tmp16_) {
#line 670 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_tmp9_ = GTK_RESPONSE_REJECT;
#line 5687 "LibraryWindow.c"
		} else {
			GtkResponseType _tmp17_ = 0;
#line 670 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_tmp17_ = copy_files_dialog ();
#line 670 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_tmp9_ = _tmp17_;
#line 5694 "LibraryWindow.c"
		}
#line 668 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		copy_files_response = _tmp9_;
#line 672 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp18_ = copy_files_response;
#line 672 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		if (_tmp18_ != GTK_RESPONSE_CANCEL) {
#line 5702 "LibraryWindow.c"
			GtkFileChooserDialog* _tmp19_ = NULL;
			GSList* _tmp20_ = NULL;
			GSList* _tmp21_ = NULL;
			GtkResponseType _tmp22_ = 0;
#line 673 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_tmp19_ = import_dialog;
#line 673 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_tmp20_ = gtk_file_chooser_get_uris (G_TYPE_CHECK_INSTANCE_CAST (_tmp19_, GTK_TYPE_FILE_CHOOSER, GtkFileChooser));
#line 673 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_tmp21_ = _tmp20_;
#line 673 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_tmp22_ = copy_files_response;
#line 673 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			library_window_dispatch_import_jobs (self, _tmp21_, "folders", _tmp22_ == GTK_RESPONSE_ACCEPT);
#line 673 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			__g_slist_free__g_free0_0 (_tmp21_);
#line 5719 "LibraryWindow.c"
		}
	}
#line 678 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp23_ = import_dialog;
#line 678 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp24_ = gtk_file_chooser_get_current_folder (G_TYPE_CHECK_INSTANCE_CAST (_tmp23_, GTK_TYPE_FILE_CHOOSER, GtkFileChooser));
#line 678 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_free0 (self->priv->import_dir);
#line 678 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	self->priv->import_dir = _tmp24_;
#line 679 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp25_ = import_dialog;
#line 679 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (_tmp25_, gtk_widget_get_type (), GtkWidget));
#line 656 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (import_dialog);
#line 5736 "LibraryWindow.c"
}


static void library_window_on_external_library_import (LibraryWindow* self) {
	GtkDialog* import_dialog = NULL;
	DataImportsUIDataImportsDialog* _tmp0_ = NULL;
#line 682 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_LIBRARY_WINDOW (self));
#line 683 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = data_imports_ui_data_imports_dialog_get_or_create_instance ();
#line 683 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	import_dialog = G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_dialog_get_type (), GtkDialog);
#line 685 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	gtk_dialog_run (import_dialog);
#line 682 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (import_dialog);
#line 5753 "LibraryWindow.c"
}


static void library_window_real_update_common_action_availability (AppWindow* base, Page* old_page, Page* new_page) {
	LibraryWindow * self;
	Page* _tmp0_ = NULL;
	Page* _tmp1_ = NULL;
	gboolean is_checkerboard = FALSE;
	Page* _tmp2_ = NULL;
#line 688 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_LIBRARY_WINDOW, LibraryWindow);
#line 688 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail ((old_page == NULL) || IS_PAGE (old_page));
#line 688 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail ((new_page == NULL) || IS_PAGE (new_page));
#line 689 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = old_page;
#line 689 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_ = new_page;
#line 689 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	APP_WINDOW_CLASS (library_window_parent_class)->update_common_action_availability (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_APP_WINDOW, AppWindow), _tmp0_, _tmp1_);
#line 691 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp2_ = new_page;
#line 691 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	is_checkerboard = G_TYPE_CHECK_INSTANCE_TYPE (_tmp2_, TYPE_CHECKERBOARD_PAGE);
#line 693 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	app_window_set_common_action_sensitive (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_APP_WINDOW, AppWindow), "CommonDisplaySearchbar", is_checkerboard);
#line 694 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	app_window_set_common_action_sensitive (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_APP_WINDOW, AppWindow), "CommonFind", is_checkerboard);
#line 5783 "LibraryWindow.c"
}


static void library_window_real_update_common_actions (AppWindow* base, Page* page, gint selected_count, gint count) {
	LibraryWindow * self;
	CollectionPage* collection = NULL;
	Photo* start = NULL;
	gboolean can_fullscreen = FALSE;
	Page* _tmp0_ = NULL;
	CollectionPage* _tmp1_ = NULL;
	Photo* _tmp2_ = NULL;
	gboolean _tmp3_ = FALSE;
	gboolean _tmp4_ = FALSE;
	gboolean _tmp5_ = FALSE;
	Page* _tmp6_ = NULL;
	gint _tmp7_ = 0;
	gint _tmp8_ = 0;
#line 697 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_LIBRARY_WINDOW, LibraryWindow);
#line 697 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_PAGE (page));
#line 703 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = page;
#line 703 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp3_ = library_window_get_fullscreen_photo (self, _tmp0_, &_tmp1_, &_tmp2_, NULL);
#line 703 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (collection);
#line 703 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	collection = _tmp1_;
#line 703 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (start);
#line 703 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	start = _tmp2_;
#line 703 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	can_fullscreen = _tmp3_;
#line 705 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp4_ = library_window_can_empty_trash (self);
#line 705 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	app_window_set_common_action_sensitive (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_APP_WINDOW, AppWindow), "CommonEmptyTrash", _tmp4_);
#line 706 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	app_window_set_common_action_visible (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_APP_WINDOW, AppWindow), "CommonJumpToEvent", TRUE);
#line 707 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp5_ = library_window_can_jump_to_event (self);
#line 707 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	app_window_set_common_action_sensitive (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_APP_WINDOW, AppWindow), "CommonJumpToEvent", _tmp5_);
#line 708 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	app_window_set_common_action_sensitive (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_APP_WINDOW, AppWindow), "CommonFullscreen", can_fullscreen);
#line 710 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp6_ = page;
#line 710 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp7_ = selected_count;
#line 710 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp8_ = count;
#line 710 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	APP_WINDOW_CLASS (library_window_parent_class)->update_common_actions (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_APP_WINDOW, AppWindow), _tmp6_, _tmp7_, _tmp8_);
#line 697 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (start);
#line 697 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (collection);
#line 5843 "LibraryWindow.c"
}


static void library_window_on_trashcan_contents_altered (LibraryWindow* self) {
	gboolean _tmp0_ = FALSE;
#line 713 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_LIBRARY_WINDOW (self));
#line 714 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = library_window_can_empty_trash (self);
#line 714 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	app_window_set_common_action_sensitive (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_APP_WINDOW, AppWindow), "CommonEmptyTrash", _tmp0_);
#line 5855 "LibraryWindow.c"
}


static gboolean library_window_can_empty_trash (LibraryWindow* self) {
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
	LibraryPhotoSourceCollection* _tmp1_ = NULL;
	gint _tmp2_ = 0;
#line 717 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_val_if_fail (IS_LIBRARY_WINDOW (self), FALSE);
#line 718 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_ = library_photo_global;
#line 718 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp2_ = media_source_collection_get_trashcan_count (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollection));
#line 718 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp2_ > 0) {
#line 718 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp0_ = TRUE;
#line 5874 "LibraryWindow.c"
	} else {
		VideoSourceCollection* _tmp3_ = NULL;
		gint _tmp4_ = 0;
#line 718 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp3_ = video_global;
#line 718 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp4_ = media_source_collection_get_trashcan_count (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollection));
#line 718 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp0_ = _tmp4_ > 0;
#line 5884 "LibraryWindow.c"
	}
#line 718 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	result = _tmp0_;
#line 718 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	return result;
#line 5890 "LibraryWindow.c"
}


static void library_window_on_empty_trash (LibraryWindow* self) {
	GeeArrayList* to_remove = NULL;
	GeeArrayList* _tmp0_ = NULL;
	LibraryPhotoSourceCollection* _tmp1_ = NULL;
	GeeCollection* _tmp2_ = NULL;
	GeeCollection* _tmp3_ = NULL;
	VideoSourceCollection* _tmp4_ = NULL;
	GeeCollection* _tmp5_ = NULL;
	GeeCollection* _tmp6_ = NULL;
	const gchar* _tmp7_ = NULL;
	const gchar* _tmp8_ = NULL;
	CommandManager* _tmp9_ = NULL;
	CommandManager* _tmp10_ = NULL;
#line 721 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_LIBRARY_WINDOW (self));
#line 722 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = gee_array_list_new (TYPE_MEDIA_SOURCE, (GBoxedCopyFunc) g_object_ref, g_object_unref, NULL, NULL, NULL);
#line 722 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	to_remove = _tmp0_;
#line 723 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_ = library_photo_global;
#line 723 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp2_ = media_source_collection_get_trashcan_contents (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollection));
#line 723 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp3_ = _tmp2_;
#line 723 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	gee_array_list_add_all (to_remove, _tmp3_);
#line 723 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (_tmp3_);
#line 724 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp4_ = video_global;
#line 724 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp5_ = media_source_collection_get_trashcan_contents (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollection));
#line 724 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp6_ = _tmp5_;
#line 724 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	gee_array_list_add_all (to_remove, _tmp6_);
#line 724 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (_tmp6_);
#line 726 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp7_ = _ ("Empty Trash");
#line 726 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp8_ = _ ("Emptying Trash...");
#line 726 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	remove_from_app (G_TYPE_CHECK_INSTANCE_CAST (to_remove, GEE_TYPE_COLLECTION, GeeCollection), _tmp7_, _tmp8_);
#line 728 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp9_ = app_window_get_command_manager ();
#line 728 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp10_ = _tmp9_;
#line 728 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	command_manager_reset (_tmp10_);
#line 728 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_command_manager_unref0 (_tmp10_);
#line 721 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (to_remove);
#line 5949 "LibraryWindow.c"
}


static void library_window_on_new_search (LibraryWindow* self) {
	SavedSearchDialog* _tmp0_ = NULL;
	SavedSearchDialog* _tmp1_ = NULL;
#line 731 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_LIBRARY_WINDOW (self));
#line 732 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = saved_search_dialog_new ();
#line 732 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_ = _tmp0_;
#line 732 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	saved_search_dialog_show (_tmp1_);
#line 732 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_saved_search_dialog_unref0 (_tmp1_);
#line 5966 "LibraryWindow.c"
}


static gboolean library_window_can_jump_to_event (LibraryWindow* self) {
	gboolean result = FALSE;
	ViewCollection* view = NULL;
	Page* _tmp0_ = NULL;
	Page* _tmp1_ = NULL;
	ViewCollection* _tmp2_ = NULL;
	ViewCollection* _tmp3_ = NULL;
	ViewCollection* _tmp4_ = NULL;
	gint _tmp5_ = 0;
#line 735 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_val_if_fail (IS_LIBRARY_WINDOW (self), FALSE);
#line 736 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = page_window_get_current_page (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE_WINDOW, PageWindow));
#line 736 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_ = _tmp0_;
#line 736 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp2_ = page_get_view (_tmp1_);
#line 736 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp3_ = _tmp2_;
#line 736 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (_tmp1_);
#line 736 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	view = _tmp3_;
#line 737 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp4_ = view;
#line 737 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp5_ = view_collection_get_selected_count (_tmp4_);
#line 737 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp5_ == 1) {
#line 5999 "LibraryWindow.c"
		DataSource* selected_source = NULL;
		ViewCollection* _tmp6_ = NULL;
		DataSource* _tmp7_ = NULL;
		DataSource* _tmp8_ = NULL;
#line 738 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp6_ = view;
#line 738 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp7_ = view_collection_get_selected_source_at (_tmp6_, 0);
#line 738 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		selected_source = _tmp7_;
#line 739 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp8_ = selected_source;
#line 739 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp8_, TYPE_EVENT)) {
#line 740 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			result = TRUE;
#line 740 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_g_object_unref0 (selected_source);
#line 740 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_data_collection_unref0 (view);
#line 740 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			return result;
#line 6022 "LibraryWindow.c"
		} else {
			DataSource* _tmp9_ = NULL;
#line 741 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_tmp9_ = selected_source;
#line 741 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp9_, TYPE_MEDIA_SOURCE)) {
#line 6029 "LibraryWindow.c"
				ViewCollection* _tmp10_ = NULL;
				DataSource* _tmp11_ = NULL;
				MediaSource* _tmp12_ = NULL;
				Event* _tmp13_ = NULL;
				Event* _tmp14_ = NULL;
				gboolean _tmp15_ = FALSE;
#line 742 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				_tmp10_ = view;
#line 742 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				_tmp11_ = view_collection_get_selected_source_at (_tmp10_, 0);
#line 742 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				_tmp12_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp11_, TYPE_MEDIA_SOURCE, MediaSource);
#line 742 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				_tmp13_ = media_source_get_event (_tmp12_);
#line 742 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				_tmp14_ = _tmp13_;
#line 742 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				_tmp15_ = _tmp14_ != NULL;
#line 742 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				_g_object_unref0 (_tmp14_);
#line 742 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				_g_object_unref0 (_tmp12_);
#line 742 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				result = _tmp15_;
#line 742 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				_g_object_unref0 (selected_source);
#line 742 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				_data_collection_unref0 (view);
#line 742 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				return result;
#line 6060 "LibraryWindow.c"
			} else {
#line 744 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				result = FALSE;
#line 744 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				_g_object_unref0 (selected_source);
#line 744 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				_data_collection_unref0 (view);
#line 744 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				return result;
#line 6070 "LibraryWindow.c"
			}
		}
#line 737 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_object_unref0 (selected_source);
#line 6075 "LibraryWindow.c"
	} else {
#line 746 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		result = FALSE;
#line 746 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_data_collection_unref0 (view);
#line 746 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		return result;
#line 6083 "LibraryWindow.c"
	}
#line 735 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_data_collection_unref0 (view);
#line 6087 "LibraryWindow.c"
}


static void library_window_on_jump_to_event (LibraryWindow* self) {
	ViewCollection* view = NULL;
	Page* _tmp0_ = NULL;
	Page* _tmp1_ = NULL;
	ViewCollection* _tmp2_ = NULL;
	ViewCollection* _tmp3_ = NULL;
	ViewCollection* _tmp4_ = NULL;
	gint _tmp5_ = 0;
	MediaSource* media = NULL;
	ViewCollection* _tmp6_ = NULL;
	DataSource* _tmp7_ = NULL;
	MediaSource* _tmp8_ = NULL;
	MediaSource* _tmp9_ = NULL;
	MediaSource* _tmp10_ = NULL;
	Event* _tmp11_ = NULL;
	Event* _tmp12_ = NULL;
	gboolean _tmp13_ = FALSE;
#line 750 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_LIBRARY_WINDOW (self));
#line 751 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = page_window_get_current_page (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE_WINDOW, PageWindow));
#line 751 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_ = _tmp0_;
#line 751 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp2_ = page_get_view (_tmp1_);
#line 751 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp3_ = _tmp2_;
#line 751 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (_tmp1_);
#line 751 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	view = _tmp3_;
#line 753 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp4_ = view;
#line 753 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp5_ = view_collection_get_selected_count (_tmp4_);
#line 753 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp5_ != 1) {
#line 754 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_data_collection_unref0 (view);
#line 754 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		return;
#line 6132 "LibraryWindow.c"
	}
#line 756 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp6_ = view;
#line 756 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp7_ = view_collection_get_selected_source_at (_tmp6_, 0);
#line 756 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp8_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp7_, TYPE_MEDIA_SOURCE) ? ((MediaSource*) _tmp7_) : NULL;
#line 756 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp8_ == NULL) {
#line 756 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_object_unref0 (_tmp7_);
#line 6144 "LibraryWindow.c"
	}
#line 756 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	media = _tmp8_;
#line 757 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp9_ = media;
#line 757 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp9_ == NULL) {
#line 758 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_object_unref0 (media);
#line 758 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_data_collection_unref0 (view);
#line 758 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		return;
#line 6158 "LibraryWindow.c"
	}
#line 760 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp10_ = media;
#line 760 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp11_ = media_source_get_event (_tmp10_);
#line 760 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp12_ = _tmp11_;
#line 760 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp13_ = _tmp12_ != NULL;
#line 760 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (_tmp12_);
#line 760 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp13_) {
#line 6172 "LibraryWindow.c"
		MediaSource* _tmp14_ = NULL;
		Event* _tmp15_ = NULL;
		Event* _tmp16_ = NULL;
#line 761 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp14_ = media;
#line 761 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp15_ = media_source_get_event (_tmp14_);
#line 761 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp16_ = _tmp15_;
#line 761 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		library_window_switch_to_event (self, _tmp16_);
#line 761 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_object_unref0 (_tmp16_);
#line 6186 "LibraryWindow.c"
	}
#line 750 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (media);
#line 750 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_data_collection_unref0 (view);
#line 6192 "LibraryWindow.c"
}


static void library_window_on_find (LibraryWindow* self) {
	GtkToggleAction* action = NULL;
	Page* _tmp0_ = NULL;
	Page* _tmp1_ = NULL;
	GtkAction* _tmp2_ = NULL;
	GtkToggleAction* _tmp3_ = NULL;
	SearchFilterToolbar* _tmp4_ = NULL;
#line 764 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_LIBRARY_WINDOW (self));
#line 765 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = page_window_get_current_page (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE_WINDOW, PageWindow));
#line 765 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_ = _tmp0_;
#line 765 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp2_ = page_get_common_action (_tmp1_, "CommonDisplaySearchbar", TRUE);
#line 765 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp3_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, gtk_toggle_action_get_type (), GtkToggleAction);
#line 765 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (_tmp1_);
#line 765 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	action = _tmp3_;
#line 767 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	gtk_toggle_action_set_active (action, TRUE);
#line 770 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp4_ = self->priv->search_toolbar;
#line 770 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	search_filter_toolbar_take_focus (_tmp4_);
#line 764 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (action);
#line 6225 "LibraryWindow.c"
}


static void library_window_on_media_altered (LibraryWindow* self) {
	gboolean _tmp0_ = FALSE;
#line 773 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_LIBRARY_WINDOW (self));
#line 774 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = library_window_can_jump_to_event (self);
#line 774 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	app_window_set_common_action_sensitive (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_APP_WINDOW, AppWindow), "CommonJumpToEvent", _tmp0_);
#line 6237 "LibraryWindow.c"
}


static void library_window_on_clear_search (LibraryWindow* self) {
	gboolean _tmp0_ = FALSE;
#line 777 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_LIBRARY_WINDOW (self));
#line 778 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = self->priv->is_search_toolbar_visible;
#line 778 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp0_) {
#line 6249 "LibraryWindow.c"
		SearchFilterActions* _tmp1_ = NULL;
#line 779 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp1_ = self->priv->search_actions;
#line 779 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		search_filter_actions_reset (_tmp1_);
#line 6255 "LibraryWindow.c"
	}
}


gint library_window_get_events_sort (LibraryWindow* self) {
	gint result = 0;
	GtkRadioAction* action = NULL;
	GtkAction* _tmp0_ = NULL;
	GtkRadioAction* _tmp1_ = NULL;
	gint _tmp2_ = 0;
	GtkRadioAction* _tmp3_ = NULL;
#line 782 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_val_if_fail (IS_LIBRARY_WINDOW (self), 0);
#line 783 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = app_window_get_common_action (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_APP_WINDOW, AppWindow), "CommonSortEventsAscending");
#line 783 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, gtk_radio_action_get_type ()) ? ((GtkRadioAction*) _tmp0_) : NULL;
#line 783 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp1_ == NULL) {
#line 783 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_object_unref0 (_tmp0_);
#line 6277 "LibraryWindow.c"
	}
#line 783 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	action = _tmp1_;
#line 785 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp3_ = action;
#line 785 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp3_ != NULL) {
#line 6285 "LibraryWindow.c"
		GtkRadioAction* _tmp4_ = NULL;
		gint _tmp5_ = 0;
		gint _tmp6_ = 0;
#line 785 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp4_ = action;
#line 785 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp5_ = gtk_radio_action_get_current_value (_tmp4_);
#line 785 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp6_ = _tmp5_;
#line 785 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp2_ = _tmp6_;
#line 6297 "LibraryWindow.c"
	} else {
#line 785 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp2_ = LIBRARY_WINDOW_SORT_EVENTS_ORDER_DESCENDING;
#line 6301 "LibraryWindow.c"
	}
#line 785 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	result = _tmp2_;
#line 785 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (action);
#line 785 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	return result;
#line 6309 "LibraryWindow.c"
}


static void library_window_on_events_sort_changed (LibraryWindow* self, GtkAction* action, GtkAction* c) {
	GtkRadioAction* current = NULL;
	GtkAction* _tmp0_ = NULL;
	GtkRadioAction* _tmp1_ = NULL;
	ConfigFacade* _tmp2_ = NULL;
	ConfigFacade* _tmp3_ = NULL;
	gint _tmp4_ = 0;
	gint _tmp5_ = 0;
#line 788 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_LIBRARY_WINDOW (self));
#line 788 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (GTK_IS_ACTION (action));
#line 788 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (GTK_IS_ACTION (c));
#line 789 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = c;
#line 789 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_radio_action_get_type (), GtkRadioAction));
#line 789 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	current = _tmp1_;
#line 791 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp2_ = config_facade_get_instance ();
#line 791 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp3_ = _tmp2_;
#line 791 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp4_ = gtk_radio_action_get_current_value (current);
#line 791 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp5_ = _tmp4_;
#line 791 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	configuration_facade_set_events_sort_ascending (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade), _tmp5_ == LIBRARY_WINDOW_SORT_EVENTS_ORDER_ASCENDING);
#line 791 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (_tmp3_);
#line 788 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (current);
#line 6347 "LibraryWindow.c"
}


static void library_window_on_preferences (LibraryWindow* self) {
#line 795 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_LIBRARY_WINDOW (self));
#line 796 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	preferences_dialog_show ();
#line 6356 "LibraryWindow.c"
}


static void library_window_on_display_basic_properties (LibraryWindow* self, GtkAction* action) {
	gboolean display = FALSE;
	GtkAction* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_ = FALSE;
	ConfigFacade* _tmp10_ = NULL;
	ConfigFacade* _tmp11_ = NULL;
	gboolean _tmp12_ = FALSE;
#line 799 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_LIBRARY_WINDOW (self));
#line 799 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (GTK_IS_ACTION (action));
#line 800 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = action;
#line 800 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_ = gtk_toggle_action_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_toggle_action_get_type (), GtkToggleAction));
#line 800 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	display = _tmp1_;
#line 802 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp2_ = display;
#line 802 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp2_) {
#line 6382 "LibraryWindow.c"
		BasicProperties* _tmp3_ = NULL;
		Page* _tmp4_ = NULL;
		Page* _tmp5_ = NULL;
		GtkFrame* _tmp6_ = NULL;
#line 803 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp3_ = self->priv->basic_properties;
#line 803 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp4_ = page_window_get_current_page (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE_WINDOW, PageWindow));
#line 803 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp5_ = _tmp4_;
#line 803 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		properties_update_properties (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, TYPE_PROPERTIES, Properties), _tmp5_);
#line 803 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_object_unref0 (_tmp5_);
#line 804 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp6_ = self->priv->bottom_frame;
#line 804 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		gtk_widget_show (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, gtk_widget_get_type (), GtkWidget));
#line 6401 "LibraryWindow.c"
	} else {
		GtkPaned* _tmp7_ = NULL;
		GtkWidget* _tmp8_ = NULL;
#line 806 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp7_ = self->priv->sidebar_paned;
#line 806 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp8_ = gtk_paned_get_child2 (_tmp7_);
#line 806 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		if (_tmp8_ != NULL) {
#line 6411 "LibraryWindow.c"
			GtkFrame* _tmp9_ = NULL;
#line 807 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_tmp9_ = self->priv->bottom_frame;
#line 807 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			gtk_widget_hide (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, gtk_widget_get_type (), GtkWidget));
#line 6417 "LibraryWindow.c"
		}
	}
#line 812 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp10_ = config_facade_get_instance ();
#line 812 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp11_ = _tmp10_;
#line 812 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp12_ = display;
#line 812 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	configuration_facade_set_display_basic_properties (G_TYPE_CHECK_INSTANCE_CAST (_tmp11_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade), _tmp12_);
#line 812 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (_tmp11_);
#line 6430 "LibraryWindow.c"
}


static void library_window_on_display_extended_properties (LibraryWindow* self, GtkAction* action) {
	gboolean display = FALSE;
	GtkAction* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_ = FALSE;
#line 815 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_LIBRARY_WINDOW (self));
#line 815 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (GTK_IS_ACTION (action));
#line 816 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = action;
#line 816 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_ = gtk_toggle_action_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_toggle_action_get_type (), GtkToggleAction));
#line 816 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	display = _tmp1_;
#line 818 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp2_ = display;
#line 818 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp2_) {
#line 6453 "LibraryWindow.c"
		ExtendedPropertiesWindow* _tmp3_ = NULL;
		Page* _tmp4_ = NULL;
		Page* _tmp5_ = NULL;
		ExtendedPropertiesWindow* _tmp6_ = NULL;
#line 819 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp3_ = self->priv->extended_properties;
#line 819 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp4_ = page_window_get_current_page (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE_WINDOW, PageWindow));
#line 819 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp5_ = _tmp4_;
#line 819 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		extended_properties_window_update_properties (_tmp3_, _tmp5_);
#line 819 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_object_unref0 (_tmp5_);
#line 820 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp6_ = self->priv->extended_properties;
#line 820 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		gtk_widget_show_all (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, gtk_widget_get_type (), GtkWidget));
#line 6472 "LibraryWindow.c"
	} else {
		ExtendedPropertiesWindow* _tmp7_ = NULL;
#line 822 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp7_ = self->priv->extended_properties;
#line 822 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		gtk_widget_hide (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, gtk_widget_get_type (), GtkWidget));
#line 6479 "LibraryWindow.c"
	}
}


static void library_window_on_display_searchbar (LibraryWindow* self, GtkAction* action) {
	gboolean is_shown = FALSE;
	GtkAction* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	ConfigFacade* _tmp2_ = NULL;
	ConfigFacade* _tmp3_ = NULL;
#line 826 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_LIBRARY_WINDOW (self));
#line 826 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (GTK_IS_ACTION (action));
#line 827 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = action;
#line 827 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_ = gtk_toggle_action_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_toggle_action_get_type (), GtkToggleAction));
#line 827 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	is_shown = _tmp1_;
#line 828 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp2_ = config_facade_get_instance ();
#line 828 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp3_ = _tmp2_;
#line 828 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	configuration_facade_set_display_search_bar (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade), is_shown);
#line 828 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (_tmp3_);
#line 829 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_window_show_search_bar (self, is_shown);
#line 6510 "LibraryWindow.c"
}


void library_window_show_search_bar (LibraryWindow* self, gboolean display) {
	Page* _tmp0_ = NULL;
	Page* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	gboolean _tmp3_ = FALSE;
	gboolean _tmp4_ = FALSE;
	Page* _tmp5_ = NULL;
	CheckerboardPage* _tmp6_ = NULL;
	CheckerboardPage* _tmp7_ = NULL;
	gboolean _tmp8_ = FALSE;
#line 832 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_LIBRARY_WINDOW (self));
#line 833 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = page_window_get_current_page (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE_WINDOW, PageWindow));
#line 833 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_ = _tmp0_;
#line 833 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp2_ = !G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, TYPE_CHECKERBOARD_PAGE);
#line 833 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (_tmp1_);
#line 833 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp2_) {
#line 834 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		return;
#line 6538 "LibraryWindow.c"
	}
#line 836 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp3_ = display;
#line 836 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	self->priv->is_search_toolbar_visible = _tmp3_;
#line 837 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp4_ = library_window_should_show_search_bar (self);
#line 837 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp5_ = page_window_get_current_page (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE_WINDOW, PageWindow));
#line 837 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp6_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp5_, TYPE_CHECKERBOARD_PAGE) ? ((CheckerboardPage*) _tmp5_) : NULL;
#line 837 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp6_ == NULL) {
#line 837 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_object_unref0 (_tmp5_);
#line 6554 "LibraryWindow.c"
	}
#line 837 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp7_ = _tmp6_;
#line 837 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_window_toggle_search_bar (self, _tmp4_, _tmp7_);
#line 837 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (_tmp7_);
#line 838 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp8_ = display;
#line 838 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (!_tmp8_) {
#line 6566 "LibraryWindow.c"
		SearchFilterActions* _tmp9_ = NULL;
#line 839 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp9_ = self->priv->search_actions;
#line 839 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		search_filter_actions_reset (_tmp9_);
#line 6572 "LibraryWindow.c"
	}
}


static void library_window_on_display_sidebar (LibraryWindow* self, GtkAction* action) {
	GtkAction* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
#line 842 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_LIBRARY_WINDOW (self));
#line 842 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (GTK_IS_ACTION (action));
#line 843 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = action;
#line 843 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_ = gtk_toggle_action_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_toggle_action_get_type (), GtkToggleAction));
#line 843 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_window_set_sidebar_visible (self, _tmp1_);
#line 6590 "LibraryWindow.c"
}


static void library_window_set_sidebar_visible (LibraryWindow* self, gboolean visible) {
	GtkPaned* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	ConfigFacade* _tmp2_ = NULL;
	ConfigFacade* _tmp3_ = NULL;
	gboolean _tmp4_ = FALSE;
#line 847 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_LIBRARY_WINDOW (self));
#line 848 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = self->priv->sidebar_paned;
#line 848 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_ = visible;
#line 848 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	gtk_widget_set_visible (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_widget_get_type (), GtkWidget), _tmp1_);
#line 849 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp2_ = config_facade_get_instance ();
#line 849 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp3_ = _tmp2_;
#line 849 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp4_ = visible;
#line 849 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	configuration_facade_set_display_sidebar (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade), _tmp4_);
#line 849 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (_tmp3_);
#line 6618 "LibraryWindow.c"
}


static gboolean library_window_is_sidebar_visible (LibraryWindow* self) {
	gboolean result = FALSE;
	ConfigFacade* _tmp0_ = NULL;
	ConfigFacade* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	gboolean _tmp3_ = FALSE;
#line 852 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_val_if_fail (IS_LIBRARY_WINDOW (self), FALSE);
#line 853 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = config_facade_get_instance ();
#line 853 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_ = _tmp0_;
#line 853 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp2_ = configuration_facade_get_display_sidebar (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade));
#line 853 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp3_ = _tmp2_;
#line 853 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (_tmp1_);
#line 853 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	result = _tmp3_;
#line 853 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	return result;
#line 6644 "LibraryWindow.c"
}


static void library_window_on_display_toolbar (LibraryWindow* self, GtkAction* action) {
	GtkAction* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
#line 856 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_LIBRARY_WINDOW (self));
#line 856 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (GTK_IS_ACTION (action));
#line 857 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = action;
#line 857 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_ = gtk_toggle_action_get_active (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, gtk_toggle_action_get_type ()) ? ((GtkToggleAction*) _tmp0_) : NULL);
#line 857 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_window_set_toolbar_visible (self, _tmp1_);
#line 6661 "LibraryWindow.c"
}


static void library_window_set_toolbar_visible (LibraryWindow* self, gboolean visible) {
	GtkToolbar* toolbar = NULL;
	Page* _tmp0_ = NULL;
	Page* _tmp1_ = NULL;
	GtkToolbar* _tmp2_ = NULL;
	GtkToolbar* _tmp3_ = NULL;
	GtkToolbar* _tmp4_ = NULL;
	ConfigFacade* _tmp7_ = NULL;
	ConfigFacade* _tmp8_ = NULL;
	gboolean _tmp9_ = FALSE;
#line 860 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_LIBRARY_WINDOW (self));
#line 861 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = page_window_get_current_page (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE_WINDOW, PageWindow));
#line 861 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_ = _tmp0_;
#line 861 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp2_ = page_get_toolbar (_tmp1_);
#line 861 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp3_ = _tmp2_;
#line 861 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (_tmp1_);
#line 861 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	toolbar = _tmp3_;
#line 862 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp4_ = toolbar;
#line 862 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp4_ != NULL) {
#line 6693 "LibraryWindow.c"
		GtkToolbar* _tmp5_ = NULL;
		gboolean _tmp6_ = FALSE;
#line 863 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp5_ = toolbar;
#line 863 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp6_ = visible;
#line 863 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		gtk_widget_set_visible (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, gtk_widget_get_type (), GtkWidget), _tmp6_);
#line 6702 "LibraryWindow.c"
	}
#line 865 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp7_ = config_facade_get_instance ();
#line 865 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp8_ = _tmp7_;
#line 865 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp9_ = visible;
#line 865 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	configuration_facade_set_display_toolbar (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade), _tmp9_);
#line 865 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (_tmp8_);
#line 860 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (toolbar);
#line 6716 "LibraryWindow.c"
}


static gboolean library_window_is_toolbar_visible (LibraryWindow* self) {
	gboolean result = FALSE;
	ConfigFacade* _tmp0_ = NULL;
	ConfigFacade* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	gboolean _tmp3_ = FALSE;
#line 868 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_val_if_fail (IS_LIBRARY_WINDOW (self), FALSE);
#line 869 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = config_facade_get_instance ();
#line 869 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_ = _tmp0_;
#line 869 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp2_ = configuration_facade_get_display_toolbar (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade));
#line 869 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp3_ = _tmp2_;
#line 869 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (_tmp1_);
#line 869 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	result = _tmp3_;
#line 869 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	return result;
#line 6742 "LibraryWindow.c"
}


static void library_window_show_extended_properties (LibraryWindow* self) {
#line 872 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_LIBRARY_WINDOW (self));
#line 873 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_window_sync_extended_properties (self, TRUE);
#line 6751 "LibraryWindow.c"
}


static void library_window_hide_extended_properties (LibraryWindow* self) {
#line 876 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_LIBRARY_WINDOW (self));
#line 877 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_window_sync_extended_properties (self, FALSE);
#line 6760 "LibraryWindow.c"
}


static void library_window_sync_extended_properties (LibraryWindow* self, gboolean show) {
	GtkToggleAction* extended_display_action = NULL;
	GtkAction* _tmp0_ = NULL;
	GtkToggleAction* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	ConfigFacade* _tmp3_ = NULL;
	ConfigFacade* _tmp4_ = NULL;
	gboolean _tmp5_ = FALSE;
#line 880 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_LIBRARY_WINDOW (self));
#line 881 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = app_window_get_common_action (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_APP_WINDOW, AppWindow), "CommonDisplayExtendedProperties");
#line 881 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, gtk_toggle_action_get_type ()) ? ((GtkToggleAction*) _tmp0_) : NULL;
#line 881 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp1_ == NULL) {
#line 881 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_object_unref0 (_tmp0_);
#line 6782 "LibraryWindow.c"
	}
#line 881 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	extended_display_action = _tmp1_;
#line 883 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_vala_assert (extended_display_action != NULL, "extended_display_action != null");
#line 884 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp2_ = show;
#line 884 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	gtk_toggle_action_set_active (extended_display_action, _tmp2_);
#line 887 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp3_ = config_facade_get_instance ();
#line 887 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp4_ = _tmp3_;
#line 887 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp5_ = show;
#line 887 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	configuration_facade_set_display_extended_properties (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade), _tmp5_);
#line 887 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (_tmp4_);
#line 880 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (extended_display_action);
#line 6804 "LibraryWindow.c"
}


void library_window_enqueue_batch_import (LibraryWindow* self, BatchImport* batch_import, gboolean allow_user_cancel) {
	LibraryBranch* _tmp0_ = NULL;
	LibraryImportQueueSidebarEntry* _tmp1_ = NULL;
	LibraryImportQueueSidebarEntry* _tmp2_ = NULL;
	BatchImport* _tmp3_ = NULL;
	gboolean _tmp4_ = FALSE;
#line 890 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_LIBRARY_WINDOW (self));
#line 890 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_BATCH_IMPORT (batch_import));
#line 891 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = self->priv->library_branch;
#line 891 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_ = library_branch_get_import_queue_entry (_tmp0_);
#line 891 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp2_ = _tmp1_;
#line 891 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp3_ = batch_import;
#line 891 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp4_ = allow_user_cancel;
#line 891 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_import_queue_sidebar_entry_enqueue_and_schedule (_tmp2_, _tmp3_, _tmp4_);
#line 6830 "LibraryWindow.c"
}


static void library_window_import_reporter (LibraryWindow* self, ImportManifest* manifest) {
	ImportManifest* _tmp0_ = NULL;
#line 894 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_LIBRARY_WINDOW (self));
#line 894 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_IMPORT_MANIFEST (manifest));
#line 895 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = manifest;
#line 895 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	import_ui_report_manifest (_tmp0_, TRUE, NULL);
#line 6844 "LibraryWindow.c"
}


static void _library_window_import_reporter_batch_import_import_reporter (ImportManifest* manifest, BatchImportRoll* import_roll, gpointer self) {
#line 926 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_window_import_reporter ((LibraryWindow*) self, manifest);
#line 6851 "LibraryWindow.c"
}


static void library_window_dispatch_import_jobs (LibraryWindow* self, GSList* uris, const gchar* job_name, gboolean copy_to_library) {
	gboolean _tmp0_ = FALSE;
	GFile* _tmp1_ = NULL;
	GFile* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
	gboolean _tmp6_ = FALSE;
	GeeArrayList* jobs = NULL;
	GeeArrayList* _tmp18_ = NULL;
	GSList* _tmp19_ = NULL;
	GeeArrayList* _tmp33_ = NULL;
	gint _tmp34_ = 0;
	gint _tmp35_ = 0;
#line 898 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_LIBRARY_WINDOW (self));
#line 898 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (job_name != NULL);
#line 899 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_ = app_dirs_get_import_dir ();
#line 899 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp2_ = _tmp1_;
#line 899 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp3_ = g_file_get_path (_tmp2_);
#line 899 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp4_ = _tmp3_;
#line 899 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp5_ = g_get_home_dir ();
#line 899 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp6_ = g_strcmp0 (_tmp4_, _tmp5_) == 0;
#line 899 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_free0 (_tmp4_);
#line 899 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (_tmp2_);
#line 899 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp6_) {
#line 6891 "LibraryWindow.c"
		gboolean _tmp7_ = FALSE;
#line 899 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp7_ = self->priv->notify_library_is_home_dir;
#line 899 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp0_ = _tmp7_;
#line 6897 "LibraryWindow.c"
	} else {
#line 899 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp0_ = FALSE;
#line 6901 "LibraryWindow.c"
	}
#line 899 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp0_) {
#line 6905 "LibraryWindow.c"
		GtkResponseType response = 0;
		const gchar* _tmp8_ = NULL;
		gchar* _tmp9_ = NULL;
		gchar* _tmp10_ = NULL;
		const gchar* _tmp11_ = NULL;
		const gchar* _tmp12_ = NULL;
		AppWindow* _tmp13_ = NULL;
		AppWindow* _tmp14_ = NULL;
		GtkResponseType _tmp15_ = 0;
		GtkResponseType _tmp16_ = 0;
		GtkResponseType _tmp17_ = 0;
#line 900 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp8_ = _ ("Shotwell is configured to import photos to your home directory.\n" "We recommend changing this in <span weight=\"bold\">Edit %s Preference" \
"s</span>.\n" "Do you want to continue importing photos?");
#line 900 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp9_ = g_strdup_printf (_tmp8_, "▸");
#line 900 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp10_ = _tmp9_;
#line 900 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp11_ = _ ("_Import");
#line 900 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp12_ = _ ("Library Location");
#line 900 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp13_ = app_window_get_instance ();
#line 900 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp14_ = _tmp13_;
#line 900 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp15_ = app_window_affirm_cancel_question (_tmp10_, _tmp11_, _tmp12_, G_TYPE_CHECK_INSTANCE_CAST (_tmp14_, gtk_window_get_type (), GtkWindow));
#line 900 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp16_ = _tmp15_;
#line 900 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_object_unref0 (_tmp14_);
#line 900 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_free0 (_tmp10_);
#line 900 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		response = _tmp16_;
#line 906 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp17_ = response;
#line 906 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		if (_tmp17_ == GTK_RESPONSE_CANCEL) {
#line 907 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			return;
#line 6947 "LibraryWindow.c"
		}
#line 909 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		self->priv->notify_library_is_home_dir = FALSE;
#line 6951 "LibraryWindow.c"
	}
#line 912 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp18_ = gee_array_list_new (TYPE_FILE_IMPORT_JOB, (GBoxedCopyFunc) batch_import_job_ref, batch_import_job_unref, NULL, NULL, NULL);
#line 912 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	jobs = _tmp18_;
#line 913 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp19_ = uris;
#line 6959 "LibraryWindow.c"
	{
		GSList* uri_collection = NULL;
		GSList* uri_it = NULL;
#line 913 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		uri_collection = _tmp19_;
#line 913 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		for (uri_it = uri_collection; uri_it != NULL; uri_it = uri_it->next) {
#line 6967 "LibraryWindow.c"
			gchar* _tmp20_ = NULL;
			gchar* uri = NULL;
#line 913 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_tmp20_ = g_strdup ((const gchar*) uri_it->data);
#line 913 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			uri = _tmp20_;
#line 6974 "LibraryWindow.c"
			{
				GFile* file_or_dir = NULL;
				const gchar* _tmp21_ = NULL;
				GFile* _tmp22_ = NULL;
				GFile* _tmp23_ = NULL;
				gchar* _tmp24_ = NULL;
				gchar* _tmp25_ = NULL;
				gboolean _tmp26_ = FALSE;
				GeeArrayList* _tmp28_ = NULL;
				GFile* _tmp29_ = NULL;
				gboolean _tmp30_ = FALSE;
				FileImportJob* _tmp31_ = NULL;
				FileImportJob* _tmp32_ = NULL;
#line 914 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				_tmp21_ = uri;
#line 914 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				_tmp22_ = g_file_new_for_uri (_tmp21_);
#line 914 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				file_or_dir = _tmp22_;
#line 915 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				_tmp23_ = file_or_dir;
#line 915 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				_tmp24_ = g_file_get_path (_tmp23_);
#line 915 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				_tmp25_ = _tmp24_;
#line 915 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				_tmp26_ = _tmp25_ == NULL;
#line 915 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				_g_free0 (_tmp25_);
#line 915 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				if (_tmp26_) {
#line 7006 "LibraryWindow.c"
					const gchar* _tmp27_ = NULL;
#line 917 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
					_tmp27_ = _ ("Photos cannot be imported from this directory.");
#line 917 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
					app_window_error_message (_tmp27_, NULL);
#line 919 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
					_g_object_unref0 (file_or_dir);
#line 919 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
					_g_free0 (uri);
#line 919 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
					continue;
#line 7018 "LibraryWindow.c"
				}
#line 922 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				_tmp28_ = jobs;
#line 922 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				_tmp29_ = file_or_dir;
#line 922 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				_tmp30_ = copy_to_library;
#line 922 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				_tmp31_ = file_import_job_new (_tmp29_, _tmp30_);
#line 922 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				_tmp32_ = _tmp31_;
#line 922 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				gee_abstract_collection_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp28_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection), _tmp32_);
#line 922 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				_batch_import_job_unref0 (_tmp32_);
#line 913 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				_g_object_unref0 (file_or_dir);
#line 913 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				_g_free0 (uri);
#line 7038 "LibraryWindow.c"
			}
		}
	}
#line 925 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp33_ = jobs;
#line 925 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp34_ = gee_abstract_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp33_, GEE_TYPE_COLLECTION, GeeCollection));
#line 925 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp35_ = _tmp34_;
#line 925 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp35_ > 0) {
#line 7050 "LibraryWindow.c"
		BatchImport* batch_import = NULL;
		GeeArrayList* _tmp36_ = NULL;
		const gchar* _tmp37_ = NULL;
		BatchImport* _tmp38_ = NULL;
		BatchImport* _tmp39_ = NULL;
#line 926 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp36_ = jobs;
#line 926 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp37_ = job_name;
#line 926 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp38_ = batch_import_new (G_TYPE_CHECK_INSTANCE_CAST (_tmp36_, GEE_TYPE_ITERABLE, GeeIterable), _tmp37_, _library_window_import_reporter_batch_import_import_reporter, self, NULL, NULL, NULL, NULL, NULL);
#line 926 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		batch_import = _tmp38_;
#line 927 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp39_ = batch_import;
#line 927 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		library_window_enqueue_batch_import (self, _tmp39_, TRUE);
#line 928 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		library_window_switch_to_import_queue_page (self);
#line 925 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_object_unref0 (batch_import);
#line 7072 "LibraryWindow.c"
	}
#line 898 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (jobs);
#line 7076 "LibraryWindow.c"
}


static GdkDragAction library_window_get_drag_action (LibraryWindow* self) {
	GdkDragAction result = 0;
	GdkModifierType mask = 0;
	GdkWindow* _tmp0_ = NULL;
	GdkDisplay* _tmp1_ = NULL;
	GdkDeviceManager* _tmp2_ = NULL;
	GdkDevice* _tmp3_ = NULL;
	GdkModifierType _tmp4_ = 0;
	gboolean ctrl = FALSE;
	GdkModifierType _tmp5_ = 0;
	gboolean alt = FALSE;
	GdkModifierType _tmp6_ = 0;
	gboolean shift = FALSE;
	GdkModifierType _tmp7_ = 0;
	gboolean _tmp8_ = FALSE;
	gboolean _tmp9_ = FALSE;
	gboolean _tmp10_ = FALSE;
#line 932 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_val_if_fail (IS_LIBRARY_WINDOW (self), 0);
#line 935 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = gtk_widget_get_window (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 935 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_ = gdk_display_get_default ();
#line 935 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp2_ = gdk_display_get_device_manager (_tmp1_);
#line 935 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp3_ = gdk_device_manager_get_client_pointer (_tmp2_);
#line 935 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	gdk_window_get_device_position (_tmp0_, _tmp3_, NULL, NULL, &_tmp4_);
#line 935 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	mask = _tmp4_;
#line 938 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp5_ = mask;
#line 938 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	ctrl = (_tmp5_ & GDK_CONTROL_MASK) != 0;
#line 939 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp6_ = mask;
#line 939 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	alt = (_tmp6_ & GDK_MOD1_MASK) != 0;
#line 940 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp7_ = mask;
#line 940 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	shift = (_tmp7_ & GDK_SHIFT_MASK) != 0;
#line 942 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp10_ = ctrl;
#line 942 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp10_) {
#line 7127 "LibraryWindow.c"
		gboolean _tmp11_ = FALSE;
#line 942 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp11_ = alt;
#line 942 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp9_ = !_tmp11_;
#line 7133 "LibraryWindow.c"
	} else {
#line 942 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp9_ = FALSE;
#line 7137 "LibraryWindow.c"
	}
#line 942 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp9_) {
#line 7141 "LibraryWindow.c"
		gboolean _tmp12_ = FALSE;
#line 942 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp12_ = shift;
#line 942 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp8_ = !_tmp12_;
#line 7147 "LibraryWindow.c"
	} else {
#line 942 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp8_ = FALSE;
#line 7151 "LibraryWindow.c"
	}
#line 942 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp8_) {
#line 943 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		result = GDK_ACTION_COPY;
#line 943 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		return result;
#line 7159 "LibraryWindow.c"
	} else {
		gboolean _tmp13_ = FALSE;
		gboolean _tmp14_ = FALSE;
		gboolean _tmp15_ = FALSE;
#line 944 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp15_ = ctrl;
#line 944 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		if (!_tmp15_) {
#line 7168 "LibraryWindow.c"
			gboolean _tmp16_ = FALSE;
#line 944 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_tmp16_ = alt;
#line 944 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_tmp14_ = _tmp16_;
#line 7174 "LibraryWindow.c"
		} else {
#line 944 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_tmp14_ = FALSE;
#line 7178 "LibraryWindow.c"
		}
#line 944 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		if (_tmp14_) {
#line 7182 "LibraryWindow.c"
			gboolean _tmp17_ = FALSE;
#line 944 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_tmp17_ = shift;
#line 944 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_tmp13_ = !_tmp17_;
#line 7188 "LibraryWindow.c"
		} else {
#line 944 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_tmp13_ = FALSE;
#line 7192 "LibraryWindow.c"
		}
#line 944 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		if (_tmp13_) {
#line 945 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			result = GDK_ACTION_ASK;
#line 945 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			return result;
#line 7200 "LibraryWindow.c"
		} else {
			gboolean _tmp18_ = FALSE;
			gboolean _tmp19_ = FALSE;
			gboolean _tmp20_ = FALSE;
#line 946 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_tmp20_ = ctrl;
#line 946 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			if (_tmp20_) {
#line 7209 "LibraryWindow.c"
				gboolean _tmp21_ = FALSE;
#line 946 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				_tmp21_ = alt;
#line 946 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				_tmp19_ = !_tmp21_;
#line 7215 "LibraryWindow.c"
			} else {
#line 946 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				_tmp19_ = FALSE;
#line 7219 "LibraryWindow.c"
			}
#line 946 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			if (_tmp19_) {
#line 7223 "LibraryWindow.c"
				gboolean _tmp22_ = FALSE;
#line 946 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				_tmp22_ = shift;
#line 946 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				_tmp18_ = _tmp22_;
#line 7229 "LibraryWindow.c"
			} else {
#line 946 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				_tmp18_ = FALSE;
#line 7233 "LibraryWindow.c"
			}
#line 946 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			if (_tmp18_) {
#line 947 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				result = GDK_ACTION_LINK;
#line 947 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				return result;
#line 7241 "LibraryWindow.c"
			} else {
#line 949 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				result = GDK_ACTION_DEFAULT;
#line 949 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				return result;
#line 7247 "LibraryWindow.c"
			}
		}
	}
}


static gboolean library_window_real_drag_motion (GtkWidget* base, GdkDragContext* context, gint x, gint y, guint time) {
	LibraryWindow * self;
	gboolean result = FALSE;
	GdkAtom target = 0U;
	GdkDragContext* _tmp0_ = NULL;
	GtkTargetList* _tmp1_ = NULL;
	GdkAtom _tmp2_ = 0U;
	GdkAtom _tmp3_ = 0U;
	GdkDragContext* _tmp6_ = NULL;
	GtkWidget* _tmp7_ = NULL;
	GdkDragAction drag_action = 0;
	GdkDragAction _tmp10_ = 0;
	GdkDragAction _tmp11_ = 0;
	GdkDragContext* _tmp12_ = NULL;
	GdkDragAction _tmp13_ = 0;
	guint _tmp14_ = 0U;
#line 952 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_LIBRARY_WINDOW, LibraryWindow);
#line 952 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_val_if_fail (GDK_IS_DRAG_CONTEXT (context), FALSE);
#line 953 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = context;
#line 953 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_ = gtk_drag_dest_get_target_list (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 953 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp2_ = gtk_drag_dest_find_target (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget), _tmp0_, _tmp1_);
#line 953 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	target = _tmp2_;
#line 956 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp3_ = target;
#line 956 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (((gint) _tmp3_) == 0) {
#line 7286 "LibraryWindow.c"
		GdkDragContext* _tmp4_ = NULL;
		guint _tmp5_ = 0U;
#line 957 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		g_debug ("LibraryWindow.vala:957: drag target is GDK_NONE");
#line 958 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp4_ = context;
#line 958 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp5_ = time;
#line 958 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		gdk_drag_status (_tmp4_, 0, (guint32) _tmp5_);
#line 960 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		result = TRUE;
#line 960 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		return result;
#line 7301 "LibraryWindow.c"
	}
#line 964 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp6_ = context;
#line 964 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp7_ = gtk_drag_get_source_widget (_tmp6_);
#line 964 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp7_ != NULL) {
#line 7309 "LibraryWindow.c"
		GdkDragContext* _tmp8_ = NULL;
		guint _tmp9_ = 0U;
#line 965 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp8_ = context;
#line 965 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp9_ = time;
#line 965 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		gdk_drag_status (_tmp8_, GDK_ACTION_PRIVATE, (guint32) _tmp9_);
#line 967 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		result = TRUE;
#line 967 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		return result;
#line 7322 "LibraryWindow.c"
	}
#line 971 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp10_ = library_window_get_drag_action (self);
#line 971 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	drag_action = _tmp10_;
#line 973 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp11_ = drag_action;
#line 973 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp11_ == GDK_ACTION_DEFAULT) {
#line 974 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		drag_action = GDK_ACTION_ASK;
#line 7334 "LibraryWindow.c"
	}
#line 976 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp12_ = context;
#line 976 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp13_ = drag_action;
#line 976 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp14_ = time;
#line 976 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	gdk_drag_status (_tmp12_, _tmp13_, (guint32) _tmp14_);
#line 978 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	result = TRUE;
#line 978 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	return result;
#line 7348 "LibraryWindow.c"
}


static void library_window_real_drag_data_received (GtkWidget* base, GdkDragContext* context, gint x, gint y, GtkSelectionData* selection_data, guint info, guint time) {
	LibraryWindow * self;
	GtkSelectionData* _tmp0_ = NULL;
	guchar* _tmp1_ = NULL;
	GdkDragContext* _tmp2_ = NULL;
	GtkWidget* _tmp3_ = NULL;
#line 981 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_LIBRARY_WINDOW, LibraryWindow);
#line 981 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (GDK_IS_DRAG_CONTEXT (context));
#line 981 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (selection_data != NULL);
#line 983 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = selection_data;
#line 983 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_ = gtk_selection_data_get_data (_tmp0_);
#line 983 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (-1 < 0) {
#line 984 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		g_debug ("LibraryWindow.vala:984: failed to retrieve SelectionData");
#line 7372 "LibraryWindow.c"
	}
#line 988 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp2_ = context;
#line 988 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp3_ = gtk_drag_get_source_widget (_tmp2_);
#line 988 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp3_ == NULL) {
#line 7380 "LibraryWindow.c"
		GdkDragContext* _tmp4_ = NULL;
		GtkSelectionData* _tmp5_ = NULL;
		guint _tmp6_ = 0U;
		guint _tmp7_ = 0U;
#line 989 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp4_ = context;
#line 989 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp5_ = selection_data;
#line 989 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp6_ = info;
#line 989 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp7_ = time;
#line 989 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		library_window_external_drop_handler (self, _tmp4_, NULL, _tmp5_, _tmp6_, _tmp7_);
#line 7395 "LibraryWindow.c"
	} else {
		GdkDragContext* _tmp8_ = NULL;
		guint _tmp9_ = 0U;
#line 991 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp8_ = context;
#line 991 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp9_ = time;
#line 991 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		gtk_drag_finish (_tmp8_, FALSE, FALSE, (guint32) _tmp9_);
#line 7405 "LibraryWindow.c"
	}
}


static void library_window_external_drop_handler (LibraryWindow* self, GdkDragContext* context, SidebarEntry* entry, GtkSelectionData* data, guint info, guint time) {
	gchar** uris_array = NULL;
	GtkSelectionData* _tmp0_ = NULL;
	gchar** _tmp1_ = NULL;
	gchar** _tmp2_ = NULL;
	gint uris_array_length1 = 0;
	gint _uris_array_size_ = 0;
	GSList* uris = NULL;
	gchar** _tmp3_ = NULL;
	gint _tmp3__length1 = 0;
	GdkDragAction selected_action = 0;
	GdkDragContext* _tmp7_ = NULL;
	GdkDragAction _tmp8_ = 0;
	GdkDragAction _tmp9_ = 0;
	GSList* _tmp21_ = NULL;
	GdkDragAction _tmp22_ = 0;
	GdkDragContext* _tmp23_ = NULL;
	guint _tmp24_ = 0U;
#line 994 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_LIBRARY_WINDOW (self));
#line 994 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (GDK_IS_DRAG_CONTEXT (context));
#line 994 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail ((entry == NULL) || SIDEBAR_IS_ENTRY (entry));
#line 994 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (data != NULL);
#line 996 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = data;
#line 996 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp2_ = _tmp1_ = gtk_selection_data_get_uris (_tmp0_);
#line 996 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	uris_array = _tmp2_;
#line 996 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	uris_array_length1 = _vala_array_length (_tmp1_);
#line 996 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_uris_array_size_ = uris_array_length1;
#line 998 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	uris = NULL;
#line 999 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp3_ = uris_array;
#line 999 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp3__length1 = uris_array_length1;
#line 7452 "LibraryWindow.c"
	{
		gchar** uri_collection = NULL;
		gint uri_collection_length1 = 0;
		gint _uri_collection_size_ = 0;
		gint uri_it = 0;
#line 999 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		uri_collection = _tmp3_;
#line 999 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		uri_collection_length1 = _tmp3__length1;
#line 999 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		for (uri_it = 0; uri_it < _tmp3__length1; uri_it = uri_it + 1) {
#line 7464 "LibraryWindow.c"
			gchar* _tmp4_ = NULL;
			gchar* uri = NULL;
#line 999 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_tmp4_ = g_strdup (uri_collection[uri_it]);
#line 999 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			uri = _tmp4_;
#line 7471 "LibraryWindow.c"
			{
				const gchar* _tmp5_ = NULL;
				gchar* _tmp6_ = NULL;
#line 1000 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				_tmp5_ = uri;
#line 1000 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				_tmp6_ = g_strdup (_tmp5_);
#line 1000 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				uris = g_slist_append (uris, _tmp6_);
#line 999 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				_g_free0 (uri);
#line 7483 "LibraryWindow.c"
			}
		}
	}
#line 1002 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp7_ = context;
#line 1002 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp8_ = gdk_drag_context_get_selected_action (_tmp7_);
#line 1002 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	selected_action = _tmp8_;
#line 1003 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp9_ = selected_action;
#line 1003 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp9_ == GDK_ACTION_ASK) {
#line 7497 "LibraryWindow.c"
		GtkResponseType _result_ = 0;
		GSList* _tmp10_ = NULL;
		GtkResponseType _tmp18_ = 0;
#line 1005 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_result_ = GTK_RESPONSE_REJECT;
#line 1006 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp10_ = uris;
#line 7505 "LibraryWindow.c"
		{
			GSList* uri_collection = NULL;
			GSList* uri_it = NULL;
#line 1006 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			uri_collection = _tmp10_;
#line 1006 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			for (uri_it = uri_collection; uri_it != NULL; uri_it = uri_it->next) {
#line 7513 "LibraryWindow.c"
				gchar* _tmp11_ = NULL;
				gchar* uri = NULL;
#line 1006 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				_tmp11_ = g_strdup ((const gchar*) uri_it->data);
#line 1006 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				uri = _tmp11_;
#line 7520 "LibraryWindow.c"
				{
					const gchar* _tmp12_ = NULL;
					GFile* _tmp13_ = NULL;
					GFile* _tmp14_ = NULL;
					gboolean _tmp15_ = FALSE;
					gboolean _tmp16_ = FALSE;
#line 1007 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
					_tmp12_ = uri;
#line 1007 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
					_tmp13_ = g_file_new_for_uri (_tmp12_);
#line 1007 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
					_tmp14_ = _tmp13_;
#line 1007 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
					_tmp15_ = app_dirs_is_in_import_dir (_tmp14_);
#line 1007 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
					_tmp16_ = !_tmp15_;
#line 1007 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
					_g_object_unref0 (_tmp14_);
#line 1007 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
					if (_tmp16_) {
#line 7541 "LibraryWindow.c"
						GtkResponseType _tmp17_ = 0;
#line 1008 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
						_tmp17_ = copy_files_dialog ();
#line 1008 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
						_result_ = _tmp17_;
#line 1010 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
						_g_free0 (uri);
#line 1010 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
						break;
#line 7551 "LibraryWindow.c"
					}
#line 1006 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
					_g_free0 (uri);
#line 7555 "LibraryWindow.c"
				}
			}
		}
#line 1014 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp18_ = _result_;
#line 1014 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		switch (_tmp18_) {
#line 1014 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			case GTK_RESPONSE_ACCEPT:
#line 7565 "LibraryWindow.c"
			{
#line 1016 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				selected_action = GDK_ACTION_COPY;
#line 1017 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				break;
#line 7571 "LibraryWindow.c"
			}
#line 1014 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			case GTK_RESPONSE_REJECT:
#line 7575 "LibraryWindow.c"
			{
#line 1020 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				selected_action = GDK_ACTION_LINK;
#line 1021 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				break;
#line 7581 "LibraryWindow.c"
			}
			default:
			{
				GdkDragContext* _tmp19_ = NULL;
				guint _tmp20_ = 0U;
#line 1025 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				_tmp19_ = context;
#line 1025 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				_tmp20_ = time;
#line 1025 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				gtk_drag_finish (_tmp19_, FALSE, FALSE, (guint32) _tmp20_);
#line 1027 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				__g_slist_free__g_free0_0 (uris);
#line 1027 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				uris_array = (_vala_array_free (uris_array, uris_array_length1, (GDestroyNotify) g_free), NULL);
#line 1027 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				return;
#line 7599 "LibraryWindow.c"
			}
		}
	}
#line 1031 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp21_ = uris;
#line 1031 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp22_ = selected_action;
#line 1031 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_window_dispatch_import_jobs (self, _tmp21_, "drag-and-drop", _tmp22_ == GDK_ACTION_COPY);
#line 1033 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp23_ = context;
#line 1033 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp24_ = time;
#line 1033 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	gtk_drag_finish (_tmp23_, TRUE, FALSE, (guint32) _tmp24_);
#line 994 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	__g_slist_free__g_free0_0 (uris);
#line 994 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	uris_array = (_vala_array_free (uris_array, uris_array_length1, (GDestroyNotify) g_free), NULL);
#line 7619 "LibraryWindow.c"
}


void library_window_switch_to_library_page (LibraryWindow* self) {
	LibraryBranch* _tmp0_ = NULL;
	LibraryPhotosEntry* _tmp1_ = NULL;
	LibraryPhotosEntry* _tmp2_ = NULL;
	Page* _tmp3_ = NULL;
	Page* _tmp4_ = NULL;
#line 1036 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_LIBRARY_WINDOW (self));
#line 1037 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = self->priv->library_branch;
#line 1037 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_ = library_branch_get_photos_entry (_tmp0_);
#line 1037 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp2_ = _tmp1_;
#line 1037 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp3_ = sidebar_page_representative_get_page (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, SIDEBAR_TYPE_PAGE_REPRESENTATIVE, SidebarPageRepresentative));
#line 1037 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp4_ = _tmp3_;
#line 1037 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_window_switch_to_page (self, _tmp4_);
#line 1037 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (_tmp4_);
#line 7645 "LibraryWindow.c"
}


void library_window_switch_to_event (LibraryWindow* self, Event* event) {
	EventsEventEntry* entry = NULL;
	EventsBranch* _tmp0_ = NULL;
	Event* _tmp1_ = NULL;
	EventsEventEntry* _tmp2_ = NULL;
	EventsEventEntry* _tmp3_ = NULL;
#line 1040 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_LIBRARY_WINDOW (self));
#line 1040 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_EVENT (event));
#line 1041 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = self->priv->events_branch;
#line 1041 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_ = event;
#line 1041 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp2_ = events_branch_get_entry_for_event (_tmp0_, _tmp1_);
#line 1041 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	entry = _tmp2_;
#line 1042 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp3_ = entry;
#line 1042 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp3_ != NULL) {
#line 7671 "LibraryWindow.c"
		EventsEventEntry* _tmp4_ = NULL;
		Page* _tmp5_ = NULL;
		Page* _tmp6_ = NULL;
#line 1043 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp4_ = entry;
#line 1043 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp5_ = sidebar_page_representative_get_page (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, SIDEBAR_TYPE_PAGE_REPRESENTATIVE, SidebarPageRepresentative));
#line 1043 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp6_ = _tmp5_;
#line 1043 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		library_window_switch_to_page (self, _tmp6_);
#line 1043 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_object_unref0 (_tmp6_);
#line 7685 "LibraryWindow.c"
	}
#line 1040 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (entry);
#line 7689 "LibraryWindow.c"
}


void library_window_switch_to_tag (LibraryWindow* self, Tag* tag) {
	TagsSidebarEntry* entry = NULL;
	TagsBranch* _tmp0_ = NULL;
	Tag* _tmp1_ = NULL;
	TagsSidebarEntry* _tmp2_ = NULL;
	TagsSidebarEntry* _tmp3_ = NULL;
#line 1046 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_LIBRARY_WINDOW (self));
#line 1046 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_TAG (tag));
#line 1047 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = self->priv->tags_branch;
#line 1047 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_ = tag;
#line 1047 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp2_ = tags_branch_get_entry_for_tag (_tmp0_, _tmp1_);
#line 1047 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	entry = _tmp2_;
#line 1048 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp3_ = entry;
#line 1048 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp3_ != NULL) {
#line 7715 "LibraryWindow.c"
		TagsSidebarEntry* _tmp4_ = NULL;
		Page* _tmp5_ = NULL;
		Page* _tmp6_ = NULL;
#line 1049 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp4_ = entry;
#line 1049 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp5_ = sidebar_page_representative_get_page (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, SIDEBAR_TYPE_PAGE_REPRESENTATIVE, SidebarPageRepresentative));
#line 1049 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp6_ = _tmp5_;
#line 1049 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		library_window_switch_to_page (self, _tmp6_);
#line 1049 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_object_unref0 (_tmp6_);
#line 7729 "LibraryWindow.c"
	}
#line 1046 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (entry);
#line 7733 "LibraryWindow.c"
}


void library_window_switch_to_saved_search (LibraryWindow* self, SavedSearch* search) {
	SearchesSidebarEntry* entry = NULL;
	SearchesBranch* _tmp0_ = NULL;
	SavedSearch* _tmp1_ = NULL;
	SearchesSidebarEntry* _tmp2_ = NULL;
	SearchesSidebarEntry* _tmp3_ = NULL;
#line 1052 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_LIBRARY_WINDOW (self));
#line 1052 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_SAVED_SEARCH (search));
#line 1053 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = self->priv->saved_search_branch;
#line 1053 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_ = search;
#line 1053 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp2_ = searches_branch_get_entry_for_saved_search (_tmp0_, _tmp1_);
#line 1053 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	entry = _tmp2_;
#line 1054 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp3_ = entry;
#line 1054 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp3_ != NULL) {
#line 7759 "LibraryWindow.c"
		SearchesSidebarEntry* _tmp4_ = NULL;
		Page* _tmp5_ = NULL;
		Page* _tmp6_ = NULL;
#line 1055 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp4_ = entry;
#line 1055 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp5_ = sidebar_page_representative_get_page (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, SIDEBAR_TYPE_PAGE_REPRESENTATIVE, SidebarPageRepresentative));
#line 1055 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp6_ = _tmp5_;
#line 1055 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		library_window_switch_to_page (self, _tmp6_);
#line 1055 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_object_unref0 (_tmp6_);
#line 7773 "LibraryWindow.c"
	}
#line 1052 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (entry);
#line 7777 "LibraryWindow.c"
}


void library_window_switch_to_photo_page (LibraryWindow* self, CollectionPage* controller, Photo* current) {
	CollectionPage* _tmp0_ = NULL;
	ViewCollection* _tmp1_ = NULL;
	ViewCollection* _tmp2_ = NULL;
	Photo* _tmp3_ = NULL;
	DataView* _tmp4_ = NULL;
	DataView* _tmp5_ = NULL;
	LibraryPhotoPage* _tmp6_ = NULL;
	LibraryPhotoPage* _tmp9_ = NULL;
	CollectionPage* _tmp10_ = NULL;
	Photo* _tmp11_ = NULL;
	LibraryPhotoPage* _tmp12_ = NULL;
#line 1058 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_LIBRARY_WINDOW (self));
#line 1058 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_COLLECTION_PAGE (controller));
#line 1058 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_PHOTO (current));
#line 1059 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = controller;
#line 1059 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, TYPE_PAGE, Page));
#line 1059 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp2_ = _tmp1_;
#line 1059 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp3_ = current;
#line 1059 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp4_ = view_collection_get_view_for_source (_tmp2_, G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, TYPE_DATA_SOURCE, DataSource));
#line 1059 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp5_ = _tmp4_;
#line 1059 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_vala_assert (_tmp5_ != NULL, "controller.get_view().get_view_for_source(current) != null");
#line 1059 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (_tmp5_);
#line 1059 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_data_collection_unref0 (_tmp2_);
#line 1060 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp6_ = self->priv->photo_page;
#line 1060 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp6_ == NULL) {
#line 7821 "LibraryWindow.c"
		LibraryPhotoPage* _tmp7_ = NULL;
		LibraryPhotoPage* _tmp8_ = NULL;
#line 1061 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp7_ = library_photo_page_new ();
#line 1061 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		g_object_ref_sink (_tmp7_);
#line 1061 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_object_unref0 (self->priv->photo_page);
#line 1061 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		self->priv->photo_page = _tmp7_;
#line 1062 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp8_ = self->priv->photo_page;
#line 1062 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		library_window_add_to_stack (self, G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, TYPE_PAGE, Page));
#line 1066 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		spin_event_loop ();
#line 7838 "LibraryWindow.c"
	}
#line 1069 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp9_ = self->priv->photo_page;
#line 1069 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp10_ = controller;
#line 1069 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp11_ = current;
#line 1069 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_photo_page_display_for_collection (_tmp9_, _tmp10_, _tmp11_, NULL);
#line 1070 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp12_ = self->priv->photo_page;
#line 1070 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_window_switch_to_page (self, G_TYPE_CHECK_INSTANCE_CAST (_tmp12_, TYPE_PAGE, Page));
#line 7852 "LibraryWindow.c"
}


void library_window_switch_to_import_queue_page (LibraryWindow* self) {
	LibraryBranch* _tmp0_ = NULL;
	LibraryImportQueueSidebarEntry* _tmp1_ = NULL;
	LibraryImportQueueSidebarEntry* _tmp2_ = NULL;
	Page* _tmp3_ = NULL;
	Page* _tmp4_ = NULL;
#line 1073 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_LIBRARY_WINDOW (self));
#line 1074 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = self->priv->library_branch;
#line 1074 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_ = library_branch_get_import_queue_entry (_tmp0_);
#line 1074 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp2_ = _tmp1_;
#line 1074 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp3_ = sidebar_page_representative_get_page (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, SIDEBAR_TYPE_PAGE_REPRESENTATIVE, SidebarPageRepresentative));
#line 1074 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp4_ = _tmp3_;
#line 1074 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_window_switch_to_page (self, _tmp4_);
#line 1074 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (_tmp4_);
#line 7878 "LibraryWindow.c"
}


static void library_window_on_camera_added (LibraryWindow* self, DiscoveredCamera* camera) {
	CameraSidebarEntry* entry = NULL;
	CameraBranch* _tmp0_ = NULL;
	DiscoveredCamera* _tmp1_ = NULL;
	CameraSidebarEntry* _tmp2_ = NULL;
	CameraSidebarEntry* _tmp3_ = NULL;
	ImportPage* page = NULL;
	CameraSidebarEntry* _tmp4_ = NULL;
	Page* _tmp5_ = NULL;
	GFile* uri_file = NULL;
	DiscoveredCamera* _tmp6_ = NULL;
	const gchar* _tmp7_ = NULL;
	GFile* _tmp8_ = NULL;
	GMount* mount = NULL;
	gboolean _tmp13_ = FALSE;
	GMount* _tmp14_ = NULL;
	GError * _inner_error_ = NULL;
#line 1077 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_LIBRARY_WINDOW (self));
#line 1077 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_DISCOVERED_CAMERA (camera));
#line 1078 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = self->priv->camera_branch;
#line 1078 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_ = camera;
#line 1078 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp2_ = camera_branch_get_entry_for_camera (_tmp0_, _tmp1_);
#line 1078 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	entry = _tmp2_;
#line 1079 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp3_ = entry;
#line 1079 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp3_ == NULL) {
#line 1080 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_object_unref0 (entry);
#line 1080 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		return;
#line 7919 "LibraryWindow.c"
	}
#line 1082 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp4_ = entry;
#line 1082 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp5_ = sidebar_page_representative_get_page (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, SIDEBAR_TYPE_PAGE_REPRESENTATIVE, SidebarPageRepresentative));
#line 1082 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	page = G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, TYPE_IMPORT_PAGE, ImportPage);
#line 1083 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp6_ = camera;
#line 1083 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp7_ = _tmp6_->uri;
#line 1083 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp8_ = g_file_new_for_uri (_tmp7_);
#line 1083 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	uri_file = _tmp8_;
#line 1086 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	mount = NULL;
#line 7937 "LibraryWindow.c"
	{
		GMount* _tmp9_ = NULL;
		GFile* _tmp10_ = NULL;
		GMount* _tmp11_ = NULL;
		GMount* _tmp12_ = NULL;
#line 1088 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp10_ = uri_file;
#line 1088 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp11_ = g_file_find_enclosing_mount (_tmp10_, NULL, &_inner_error_);
#line 1088 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp9_ = _tmp11_;
#line 1088 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 7951 "LibraryWindow.c"
			goto __catch39_g_error;
		}
#line 1088 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp12_ = _tmp9_;
#line 1088 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp9_ = NULL;
#line 1088 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_object_unref0 (mount);
#line 1088 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		mount = _tmp12_;
#line 1087 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_object_unref0 (_tmp9_);
#line 7964 "LibraryWindow.c"
	}
	goto __finally39;
	__catch39_g_error:
	{
		GError* err = NULL;
#line 1087 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		err = _inner_error_;
#line 1087 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_inner_error_ = NULL;
#line 1087 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_error_free0 (err);
#line 7976 "LibraryWindow.c"
	}
	__finally39:
#line 1087 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1087 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_object_unref0 (mount);
#line 1087 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_object_unref0 (uri_file);
#line 1087 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_object_unref0 (page);
#line 1087 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_object_unref0 (entry);
#line 1087 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1087 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		g_clear_error (&_inner_error_);
#line 1087 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		return;
#line 7995 "LibraryWindow.c"
	}
#line 1094 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp14_ = mount;
#line 1094 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp14_ != NULL) {
#line 8001 "LibraryWindow.c"
		DiscoveredCamera* _tmp15_ = NULL;
		const gchar* _tmp16_ = NULL;
		gboolean _tmp17_ = FALSE;
#line 1094 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp15_ = camera;
#line 1094 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp16_ = _tmp15_->uri;
#line 1094 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp17_ = g_str_has_prefix (_tmp16_, "file://");
#line 1094 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp13_ = !_tmp17_;
#line 8013 "LibraryWindow.c"
	} else {
#line 1094 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp13_ = FALSE;
#line 8017 "LibraryWindow.c"
	}
#line 1094 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp13_) {
#line 8021 "LibraryWindow.c"
		ImportPage* _tmp18_ = NULL;
		GMount* _tmp19_ = NULL;
		gboolean _tmp20_ = FALSE;
#line 1095 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp18_ = page;
#line 1095 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp19_ = mount;
#line 1095 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp20_ = import_page_unmount_camera (_tmp18_, _tmp19_);
#line 1095 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		if (_tmp20_) {
#line 8033 "LibraryWindow.c"
			ImportPage* _tmp21_ = NULL;
#line 1096 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_tmp21_ = page;
#line 1096 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			library_window_switch_to_page (self, G_TYPE_CHECK_INSTANCE_CAST (_tmp21_, TYPE_PAGE, Page));
#line 8039 "LibraryWindow.c"
		} else {
#line 1098 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			app_window_error_message ("Unable to unmount the camera at this time.", NULL);
#line 8043 "LibraryWindow.c"
		}
	} else {
		ImportPage* _tmp22_ = NULL;
#line 1100 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp22_ = page;
#line 1100 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		library_window_switch_to_page (self, G_TYPE_CHECK_INSTANCE_CAST (_tmp22_, TYPE_PAGE, Page));
#line 8051 "LibraryWindow.c"
	}
#line 1077 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (mount);
#line 1077 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (uri_file);
#line 1077 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (page);
#line 1077 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (entry);
#line 8061 "LibraryWindow.c"
}


void library_window_add_to_stack (LibraryWindow* self, Page* page) {
	Page* _tmp0_ = NULL;
	GtkStack* _tmp1_ = NULL;
	Page* _tmp2_ = NULL;
	GtkStack* _tmp3_ = NULL;
#line 1105 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_LIBRARY_WINDOW (self));
#line 1105 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_PAGE (page));
#line 1107 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = page;
#line 1107 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	gtk_widget_show_all (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_widget_get_type (), GtkWidget));
#line 1109 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_ = self->priv->stack;
#line 1109 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp2_ = page;
#line 1109 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	gtk_container_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, gtk_container_get_type (), GtkContainer), G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, gtk_widget_get_type (), GtkWidget));
#line 1111 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp3_ = self->priv->stack;
#line 1111 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	gtk_widget_show_all (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, gtk_widget_get_type (), GtkWidget));
#line 8088 "LibraryWindow.c"
}


static void library_window_remove_from_stack (LibraryWindow* self, Page* page) {
	GtkStack* _tmp0_ = NULL;
	Page* _tmp1_ = NULL;
	GtkStack* _tmp2_ = NULL;
#line 1114 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_LIBRARY_WINDOW (self));
#line 1114 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_PAGE (page));
#line 1115 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = self->priv->stack;
#line 1115 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_ = page;
#line 1115 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	gtk_container_remove (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_container_get_type (), GtkContainer), G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, gtk_widget_get_type (), GtkWidget));
#line 1118 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp2_ = self->priv->stack;
#line 1118 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	gtk_widget_show_all (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, gtk_widget_get_type (), GtkWidget));
#line 8110 "LibraryWindow.c"
}


static void library_window_load_configuration (LibraryWindow* self) {
	GtkToggleAction* basic_display_action = NULL;
	GtkAction* _tmp0_ = NULL;
	GtkToggleAction* _tmp1_ = NULL;
	GtkToggleAction* _tmp2_ = NULL;
	GtkToggleAction* _tmp3_ = NULL;
	ConfigFacade* _tmp4_ = NULL;
	ConfigFacade* _tmp5_ = NULL;
	gboolean _tmp6_ = FALSE;
	GtkToggleAction* extended_display_action = NULL;
	GtkAction* _tmp7_ = NULL;
	GtkToggleAction* _tmp8_ = NULL;
	GtkToggleAction* _tmp9_ = NULL;
	GtkToggleAction* _tmp10_ = NULL;
	ConfigFacade* _tmp11_ = NULL;
	ConfigFacade* _tmp12_ = NULL;
	gboolean _tmp13_ = FALSE;
	GtkToggleAction* search_bar_display_action = NULL;
	GtkAction* _tmp14_ = NULL;
	GtkToggleAction* _tmp15_ = NULL;
	GtkToggleAction* _tmp16_ = NULL;
	GtkToggleAction* _tmp17_ = NULL;
	ConfigFacade* _tmp18_ = NULL;
	ConfigFacade* _tmp19_ = NULL;
	gboolean _tmp20_ = FALSE;
	GtkRadioAction* sort_events_action = NULL;
	GtkAction* _tmp21_ = NULL;
	GtkRadioAction* _tmp22_ = NULL;
	GtkRadioAction* _tmp23_ = NULL;
	gint _tmp24_ = 0;
	ConfigFacade* _tmp25_ = NULL;
	ConfigFacade* _tmp26_ = NULL;
	gboolean _tmp27_ = FALSE;
	gboolean _tmp28_ = FALSE;
	gint event_sort_val = 0;
	GtkRadioAction* _tmp29_ = NULL;
#line 1122 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_LIBRARY_WINDOW (self));
#line 1123 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = app_window_get_common_action (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_APP_WINDOW, AppWindow), "CommonDisplayBasicProperties");
#line 1123 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, gtk_toggle_action_get_type ()) ? ((GtkToggleAction*) _tmp0_) : NULL;
#line 1123 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp1_ == NULL) {
#line 1123 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_object_unref0 (_tmp0_);
#line 8160 "LibraryWindow.c"
	}
#line 1123 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	basic_display_action = _tmp1_;
#line 1125 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp2_ = basic_display_action;
#line 1125 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_vala_assert (_tmp2_ != NULL, "basic_display_action != null");
#line 1126 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp3_ = basic_display_action;
#line 1126 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp4_ = config_facade_get_instance ();
#line 1126 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp5_ = _tmp4_;
#line 1126 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp6_ = configuration_facade_get_display_basic_properties (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade));
#line 1126 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	gtk_toggle_action_set_active (_tmp3_, _tmp6_);
#line 1126 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (_tmp5_);
#line 1128 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp7_ = app_window_get_common_action (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_APP_WINDOW, AppWindow), "CommonDisplayExtendedProperties");
#line 1128 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp8_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp7_, gtk_toggle_action_get_type ()) ? ((GtkToggleAction*) _tmp7_) : NULL;
#line 1128 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp8_ == NULL) {
#line 1128 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_object_unref0 (_tmp7_);
#line 8188 "LibraryWindow.c"
	}
#line 1128 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	extended_display_action = _tmp8_;
#line 1130 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp9_ = extended_display_action;
#line 1130 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_vala_assert (_tmp9_ != NULL, "extended_display_action != null");
#line 1131 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp10_ = extended_display_action;
#line 1131 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp11_ = config_facade_get_instance ();
#line 1131 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp12_ = _tmp11_;
#line 1131 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp13_ = configuration_facade_get_display_extended_properties (G_TYPE_CHECK_INSTANCE_CAST (_tmp12_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade));
#line 1131 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	gtk_toggle_action_set_active (_tmp10_, _tmp13_);
#line 1131 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (_tmp12_);
#line 1133 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp14_ = app_window_get_common_action (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_APP_WINDOW, AppWindow), "CommonDisplaySearchbar");
#line 1133 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp15_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp14_, gtk_toggle_action_get_type ()) ? ((GtkToggleAction*) _tmp14_) : NULL;
#line 1133 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp15_ == NULL) {
#line 1133 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_object_unref0 (_tmp14_);
#line 8216 "LibraryWindow.c"
	}
#line 1133 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	search_bar_display_action = _tmp15_;
#line 1135 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp16_ = search_bar_display_action;
#line 1135 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_vala_assert (_tmp16_ != NULL, "search_bar_display_action != null");
#line 1136 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp17_ = search_bar_display_action;
#line 1136 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp18_ = config_facade_get_instance ();
#line 1136 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp19_ = _tmp18_;
#line 1136 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp20_ = configuration_facade_get_display_search_bar (G_TYPE_CHECK_INSTANCE_CAST (_tmp19_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade));
#line 1136 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	gtk_toggle_action_set_active (_tmp17_, _tmp20_);
#line 1136 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (_tmp19_);
#line 1138 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp21_ = app_window_get_common_action (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_APP_WINDOW, AppWindow), "CommonSortEventsAscending");
#line 1138 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp22_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp21_, gtk_radio_action_get_type ()) ? ((GtkRadioAction*) _tmp21_) : NULL;
#line 1138 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp22_ == NULL) {
#line 1138 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_object_unref0 (_tmp21_);
#line 8244 "LibraryWindow.c"
	}
#line 1138 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	sort_events_action = _tmp22_;
#line 1140 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp23_ = sort_events_action;
#line 1140 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_vala_assert (_tmp23_ != NULL, "sort_events_action != null");
#line 1145 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp25_ = config_facade_get_instance ();
#line 1145 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp26_ = _tmp25_;
#line 1145 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp27_ = configuration_facade_get_events_sort_ascending (G_TYPE_CHECK_INSTANCE_CAST (_tmp26_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade));
#line 1145 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp28_ = _tmp27_;
#line 1145 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (_tmp26_);
#line 1145 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp28_) {
#line 1145 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp24_ = LIBRARY_WINDOW_SORT_EVENTS_ORDER_ASCENDING;
#line 8266 "LibraryWindow.c"
	} else {
#line 1146 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp24_ = LIBRARY_WINDOW_SORT_EVENTS_ORDER_DESCENDING;
#line 8270 "LibraryWindow.c"
	}
#line 1145 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	event_sort_val = _tmp24_;
#line 1148 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp29_ = sort_events_action;
#line 1148 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	gtk_radio_action_set_current_value (_tmp29_, event_sort_val);
#line 1122 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (sort_events_action);
#line 1122 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (search_bar_display_action);
#line 1122 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (extended_display_action);
#line 1122 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (basic_display_action);
#line 8286 "LibraryWindow.c"
}


static gboolean _library_window_on_pulse_background_progress_bar_gsource_func (gpointer self) {
	gboolean result;
	result = library_window_on_pulse_background_progress_bar ((LibraryWindow*) self);
#line 1163 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	return result;
#line 8295 "LibraryWindow.c"
}


static void library_window_start_pulse_background_progress_bar (LibraryWindow* self, const gchar* label, gint priority) {
	gint _tmp0_ = 0;
	gint _tmp1_ = 0;
	gint _tmp2_ = 0;
	gint _tmp3_ = 0;
	GtkProgressBar* _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
	GtkProgressBar* _tmp6_ = NULL;
	guint _tmp7_ = 0U;
#line 1151 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_LIBRARY_WINDOW (self));
#line 1151 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (label != NULL);
#line 1152 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = priority;
#line 1152 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_ = self->priv->current_progress_priority;
#line 1152 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp0_ < _tmp1_) {
#line 1153 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		return;
#line 8320 "LibraryWindow.c"
	}
#line 1155 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp2_ = priority;
#line 1155 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_window_stop_pulse_background_progress_bar (self, _tmp2_, FALSE);
#line 1157 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp3_ = priority;
#line 1157 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	self->priv->current_progress_priority = _tmp3_;
#line 1159 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp4_ = self->priv->background_progress_bar;
#line 1159 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp5_ = label;
#line 1159 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	gtk_progress_bar_set_text (_tmp4_, _tmp5_);
#line 1160 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp6_ = self->priv->background_progress_bar;
#line 1160 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	gtk_progress_bar_pulse (_tmp6_);
#line 1161 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_window_show_background_progress_bar (self);
#line 1163 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp7_ = g_timeout_add_full (G_PRIORITY_DEFAULT, (guint) LIBRARY_WINDOW_BACKGROUND_PROGRESS_PULSE_MSEC, _library_window_on_pulse_background_progress_bar_gsource_func, g_object_ref (self), g_object_unref);
#line 1163 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	self->priv->background_progress_pulse_id = _tmp7_;
#line 8346 "LibraryWindow.c"
}


static gboolean library_window_on_pulse_background_progress_bar (LibraryWindow* self) {
	gboolean result = FALSE;
	GtkProgressBar* _tmp0_ = NULL;
#line 1167 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_val_if_fail (IS_LIBRARY_WINDOW (self), FALSE);
#line 1168 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = self->priv->background_progress_bar;
#line 1168 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	gtk_progress_bar_pulse (_tmp0_);
#line 1170 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	result = TRUE;
#line 1170 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	return result;
#line 8363 "LibraryWindow.c"
}


static void library_window_stop_pulse_background_progress_bar (LibraryWindow* self, gint priority, gboolean clear) {
	gint _tmp0_ = 0;
	gint _tmp1_ = 0;
	guint _tmp2_ = 0U;
	gboolean _tmp4_ = FALSE;
#line 1173 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_LIBRARY_WINDOW (self));
#line 1174 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = priority;
#line 1174 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_ = self->priv->current_progress_priority;
#line 1174 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp0_ < _tmp1_) {
#line 1175 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		return;
#line 8382 "LibraryWindow.c"
	}
#line 1177 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp2_ = self->priv->background_progress_pulse_id;
#line 1177 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp2_ != ((guint) 0)) {
#line 8388 "LibraryWindow.c"
		guint _tmp3_ = 0U;
#line 1178 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp3_ = self->priv->background_progress_pulse_id;
#line 1178 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		g_source_remove (_tmp3_);
#line 1179 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		self->priv->background_progress_pulse_id = (guint) 0;
#line 8396 "LibraryWindow.c"
	}
#line 1182 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp4_ = clear;
#line 1182 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp4_) {
#line 8402 "LibraryWindow.c"
		gint _tmp5_ = 0;
#line 1183 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp5_ = priority;
#line 1183 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		library_window_clear_background_progress_bar (self, _tmp5_);
#line 8408 "LibraryWindow.c"
	}
}


static void library_window_update_background_progress_bar (LibraryWindow* self, const gchar* label, gint priority, gdouble count, gdouble total) {
	gint _tmp0_ = 0;
	gint _tmp1_ = 0;
	gint _tmp2_ = 0;
	gboolean _tmp3_ = FALSE;
	gboolean _tmp4_ = FALSE;
	gdouble _tmp5_ = 0.0;
	gint _tmp10_ = 0;
	gdouble fraction = 0.0;
	gdouble _tmp11_ = 0.0;
	gdouble _tmp12_ = 0.0;
	GtkProgressBar* _tmp13_ = NULL;
	gdouble _tmp14_ = 0.0;
	GtkProgressBar* _tmp15_ = NULL;
	const gchar* _tmp16_ = NULL;
	const gchar* _tmp17_ = NULL;
	gdouble _tmp18_ = 0.0;
	gchar* _tmp19_ = NULL;
	gchar* _tmp20_ = NULL;
#line 1186 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_LIBRARY_WINDOW (self));
#line 1186 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (label != NULL);
#line 1188 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = priority;
#line 1188 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_ = self->priv->current_progress_priority;
#line 1188 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp0_ < _tmp1_) {
#line 1189 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		return;
#line 8444 "LibraryWindow.c"
	}
#line 1191 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp2_ = priority;
#line 1191 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_window_stop_pulse_background_progress_bar (self, _tmp2_, FALSE);
#line 1193 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp5_ = count;
#line 1193 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp5_ <= 0.0) {
#line 1193 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp4_ = TRUE;
#line 8456 "LibraryWindow.c"
	} else {
		gdouble _tmp6_ = 0.0;
#line 1193 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp6_ = total;
#line 1193 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp4_ = _tmp6_ <= 0.0;
#line 8463 "LibraryWindow.c"
	}
#line 1193 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp4_) {
#line 1193 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp3_ = TRUE;
#line 8469 "LibraryWindow.c"
	} else {
		gdouble _tmp7_ = 0.0;
		gdouble _tmp8_ = 0.0;
#line 1193 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp7_ = count;
#line 1193 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp8_ = total;
#line 1193 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp3_ = _tmp7_ >= _tmp8_;
#line 8479 "LibraryWindow.c"
	}
#line 1193 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp3_) {
#line 8483 "LibraryWindow.c"
		gint _tmp9_ = 0;
#line 1194 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp9_ = priority;
#line 1194 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		library_window_clear_background_progress_bar (self, _tmp9_);
#line 1196 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		return;
#line 8491 "LibraryWindow.c"
	}
#line 1199 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp10_ = priority;
#line 1199 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	self->priv->current_progress_priority = _tmp10_;
#line 1201 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp11_ = count;
#line 1201 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp12_ = total;
#line 1201 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	fraction = _tmp11_ / _tmp12_;
#line 1202 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp13_ = self->priv->background_progress_bar;
#line 1202 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp14_ = fraction;
#line 1202 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	gtk_progress_bar_set_fraction (_tmp13_, _tmp14_);
#line 1203 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp15_ = self->priv->background_progress_bar;
#line 1203 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp16_ = _ ("%s (%d%%)");
#line 1203 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp17_ = label;
#line 1203 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp18_ = fraction;
#line 1203 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp19_ = g_strdup_printf (_tmp16_, _tmp17_, (gint) (_tmp18_ * 100.0));
#line 1203 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp20_ = _tmp19_;
#line 1203 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	gtk_progress_bar_set_text (_tmp15_, _tmp20_);
#line 1203 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_free0 (_tmp20_);
#line 1204 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_window_show_background_progress_bar (self);
#line 8527 "LibraryWindow.c"
}


static void library_window_clear_background_progress_bar (LibraryWindow* self, gint priority) {
	gint _tmp0_ = 0;
	gint _tmp1_ = 0;
	gint _tmp2_ = 0;
	GtkProgressBar* _tmp3_ = NULL;
	GtkProgressBar* _tmp4_ = NULL;
#line 1213 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_LIBRARY_WINDOW (self));
#line 1214 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = priority;
#line 1214 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_ = self->priv->current_progress_priority;
#line 1214 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp0_ < _tmp1_) {
#line 1215 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		return;
#line 8547 "LibraryWindow.c"
	}
#line 1217 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp2_ = priority;
#line 1217 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_window_stop_pulse_background_progress_bar (self, _tmp2_, FALSE);
#line 1219 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	self->priv->current_progress_priority = 0;
#line 1221 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp3_ = self->priv->background_progress_bar;
#line 1221 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	gtk_progress_bar_set_fraction (_tmp3_, 0.0);
#line 1222 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp4_ = self->priv->background_progress_bar;
#line 1222 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	gtk_progress_bar_set_text (_tmp4_, "");
#line 1223 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_window_hide_background_progress_bar (self);
#line 8565 "LibraryWindow.c"
}


static void library_window_show_background_progress_bar (LibraryWindow* self) {
	gboolean _tmp0_ = FALSE;
#line 1231 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_LIBRARY_WINDOW (self));
#line 1232 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = self->priv->background_progress_displayed;
#line 1232 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (!_tmp0_) {
#line 8577 "LibraryWindow.c"
		GtkBox* _tmp1_ = NULL;
		GtkFrame* _tmp2_ = NULL;
		GtkFrame* _tmp3_ = NULL;
#line 1233 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp1_ = self->priv->top_section;
#line 1233 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp2_ = self->priv->background_progress_frame;
#line 1233 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		gtk_box_pack_end (_tmp1_, G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, gtk_widget_get_type (), GtkWidget), FALSE, FALSE, (guint) 0);
#line 1234 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp3_ = self->priv->background_progress_frame;
#line 1234 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		gtk_widget_show_all (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, gtk_widget_get_type (), GtkWidget));
#line 1235 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		self->priv->background_progress_displayed = TRUE;
#line 8593 "LibraryWindow.c"
	}
}


static void library_window_hide_background_progress_bar (LibraryWindow* self) {
	gboolean _tmp0_ = FALSE;
#line 1239 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_LIBRARY_WINDOW (self));
#line 1240 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = self->priv->background_progress_displayed;
#line 1240 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp0_) {
#line 8606 "LibraryWindow.c"
		GtkBox* _tmp1_ = NULL;
		GtkFrame* _tmp2_ = NULL;
#line 1241 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp1_ = self->priv->top_section;
#line 1241 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp2_ = self->priv->background_progress_frame;
#line 1241 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		gtk_container_remove (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, gtk_container_get_type (), GtkContainer), G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, gtk_widget_get_type (), GtkWidget));
#line 1242 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		self->priv->background_progress_displayed = FALSE;
#line 8617 "LibraryWindow.c"
	}
}


static void library_window_on_library_monitor_discovery_started (LibraryWindow* self) {
	const gchar* _tmp0_ = NULL;
#line 1246 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_LIBRARY_WINDOW (self));
#line 1247 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = _ ("Updating library...");
#line 1247 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_window_start_pulse_background_progress_bar (self, _tmp0_, LIBRARY_WINDOW_STARTUP_SCAN_PROGRESS_PRIORITY);
#line 8630 "LibraryWindow.c"
}


static void library_window_on_library_monitor_discovery_completed (LibraryWindow* self) {
#line 1250 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_LIBRARY_WINDOW (self));
#line 1251 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_window_stop_pulse_background_progress_bar (self, LIBRARY_WINDOW_STARTUP_SCAN_PROGRESS_PRIORITY, TRUE);
#line 8639 "LibraryWindow.c"
}


static void library_window_on_library_monitor_auto_update_progress (LibraryWindow* self, gint completed_files, gint total_files) {
	gint _tmp0_ = 0;
#line 1254 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_LIBRARY_WINDOW (self));
#line 1255 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = total_files;
#line 1255 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp0_ < LIBRARY_WINDOW_MIN_PROGRESS_BAR_FILES) {
#line 1256 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		library_window_clear_background_progress_bar (self, LIBRARY_WINDOW_REALTIME_UPDATE_PROGRESS_PRIORITY);
#line 8653 "LibraryWindow.c"
	} else {
		const gchar* _tmp1_ = NULL;
		gint _tmp2_ = 0;
		gint _tmp3_ = 0;
#line 1258 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp1_ = _ ("Updating library...");
#line 1258 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp2_ = completed_files;
#line 1258 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp3_ = total_files;
#line 1258 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		library_window_update_background_progress_bar (self, _tmp1_, LIBRARY_WINDOW_REALTIME_UPDATE_PROGRESS_PRIORITY, (gdouble) _tmp2_, (gdouble) _tmp3_);
#line 8666 "LibraryWindow.c"
	}
}


static void library_window_on_library_monitor_auto_import_preparing (LibraryWindow* self) {
	const gchar* _tmp0_ = NULL;
#line 1263 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_LIBRARY_WINDOW (self));
#line 1264 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = _ ("Preparing to auto-import photos...");
#line 1264 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_window_start_pulse_background_progress_bar (self, _tmp0_, LIBRARY_WINDOW_REALTIME_IMPORT_PROGRESS_PRIORITY);
#line 8679 "LibraryWindow.c"
}


static void library_window_on_library_monitor_auto_import_progress (LibraryWindow* self, guint64 completed_bytes, guint64 total_bytes) {
	const gchar* _tmp0_ = NULL;
	guint64 _tmp1_ = 0ULL;
	guint64 _tmp2_ = 0ULL;
#line 1268 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_LIBRARY_WINDOW (self));
#line 1269 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = _ ("Auto-importing photos...");
#line 1269 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_ = completed_bytes;
#line 1269 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp2_ = total_bytes;
#line 1269 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_window_update_background_progress_bar (self, _tmp0_, LIBRARY_WINDOW_REALTIME_IMPORT_PROGRESS_PRIORITY, (gdouble) _tmp1_, (gdouble) _tmp2_);
#line 8697 "LibraryWindow.c"
}


static void library_window_on_metadata_writer_progress (LibraryWindow* self, guint completed, guint total) {
	guint _tmp0_ = 0U;
#line 1273 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_LIBRARY_WINDOW (self));
#line 1274 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = total;
#line 1274 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp0_ < ((guint) LIBRARY_WINDOW_MIN_PROGRESS_BAR_FILES)) {
#line 1275 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		library_window_clear_background_progress_bar (self, LIBRARY_WINDOW_METADATA_WRITER_PROGRESS_PRIORITY);
#line 8711 "LibraryWindow.c"
	} else {
		const gchar* _tmp1_ = NULL;
		guint _tmp2_ = 0U;
		guint _tmp3_ = 0U;
#line 1277 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp1_ = _ ("Writing metadata to files...");
#line 1277 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp2_ = completed;
#line 1277 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp3_ = total;
#line 1277 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		library_window_update_background_progress_bar (self, _tmp1_, LIBRARY_WINDOW_METADATA_WRITER_PROGRESS_PRIORITY, (gdouble) _tmp2_, (gdouble) _tmp3_);
#line 8724 "LibraryWindow.c"
	}
}


static void library_window_create_layout (LibraryWindow* self, Page* start_page) {
	GtkScrolledWindow* scrolled_sidebar = NULL;
	GtkScrolledWindow* _tmp0_ = NULL;
	SidebarTree* _tmp1_ = NULL;
	GtkFrame* _tmp2_ = NULL;
	GtkFrame* _tmp3_ = NULL;
	GtkProgressBar* _tmp4_ = NULL;
	GtkFrame* _tmp5_ = NULL;
	GtkStyleContext* _tmp6_ = NULL;
	GtkAlignment* bottom_alignment = NULL;
	GtkAlignment* _tmp7_ = NULL;
	BasicProperties* _tmp8_ = NULL;
	GtkFrame* _tmp9_ = NULL;
	GtkFrame* _tmp10_ = NULL;
	GtkStyleContext* _tmp11_ = NULL;
	GtkBox* _tmp12_ = NULL;
	GtkPaned* _tmp13_ = NULL;
	GtkBox* _tmp14_ = NULL;
	GtkPaned* _tmp15_ = NULL;
	GtkFrame* _tmp16_ = NULL;
	GtkPaned* _tmp17_ = NULL;
	GtkBox* _tmp18_ = NULL;
	GtkBox* _tmp19_ = NULL;
	SearchFilterToolbar* _tmp20_ = NULL;
	GtkBox* _tmp21_ = NULL;
	GtkStack* _tmp22_ = NULL;
	GtkPaned* _tmp23_ = NULL;
	GtkPaned* _tmp24_ = NULL;
	GtkPaned* _tmp25_ = NULL;
	SidebarTree* _tmp26_ = NULL;
	GtkPaned* _tmp27_ = NULL;
	GtkBox* _tmp28_ = NULL;
	GtkPaned* _tmp29_ = NULL;
	ConfigFacade* _tmp30_ = NULL;
	ConfigFacade* _tmp31_ = NULL;
	gint _tmp32_ = 0;
	GtkStack* _tmp33_ = NULL;
	gint _tmp34_ = 0;
	gint _tmp35_ = 0;
	GtkBox* _tmp36_ = NULL;
	GtkPaned* _tmp37_ = NULL;
	GtkBox* _tmp38_ = NULL;
	Page* _tmp39_ = NULL;
	Page* _tmp40_ = NULL;
#line 1282 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_LIBRARY_WINDOW (self));
#line 1282 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_PAGE (start_page));
#line 1285 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = (GtkScrolledWindow*) gtk_scrolled_window_new (NULL, NULL);
#line 1285 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_object_ref_sink (_tmp0_);
#line 1285 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	scrolled_sidebar = _tmp0_;
#line 1286 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	gtk_scrolled_window_set_policy (scrolled_sidebar, GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
#line 1287 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_ = self->priv->sidebar_tree;
#line 1287 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	gtk_container_add (G_TYPE_CHECK_INSTANCE_CAST (scrolled_sidebar, gtk_container_get_type (), GtkContainer), G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, gtk_widget_get_type (), GtkWidget));
#line 1289 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp2_ = self->priv->background_progress_frame;
#line 1289 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	gtk_container_set_border_width (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, gtk_container_get_type (), GtkContainer), (guint) 2);
#line 1290 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp3_ = self->priv->background_progress_frame;
#line 1290 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp4_ = self->priv->background_progress_bar;
#line 1290 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	gtk_container_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, gtk_container_get_type (), GtkContainer), G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, gtk_widget_get_type (), GtkWidget));
#line 1291 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp5_ = self->priv->background_progress_frame;
#line 1291 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp6_ = gtk_widget_get_style_context (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, gtk_widget_get_type (), GtkWidget));
#line 1291 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	gtk_style_context_remove_class (_tmp6_, "frame");
#line 1294 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp7_ = (GtkAlignment*) gtk_alignment_new ((gfloat) 0, 0.5f, (gfloat) 1, (gfloat) 0);
#line 1294 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_object_ref_sink (_tmp7_);
#line 1294 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	bottom_alignment = _tmp7_;
#line 1296 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	gtk_alignment_set_padding (bottom_alignment, (guint) 10, (guint) 10, (guint) 6, (guint) 0);
#line 1297 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp8_ = self->priv->basic_properties;
#line 1297 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	gtk_container_add (G_TYPE_CHECK_INSTANCE_CAST (bottom_alignment, gtk_container_get_type (), GtkContainer), G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, gtk_widget_get_type (), GtkWidget));
#line 1299 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp9_ = self->priv->bottom_frame;
#line 1299 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	gtk_container_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, gtk_container_get_type (), GtkContainer), G_TYPE_CHECK_INSTANCE_CAST (bottom_alignment, gtk_widget_get_type (), GtkWidget));
#line 1300 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp10_ = self->priv->bottom_frame;
#line 1300 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp11_ = gtk_widget_get_style_context (G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, gtk_widget_get_type (), GtkWidget));
#line 1300 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	gtk_style_context_remove_class (_tmp11_, "frame");
#line 1304 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp12_ = self->priv->top_section;
#line 1304 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	gtk_box_pack_start (_tmp12_, G_TYPE_CHECK_INSTANCE_CAST (scrolled_sidebar, gtk_widget_get_type (), GtkWidget), TRUE, TRUE, (guint) 0);
#line 1306 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp13_ = self->priv->sidebar_paned;
#line 1306 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp14_ = self->priv->top_section;
#line 1306 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	gtk_paned_pack1 (_tmp13_, G_TYPE_CHECK_INSTANCE_CAST (_tmp14_, gtk_widget_get_type (), GtkWidget), TRUE, FALSE);
#line 1307 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp15_ = self->priv->sidebar_paned;
#line 1307 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp16_ = self->priv->bottom_frame;
#line 1307 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	gtk_paned_pack2 (_tmp15_, G_TYPE_CHECK_INSTANCE_CAST (_tmp16_, gtk_widget_get_type (), GtkWidget), FALSE, FALSE);
#line 1308 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp17_ = self->priv->sidebar_paned;
#line 1308 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	gtk_paned_set_position (_tmp17_, 1000);
#line 1310 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp18_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
#line 1310 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_object_ref_sink (_tmp18_);
#line 1310 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (self->priv->right_vbox);
#line 1310 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	self->priv->right_vbox = _tmp18_;
#line 1311 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp19_ = self->priv->right_vbox;
#line 1311 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp20_ = self->priv->search_toolbar;
#line 1311 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	gtk_box_pack_start (_tmp19_, G_TYPE_CHECK_INSTANCE_CAST (_tmp20_, gtk_widget_get_type (), GtkWidget), FALSE, FALSE, (guint) 0);
#line 1312 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp21_ = self->priv->right_vbox;
#line 1312 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp22_ = self->priv->stack;
#line 1312 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	gtk_box_pack_start (_tmp21_, G_TYPE_CHECK_INSTANCE_CAST (_tmp22_, gtk_widget_get_type (), GtkWidget), TRUE, TRUE, (guint) 0);
#line 1314 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp23_ = (GtkPaned*) gtk_paned_new (GTK_ORIENTATION_HORIZONTAL);
#line 1314 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_object_ref_sink (_tmp23_);
#line 1314 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (self->priv->client_paned);
#line 1314 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	self->priv->client_paned = _tmp23_;
#line 1315 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp24_ = self->priv->client_paned;
#line 1315 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp25_ = self->priv->sidebar_paned;
#line 1315 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	gtk_paned_pack1 (_tmp24_, G_TYPE_CHECK_INSTANCE_CAST (_tmp25_, gtk_widget_get_type (), GtkWidget), FALSE, FALSE);
#line 1316 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp26_ = self->priv->sidebar_tree;
#line 1316 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	gtk_widget_set_size_request (G_TYPE_CHECK_INSTANCE_CAST (_tmp26_, gtk_widget_get_type (), GtkWidget), LIBRARY_WINDOW_SIDEBAR_MIN_WIDTH, -1);
#line 1317 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp27_ = self->priv->client_paned;
#line 1317 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp28_ = self->priv->right_vbox;
#line 1317 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	gtk_paned_pack2 (_tmp27_, G_TYPE_CHECK_INSTANCE_CAST (_tmp28_, gtk_widget_get_type (), GtkWidget), TRUE, FALSE);
#line 1318 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp29_ = self->priv->client_paned;
#line 1318 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp30_ = config_facade_get_instance ();
#line 1318 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp31_ = _tmp30_;
#line 1318 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp32_ = configuration_facade_get_sidebar_position (G_TYPE_CHECK_INSTANCE_CAST (_tmp31_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade));
#line 1318 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	gtk_paned_set_position (_tmp29_, _tmp32_);
#line 1318 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (_tmp31_);
#line 1320 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp33_ = self->priv->stack;
#line 1320 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp34_ = library_window_get_PAGE_MIN_WIDTH ();
#line 1320 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp35_ = _tmp34_;
#line 1320 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	gtk_widget_set_size_request (G_TYPE_CHECK_INSTANCE_CAST (_tmp33_, gtk_widget_get_type (), GtkWidget), _tmp35_, -1);
#line 1322 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp36_ = self->priv->layout;
#line 1322 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp37_ = self->priv->client_paned;
#line 1322 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	gtk_box_pack_end (_tmp36_, G_TYPE_CHECK_INSTANCE_CAST (_tmp37_, gtk_widget_get_type (), GtkWidget), TRUE, TRUE, (guint) 0);
#line 1324 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp38_ = self->priv->layout;
#line 1324 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	gtk_container_add (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_container_get_type (), GtkContainer), G_TYPE_CHECK_INSTANCE_CAST (_tmp38_, gtk_widget_get_type (), GtkWidget));
#line 1326 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp39_ = start_page;
#line 1326 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_window_switch_to_page (self, _tmp39_);
#line 1327 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp40_ = start_page;
#line 1327 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	gtk_widget_grab_focus (G_TYPE_CHECK_INSTANCE_CAST (_tmp40_, gtk_widget_get_type (), GtkWidget));
#line 1282 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (bottom_alignment);
#line 1282 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (scrolled_sidebar);
#line 8933 "LibraryWindow.c"
}


static void library_window_real_set_current_page (PageWindow* base, Page* page) {
	LibraryWindow * self;
	Page* _tmp0_ = NULL;
#line 1330 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_LIBRARY_WINDOW, LibraryWindow);
#line 1330 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_PAGE (page));
#line 1332 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = page;
#line 1332 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_window_switch_to_page (self, _tmp0_);
#line 8948 "LibraryWindow.c"
}


void library_window_set_page_switching_enabled (LibraryWindow* self, gboolean should_enable) {
	gboolean _tmp0_ = FALSE;
#line 1335 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_LIBRARY_WINDOW (self));
#line 1336 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = should_enable;
#line 1336 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	self->priv->page_switching_enabled = _tmp0_;
#line 8960 "LibraryWindow.c"
}


void library_window_switch_to_page (LibraryWindow* self, Page* page) {
	gboolean _tmp0_ = FALSE;
	Page* _tmp1_ = NULL;
	Page* _tmp2_ = NULL;
	Page* _tmp3_ = NULL;
	gboolean _tmp4_ = FALSE;
	Page* current_page = NULL;
	Page* _tmp5_ = NULL;
	Page* _tmp6_ = NULL;
	GtkStack* _tmp16_ = NULL;
	Page* _tmp17_ = NULL;
	Page* _tmp18_ = NULL;
	Page* _tmp19_ = NULL;
	gboolean _tmp21_ = FALSE;
	Page* _tmp22_ = NULL;
	SidebarEntry* entry = NULL;
	GeeHashMap* _tmp23_ = NULL;
	Page* _tmp24_ = NULL;
	gpointer _tmp25_ = NULL;
	SidebarEntry* _tmp26_ = NULL;
	Page* _tmp37_ = NULL;
	Page* _tmp39_ = NULL;
	Page* _tmp40_ = NULL;
	Page* _tmp41_ = NULL;
	Page* _tmp42_ = NULL;
	GtkToolbar* toolbar = NULL;
	Page* _tmp43_ = NULL;
	GtkToolbar* _tmp44_ = NULL;
	GtkToolbar* _tmp45_ = NULL;
	Page* _tmp51_ = NULL;
#line 1339 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_LIBRARY_WINDOW (self));
#line 1339 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_PAGE (page));
#line 1340 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = self->priv->page_switching_enabled;
#line 1340 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (!_tmp0_) {
#line 1341 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		return;
#line 9004 "LibraryWindow.c"
	}
#line 1343 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_ = page;
#line 1343 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp2_ = page_window_get_current_page (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE_WINDOW, PageWindow));
#line 1343 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp3_ = _tmp2_;
#line 1343 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp4_ = _tmp1_ == _tmp3_;
#line 1343 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (_tmp3_);
#line 1343 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp4_) {
#line 1344 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		return;
#line 9020 "LibraryWindow.c"
	}
#line 1346 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp5_ = page_window_get_current_page (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE_WINDOW, PageWindow));
#line 1346 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	current_page = _tmp5_;
#line 1347 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp6_ = current_page;
#line 1347 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp6_ != NULL) {
#line 9030 "LibraryWindow.c"
		GtkToolbar* toolbar = NULL;
		Page* _tmp7_ = NULL;
		GtkToolbar* _tmp8_ = NULL;
		GtkToolbar* _tmp9_ = NULL;
		Page* _tmp12_ = NULL;
		Page* _tmp13_ = NULL;
		Page* _tmp15_ = NULL;
#line 1348 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp7_ = current_page;
#line 1348 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp8_ = page_get_toolbar (_tmp7_);
#line 1348 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		toolbar = _tmp8_;
#line 1349 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp9_ = toolbar;
#line 1349 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		if (_tmp9_ != NULL) {
#line 9048 "LibraryWindow.c"
			GtkBox* _tmp10_ = NULL;
			GtkToolbar* _tmp11_ = NULL;
#line 1350 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_tmp10_ = self->priv->right_vbox;
#line 1350 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_tmp11_ = toolbar;
#line 1350 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			gtk_container_remove (G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, gtk_container_get_type (), GtkContainer), G_TYPE_CHECK_INSTANCE_CAST (_tmp11_, gtk_widget_get_type (), GtkWidget));
#line 9057 "LibraryWindow.c"
		}
#line 1352 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp12_ = current_page;
#line 1352 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		page_switching_from (_tmp12_);
#line 1356 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp13_ = current_page;
#line 1356 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp13_, TYPE_LIBRARY_PHOTO_PAGE)) {
#line 9067 "LibraryWindow.c"
			SidebarTree* _tmp14_ = NULL;
#line 1357 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_tmp14_ = self->priv->sidebar_tree;
#line 1357 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			sidebar_tree_enable_editing (_tmp14_);
#line 9073 "LibraryWindow.c"
		}
#line 1360 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp15_ = current_page;
#line 1360 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		library_window_unsubscribe_from_basic_information (self, _tmp15_);
#line 1347 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_object_unref0 (toolbar);
#line 9081 "LibraryWindow.c"
	}
#line 1363 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp16_ = self->priv->stack;
#line 1363 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp17_ = page;
#line 1363 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	gtk_stack_set_visible_child (_tmp16_, G_TYPE_CHECK_INSTANCE_CAST (_tmp17_, gtk_widget_get_type (), GtkWidget));
#line 1367 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp18_ = page;
#line 1367 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	PAGE_WINDOW_CLASS (library_window_parent_class)->set_current_page (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_APP_WINDOW, AppWindow), TYPE_PAGE_WINDOW, PageWindow), _tmp18_);
#line 1373 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp19_ = page;
#line 1373 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp19_, TYPE_LIBRARY_PHOTO_PAGE)) {
#line 9097 "LibraryWindow.c"
		SidebarTree* _tmp20_ = NULL;
#line 1374 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp20_ = self->priv->sidebar_tree;
#line 1374 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		sidebar_tree_disable_editing (_tmp20_);
#line 9103 "LibraryWindow.c"
	}
#line 1377 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp21_ = library_window_should_show_search_bar (self);
#line 1377 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp22_ = page;
#line 1377 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_window_toggle_search_bar (self, _tmp21_, G_TYPE_CHECK_INSTANCE_TYPE (_tmp22_, TYPE_CHECKERBOARD_PAGE) ? ((CheckerboardPage*) _tmp22_) : NULL);
#line 1380 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp23_ = self->priv->page_map;
#line 1380 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp24_ = page;
#line 1380 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp25_ = gee_abstract_map_get (G_TYPE_CHECK_INSTANCE_CAST (_tmp23_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp24_);
#line 1380 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	entry = (SidebarEntry*) _tmp25_;
#line 1381 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp26_ = entry;
#line 1381 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp26_ != NULL) {
#line 9123 "LibraryWindow.c"
		SidebarExpandableEntry* expandable_entry = NULL;
		SidebarEntry* _tmp27_ = NULL;
		SidebarExpandableEntry* _tmp28_ = NULL;
		gboolean _tmp29_ = FALSE;
		SidebarExpandableEntry* _tmp30_ = NULL;
		SidebarTree* _tmp35_ = NULL;
		SidebarEntry* _tmp36_ = NULL;
#line 1384 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp27_ = entry;
#line 1384 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp28_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp27_, SIDEBAR_TYPE_EXPANDABLE_ENTRY) ? ((SidebarExpandableEntry*) _tmp27_) : NULL);
#line 1384 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		expandable_entry = _tmp28_;
#line 1385 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp30_ = expandable_entry;
#line 1385 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		if (_tmp30_ != NULL) {
#line 9141 "LibraryWindow.c"
			SidebarExpandableEntry* _tmp31_ = NULL;
			gboolean _tmp32_ = FALSE;
#line 1385 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_tmp31_ = expandable_entry;
#line 1385 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_tmp32_ = sidebar_expandable_entry_expand_on_select (_tmp31_);
#line 1385 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_tmp29_ = _tmp32_;
#line 9150 "LibraryWindow.c"
		} else {
#line 1385 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_tmp29_ = FALSE;
#line 9154 "LibraryWindow.c"
		}
#line 1385 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		if (_tmp29_) {
#line 9158 "LibraryWindow.c"
			SidebarTree* _tmp33_ = NULL;
			SidebarEntry* _tmp34_ = NULL;
#line 1386 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_tmp33_ = self->priv->sidebar_tree;
#line 1386 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_tmp34_ = entry;
#line 1386 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			sidebar_tree_expand_to_entry (_tmp33_, _tmp34_);
#line 9167 "LibraryWindow.c"
		}
#line 1388 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp35_ = self->priv->sidebar_tree;
#line 1388 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp36_ = entry;
#line 1388 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		sidebar_tree_place_cursor (_tmp35_, _tmp36_, TRUE);
#line 1381 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_object_unref0 (expandable_entry);
#line 9177 "LibraryWindow.c"
	}
#line 1391 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_window_on_update_properties (self);
#line 1393 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp37_ = page;
#line 1393 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp37_, TYPE_CHECKERBOARD_PAGE)) {
#line 9185 "LibraryWindow.c"
		Page* _tmp38_ = NULL;
#line 1394 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp38_ = page;
#line 1394 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		library_window_init_view_filter (self, G_TYPE_CHECK_INSTANCE_CAST (_tmp38_, TYPE_CHECKERBOARD_PAGE, CheckerboardPage));
#line 9191 "LibraryWindow.c"
	}
#line 1396 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp39_ = page;
#line 1396 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	gtk_widget_show_all (G_TYPE_CHECK_INSTANCE_CAST (_tmp39_, gtk_widget_get_type (), GtkWidget));
#line 1399 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp40_ = page_window_get_current_page (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE_WINDOW, PageWindow));
#line 1399 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp41_ = _tmp40_;
#line 1399 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_window_subscribe_for_basic_information (self, _tmp41_);
#line 1399 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (_tmp41_);
#line 1401 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp42_ = page;
#line 1401 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	page_switched_to (_tmp42_);
#line 1403 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp43_ = page;
#line 1403 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp44_ = page_get_toolbar (_tmp43_);
#line 1403 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	toolbar = _tmp44_;
#line 1404 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp45_ = toolbar;
#line 1404 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp45_ != NULL) {
#line 9219 "LibraryWindow.c"
		GtkBox* _tmp46_ = NULL;
		GtkToolbar* _tmp47_ = NULL;
		GtkToolbar* _tmp48_ = NULL;
		GtkToolbar* _tmp49_ = NULL;
		gboolean _tmp50_ = FALSE;
#line 1405 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp46_ = self->priv->right_vbox;
#line 1405 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp47_ = toolbar;
#line 1405 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		gtk_container_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp46_, gtk_container_get_type (), GtkContainer), G_TYPE_CHECK_INSTANCE_CAST (_tmp47_, gtk_widget_get_type (), GtkWidget));
#line 1406 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp48_ = toolbar;
#line 1406 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		gtk_widget_show_all (G_TYPE_CHECK_INSTANCE_CAST (_tmp48_, gtk_widget_get_type (), GtkWidget));
#line 1407 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp49_ = toolbar;
#line 1407 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp50_ = library_window_is_toolbar_visible (self);
#line 1407 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		gtk_widget_set_visible (G_TYPE_CHECK_INSTANCE_CAST (_tmp49_, gtk_widget_get_type (), GtkWidget), _tmp50_);
#line 9241 "LibraryWindow.c"
	}
#line 1410 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp51_ = page;
#line 1410 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	page_ready (_tmp51_);
#line 1339 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (toolbar);
#line 1339 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (entry);
#line 1339 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (current_page);
#line 9253 "LibraryWindow.c"
}


static void library_window_init_view_filter (LibraryWindow* self, CheckerboardPage* page) {
	SearchFilterToolbar* _tmp0_ = NULL;
	CheckerboardPage* _tmp1_ = NULL;
	SearchViewFilter* _tmp2_ = NULL;
	SearchViewFilter* _tmp3_ = NULL;
	CheckerboardPage* _tmp4_ = NULL;
	ViewCollection* _tmp5_ = NULL;
	ViewCollection* _tmp6_ = NULL;
	CheckerboardPage* _tmp7_ = NULL;
	SearchViewFilter* _tmp8_ = NULL;
	SearchViewFilter* _tmp9_ = NULL;
#line 1413 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_LIBRARY_WINDOW (self));
#line 1413 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_CHECKERBOARD_PAGE (page));
#line 1414 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = self->priv->search_toolbar;
#line 1414 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_ = page;
#line 1414 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp2_ = checkerboard_page_get_search_view_filter (_tmp1_);
#line 1414 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp3_ = _tmp2_;
#line 1414 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	search_filter_toolbar_set_view_filter (_tmp0_, _tmp3_);
#line 1414 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_view_filter_unref0 (_tmp3_);
#line 1415 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp4_ = page;
#line 1415 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp5_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, TYPE_PAGE, Page));
#line 1415 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp6_ = _tmp5_;
#line 1415 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp7_ = page;
#line 1415 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp8_ = checkerboard_page_get_search_view_filter (_tmp7_);
#line 1415 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp9_ = _tmp8_;
#line 1415 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	view_collection_install_view_filter (_tmp6_, G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, TYPE_VIEW_FILTER, ViewFilter));
#line 1415 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_view_filter_unref0 (_tmp9_);
#line 1415 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_data_collection_unref0 (_tmp6_);
#line 9302 "LibraryWindow.c"
}


static gboolean library_window_should_show_search_bar (LibraryWindow* self) {
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
	Page* _tmp1_ = NULL;
	Page* _tmp2_ = NULL;
	gboolean _tmp3_ = FALSE;
#line 1418 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_val_if_fail (IS_LIBRARY_WINDOW (self), FALSE);
#line 1419 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_ = page_window_get_current_page (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE_WINDOW, PageWindow));
#line 1419 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp2_ = _tmp1_;
#line 1419 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp3_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp2_, TYPE_CHECKERBOARD_PAGE);
#line 1419 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (_tmp2_);
#line 1419 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp3_) {
#line 9324 "LibraryWindow.c"
		gboolean _tmp4_ = FALSE;
#line 1419 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp4_ = self->priv->is_search_toolbar_visible;
#line 1419 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp0_ = _tmp4_;
#line 9330 "LibraryWindow.c"
	} else {
#line 1419 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp0_ = FALSE;
#line 9334 "LibraryWindow.c"
	}
#line 1419 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	result = _tmp0_;
#line 1419 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	return result;
#line 9340 "LibraryWindow.c"
}


static void library_window_toggle_search_bar (LibraryWindow* self, gboolean show, CheckerboardPage* page) {
	SearchFilterToolbar* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_ = FALSE;
#line 1423 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_LIBRARY_WINDOW (self));
#line 1423 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail ((page == NULL) || IS_CHECKERBOARD_PAGE (page));
#line 1424 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = self->priv->search_toolbar;
#line 1424 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_ = show;
#line 1424 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	gtk_revealer_set_reveal_child (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_revealer_get_type (), GtkRevealer), _tmp1_);
#line 1425 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp2_ = show;
#line 1425 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp2_) {
#line 9362 "LibraryWindow.c"
		CheckerboardPage* _tmp3_ = NULL;
		SearchFilterToolbar* _tmp4_ = NULL;
		CheckerboardPage* _tmp5_ = NULL;
		SearchViewFilter* _tmp6_ = NULL;
		SearchViewFilter* _tmp7_ = NULL;
		CheckerboardPage* _tmp8_ = NULL;
		ViewCollection* _tmp9_ = NULL;
		ViewCollection* _tmp10_ = NULL;
		CheckerboardPage* _tmp11_ = NULL;
		SearchViewFilter* _tmp12_ = NULL;
		SearchViewFilter* _tmp13_ = NULL;
#line 1426 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp3_ = page;
#line 1426 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_vala_assert (NULL != _tmp3_, "null != page");
#line 1427 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp4_ = self->priv->search_toolbar;
#line 1427 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp5_ = page;
#line 1427 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp6_ = checkerboard_page_get_search_view_filter (_tmp5_);
#line 1427 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp7_ = _tmp6_;
#line 1427 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		search_filter_toolbar_set_view_filter (_tmp4_, _tmp7_);
#line 1427 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_view_filter_unref0 (_tmp7_);
#line 1428 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp8_ = page;
#line 1428 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp9_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, TYPE_PAGE, Page));
#line 1428 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp10_ = _tmp9_;
#line 1428 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp11_ = page;
#line 1428 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp12_ = checkerboard_page_get_search_view_filter (_tmp11_);
#line 1428 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp13_ = _tmp12_;
#line 1428 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		view_collection_install_view_filter (_tmp10_, G_TYPE_CHECK_INSTANCE_CAST (_tmp13_, TYPE_VIEW_FILTER, ViewFilter));
#line 1428 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_view_filter_unref0 (_tmp13_);
#line 1428 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_data_collection_unref0 (_tmp10_);
#line 9408 "LibraryWindow.c"
	} else {
		CheckerboardPage* _tmp14_ = NULL;
#line 1430 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp14_ = page;
#line 1430 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		if (_tmp14_ != NULL) {
#line 9415 "LibraryWindow.c"
			CheckerboardPage* _tmp15_ = NULL;
			ViewCollection* _tmp16_ = NULL;
			ViewCollection* _tmp17_ = NULL;
			DisabledViewFilter* _tmp18_ = NULL;
			DisabledViewFilter* _tmp19_ = NULL;
#line 1431 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_tmp15_ = page;
#line 1431 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_tmp16_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (_tmp15_, TYPE_PAGE, Page));
#line 1431 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_tmp17_ = _tmp16_;
#line 1431 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_tmp18_ = disabled_view_filter_new ();
#line 1431 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_tmp19_ = _tmp18_;
#line 1431 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			view_collection_install_view_filter (_tmp17_, G_TYPE_CHECK_INSTANCE_CAST (_tmp19_, TYPE_VIEW_FILTER, ViewFilter));
#line 1431 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_view_filter_unref0 (_tmp19_);
#line 1431 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_data_collection_unref0 (_tmp17_);
#line 9437 "LibraryWindow.c"
		}
	}
}


static void library_window_on_page_created (LibraryWindow* self, SidebarPageRepresentative* entry, Page* page) {
	GeeHashMap* _tmp0_ = NULL;
	Page* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	GeeHashMap* _tmp3_ = NULL;
	Page* _tmp4_ = NULL;
	SidebarPageRepresentative* _tmp5_ = NULL;
	Page* _tmp6_ = NULL;
#line 1435 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_LIBRARY_WINDOW (self));
#line 1435 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (SIDEBAR_IS_PAGE_REPRESENTATIVE (entry));
#line 1435 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_PAGE (page));
#line 1436 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = self->priv->page_map;
#line 1436 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_ = page;
#line 1436 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp2_ = gee_abstract_map_has_key (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp1_);
#line 1436 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_vala_assert (!_tmp2_, "!page_map.has_key(page)");
#line 1437 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp3_ = self->priv->page_map;
#line 1437 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp4_ = page;
#line 1437 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp5_ = entry;
#line 1437 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	gee_abstract_map_set (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp4_, G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, SIDEBAR_TYPE_ENTRY, SidebarEntry));
#line 1439 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp6_ = page;
#line 1439 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_window_add_to_stack (self, _tmp6_);
#line 9477 "LibraryWindow.c"
}


static void library_window_on_destroying_page (LibraryWindow* self, SidebarPageRepresentative* entry, Page* page) {
	Page* _tmp0_ = NULL;
	Page* _tmp1_ = NULL;
	Page* _tmp2_ = NULL;
	gboolean _tmp3_ = FALSE;
	Page* _tmp9_ = NULL;
	gboolean removed = FALSE;
	GeeHashMap* _tmp10_ = NULL;
	Page* _tmp11_ = NULL;
	gboolean _tmp12_ = FALSE;
#line 1442 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_LIBRARY_WINDOW (self));
#line 1442 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (SIDEBAR_IS_PAGE_REPRESENTATIVE (entry));
#line 1442 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_PAGE (page));
#line 1444 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = page;
#line 1444 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_ = page_window_get_current_page (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE_WINDOW, PageWindow));
#line 1444 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp2_ = _tmp1_;
#line 1444 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp3_ = _tmp0_ == _tmp2_;
#line 1444 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (_tmp2_);
#line 1444 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp3_) {
#line 9509 "LibraryWindow.c"
		LibraryBranch* _tmp4_ = NULL;
		LibraryPhotosEntry* _tmp5_ = NULL;
		LibraryPhotosEntry* _tmp6_ = NULL;
		Page* _tmp7_ = NULL;
		Page* _tmp8_ = NULL;
#line 1445 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp4_ = self->priv->library_branch;
#line 1445 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp5_ = library_branch_get_photos_entry (_tmp4_);
#line 1445 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp6_ = _tmp5_;
#line 1445 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp7_ = sidebar_page_representative_get_page (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, SIDEBAR_TYPE_PAGE_REPRESENTATIVE, SidebarPageRepresentative));
#line 1445 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp8_ = _tmp7_;
#line 1445 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		library_window_switch_to_page (self, _tmp8_);
#line 1445 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_object_unref0 (_tmp8_);
#line 9529 "LibraryWindow.c"
	}
#line 1447 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp9_ = page;
#line 1447 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_window_remove_from_stack (self, _tmp9_);
#line 1449 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp10_ = self->priv->page_map;
#line 1449 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp11_ = page;
#line 1449 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp12_ = gee_abstract_map_unset (G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp11_, NULL);
#line 1449 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	removed = _tmp12_;
#line 1450 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_vala_assert (removed, "removed");
#line 9545 "LibraryWindow.c"
}


static void library_window_on_sidebar_entry_selected (LibraryWindow* self, SidebarSelectableEntry* selectable) {
	SidebarPageRepresentative* page_rep = NULL;
	SidebarSelectableEntry* _tmp0_ = NULL;
	SidebarPageRepresentative* _tmp1_ = NULL;
	SidebarPageRepresentative* _tmp2_ = NULL;
#line 1453 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_LIBRARY_WINDOW (self));
#line 1453 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (SIDEBAR_IS_SELECTABLE_ENTRY (selectable));
#line 1454 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = selectable;
#line 1454 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, SIDEBAR_TYPE_PAGE_REPRESENTATIVE) ? ((SidebarPageRepresentative*) _tmp0_) : NULL);
#line 1454 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	page_rep = _tmp1_;
#line 1455 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp2_ = page_rep;
#line 1455 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp2_ != NULL) {
#line 9568 "LibraryWindow.c"
		SidebarPageRepresentative* _tmp3_ = NULL;
		Page* _tmp4_ = NULL;
		Page* _tmp5_ = NULL;
#line 1456 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp3_ = page_rep;
#line 1456 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp4_ = sidebar_page_representative_get_page (_tmp3_);
#line 1456 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp5_ = _tmp4_;
#line 1456 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		library_window_switch_to_page (self, _tmp5_);
#line 1456 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_object_unref0 (_tmp5_);
#line 9582 "LibraryWindow.c"
	}
#line 1453 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (page_rep);
#line 9586 "LibraryWindow.c"
}


static void library_window_on_sidebar_selected_entry_removed (LibraryWindow* self, SidebarSelectableEntry* selectable) {
	LibraryLastImportSidebarEntry* last_import_entry = NULL;
	LibraryBranch* _tmp0_ = NULL;
	LibraryLastImportSidebarEntry* _tmp1_ = NULL;
	LibraryLastImportSidebarEntry* _tmp2_ = NULL;
	LibraryLastImportSidebarEntry* _tmp3_ = NULL;
	gboolean _tmp4_ = FALSE;
	SidebarSelectableEntry* _tmp5_ = NULL;
	gboolean _tmp12_ = FALSE;
	SidebarSelectableEntry* _tmp13_ = NULL;
	gboolean _tmp21_ = FALSE;
	SidebarSelectableEntry* _tmp22_ = NULL;
	LibraryBranch* _tmp30_ = NULL;
	LibraryPhotosEntry* _tmp31_ = NULL;
	LibraryPhotosEntry* _tmp32_ = NULL;
	Page* _tmp33_ = NULL;
	Page* _tmp34_ = NULL;
#line 1459 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_LIBRARY_WINDOW (self));
#line 1459 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (SIDEBAR_IS_SELECTABLE_ENTRY (selectable));
#line 1463 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = self->priv->library_branch;
#line 1463 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_ = library_branch_get_last_imported_entry (_tmp0_);
#line 1463 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp2_ = _tmp1_;
#line 1463 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 1463 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	last_import_entry = _tmp3_;
#line 1466 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp5_ = selectable;
#line 1466 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp5_, LIBRARY_TYPE_IMPORT_QUEUE_SIDEBAR_ENTRY)) {
#line 9625 "LibraryWindow.c"
		LibraryLastImportSidebarEntry* _tmp6_ = NULL;
		gboolean _tmp7_ = FALSE;
		gboolean _tmp8_ = FALSE;
#line 1466 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp6_ = last_import_entry;
#line 1466 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp7_ = library_hideable_page_entry_get_visible (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, LIBRARY_TYPE_HIDEABLE_PAGE_ENTRY, LibraryHideablePageEntry));
#line 1466 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp8_ = _tmp7_;
#line 1466 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp4_ = _tmp8_;
#line 9637 "LibraryWindow.c"
	} else {
#line 1466 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp4_ = FALSE;
#line 9641 "LibraryWindow.c"
	}
#line 1466 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp4_) {
#line 9645 "LibraryWindow.c"
		LibraryLastImportSidebarEntry* _tmp9_ = NULL;
		Page* _tmp10_ = NULL;
		Page* _tmp11_ = NULL;
#line 1467 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp9_ = last_import_entry;
#line 1467 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp10_ = sidebar_page_representative_get_page (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, SIDEBAR_TYPE_PAGE_REPRESENTATIVE, SidebarPageRepresentative));
#line 1467 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp11_ = _tmp10_;
#line 1467 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		library_window_switch_to_page (self, _tmp11_);
#line 1467 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_object_unref0 (_tmp11_);
#line 1469 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_object_unref0 (last_import_entry);
#line 1469 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		return;
#line 9663 "LibraryWindow.c"
	}
#line 1473 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp13_ = selectable;
#line 1473 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp13_, EVENTS_TYPE_EVENT_ENTRY)) {
#line 9669 "LibraryWindow.c"
		EventsBranch* _tmp14_ = NULL;
		gboolean _tmp15_ = FALSE;
#line 1473 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp14_ = self->priv->events_branch;
#line 1473 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp15_ = sidebar_branch_get_show_branch (G_TYPE_CHECK_INSTANCE_CAST (_tmp14_, SIDEBAR_TYPE_BRANCH, SidebarBranch));
#line 1473 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp12_ = _tmp15_;
#line 9678 "LibraryWindow.c"
	} else {
#line 1473 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp12_ = FALSE;
#line 9682 "LibraryWindow.c"
	}
#line 1473 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp12_) {
#line 9686 "LibraryWindow.c"
		EventsBranch* _tmp16_ = NULL;
		EventsMasterDirectoryEntry* _tmp17_ = NULL;
		EventsMasterDirectoryEntry* _tmp18_ = NULL;
		Page* _tmp19_ = NULL;
		Page* _tmp20_ = NULL;
#line 1474 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp16_ = self->priv->events_branch;
#line 1474 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp17_ = events_branch_get_master_entry (_tmp16_);
#line 1474 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp18_ = _tmp17_;
#line 1474 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp19_ = sidebar_page_representative_get_page (G_TYPE_CHECK_INSTANCE_CAST (_tmp18_, SIDEBAR_TYPE_PAGE_REPRESENTATIVE, SidebarPageRepresentative));
#line 1474 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp20_ = _tmp19_;
#line 1474 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		library_window_switch_to_page (self, _tmp20_);
#line 1474 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_object_unref0 (_tmp20_);
#line 1474 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_object_unref0 (_tmp18_);
#line 1476 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_object_unref0 (last_import_entry);
#line 1476 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		return;
#line 9712 "LibraryWindow.c"
	}
#line 1480 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp22_ = selectable;
#line 1480 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp22_, EVENTS_TYPE_DIRECTORY_ENTRY)) {
#line 9718 "LibraryWindow.c"
		EventsBranch* _tmp23_ = NULL;
		gboolean _tmp24_ = FALSE;
#line 1480 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp23_ = self->priv->events_branch;
#line 1480 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp24_ = sidebar_branch_get_show_branch (G_TYPE_CHECK_INSTANCE_CAST (_tmp23_, SIDEBAR_TYPE_BRANCH, SidebarBranch));
#line 1480 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp21_ = _tmp24_;
#line 9727 "LibraryWindow.c"
	} else {
#line 1480 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp21_ = FALSE;
#line 9731 "LibraryWindow.c"
	}
#line 1480 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp21_) {
#line 9735 "LibraryWindow.c"
		EventsBranch* _tmp25_ = NULL;
		EventsMasterDirectoryEntry* _tmp26_ = NULL;
		EventsMasterDirectoryEntry* _tmp27_ = NULL;
		Page* _tmp28_ = NULL;
		Page* _tmp29_ = NULL;
#line 1481 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp25_ = self->priv->events_branch;
#line 1481 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp26_ = events_branch_get_master_entry (_tmp25_);
#line 1481 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp27_ = _tmp26_;
#line 1481 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp28_ = sidebar_page_representative_get_page (G_TYPE_CHECK_INSTANCE_CAST (_tmp27_, SIDEBAR_TYPE_PAGE_REPRESENTATIVE, SidebarPageRepresentative));
#line 1481 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp29_ = _tmp28_;
#line 1481 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		library_window_switch_to_page (self, _tmp29_);
#line 1481 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_object_unref0 (_tmp29_);
#line 1481 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_object_unref0 (_tmp27_);
#line 1483 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_object_unref0 (last_import_entry);
#line 1483 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		return;
#line 9761 "LibraryWindow.c"
	}
#line 1487 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp30_ = self->priv->library_branch;
#line 1487 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp31_ = library_branch_get_photos_entry (_tmp30_);
#line 1487 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp32_ = _tmp31_;
#line 1487 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp33_ = sidebar_page_representative_get_page (G_TYPE_CHECK_INSTANCE_CAST (_tmp32_, SIDEBAR_TYPE_PAGE_REPRESENTATIVE, SidebarPageRepresentative));
#line 1487 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp34_ = _tmp33_;
#line 1487 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_window_switch_to_page (self, _tmp34_);
#line 1487 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (_tmp34_);
#line 1459 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (last_import_entry);
#line 9779 "LibraryWindow.c"
}


static void _library_window_on_update_properties_view_collection_items_state_changed (ViewCollection* _sender, GeeIterable* changed, gpointer self) {
#line 1493 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_window_on_update_properties ((LibraryWindow*) self);
#line 9786 "LibraryWindow.c"
}


static void _library_window_on_update_properties_data_collection_items_altered (DataCollection* _sender, GeeMap* items, gpointer self) {
#line 1494 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_window_on_update_properties ((LibraryWindow*) self);
#line 9793 "LibraryWindow.c"
}


static void _library_window_on_update_properties_data_collection_contents_altered (DataCollection* _sender, GeeIterable* added, GeeIterable* removed, gpointer self) {
#line 1495 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_window_on_update_properties ((LibraryWindow*) self);
#line 9800 "LibraryWindow.c"
}


static void _library_window_on_update_properties_view_collection_items_visibility_changed (ViewCollection* _sender, GeeCollection* changed, gpointer self) {
#line 1496 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_window_on_update_properties ((LibraryWindow*) self);
#line 9807 "LibraryWindow.c"
}


static void library_window_subscribe_for_basic_information (LibraryWindow* self, Page* page) {
	ViewCollection* view = NULL;
	Page* _tmp0_ = NULL;
	ViewCollection* _tmp1_ = NULL;
#line 1490 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_LIBRARY_WINDOW (self));
#line 1490 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_PAGE (page));
#line 1491 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = page;
#line 1491 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_ = page_get_view (_tmp0_);
#line 1491 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	view = _tmp1_;
#line 1493 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_signal_connect_object (view, "items-state-changed", (GCallback) _library_window_on_update_properties_view_collection_items_state_changed, self, 0);
#line 1494 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (view, TYPE_DATA_COLLECTION, DataCollection), "items-altered", (GCallback) _library_window_on_update_properties_data_collection_items_altered, self, 0);
#line 1495 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (view, TYPE_DATA_COLLECTION, DataCollection), "contents-altered", (GCallback) _library_window_on_update_properties_data_collection_contents_altered, self, 0);
#line 1496 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_signal_connect_object (view, "items-visibility-changed", (GCallback) _library_window_on_update_properties_view_collection_items_visibility_changed, self, 0);
#line 1490 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_data_collection_unref0 (view);
#line 9835 "LibraryWindow.c"
}


static void library_window_unsubscribe_from_basic_information (LibraryWindow* self, Page* page) {
	ViewCollection* view = NULL;
	Page* _tmp0_ = NULL;
	ViewCollection* _tmp1_ = NULL;
	guint _tmp2_ = 0U;
	guint _tmp3_ = 0U;
	guint _tmp4_ = 0U;
	guint _tmp5_ = 0U;
#line 1499 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_LIBRARY_WINDOW (self));
#line 1499 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_PAGE (page));
#line 1500 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = page;
#line 1500 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_ = page_get_view (_tmp0_);
#line 1500 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	view = _tmp1_;
#line 1502 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_signal_parse_name ("items-state-changed", TYPE_VIEW_COLLECTION, &_tmp2_, NULL, FALSE);
#line 1502 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_signal_handlers_disconnect_matched (view, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp2_, 0, NULL, (GCallback) _library_window_on_update_properties_view_collection_items_state_changed, self);
#line 1503 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_signal_parse_name ("items-altered", TYPE_DATA_COLLECTION, &_tmp3_, NULL, FALSE);
#line 1503 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_signal_handlers_disconnect_matched (G_TYPE_CHECK_INSTANCE_CAST (view, TYPE_DATA_COLLECTION, DataCollection), G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _library_window_on_update_properties_data_collection_items_altered, self);
#line 1504 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_signal_parse_name ("contents-altered", TYPE_DATA_COLLECTION, &_tmp4_, NULL, FALSE);
#line 1504 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_signal_handlers_disconnect_matched (G_TYPE_CHECK_INSTANCE_CAST (view, TYPE_DATA_COLLECTION, DataCollection), G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp4_, 0, NULL, (GCallback) _library_window_on_update_properties_data_collection_contents_altered, self);
#line 1505 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_signal_parse_name ("items-visibility-changed", TYPE_VIEW_COLLECTION, &_tmp5_, NULL, FALSE);
#line 1505 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_signal_handlers_disconnect_matched (view, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp5_, 0, NULL, (GCallback) _library_window_on_update_properties_view_collection_items_visibility_changed, self);
#line 1499 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_data_collection_unref0 (view);
#line 9875 "LibraryWindow.c"
}


static void library_window_on_update_properties (LibraryWindow* self) {
	OneShotScheduler* _tmp0_ = NULL;
#line 1508 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_LIBRARY_WINDOW (self));
#line 1509 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = self->priv->properties_scheduler;
#line 1509 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	one_shot_scheduler_at_idle (_tmp0_);
#line 9887 "LibraryWindow.c"
}


static void library_window_on_update_properties_now (LibraryWindow* self) {
	GtkFrame* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_ = FALSE;
	ExtendedPropertiesWindow* _tmp6_ = NULL;
	gboolean _tmp7_ = FALSE;
	gboolean _tmp8_ = FALSE;
#line 1512 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_LIBRARY_WINDOW (self));
#line 1513 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = self->priv->bottom_frame;
#line 1513 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_ = gtk_widget_get_visible (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_widget_get_type (), GtkWidget));
#line 1513 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp2_ = _tmp1_;
#line 1513 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp2_) {
#line 9908 "LibraryWindow.c"
		BasicProperties* _tmp3_ = NULL;
		Page* _tmp4_ = NULL;
		Page* _tmp5_ = NULL;
#line 1514 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp3_ = self->priv->basic_properties;
#line 1514 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp4_ = page_window_get_current_page (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE_WINDOW, PageWindow));
#line 1514 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp5_ = _tmp4_;
#line 1514 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		properties_update_properties (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, TYPE_PROPERTIES, Properties), _tmp5_);
#line 1514 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_object_unref0 (_tmp5_);
#line 9922 "LibraryWindow.c"
	}
#line 1516 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp6_ = self->priv->extended_properties;
#line 1516 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp7_ = gtk_widget_get_visible (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, gtk_widget_get_type (), GtkWidget));
#line 1516 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp8_ = _tmp7_;
#line 1516 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp8_) {
#line 9932 "LibraryWindow.c"
		ExtendedPropertiesWindow* _tmp9_ = NULL;
		Page* _tmp10_ = NULL;
		Page* _tmp11_ = NULL;
#line 1517 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp9_ = self->priv->extended_properties;
#line 1517 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp10_ = page_window_get_current_page (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE_WINDOW, PageWindow));
#line 1517 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp11_ = _tmp10_;
#line 1517 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		extended_properties_window_update_properties (_tmp9_, _tmp11_);
#line 1517 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_object_unref0 (_tmp11_);
#line 9946 "LibraryWindow.c"
	}
}


static gchar* string_replace (const gchar* self, const gchar* old, const gchar* replacement) {
	gchar* result = NULL;
	GError * _inner_error_ = NULL;
#line 1380 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1380 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	g_return_val_if_fail (old != NULL, NULL);
#line 1380 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	g_return_val_if_fail (replacement != NULL, NULL);
#line 9960 "LibraryWindow.c"
	{
		GRegex* regex = NULL;
		const gchar* _tmp0_ = NULL;
		gchar* _tmp1_ = NULL;
		gchar* _tmp2_ = NULL;
		GRegex* _tmp3_ = NULL;
		GRegex* _tmp4_ = NULL;
		gchar* _tmp5_ = NULL;
		GRegex* _tmp6_ = NULL;
		const gchar* _tmp7_ = NULL;
		gchar* _tmp8_ = NULL;
		gchar* _tmp9_ = NULL;
#line 1382 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp0_ = old;
#line 1382 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp1_ = g_regex_escape_string (_tmp0_, -1);
#line 1382 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp2_ = _tmp1_;
#line 1382 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp3_ = g_regex_new (_tmp2_, 0, 0, &_inner_error_);
#line 1382 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp4_ = _tmp3_;
#line 1382 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_g_free0 (_tmp2_);
#line 1382 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		regex = _tmp4_;
#line 1382 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1382 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
			if (_inner_error_->domain == G_REGEX_ERROR) {
#line 9991 "LibraryWindow.c"
				goto __catch41_g_regex_error;
			}
#line 1382 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1382 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
			g_clear_error (&_inner_error_);
#line 1382 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
			return NULL;
#line 10000 "LibraryWindow.c"
		}
#line 1383 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp6_ = regex;
#line 1383 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp7_ = replacement;
#line 1383 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp8_ = g_regex_replace_literal (_tmp6_, self, (gssize) -1, 0, _tmp7_, 0, &_inner_error_);
#line 1383 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp5_ = _tmp8_;
#line 1383 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1383 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
			_g_regex_unref0 (regex);
#line 1383 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
			if (_inner_error_->domain == G_REGEX_ERROR) {
#line 10016 "LibraryWindow.c"
				goto __catch41_g_regex_error;
			}
#line 1383 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
			_g_regex_unref0 (regex);
#line 1383 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1383 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
			g_clear_error (&_inner_error_);
#line 1383 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
			return NULL;
#line 10027 "LibraryWindow.c"
		}
#line 1383 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp9_ = _tmp5_;
#line 1383 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp5_ = NULL;
#line 1383 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		result = _tmp9_;
#line 1383 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_g_free0 (_tmp5_);
#line 1383 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_g_regex_unref0 (regex);
#line 1383 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		return result;
#line 10041 "LibraryWindow.c"
	}
	goto __finally41;
	__catch41_g_regex_error:
	{
		GError* e = NULL;
#line 1381 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		e = _inner_error_;
#line 1381 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_inner_error_ = NULL;
#line 1385 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		g_assert_not_reached ();
#line 1381 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_g_error_free0 (e);
#line 10055 "LibraryWindow.c"
	}
	__finally41:
#line 1381 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1381 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1381 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		g_clear_error (&_inner_error_);
#line 1381 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		return NULL;
#line 10066 "LibraryWindow.c"
	}
}


void library_window_mounted_camera_shell_notification (LibraryWindow* self, const gchar* uri, gboolean at_startup) {
	const gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	GFile* uri_file = NULL;
	const gchar* _tmp4_ = NULL;
	GFile* _tmp5_ = NULL;
	GMount* mount = NULL;
	gchar* alt_uri = NULL;
	const gchar* _tmp12_ = NULL;
	gboolean _tmp13_ = FALSE;
	gboolean _tmp18_ = FALSE;
	GError * _inner_error_ = NULL;
#line 1520 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (IS_LIBRARY_WINDOW (self));
#line 1520 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (uri != NULL);
#line 1521 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = uri;
#line 1521 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_debug ("LibraryWindow.vala:1521: mount point reported: %s", _tmp0_);
#line 1524 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_ = uri;
#line 1524 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp2_ = library_window_is_mount_uri_supported (_tmp1_);
#line 1524 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (!_tmp2_) {
#line 10098 "LibraryWindow.c"
		const gchar* _tmp3_ = NULL;
#line 1525 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp3_ = uri;
#line 1525 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		g_debug ("LibraryWindow.vala:1525: Unsupported mount scheme: %s", _tmp3_);
#line 1527 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		return;
#line 10106 "LibraryWindow.c"
	}
#line 1530 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp4_ = uri;
#line 1530 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp5_ = g_file_new_for_uri (_tmp4_);
#line 1530 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	uri_file = _tmp5_;
#line 1533 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	mount = NULL;
#line 10116 "LibraryWindow.c"
	{
		GMount* _tmp6_ = NULL;
		GFile* _tmp7_ = NULL;
		GMount* _tmp8_ = NULL;
		GMount* _tmp9_ = NULL;
#line 1535 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp7_ = uri_file;
#line 1535 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp8_ = g_file_find_enclosing_mount (_tmp7_, NULL, &_inner_error_);
#line 1535 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp6_ = _tmp8_;
#line 1535 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 10130 "LibraryWindow.c"
			goto __catch40_g_error;
		}
#line 1535 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp9_ = _tmp6_;
#line 1535 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp6_ = NULL;
#line 1535 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_object_unref0 (mount);
#line 1535 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		mount = _tmp9_;
#line 1534 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_object_unref0 (_tmp6_);
#line 10143 "LibraryWindow.c"
	}
	goto __finally40;
	__catch40_g_error:
	{
		GError* err = NULL;
		GError* _tmp10_ = NULL;
		const gchar* _tmp11_ = NULL;
#line 1534 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		err = _inner_error_;
#line 1534 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_inner_error_ = NULL;
#line 1537 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp10_ = err;
#line 1537 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp11_ = _tmp10_->message;
#line 1537 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		g_debug ("LibraryWindow.vala:1537: %s", _tmp11_);
#line 1539 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_error_free0 (err);
#line 1539 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_object_unref0 (mount);
#line 1539 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_object_unref0 (uri_file);
#line 1539 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		return;
#line 10169 "LibraryWindow.c"
	}
	__finally40:
#line 1534 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1534 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_object_unref0 (mount);
#line 1534 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_object_unref0 (uri_file);
#line 1534 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1534 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		g_clear_error (&_inner_error_);
#line 1534 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		return;
#line 10184 "LibraryWindow.c"
	}
#line 1543 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	alt_uri = NULL;
#line 1544 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp12_ = uri;
#line 1544 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp13_ = g_str_has_prefix (_tmp12_, "file://");
#line 1544 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp13_) {
#line 10194 "LibraryWindow.c"
		const gchar* _tmp14_ = NULL;
		gchar* _tmp15_ = NULL;
		gchar* _tmp16_ = NULL;
		gchar* _tmp17_ = NULL;
#line 1545 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp14_ = uri;
#line 1545 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp15_ = string_replace (_tmp14_, "file://", "disk:");
#line 1545 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp16_ = _tmp15_;
#line 1545 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp17_ = camera_table_get_port_uri (_tmp16_);
#line 1545 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_free0 (alt_uri);
#line 1545 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		alt_uri = _tmp17_;
#line 1545 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_free0 (_tmp16_);
#line 10213 "LibraryWindow.c"
	}
#line 1548 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp18_ = at_startup;
#line 1548 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp18_) {
#line 10219 "LibraryWindow.c"
		const gchar* _tmp19_ = NULL;
		gboolean _tmp20_ = FALSE;
		const gchar* _tmp23_ = NULL;
		gboolean _tmp24_ = FALSE;
#line 1549 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp19_ = uri;
#line 1549 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp20_ = is_string_empty (_tmp19_);
#line 1549 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		if (!_tmp20_) {
#line 10230 "LibraryWindow.c"
			GeeHashSet* _tmp21_ = NULL;
			const gchar* _tmp22_ = NULL;
#line 1550 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_tmp21_ = library_window_initial_camera_uris;
#line 1550 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_tmp22_ = uri;
#line 1550 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			gee_abstract_collection_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp21_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection), _tmp22_);
#line 10239 "LibraryWindow.c"
		}
#line 1552 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp23_ = alt_uri;
#line 1552 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp24_ = is_string_empty (_tmp23_);
#line 1552 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		if (!_tmp24_) {
#line 10247 "LibraryWindow.c"
			GeeHashSet* _tmp25_ = NULL;
			const gchar* _tmp26_ = NULL;
#line 1553 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_tmp25_ = library_window_initial_camera_uris;
#line 1553 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_tmp26_ = alt_uri;
#line 1553 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			gee_abstract_collection_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp25_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection), _tmp26_);
#line 10256 "LibraryWindow.c"
		}
	}
#line 1520 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_free0 (alt_uri);
#line 1520 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (mount);
#line 1520 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (uri_file);
#line 10265 "LibraryWindow.c"
}


static gboolean library_window_real_key_press_event (GtkWidget* base, GdkEventKey* event) {
	LibraryWindow * self;
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	SidebarTree* _tmp2_ = NULL;
	gboolean _tmp3_ = FALSE;
	gboolean _tmp4_ = FALSE;
	GdkEventKey* _tmp11_ = NULL;
	gboolean _tmp12_ = FALSE;
	GdkEventKey* _tmp13_ = NULL;
	guint _tmp14_ = 0U;
	const gchar* _tmp15_ = NULL;
#line 1557 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_LIBRARY_WINDOW, LibraryWindow);
#line 1557 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 1558 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp2_ = self->priv->sidebar_tree;
#line 1558 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_object_get (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, gtk_widget_get_type (), GtkWidget), "has-focus", &_tmp3_, NULL);
#line 1558 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp4_ = _tmp3_;
#line 1558 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp4_) {
#line 10294 "LibraryWindow.c"
		SidebarTree* _tmp5_ = NULL;
		GdkEventKey* _tmp6_ = NULL;
		gboolean _tmp7_ = FALSE;
#line 1558 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp5_ = self->priv->sidebar_tree;
#line 1558 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp6_ = event;
#line 1558 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp7_ = sidebar_tree_is_keypress_interpreted (_tmp5_, _tmp6_);
#line 1558 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp1_ = _tmp7_;
#line 10306 "LibraryWindow.c"
	} else {
#line 1558 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp1_ = FALSE;
#line 10310 "LibraryWindow.c"
	}
#line 1558 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp1_) {
#line 10314 "LibraryWindow.c"
		SidebarTree* _tmp8_ = NULL;
		GdkEventKey* _tmp9_ = NULL;
		gboolean _tmp10_ = FALSE;
#line 1559 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp8_ = self->priv->sidebar_tree;
#line 1559 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp9_ = event;
#line 1559 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		g_signal_emit_by_name (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, gtk_widget_get_type (), GtkWidget), "key-press-event", _tmp9_, &_tmp10_);
#line 1559 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp0_ = _tmp10_;
#line 10326 "LibraryWindow.c"
	} else {
#line 1558 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp0_ = FALSE;
#line 10330 "LibraryWindow.c"
	}
#line 1558 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp0_) {
#line 1560 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		result = TRUE;
#line 1560 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		return result;
#line 10338 "LibraryWindow.c"
	}
#line 1563 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp11_ = event;
#line 1563 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp12_ = GTK_WIDGET_CLASS (library_window_parent_class)->key_press_event (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_APP_WINDOW, AppWindow), gtk_widget_get_type (), GtkWidget), _tmp11_);
#line 1563 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp12_) {
#line 1564 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		result = TRUE;
#line 1564 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		return result;
#line 10350 "LibraryWindow.c"
	}
#line 1566 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp13_ = event;
#line 1566 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp14_ = _tmp13_->keyval;
#line 1566 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp15_ = gdk_keyval_name (_tmp14_);
#line 1566 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (g_strcmp0 (_tmp15_, "Escape") == 0) {
#line 1567 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		library_window_on_clear_search (self);
#line 1568 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		result = TRUE;
#line 1568 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		return result;
#line 10366 "LibraryWindow.c"
	}
#line 1571 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	result = FALSE;
#line 1571 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	return result;
#line 10372 "LibraryWindow.c"
}


gint library_window_get_PAGE_MIN_WIDTH (void) {
	gint result;
	gint _tmp0_ = 0;
	gint _tmp1_ = 0;
#line 12 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = thumbnail_get_MAX_SCALE ();
#line 12 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_ = _tmp0_;
#line 12 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	result = _tmp1_ + (CHECKERBOARD_LAYOUT_COLUMN_GUTTER_PADDING * 2);
#line 12 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	return result;
#line 10388 "LibraryWindow.c"
}


static gpointer _data_collection_ref0 (gpointer self) {
#line 78 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	return self ? data_collection_ref (self) : NULL;
#line 10395 "LibraryWindow.c"
}


static LibraryWindowFullscreenPhotoPage* library_window_fullscreen_photo_page_construct (GType object_type, CollectionPage* collection, Photo* start, ViewCollection* view) {
	LibraryWindowFullscreenPhotoPage * self = NULL;
	CollectionPage* _tmp0_ = NULL;
	CollectionPage* _tmp1_ = NULL;
	Photo* _tmp2_ = NULL;
	Photo* _tmp3_ = NULL;
	ViewCollection* _tmp4_ = NULL;
	ViewCollection* _tmp5_ = NULL;
#line 75 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_val_if_fail (IS_COLLECTION_PAGE (collection), NULL);
#line 75 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_val_if_fail (IS_PHOTO (start), NULL);
#line 75 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_val_if_fail ((view == NULL) || IS_VIEW_COLLECTION (view), NULL);
#line 75 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	self = (LibraryWindowFullscreenPhotoPage*) library_photo_page_construct (object_type);
#line 76 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = collection;
#line 76 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 76 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (self->priv->collection);
#line 76 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	self->priv->collection = _tmp1_;
#line 77 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp2_ = start;
#line 77 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 77 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (self->priv->start);
#line 77 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	self->priv->start = _tmp3_;
#line 78 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp4_ = view;
#line 78 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp5_ = _data_collection_ref0 (_tmp4_);
#line 78 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_data_collection_unref0 (self->priv->view);
#line 78 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	self->priv->view = _tmp5_;
#line 75 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	return self;
#line 10441 "LibraryWindow.c"
}


static LibraryWindowFullscreenPhotoPage* library_window_fullscreen_photo_page_new (CollectionPage* collection, Photo* start, ViewCollection* view) {
#line 75 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	return library_window_fullscreen_photo_page_construct (LIBRARY_WINDOW_TYPE_FULLSCREEN_PHOTO_PAGE, collection, start, view);
#line 10448 "LibraryWindow.c"
}


static void library_window_fullscreen_photo_page_real_switched_to (Page* base) {
	LibraryWindowFullscreenPhotoPage * self;
	CollectionPage* _tmp0_ = NULL;
	Photo* _tmp1_ = NULL;
	ViewCollection* _tmp2_ = NULL;
#line 81 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, LIBRARY_WINDOW_TYPE_FULLSCREEN_PHOTO_PAGE, LibraryWindowFullscreenPhotoPage);
#line 82 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = self->priv->collection;
#line 82 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_ = self->priv->start;
#line 82 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp2_ = self->priv->view;
#line 82 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_photo_page_display_for_collection (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_LIBRARY_PHOTO_PAGE, LibraryPhotoPage), _tmp0_, _tmp1_, _tmp2_);
#line 84 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	PAGE_CLASS (library_window_fullscreen_photo_page_parent_class)->switched_to (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_LIBRARY_PHOTO_PAGE, LibraryPhotoPage), TYPE_PAGE, Page));
#line 10469 "LibraryWindow.c"
}


static void library_window_fullscreen_photo_page_real_init_collect_ui_filenames (Page* base, GeeList* ui_filenames) {
	LibraryWindowFullscreenPhotoPage * self;
	GeeList* _tmp0_ = NULL;
#line 87 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, LIBRARY_WINDOW_TYPE_FULLSCREEN_PHOTO_PAGE, LibraryWindowFullscreenPhotoPage);
#line 87 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_return_if_fail (GEE_IS_LIST (ui_filenames));
#line 90 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = ui_filenames;
#line 90 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	gee_collection_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, GEE_TYPE_COLLECTION, GeeCollection), "photo_context.ui");
#line 10484 "LibraryWindow.c"
}


static void library_window_fullscreen_photo_page_class_init (LibraryWindowFullscreenPhotoPageClass * klass) {
#line 70 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_window_fullscreen_photo_page_parent_class = g_type_class_peek_parent (klass);
#line 70 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_type_class_add_private (klass, sizeof (LibraryWindowFullscreenPhotoPagePrivate));
#line 70 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	((PageClass *) klass)->switched_to = library_window_fullscreen_photo_page_real_switched_to;
#line 70 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	((PageClass *) klass)->init_collect_ui_filenames = library_window_fullscreen_photo_page_real_init_collect_ui_filenames;
#line 70 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	G_OBJECT_CLASS (klass)->finalize = library_window_fullscreen_photo_page_finalize;
#line 10499 "LibraryWindow.c"
}


static void library_window_fullscreen_photo_page_instance_init (LibraryWindowFullscreenPhotoPage * self) {
#line 70 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	self->priv = LIBRARY_WINDOW_FULLSCREEN_PHOTO_PAGE_GET_PRIVATE (self);
#line 10506 "LibraryWindow.c"
}


static void library_window_fullscreen_photo_page_finalize (GObject* obj) {
	LibraryWindowFullscreenPhotoPage * self;
#line 70 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, LIBRARY_WINDOW_TYPE_FULLSCREEN_PHOTO_PAGE, LibraryWindowFullscreenPhotoPage);
#line 71 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (self->priv->collection);
#line 72 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (self->priv->start);
#line 73 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_data_collection_unref0 (self->priv->view);
#line 70 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	G_OBJECT_CLASS (library_window_fullscreen_photo_page_parent_class)->finalize (obj);
#line 10522 "LibraryWindow.c"
}


static GType library_window_fullscreen_photo_page_get_type (void) {
	static volatile gsize library_window_fullscreen_photo_page_type_id__volatile = 0;
	if (g_once_init_enter (&library_window_fullscreen_photo_page_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (LibraryWindowFullscreenPhotoPageClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) library_window_fullscreen_photo_page_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (LibraryWindowFullscreenPhotoPage), 0, (GInstanceInitFunc) library_window_fullscreen_photo_page_instance_init, NULL };
		GType library_window_fullscreen_photo_page_type_id;
		library_window_fullscreen_photo_page_type_id = g_type_register_static (TYPE_LIBRARY_PHOTO_PAGE, "LibraryWindowFullscreenPhotoPage", &g_define_type_info, 0);
		g_once_init_leave (&library_window_fullscreen_photo_page_type_id__volatile, library_window_fullscreen_photo_page_type_id);
	}
	return library_window_fullscreen_photo_page_type_id__volatile;
}


static void library_window_class_init (LibraryWindowClass * klass) {
	GeeHashSet* _tmp0_ = NULL;
#line 7 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_window_parent_class = g_type_class_peek_parent (klass);
#line 7 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_type_class_add_private (klass, sizeof (LibraryWindowPrivate));
#line 7 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	((AppWindowClass *) klass)->create_common_action_groups = library_window_real_create_common_action_groups;
#line 7 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	((AppWindowClass *) klass)->replace_common_placeholders = library_window_real_replace_common_placeholders;
#line 7 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	((PageWindowClass *) klass)->switched_pages = library_window_real_switched_pages;
#line 7 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	((GtkWidgetClass *) klass)->show_all = library_window_real_show_all;
#line 7 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	((AppWindowClass *) klass)->get_app_role = library_window_real_get_app_role;
#line 7 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	((AppWindowClass *) klass)->on_quit = library_window_real_on_quit;
#line 7 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	((AppWindowClass *) klass)->on_fullscreen = library_window_real_on_fullscreen;
#line 7 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	((AppWindowClass *) klass)->update_common_action_availability = library_window_real_update_common_action_availability;
#line 7 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	((AppWindowClass *) klass)->update_common_actions = library_window_real_update_common_actions;
#line 7 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	((GtkWidgetClass *) klass)->drag_motion = library_window_real_drag_motion;
#line 7 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	((GtkWidgetClass *) klass)->drag_data_received = library_window_real_drag_data_received;
#line 7 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	((PageWindowClass *) klass)->set_current_page = library_window_real_set_current_page;
#line 7 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	((GtkWidgetClass *) klass)->key_press_event = library_window_real_key_press_event;
#line 7 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_library_window_get_property;
#line 7 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	G_OBJECT_CLASS (klass)->finalize = library_window_finalize;
#line 121 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = gee_hash_set_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL, NULL, NULL, NULL);
#line 121 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_window_initial_camera_uris = _tmp0_;
#line 10578 "LibraryWindow.c"
}


static void library_window_instance_init (LibraryWindow * self) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	GtkPaned* _tmp2_ = NULL;
	GtkPaned* _tmp3_ = NULL;
	GtkFrame* _tmp4_ = NULL;
	GtkActionGroup* _tmp5_ = NULL;
	LibraryBranch* _tmp6_ = NULL;
	TagsBranch* _tmp7_ = NULL;
	FoldersBranch* _tmp8_ = NULL;
	EventsBranch* _tmp9_ = NULL;
	CameraBranch* _tmp10_ = NULL;
	SearchesBranch* _tmp11_ = NULL;
	GeeHashMap* _tmp12_ = NULL;
	SearchFilterActions* _tmp13_ = NULL;
	GtkBox* _tmp14_ = NULL;
	GtkFrame* _tmp15_ = NULL;
	GtkProgressBar* _tmp16_ = NULL;
	BasicProperties* _tmp17_ = NULL;
	GtkStack* _tmp18_ = NULL;
	GtkBox* _tmp19_ = NULL;
#line 7 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	self->priv = LIBRARY_WINDOW_GET_PRIVATE (self);
#line 95 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = g_get_home_dir ();
#line 95 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 95 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	self->priv->import_dir = _tmp1_;
#line 97 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp2_ = (GtkPaned*) gtk_paned_new (GTK_ORIENTATION_VERTICAL);
#line 97 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_object_ref_sink (_tmp2_);
#line 97 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	self->priv->sidebar_paned = _tmp2_;
#line 98 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp3_ = (GtkPaned*) gtk_paned_new (GTK_ORIENTATION_HORIZONTAL);
#line 98 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_object_ref_sink (_tmp3_);
#line 98 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	self->priv->client_paned = _tmp3_;
#line 99 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp4_ = (GtkFrame*) gtk_frame_new (NULL);
#line 99 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_object_ref_sink (_tmp4_);
#line 99 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	self->priv->bottom_frame = _tmp4_;
#line 101 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp5_ = gtk_action_group_new ("LibraryWindowGlobalActionGroup");
#line 101 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	self->priv->common_action_group = _tmp5_;
#line 103 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	self->priv->properties_scheduler = NULL;
#line 104 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	self->priv->notify_library_is_home_dir = TRUE;
#line 108 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp6_ = library_branch_new ();
#line 108 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	self->priv->library_branch = _tmp6_;
#line 109 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp7_ = tags_branch_new ();
#line 109 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	self->priv->tags_branch = _tmp7_;
#line 110 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp8_ = folders_branch_new ();
#line 110 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	self->priv->folders_branch = _tmp8_;
#line 111 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp9_ = events_branch_new ();
#line 111 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	self->priv->events_branch = _tmp9_;
#line 112 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp10_ = camera_branch_new ();
#line 112 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	self->priv->camera_branch = _tmp10_;
#line 113 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp11_ = searches_branch_new ();
#line 113 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	self->priv->saved_search_branch = _tmp11_;
#line 114 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	self->priv->page_switching_enabled = TRUE;
#line 116 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp12_ = gee_hash_map_new (TYPE_PAGE, (GBoxedCopyFunc) g_object_ref, g_object_unref, SIDEBAR_TYPE_ENTRY, (GBoxedCopyFunc) g_object_ref, g_object_unref, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 116 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	self->priv->page_map = _tmp12_;
#line 118 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	self->priv->photo_page = NULL;
#line 123 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	self->priv->is_search_toolbar_visible = FALSE;
#line 128 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp13_ = search_filter_actions_new ();
#line 128 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	self->priv->search_actions = _tmp13_;
#line 131 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp14_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
#line 131 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_object_ref_sink (_tmp14_);
#line 131 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	self->priv->top_section = _tmp14_;
#line 132 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp15_ = (GtkFrame*) gtk_frame_new (NULL);
#line 132 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_object_ref_sink (_tmp15_);
#line 132 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	self->priv->background_progress_frame = _tmp15_;
#line 133 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp16_ = (GtkProgressBar*) gtk_progress_bar_new ();
#line 133 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_object_ref_sink (_tmp16_);
#line 133 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	self->priv->background_progress_bar = _tmp16_;
#line 134 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	self->priv->background_progress_displayed = FALSE;
#line 136 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp17_ = basic_properties_new ();
#line 136 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_object_ref_sink (_tmp17_);
#line 136 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	self->priv->basic_properties = _tmp17_;
#line 139 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp18_ = (GtkStack*) gtk_stack_new ();
#line 139 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_object_ref_sink (_tmp18_);
#line 139 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	self->priv->stack = _tmp18_;
#line 140 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp19_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
#line 140 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_object_ref_sink (_tmp19_);
#line 140 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	self->priv->layout = _tmp19_;
#line 143 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	self->priv->current_progress_priority = 0;
#line 144 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	self->priv->background_progress_pulse_id = (guint) 0;
#line 10717 "LibraryWindow.c"
}


static void library_window_finalize (GObject* obj) {
	LibraryWindow * self;
	SidebarTree* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
	SidebarTree* _tmp2_ = NULL;
	guint _tmp3_ = 0U;
	SidebarTree* _tmp4_ = NULL;
	guint _tmp5_ = 0U;
	SidebarTree* _tmp6_ = NULL;
	guint _tmp7_ = 0U;
	Page* _tmp8_ = NULL;
	Page* _tmp9_ = NULL;
	ExtendedPropertiesWindow* _tmp10_ = NULL;
	guint _tmp11_ = 0U;
	ExtendedPropertiesWindow* _tmp12_ = NULL;
	guint _tmp13_ = 0U;
	MetadataWriter* _tmp28_ = NULL;
	MetadataWriter* _tmp29_ = NULL;
	guint _tmp30_ = 0U;
	LibraryMonitor* monitor = NULL;
	LibraryMonitorPool* _tmp31_ = NULL;
	LibraryMonitorPool* _tmp32_ = NULL;
	LibraryMonitor* _tmp33_ = NULL;
	LibraryMonitor* _tmp34_ = NULL;
	LibraryMonitor* _tmp35_ = NULL;
	LibraryMonitorPool* _tmp37_ = NULL;
	LibraryMonitorPool* _tmp38_ = NULL;
	guint _tmp39_ = 0U;
	LibraryMonitorPool* _tmp40_ = NULL;
	LibraryMonitorPool* _tmp41_ = NULL;
	guint _tmp42_ = 0U;
	CameraTable* _tmp43_ = NULL;
	CameraTable* _tmp44_ = NULL;
	guint _tmp45_ = 0U;
#line 7 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_LIBRARY_WINDOW, LibraryWindow);
#line 231 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp0_ = self->priv->sidebar_tree;
#line 231 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_signal_parse_name ("page-created", SIDEBAR_TYPE_TREE, &_tmp1_, NULL, FALSE);
#line 231 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _library_window_on_page_created_sidebar_tree_page_created, self);
#line 232 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp2_ = self->priv->sidebar_tree;
#line 232 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_signal_parse_name ("destroying-page", SIDEBAR_TYPE_TREE, &_tmp3_, NULL, FALSE);
#line 232 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_signal_handlers_disconnect_matched (_tmp2_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _library_window_on_destroying_page_sidebar_tree_destroying_page, self);
#line 233 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp4_ = self->priv->sidebar_tree;
#line 233 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_signal_parse_name ("entry-selected", SIDEBAR_TYPE_TREE, &_tmp5_, NULL, FALSE);
#line 233 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_signal_handlers_disconnect_matched (_tmp4_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp5_, 0, NULL, (GCallback) _library_window_on_sidebar_entry_selected_sidebar_tree_entry_selected, self);
#line 234 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp6_ = self->priv->sidebar_tree;
#line 234 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_signal_parse_name ("selected-entry-removed", SIDEBAR_TYPE_TREE, &_tmp7_, NULL, FALSE);
#line 234 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_signal_handlers_disconnect_matched (_tmp6_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp7_, 0, NULL, (GCallback) _library_window_on_sidebar_selected_entry_removed_sidebar_tree_selected_entry_removed, self);
#line 236 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp8_ = page_window_get_current_page (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE_WINDOW, PageWindow));
#line 236 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp9_ = _tmp8_;
#line 236 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	library_window_unsubscribe_from_basic_information (self, _tmp9_);
#line 236 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (_tmp9_);
#line 238 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp10_ = self->priv->extended_properties;
#line 238 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_signal_parse_name ("hide", gtk_widget_get_type (), &_tmp11_, NULL, FALSE);
#line 238 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_signal_handlers_disconnect_matched (G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, gtk_widget_get_type (), GtkWidget), G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp11_, 0, NULL, (GCallback) _library_window_hide_extended_properties_gtk_widget_hide, self);
#line 239 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp12_ = self->priv->extended_properties;
#line 239 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_signal_parse_name ("show", gtk_widget_get_type (), &_tmp13_, NULL, FALSE);
#line 239 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_signal_handlers_disconnect_matched (G_TYPE_CHECK_INSTANCE_CAST (_tmp12_, gtk_widget_get_type (), GtkWidget), G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp13_, 0, NULL, (GCallback) _library_window_show_extended_properties_gtk_widget_show, self);
#line 10801 "LibraryWindow.c"
	{
		GeeIterator* _media_sources_it = NULL;
		MediaCollectionRegistry* _tmp14_ = NULL;
		MediaCollectionRegistry* _tmp15_ = NULL;
		GeeCollection* _tmp16_ = NULL;
		GeeCollection* _tmp17_ = NULL;
		GeeIterator* _tmp18_ = NULL;
		GeeIterator* _tmp19_ = NULL;
#line 241 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp14_ = media_collection_registry_get_instance ();
#line 241 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp15_ = _tmp14_;
#line 241 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp16_ = media_collection_registry_get_all (_tmp15_);
#line 241 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp17_ = _tmp16_;
#line 241 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp18_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp17_, GEE_TYPE_ITERABLE, GeeIterable));
#line 241 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp19_ = _tmp18_;
#line 241 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_object_unref0 (_tmp17_);
#line 241 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_media_collection_registry_unref0 (_tmp15_);
#line 241 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_media_sources_it = _tmp19_;
#line 241 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		while (TRUE) {
#line 10830 "LibraryWindow.c"
			GeeIterator* _tmp20_ = NULL;
			gboolean _tmp21_ = FALSE;
			MediaSourceCollection* media_sources = NULL;
			GeeIterator* _tmp22_ = NULL;
			gpointer _tmp23_ = NULL;
			MediaSourceCollection* _tmp24_ = NULL;
			guint _tmp25_ = 0U;
			MediaSourceCollection* _tmp26_ = NULL;
			guint _tmp27_ = 0U;
#line 241 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_tmp20_ = _media_sources_it;
#line 241 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_tmp21_ = gee_iterator_next (_tmp20_);
#line 241 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			if (!_tmp21_) {
#line 241 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
				break;
#line 10848 "LibraryWindow.c"
			}
#line 241 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_tmp22_ = _media_sources_it;
#line 241 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_tmp23_ = gee_iterator_get (_tmp22_);
#line 241 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			media_sources = (MediaSourceCollection*) _tmp23_;
#line 242 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_tmp24_ = media_sources;
#line 242 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			g_signal_parse_name ("trashcan-contents-altered", TYPE_MEDIA_SOURCE_COLLECTION, &_tmp25_, NULL, FALSE);
#line 242 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			g_signal_handlers_disconnect_matched (_tmp24_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp25_, 0, NULL, (GCallback) _library_window_on_trashcan_contents_altered_media_source_collection_trashcan_contents_altered, self);
#line 243 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_tmp26_ = media_sources;
#line 243 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			g_signal_parse_name ("items-altered", TYPE_DATA_COLLECTION, &_tmp27_, NULL, FALSE);
#line 243 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			g_signal_handlers_disconnect_matched (G_TYPE_CHECK_INSTANCE_CAST (_tmp26_, TYPE_DATA_COLLECTION, DataCollection), G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp27_, 0, NULL, (GCallback) _library_window_on_media_altered_data_collection_items_altered, self);
#line 241 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
			_data_collection_unref0 (media_sources);
#line 10870 "LibraryWindow.c"
		}
#line 241 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_g_object_unref0 (_media_sources_it);
#line 10874 "LibraryWindow.c"
	}
#line 246 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp28_ = metadata_writer_get_instance ();
#line 246 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp29_ = _tmp28_;
#line 246 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_signal_parse_name ("progress", TYPE_METADATA_WRITER, &_tmp30_, NULL, FALSE);
#line 246 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_signal_handlers_disconnect_matched (_tmp29_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp30_, 0, NULL, (GCallback) _library_window_on_metadata_writer_progress_metadata_writer_progress, self);
#line 246 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (_tmp29_);
#line 248 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp31_ = library_monitor_pool_get_instance ();
#line 248 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp32_ = _tmp31_;
#line 248 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp33_ = library_monitor_pool_get_monitor (_tmp32_);
#line 248 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp34_ = _tmp33_;
#line 248 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_library_monitor_pool_unref0 (_tmp32_);
#line 248 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	monitor = _tmp34_;
#line 249 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp35_ = monitor;
#line 249 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	if (_tmp35_ != NULL) {
#line 10902 "LibraryWindow.c"
		LibraryMonitor* _tmp36_ = NULL;
#line 250 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		_tmp36_ = monitor;
#line 250 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		library_window_on_library_monitor_destroyed (self, _tmp36_);
#line 10908 "LibraryWindow.c"
	}
#line 252 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp37_ = library_monitor_pool_get_instance ();
#line 252 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp38_ = _tmp37_;
#line 252 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_signal_parse_name ("monitor-installed", TYPE_LIBRARY_MONITOR_POOL, &_tmp39_, NULL, FALSE);
#line 252 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_signal_handlers_disconnect_matched (_tmp38_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp39_, 0, NULL, (GCallback) _library_window_on_library_monitor_installed_library_monitor_pool_monitor_installed, self);
#line 252 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_library_monitor_pool_unref0 (_tmp38_);
#line 253 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp40_ = library_monitor_pool_get_instance ();
#line 253 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp41_ = _tmp40_;
#line 253 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_signal_parse_name ("monitor-destroyed", TYPE_LIBRARY_MONITOR_POOL, &_tmp42_, NULL, FALSE);
#line 253 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_signal_handlers_disconnect_matched (_tmp41_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp42_, 0, NULL, (GCallback) _library_window_on_library_monitor_destroyed_library_monitor_pool_monitor_destroyed, self);
#line 253 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_library_monitor_pool_unref0 (_tmp41_);
#line 255 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp43_ = camera_table_get_instance ();
#line 255 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_tmp44_ = _tmp43_;
#line 255 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_signal_parse_name ("camera-added", TYPE_CAMERA_TABLE, &_tmp45_, NULL, FALSE);
#line 255 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	g_signal_handlers_disconnect_matched (_tmp44_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp45_, 0, NULL, (GCallback) _library_window_on_camera_added_camera_table_camera_added, self);
#line 255 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_camera_table_unref0 (_tmp44_);
#line 7 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (monitor);
#line 95 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_free0 (self->priv->import_dir);
#line 97 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (self->priv->sidebar_paned);
#line 98 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (self->priv->client_paned);
#line 99 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (self->priv->bottom_frame);
#line 101 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (self->priv->common_action_group);
#line 103 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_one_shot_scheduler_unref0 (self->priv->properties_scheduler);
#line 107 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (self->priv->sidebar_tree);
#line 108 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (self->priv->library_branch);
#line 109 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (self->priv->tags_branch);
#line 110 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (self->priv->folders_branch);
#line 111 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (self->priv->events_branch);
#line 112 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (self->priv->camera_branch);
#line 113 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (self->priv->saved_search_branch);
#line 116 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (self->priv->page_map);
#line 118 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (self->priv->photo_page);
#line 128 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_search_filter_actions_unref0 (self->priv->search_actions);
#line 129 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (self->priv->search_toolbar);
#line 131 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (self->priv->top_section);
#line 132 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (self->priv->background_progress_frame);
#line 133 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (self->priv->background_progress_bar);
#line 136 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (self->priv->basic_properties);
#line 137 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (self->priv->extended_properties);
#line 139 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (self->priv->stack);
#line 140 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (self->priv->layout);
#line 141 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	_g_object_unref0 (self->priv->right_vbox);
#line 7 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	G_OBJECT_CLASS (library_window_parent_class)->finalize (obj);
#line 10994 "LibraryWindow.c"
}


GType library_window_get_type (void) {
	static volatile gsize library_window_type_id__volatile = 0;
	if (g_once_init_enter (&library_window_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (LibraryWindowClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) library_window_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (LibraryWindow), 0, (GInstanceInitFunc) library_window_instance_init, NULL };
		GType library_window_type_id;
		library_window_type_id = g_type_register_static (TYPE_APP_WINDOW, "LibraryWindow", &g_define_type_info, 0);
		g_once_init_leave (&library_window_type_id__volatile, library_window_type_id);
	}
	return library_window_type_id__volatile;
}


static void _vala_library_window_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	LibraryWindow * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_LIBRARY_WINDOW, LibraryWindow);
#line 7 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
	switch (property_id) {
#line 11015 "LibraryWindow.c"
		default:
#line 7 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 7 "/home/jens/Source/shotwell/src/library/LibraryWindow.vala"
		break;
#line 11021 "LibraryWindow.c"
	}
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}


static gint _vala_array_length (gpointer array) {
	int length;
	length = 0;
	if (array) {
		while (((gpointer*) array)[length]) {
			length++;
		}
	}
	return length;
}



