/* TumblrPublishing.c generated by valac 0.32.1, the Vala compiler
 * generated from TumblrPublishing.vala, do not modify */

/* Copyright 2012 BJA Electronics
 * Author: Jeroen Arnoldus (b.j.arnoldus@bja-electronics.nl)
 *
 * This software is licensed under the GNU Lesser General Public License
 * (version 2.1 or later).  See the COPYING file in this distribution.
 */

#include <glib.h>
#include <glib-object.h>
#include <shotwell-plugin-dev-1.0.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <stdlib.h>
#include <string.h>
#include <gio/gio.h>
#include "shotwell-plugin-common.h"
#include <glib/gi18n-lib.h>
#include <gtk/gtk.h>
#include <json-glib/json-glib.h>
#include <gee.h>
#include <float.h>
#include <math.h>
#include <libsoup/soup.h>
#include <glib/gstdio.h>
#include <gobject/gvaluecollector.h>


#define TYPE_TUMBLR_SERVICE (tumblr_service_get_type ())
#define TUMBLR_SERVICE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_TUMBLR_SERVICE, TumblrService))
#define TUMBLR_SERVICE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_TUMBLR_SERVICE, TumblrServiceClass))
#define IS_TUMBLR_SERVICE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_TUMBLR_SERVICE))
#define IS_TUMBLR_SERVICE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_TUMBLR_SERVICE))
#define TUMBLR_SERVICE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_TUMBLR_SERVICE, TumblrServiceClass))

typedef struct _TumblrService TumblrService;
typedef struct _TumblrServiceClass TumblrServiceClass;
typedef struct _TumblrServicePrivate TumblrServicePrivate;
#define _g_free0(var) (var = (g_free (var), NULL))

#define PUBLISHING_TUMBLR_TYPE_TUMBLR_PUBLISHER (publishing_tumblr_tumblr_publisher_get_type ())
#define PUBLISHING_TUMBLR_TUMBLR_PUBLISHER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_TUMBLR_TYPE_TUMBLR_PUBLISHER, PublishingTumblrTumblrPublisher))
#define PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_TUMBLR_TYPE_TUMBLR_PUBLISHER, PublishingTumblrTumblrPublisherClass))
#define PUBLISHING_TUMBLR_IS_TUMBLR_PUBLISHER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_TUMBLR_TYPE_TUMBLR_PUBLISHER))
#define PUBLISHING_TUMBLR_IS_TUMBLR_PUBLISHER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_TUMBLR_TYPE_TUMBLR_PUBLISHER))
#define PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_TUMBLR_TYPE_TUMBLR_PUBLISHER, PublishingTumblrTumblrPublisherClass))

typedef struct _PublishingTumblrTumblrPublisher PublishingTumblrTumblrPublisher;
typedef struct _PublishingTumblrTumblrPublisherClass PublishingTumblrTumblrPublisherClass;

#define PUBLISHING_TUMBLR_TYPE_BLOG_ENTRY (publishing_tumblr_blog_entry_get_type ())
#define PUBLISHING_TUMBLR_BLOG_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_TUMBLR_TYPE_BLOG_ENTRY, PublishingTumblrBlogEntry))
#define PUBLISHING_TUMBLR_BLOG_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_TUMBLR_TYPE_BLOG_ENTRY, PublishingTumblrBlogEntryClass))
#define PUBLISHING_TUMBLR_IS_BLOG_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_TUMBLR_TYPE_BLOG_ENTRY))
#define PUBLISHING_TUMBLR_IS_BLOG_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_TUMBLR_TYPE_BLOG_ENTRY))
#define PUBLISHING_TUMBLR_BLOG_ENTRY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_TUMBLR_TYPE_BLOG_ENTRY, PublishingTumblrBlogEntryClass))

typedef struct _PublishingTumblrBlogEntry PublishingTumblrBlogEntry;
typedef struct _PublishingTumblrBlogEntryClass PublishingTumblrBlogEntryClass;
typedef struct _PublishingTumblrBlogEntryPrivate PublishingTumblrBlogEntryPrivate;
typedef struct _PublishingTumblrParamSpecBlogEntry PublishingTumblrParamSpecBlogEntry;

#define PUBLISHING_TUMBLR_TYPE_SIZE_ENTRY (publishing_tumblr_size_entry_get_type ())
#define PUBLISHING_TUMBLR_SIZE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_TUMBLR_TYPE_SIZE_ENTRY, PublishingTumblrSizeEntry))
#define PUBLISHING_TUMBLR_SIZE_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_TUMBLR_TYPE_SIZE_ENTRY, PublishingTumblrSizeEntryClass))
#define PUBLISHING_TUMBLR_IS_SIZE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_TUMBLR_TYPE_SIZE_ENTRY))
#define PUBLISHING_TUMBLR_IS_SIZE_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_TUMBLR_TYPE_SIZE_ENTRY))
#define PUBLISHING_TUMBLR_SIZE_ENTRY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_TUMBLR_TYPE_SIZE_ENTRY, PublishingTumblrSizeEntryClass))

typedef struct _PublishingTumblrSizeEntry PublishingTumblrSizeEntry;
typedef struct _PublishingTumblrSizeEntryClass PublishingTumblrSizeEntryClass;
typedef struct _PublishingTumblrSizeEntryPrivate PublishingTumblrSizeEntryPrivate;
typedef struct _PublishingTumblrParamSpecSizeEntry PublishingTumblrParamSpecSizeEntry;
typedef struct _PublishingTumblrTumblrPublisherPrivate PublishingTumblrTumblrPublisherPrivate;

#define PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_SESSION (publishing_tumblr_tumblr_publisher_session_get_type ())
#define PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_SESSION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_SESSION, PublishingTumblrTumblrPublisherSession))
#define PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_SESSION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_SESSION, PublishingTumblrTumblrPublisherSessionClass))
#define PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_IS_SESSION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_SESSION))
#define PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_IS_SESSION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_SESSION))
#define PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_SESSION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_SESSION, PublishingTumblrTumblrPublisherSessionClass))

typedef struct _PublishingTumblrTumblrPublisherSession PublishingTumblrTumblrPublisherSession;
typedef struct _PublishingTumblrTumblrPublisherSessionClass PublishingTumblrTumblrPublisherSessionClass;

#define PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_PUBLISHING_OPTIONS_PANE (publishing_tumblr_tumblr_publisher_publishing_options_pane_get_type ())
#define PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_PUBLISHING_OPTIONS_PANE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_PUBLISHING_OPTIONS_PANE, PublishingTumblrTumblrPublisherPublishingOptionsPane))
#define PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_PUBLISHING_OPTIONS_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_PUBLISHING_OPTIONS_PANE, PublishingTumblrTumblrPublisherPublishingOptionsPaneClass))
#define PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_IS_PUBLISHING_OPTIONS_PANE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_PUBLISHING_OPTIONS_PANE))
#define PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_IS_PUBLISHING_OPTIONS_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_PUBLISHING_OPTIONS_PANE))
#define PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_PUBLISHING_OPTIONS_PANE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_PUBLISHING_OPTIONS_PANE, PublishingTumblrTumblrPublisherPublishingOptionsPaneClass))

typedef struct _PublishingTumblrTumblrPublisherPublishingOptionsPane PublishingTumblrTumblrPublisherPublishingOptionsPane;
typedef struct _PublishingTumblrTumblrPublisherPublishingOptionsPaneClass PublishingTumblrTumblrPublisherPublishingOptionsPaneClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _publishing_rest_support_session_unref0(var) ((var == NULL) ? NULL : (var = (publishing_rest_support_session_unref (var), NULL)))

#define PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_AUTHENTICATION_PANE_TYPE_MODE (publishing_tumblr_tumblr_publisher_authentication_pane_mode_get_type ())

#define PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_AUTHENTICATION_PANE (publishing_tumblr_tumblr_publisher_authentication_pane_get_type ())
#define PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_AUTHENTICATION_PANE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_AUTHENTICATION_PANE, PublishingTumblrTumblrPublisherAuthenticationPane))
#define PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_AUTHENTICATION_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_AUTHENTICATION_PANE, PublishingTumblrTumblrPublisherAuthenticationPaneClass))
#define PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_IS_AUTHENTICATION_PANE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_AUTHENTICATION_PANE))
#define PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_IS_AUTHENTICATION_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_AUTHENTICATION_PANE))
#define PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_AUTHENTICATION_PANE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_AUTHENTICATION_PANE, PublishingTumblrTumblrPublisherAuthenticationPaneClass))

typedef struct _PublishingTumblrTumblrPublisherAuthenticationPane PublishingTumblrTumblrPublisherAuthenticationPane;
typedef struct _PublishingTumblrTumblrPublisherAuthenticationPaneClass PublishingTumblrTumblrPublisherAuthenticationPaneClass;

#define PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_TRANSACTION (publishing_tumblr_tumblr_publisher_transaction_get_type ())
#define PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_TRANSACTION, PublishingTumblrTumblrPublisherTransaction))
#define PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_TRANSACTION, PublishingTumblrTumblrPublisherTransactionClass))
#define PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_IS_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_TRANSACTION))
#define PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_IS_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_TRANSACTION))
#define PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TRANSACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_TRANSACTION, PublishingTumblrTumblrPublisherTransactionClass))

typedef struct _PublishingTumblrTumblrPublisherTransaction PublishingTumblrTumblrPublisherTransaction;
typedef struct _PublishingTumblrTumblrPublisherTransactionClass PublishingTumblrTumblrPublisherTransactionClass;

#define PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_ACCESS_TOKEN_FETCH_TRANSACTION (publishing_tumblr_tumblr_publisher_access_token_fetch_transaction_get_type ())
#define PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_ACCESS_TOKEN_FETCH_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_ACCESS_TOKEN_FETCH_TRANSACTION, PublishingTumblrTumblrPublisherAccessTokenFetchTransaction))
#define PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_ACCESS_TOKEN_FETCH_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_ACCESS_TOKEN_FETCH_TRANSACTION, PublishingTumblrTumblrPublisherAccessTokenFetchTransactionClass))
#define PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_IS_ACCESS_TOKEN_FETCH_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_ACCESS_TOKEN_FETCH_TRANSACTION))
#define PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_IS_ACCESS_TOKEN_FETCH_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_ACCESS_TOKEN_FETCH_TRANSACTION))
#define PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_ACCESS_TOKEN_FETCH_TRANSACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_ACCESS_TOKEN_FETCH_TRANSACTION, PublishingTumblrTumblrPublisherAccessTokenFetchTransactionClass))

typedef struct _PublishingTumblrTumblrPublisherAccessTokenFetchTransaction PublishingTumblrTumblrPublisherAccessTokenFetchTransaction;
typedef struct _PublishingTumblrTumblrPublisherAccessTokenFetchTransactionClass PublishingTumblrTumblrPublisherAccessTokenFetchTransactionClass;
#define _publishing_rest_support_transaction_unref0(var) ((var == NULL) ? NULL : (var = (publishing_rest_support_transaction_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))

#define PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_USER_INFO_FETCH_TRANSACTION (publishing_tumblr_tumblr_publisher_user_info_fetch_transaction_get_type ())
#define PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_USER_INFO_FETCH_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_USER_INFO_FETCH_TRANSACTION, PublishingTumblrTumblrPublisherUserInfoFetchTransaction))
#define PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_USER_INFO_FETCH_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_USER_INFO_FETCH_TRANSACTION, PublishingTumblrTumblrPublisherUserInfoFetchTransactionClass))
#define PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_IS_USER_INFO_FETCH_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_USER_INFO_FETCH_TRANSACTION))
#define PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_IS_USER_INFO_FETCH_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_USER_INFO_FETCH_TRANSACTION))
#define PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_USER_INFO_FETCH_TRANSACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_USER_INFO_FETCH_TRANSACTION, PublishingTumblrTumblrPublisherUserInfoFetchTransactionClass))

typedef struct _PublishingTumblrTumblrPublisherUserInfoFetchTransaction PublishingTumblrTumblrPublisherUserInfoFetchTransaction;
typedef struct _PublishingTumblrTumblrPublisherUserInfoFetchTransactionClass PublishingTumblrTumblrPublisherUserInfoFetchTransactionClass;
#define _g_regex_unref0(var) ((var == NULL) ? NULL : (var = (g_regex_unref (var), NULL)))
#define _json_object_unref0(var) ((var == NULL) ? NULL : (var = (json_object_unref (var), NULL)))
#define _g_list_free0(var) ((var == NULL) ? NULL : (var = (g_list_free (var), NULL)))
#define _g_date_time_unref0(var) ((var == NULL) ? NULL : (var = (g_date_time_unref (var), NULL)))

#define PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_UPLOADER (publishing_tumblr_tumblr_publisher_uploader_get_type ())
#define PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_UPLOADER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_UPLOADER, PublishingTumblrTumblrPublisherUploader))
#define PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_UPLOADER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_UPLOADER, PublishingTumblrTumblrPublisherUploaderClass))
#define PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_IS_UPLOADER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_UPLOADER))
#define PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_IS_UPLOADER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_UPLOADER))
#define PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_UPLOADER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_UPLOADER, PublishingTumblrTumblrPublisherUploaderClass))

typedef struct _PublishingTumblrTumblrPublisherUploader PublishingTumblrTumblrPublisherUploader;
typedef struct _PublishingTumblrTumblrPublisherUploaderClass PublishingTumblrTumblrPublisherUploaderClass;
#define _publishing_rest_support_batch_uploader_unref0(var) ((var == NULL) ? NULL : (var = (publishing_rest_support_batch_uploader_unref (var), NULL)))
typedef struct _PublishingTumblrTumblrPublisherAuthenticationPanePrivate PublishingTumblrTumblrPublisherAuthenticationPanePrivate;
typedef struct _PublishingTumblrTumblrPublisherPublishingOptionsPanePrivate PublishingTumblrTumblrPublisherPublishingOptionsPanePrivate;
#define _publishing_tumblr_blog_entry_unref0(var) ((var == NULL) ? NULL : (var = (publishing_tumblr_blog_entry_unref (var), NULL)))
#define _publishing_tumblr_size_entry_unref0(var) ((var == NULL) ? NULL : (var = (publishing_tumblr_size_entry_unref (var), NULL)))
typedef struct _PublishingTumblrTumblrPublisherTransactionPrivate PublishingTumblrTumblrPublisherTransactionPrivate;
typedef struct _PublishingTumblrTumblrPublisherAccessTokenFetchTransactionPrivate PublishingTumblrTumblrPublisherAccessTokenFetchTransactionPrivate;
typedef struct _PublishingTumblrTumblrPublisherUserInfoFetchTransactionPrivate PublishingTumblrTumblrPublisherUserInfoFetchTransactionPrivate;

#define PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_UPLOAD_TRANSACTION (publishing_tumblr_tumblr_publisher_upload_transaction_get_type ())
#define PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_UPLOAD_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_UPLOAD_TRANSACTION, PublishingTumblrTumblrPublisherUploadTransaction))
#define PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_UPLOAD_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_UPLOAD_TRANSACTION, PublishingTumblrTumblrPublisherUploadTransactionClass))
#define PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_IS_UPLOAD_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_UPLOAD_TRANSACTION))
#define PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_IS_UPLOAD_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_UPLOAD_TRANSACTION))
#define PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_UPLOAD_TRANSACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_UPLOAD_TRANSACTION, PublishingTumblrTumblrPublisherUploadTransactionClass))

typedef struct _PublishingTumblrTumblrPublisherUploadTransaction PublishingTumblrTumblrPublisherUploadTransaction;
typedef struct _PublishingTumblrTumblrPublisherUploadTransactionClass PublishingTumblrTumblrPublisherUploadTransactionClass;
typedef struct _PublishingTumblrTumblrPublisherUploadTransactionPrivate PublishingTumblrTumblrPublisherUploadTransactionPrivate;
#define _g_string_free0(var) ((var == NULL) ? NULL : (var = (g_string_free (var, TRUE), NULL)))
typedef struct _PublishingTumblrTumblrPublisherUploaderPrivate PublishingTumblrTumblrPublisherUploaderPrivate;
typedef struct _PublishingTumblrTumblrPublisherSessionPrivate PublishingTumblrTumblrPublisherSessionPrivate;
#define _publishing_rest_support_argument_unref0(var) ((var == NULL) ? NULL : (var = (publishing_rest_support_argument_unref (var), NULL)))
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _TumblrService {
	GObject parent_instance;
	TumblrServicePrivate * priv;
};

struct _TumblrServiceClass {
	GObjectClass parent_class;
};

struct _PublishingTumblrBlogEntry {
	GTypeInstance parent_instance;
	volatile int ref_count;
	PublishingTumblrBlogEntryPrivate * priv;
	gchar* blog;
	gchar* url;
};

struct _PublishingTumblrBlogEntryClass {
	GTypeClass parent_class;
	void (*finalize) (PublishingTumblrBlogEntry *self);
};

struct _PublishingTumblrParamSpecBlogEntry {
	GParamSpec parent_instance;
};

struct _PublishingTumblrSizeEntry {
	GTypeInstance parent_instance;
	volatile int ref_count;
	PublishingTumblrSizeEntryPrivate * priv;
	gchar* title;
	gint size;
};

struct _PublishingTumblrSizeEntryClass {
	GTypeClass parent_class;
	void (*finalize) (PublishingTumblrSizeEntry *self);
};

struct _PublishingTumblrParamSpecSizeEntry {
	GParamSpec parent_instance;
};

struct _PublishingTumblrTumblrPublisher {
	GObject parent_instance;
	PublishingTumblrTumblrPublisherPrivate * priv;
};

struct _PublishingTumblrTumblrPublisherClass {
	GObjectClass parent_class;
};

struct _PublishingTumblrTumblrPublisherPrivate {
	SpitPublishingService* service;
	SpitPublishingPluginHost* host;
	SpitPublishingProgressCallback progress_reporter;
	gpointer progress_reporter_target;
	GDestroyNotify progress_reporter_target_destroy_notify;
	gboolean running;
	gboolean was_started;
	PublishingTumblrTumblrPublisherSession* session;
	PublishingTumblrTumblrPublisherPublishingOptionsPane* publishing_options_pane;
	PublishingTumblrSizeEntry** sizes;
	gint sizes_length1;
	gint _sizes_size_;
	PublishingTumblrBlogEntry** blogs;
	gint blogs_length1;
	gint _blogs_size_;
	gchar* username;
};

typedef enum  {
	PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_AUTHENTICATION_PANE_MODE_INTRO,
	PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_AUTHENTICATION_PANE_MODE_FAILED_RETRY_USER
} PublishingTumblrTumblrPublisherAuthenticationPaneMode;

struct _PublishingTumblrTumblrPublisherAuthenticationPane {
	GObject parent_instance;
	PublishingTumblrTumblrPublisherAuthenticationPanePrivate * priv;
};

struct _PublishingTumblrTumblrPublisherAuthenticationPaneClass {
	GObjectClass parent_class;
};

struct _PublishingTumblrTumblrPublisherAuthenticationPanePrivate {
	GtkBox* pane_widget;
	GtkBuilder* builder;
	GtkEntry* username_entry;
	GtkEntry* password_entry;
	GtkButton* login_button;
};

struct _PublishingTumblrTumblrPublisherPublishingOptionsPane {
	GObject parent_instance;
	PublishingTumblrTumblrPublisherPublishingOptionsPanePrivate * priv;
};

struct _PublishingTumblrTumblrPublisherPublishingOptionsPaneClass {
	GObjectClass parent_class;
};

struct _PublishingTumblrTumblrPublisherPublishingOptionsPanePrivate {
	GtkBuilder* builder;
	GtkBox* pane_widget;
	GtkLabel* upload_info_label;
	GtkLabel* size_label;
	GtkLabel* blog_label;
	GtkButton* logout_button;
	GtkButton* publish_button;
	GtkComboBoxText* size_combo;
	GtkComboBoxText* blog_combo;
	PublishingTumblrSizeEntry** sizes;
	gint sizes_length1;
	gint _sizes_size_;
	PublishingTumblrBlogEntry** blogs;
	gint blogs_length1;
	gint _blogs_size_;
	gchar* username;
	PublishingTumblrTumblrPublisher* publisher;
	SpitPublishingPublisherMediaType media_type;
};

struct _PublishingTumblrTumblrPublisherTransaction {
	PublishingRESTSupportTransaction parent_instance;
	PublishingTumblrTumblrPublisherTransactionPrivate * priv;
};

struct _PublishingTumblrTumblrPublisherTransactionClass {
	PublishingRESTSupportTransactionClass parent_class;
};

struct _PublishingTumblrTumblrPublisherAccessTokenFetchTransaction {
	PublishingTumblrTumblrPublisherTransaction parent_instance;
	PublishingTumblrTumblrPublisherAccessTokenFetchTransactionPrivate * priv;
};

struct _PublishingTumblrTumblrPublisherAccessTokenFetchTransactionClass {
	PublishingTumblrTumblrPublisherTransactionClass parent_class;
};

struct _PublishingTumblrTumblrPublisherUserInfoFetchTransaction {
	PublishingTumblrTumblrPublisherTransaction parent_instance;
	PublishingTumblrTumblrPublisherUserInfoFetchTransactionPrivate * priv;
};

struct _PublishingTumblrTumblrPublisherUserInfoFetchTransactionClass {
	PublishingTumblrTumblrPublisherTransactionClass parent_class;
};

struct _PublishingTumblrTumblrPublisherUploadTransaction {
	PublishingRESTSupportUploadTransaction parent_instance;
	PublishingTumblrTumblrPublisherUploadTransactionPrivate * priv;
};

struct _PublishingTumblrTumblrPublisherUploadTransactionClass {
	PublishingRESTSupportUploadTransactionClass parent_class;
};

struct _PublishingTumblrTumblrPublisherUploadTransactionPrivate {
	PublishingTumblrTumblrPublisherSession* session;
	PublishingRESTSupportArgument** auth_header_fields;
	gint auth_header_fields_length1;
	gint _auth_header_fields_size_;
};

struct _PublishingTumblrTumblrPublisherUploader {
	PublishingRESTSupportBatchUploader parent_instance;
	PublishingTumblrTumblrPublisherUploaderPrivate * priv;
};

struct _PublishingTumblrTumblrPublisherUploaderClass {
	PublishingRESTSupportBatchUploaderClass parent_class;
};

struct _PublishingTumblrTumblrPublisherUploaderPrivate {
	gchar* blog_url;
};

struct _PublishingTumblrTumblrPublisherSession {
	PublishingRESTSupportSession parent_instance;
	PublishingTumblrTumblrPublisherSessionPrivate * priv;
};

struct _PublishingTumblrTumblrPublisherSessionClass {
	PublishingRESTSupportSessionClass parent_class;
};

struct _PublishingTumblrTumblrPublisherSessionPrivate {
	gchar* access_phase_token;
	gchar* access_phase_token_secret;
};


static gpointer tumblr_service_parent_class = NULL;
static GdkPixbuf** tumblr_service_icon_pixbuf_set;
static gint tumblr_service_icon_pixbuf_set_length1;
static GdkPixbuf** tumblr_service_icon_pixbuf_set = NULL;
static gint tumblr_service_icon_pixbuf_set_length1 = 0;
static gint _tumblr_service_icon_pixbuf_set_size_ = 0;
static SpitPluggableIface* tumblr_service_spit_pluggable_parent_iface = NULL;
static SpitPublishingServiceIface* tumblr_service_spit_publishing_service_parent_iface = NULL;
static gpointer publishing_tumblr_blog_entry_parent_class = NULL;
static gpointer publishing_tumblr_size_entry_parent_class = NULL;
static gpointer publishing_tumblr_tumblr_publisher_parent_class = NULL;
static gpointer publishing_tumblr_tumblr_publisher_authentication_pane_parent_class = NULL;
static gchar* publishing_tumblr_tumblr_publisher_authentication_pane_INTRO_MESSAGE;
static gchar* publishing_tumblr_tumblr_publisher_authentication_pane_INTRO_MESSAGE = NULL;
static gchar* publishing_tumblr_tumblr_publisher_authentication_pane_FAILED_RETRY_USER_MESSAGE;
static gchar* publishing_tumblr_tumblr_publisher_authentication_pane_FAILED_RETRY_USER_MESSAGE = NULL;
static SpitPublishingDialogPaneIface* publishing_tumblr_tumblr_publisher_authentication_pane_spit_publishing_dialog_pane_parent_iface = NULL;
static gpointer publishing_tumblr_tumblr_publisher_publishing_options_pane_parent_class = NULL;
static SpitPublishingDialogPaneIface* publishing_tumblr_tumblr_publisher_publishing_options_pane_spit_publishing_dialog_pane_parent_iface = NULL;
static gpointer publishing_tumblr_tumblr_publisher_transaction_parent_class = NULL;
static gpointer publishing_tumblr_tumblr_publisher_access_token_fetch_transaction_parent_class = NULL;
static gpointer publishing_tumblr_tumblr_publisher_user_info_fetch_transaction_parent_class = NULL;
static gpointer publishing_tumblr_tumblr_publisher_upload_transaction_parent_class = NULL;
static gpointer publishing_tumblr_tumblr_publisher_uploader_parent_class = NULL;
static gpointer publishing_tumblr_tumblr_publisher_session_parent_class = NULL;
static SpitPublishingPublisherIface* publishing_tumblr_tumblr_publisher_spit_publishing_publisher_parent_iface = NULL;

GType tumblr_service_get_type (void) G_GNUC_CONST;
enum  {
	TUMBLR_SERVICE_DUMMY_PROPERTY
};
#define TUMBLR_SERVICE_ICON_FILENAME "tumblr.png"
TumblrService* tumblr_service_new (GFile* resource_directory);
TumblrService* tumblr_service_construct (GType object_type, GFile* resource_directory);
static gint tumblr_service_real_get_pluggable_interface (SpitPluggable* base, gint min_host_interface, gint max_host_interface);
static const gchar* tumblr_service_real_get_id (SpitPluggable* base);
static const gchar* tumblr_service_real_get_pluggable_name (SpitPluggable* base);
static void tumblr_service_real_get_info (SpitPluggable* base, SpitPluggableInfo* info);
static GdkPixbuf** _vala_array_dup6 (GdkPixbuf** self, int length);
static void tumblr_service_real_activation (SpitPluggable* base, gboolean enabled);
static SpitPublishingPublisher* tumblr_service_real_create_publisher (SpitPublishingService* base, SpitPublishingPluginHost* host);
PublishingTumblrTumblrPublisher* publishing_tumblr_tumblr_publisher_new (SpitPublishingService* service, SpitPublishingPluginHost* host);
PublishingTumblrTumblrPublisher* publishing_tumblr_tumblr_publisher_construct (GType object_type, SpitPublishingService* service, SpitPublishingPluginHost* host);
GType publishing_tumblr_tumblr_publisher_get_type (void) G_GNUC_CONST;
static SpitPublishingPublisherMediaType tumblr_service_real_get_supported_media (SpitPublishingService* base);
static void tumblr_service_finalize (GObject* obj);
#define PUBLISHING_TUMBLR_SERVICE_NAME "Tumblr"
#define PUBLISHING_TUMBLR_ENDPOINT_URL "http://www.tumblr.com/"
#define PUBLISHING_TUMBLR_API_KEY "NdXvXQuKVccOsCOj0H4k9HUJcbcjDBYSo2AkaHzXFECHGNuP9k"
#define PUBLISHING_TUMBLR_API_SECRET "BN0Uoig0MwbeD27OgA0IwYlp3Uvonyfsrl9pf1cnnMj1QoEUvi"
#define PUBLISHING_TUMBLR_ENCODE_RFC_3986_EXTRA "!*'();:@&=+$,/?%#[] \\"
#define PUBLISHING_TUMBLR_ORIGINAL_SIZE -1
gpointer publishing_tumblr_blog_entry_ref (gpointer instance);
void publishing_tumblr_blog_entry_unref (gpointer instance);
GParamSpec* publishing_tumblr_param_spec_blog_entry (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void publishing_tumblr_value_set_blog_entry (GValue* value, gpointer v_object);
void publishing_tumblr_value_take_blog_entry (GValue* value, gpointer v_object);
gpointer publishing_tumblr_value_get_blog_entry (const GValue* value);
GType publishing_tumblr_blog_entry_get_type (void) G_GNUC_CONST;
enum  {
	PUBLISHING_TUMBLR_BLOG_ENTRY_DUMMY_PROPERTY
};
PublishingTumblrBlogEntry* publishing_tumblr_blog_entry_new (const gchar* creator_blog, const gchar* creator_url);
PublishingTumblrBlogEntry* publishing_tumblr_blog_entry_construct (GType object_type, const gchar* creator_blog, const gchar* creator_url);
static void publishing_tumblr_blog_entry_finalize (PublishingTumblrBlogEntry* obj);
gpointer publishing_tumblr_size_entry_ref (gpointer instance);
void publishing_tumblr_size_entry_unref (gpointer instance);
GParamSpec* publishing_tumblr_param_spec_size_entry (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void publishing_tumblr_value_set_size_entry (GValue* value, gpointer v_object);
void publishing_tumblr_value_take_size_entry (GValue* value, gpointer v_object);
gpointer publishing_tumblr_value_get_size_entry (const GValue* value);
GType publishing_tumblr_size_entry_get_type (void) G_GNUC_CONST;
enum  {
	PUBLISHING_TUMBLR_SIZE_ENTRY_DUMMY_PROPERTY
};
PublishingTumblrSizeEntry* publishing_tumblr_size_entry_new (const gchar* creator_title, gint creator_size);
PublishingTumblrSizeEntry* publishing_tumblr_size_entry_construct (GType object_type, const gchar* creator_title, gint creator_size);
static void publishing_tumblr_size_entry_finalize (PublishingTumblrSizeEntry* obj);
GType publishing_tumblr_tumblr_publisher_session_get_type (void) G_GNUC_CONST;
GType publishing_tumblr_tumblr_publisher_publishing_options_pane_get_type (void) G_GNUC_CONST;
#define PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_TUMBLR_TYPE_TUMBLR_PUBLISHER, PublishingTumblrTumblrPublisherPrivate))
enum  {
	PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_DUMMY_PROPERTY
};
static void publishing_tumblr_tumblr_publisher_on_session_authenticated (PublishingTumblrTumblrPublisher* self);
static void _publishing_tumblr_tumblr_publisher_on_session_authenticated_publishing_rest_support_session_authenticated (PublishingRESTSupportSession* _sender, gpointer self);
static PublishingTumblrSizeEntry** publishing_tumblr_tumblr_publisher_create_sizes (PublishingTumblrTumblrPublisher* self, int* result_length1);
static void _vala_array_add18 (PublishingTumblrSizeEntry*** array, int* length, int* size, PublishingTumblrSizeEntry* value);
static void _vala_array_add19 (PublishingTumblrSizeEntry*** array, int* length, int* size, PublishingTumblrSizeEntry* value);
static void _vala_array_add20 (PublishingTumblrSizeEntry*** array, int* length, int* size, PublishingTumblrSizeEntry* value);
static PublishingTumblrBlogEntry** publishing_tumblr_tumblr_publisher_create_blogs (PublishingTumblrTumblrPublisher* self, int* result_length1);
PublishingTumblrTumblrPublisherSession* publishing_tumblr_tumblr_publisher_session_new (void);
PublishingTumblrTumblrPublisherSession* publishing_tumblr_tumblr_publisher_session_construct (GType object_type);
static void publishing_tumblr_tumblr_publisher_invalidate_persistent_session (PublishingTumblrTumblrPublisher* self);
static void publishing_tumblr_tumblr_publisher_set_persistent_access_phase_token (PublishingTumblrTumblrPublisher* self, const gchar* token);
static void publishing_tumblr_tumblr_publisher_set_persistent_access_phase_token_secret (PublishingTumblrTumblrPublisher* self, const gchar* token_secret);
static SpitPublishingService* publishing_tumblr_tumblr_publisher_real_get_service (SpitPublishingPublisher* base);
SpitPublishingPluginHost* publishing_tumblr_tumblr_publisher_get_host (PublishingTumblrTumblrPublisher* self);
static gboolean publishing_tumblr_tumblr_publisher_real_is_running (SpitPublishingPublisher* base);
static gboolean publishing_tumblr_tumblr_publisher_is_persistent_session_valid (PublishingTumblrTumblrPublisher* self);
gchar* publishing_tumblr_tumblr_publisher_get_persistent_access_phase_token (PublishingTumblrTumblrPublisher* self);
gchar* publishing_tumblr_tumblr_publisher_get_persistent_access_phase_token_secret (PublishingTumblrTumblrPublisher* self);
gint publishing_tumblr_tumblr_publisher_get_persistent_default_size (PublishingTumblrTumblrPublisher* self);
void publishing_tumblr_tumblr_publisher_set_persistent_default_size (PublishingTumblrTumblrPublisher* self, gint size);
gint publishing_tumblr_tumblr_publisher_get_persistent_default_blog (PublishingTumblrTumblrPublisher* self);
void publishing_tumblr_tumblr_publisher_set_persistent_default_blog (PublishingTumblrTumblrPublisher* self, gint blog);
GType publishing_tumblr_tumblr_publisher_authentication_pane_mode_get_type (void) G_GNUC_CONST;
static void publishing_tumblr_tumblr_publisher_do_show_authentication_pane (PublishingTumblrTumblrPublisher* self, PublishingTumblrTumblrPublisherAuthenticationPaneMode mode);
GType publishing_tumblr_tumblr_publisher_authentication_pane_get_type (void) G_GNUC_CONST;
PublishingTumblrTumblrPublisherAuthenticationPane* publishing_tumblr_tumblr_publisher_authentication_pane_new (PublishingTumblrTumblrPublisher* publisher, PublishingTumblrTumblrPublisherAuthenticationPaneMode mode);
PublishingTumblrTumblrPublisherAuthenticationPane* publishing_tumblr_tumblr_publisher_authentication_pane_construct (GType object_type, PublishingTumblrTumblrPublisher* publisher, PublishingTumblrTumblrPublisherAuthenticationPaneMode mode);
static void publishing_tumblr_tumblr_publisher_on_authentication_pane_login_clicked (PublishingTumblrTumblrPublisher* self, const gchar* username, const gchar* password);
static void _publishing_tumblr_tumblr_publisher_on_authentication_pane_login_clicked_publishing_tumblr_tumblr_publisher_authentication_pane_login (PublishingTumblrTumblrPublisherAuthenticationPane* _sender, const gchar* user, const gchar* password, gpointer self);
GtkWidget* publishing_tumblr_tumblr_publisher_authentication_pane_get_default_widget (PublishingTumblrTumblrPublisherAuthenticationPane* self);
static void publishing_tumblr_tumblr_publisher_do_network_login (PublishingTumblrTumblrPublisher* self, const gchar* username, const gchar* password);
GType publishing_tumblr_tumblr_publisher_transaction_get_type (void) G_GNUC_CONST;
GType publishing_tumblr_tumblr_publisher_access_token_fetch_transaction_get_type (void) G_GNUC_CONST;
PublishingTumblrTumblrPublisherAccessTokenFetchTransaction* publishing_tumblr_tumblr_publisher_access_token_fetch_transaction_new (PublishingTumblrTumblrPublisherSession* session, const gchar* username, const gchar* password);
PublishingTumblrTumblrPublisherAccessTokenFetchTransaction* publishing_tumblr_tumblr_publisher_access_token_fetch_transaction_construct (GType object_type, PublishingTumblrTumblrPublisherSession* session, const gchar* username, const gchar* password);
static void publishing_tumblr_tumblr_publisher_on_auth_request_txn_completed (PublishingTumblrTumblrPublisher* self, PublishingRESTSupportTransaction* txn);
static void _publishing_tumblr_tumblr_publisher_on_auth_request_txn_completed_publishing_rest_support_transaction_completed (PublishingRESTSupportTransaction* _sender, gpointer self);
static void publishing_tumblr_tumblr_publisher_on_auth_request_txn_error (PublishingTumblrTumblrPublisher* self, PublishingRESTSupportTransaction* txn, GError* err);
static void _publishing_tumblr_tumblr_publisher_on_auth_request_txn_error_publishing_rest_support_transaction_network_error (PublishingRESTSupportTransaction* _sender, GError* err, gpointer self);
static void publishing_tumblr_tumblr_publisher_do_parse_token_info_from_auth_request (PublishingTumblrTumblrPublisher* self, const gchar* response);
void publishing_tumblr_tumblr_publisher_session_set_access_phase_credentials (PublishingTumblrTumblrPublisherSession* self, const gchar* token, const gchar* secret);
gchar* publishing_tumblr_tumblr_publisher_session_get_access_phase_token (PublishingTumblrTumblrPublisherSession* self);
gchar* publishing_tumblr_tumblr_publisher_session_get_access_phase_token_secret (PublishingTumblrTumblrPublisherSession* self);
static void publishing_tumblr_tumblr_publisher_do_get_blogs (PublishingTumblrTumblrPublisher* self);
GType publishing_tumblr_tumblr_publisher_user_info_fetch_transaction_get_type (void) G_GNUC_CONST;
PublishingTumblrTumblrPublisherUserInfoFetchTransaction* publishing_tumblr_tumblr_publisher_user_info_fetch_transaction_new (PublishingTumblrTumblrPublisherSession* session);
PublishingTumblrTumblrPublisherUserInfoFetchTransaction* publishing_tumblr_tumblr_publisher_user_info_fetch_transaction_construct (GType object_type, PublishingTumblrTumblrPublisherSession* session);
static void publishing_tumblr_tumblr_publisher_on_info_request_txn_completed (PublishingTumblrTumblrPublisher* self, PublishingRESTSupportTransaction* txn);
static void _publishing_tumblr_tumblr_publisher_on_info_request_txn_completed_publishing_rest_support_transaction_completed (PublishingRESTSupportTransaction* _sender, gpointer self);
static void publishing_tumblr_tumblr_publisher_on_info_request_txn_error (PublishingTumblrTumblrPublisher* self, PublishingRESTSupportTransaction* txn, GError* err);
static void _publishing_tumblr_tumblr_publisher_on_info_request_txn_error_publishing_rest_support_transaction_network_error (PublishingRESTSupportTransaction* _sender, GError* err, gpointer self);
static void publishing_tumblr_tumblr_publisher_do_parse_token_info_from_user_request (PublishingTumblrTumblrPublisher* self, const gchar* response);
static void publishing_tumblr_tumblr_publisher_do_show_publishing_options_pane (PublishingTumblrTumblrPublisher* self);
static void _vala_array_add21 (PublishingTumblrBlogEntry*** array, int* length, int* size, PublishingTumblrBlogEntry* value);
void publishing_tumblr_tumblr_publisher_session_deauthenticate (PublishingTumblrTumblrPublisherSession* self);
PublishingTumblrTumblrPublisherPublishingOptionsPane* publishing_tumblr_tumblr_publisher_publishing_options_pane_new (PublishingTumblrTumblrPublisher* publisher, SpitPublishingPublisherMediaType media_type, PublishingTumblrSizeEntry** sizes, int sizes_length1, PublishingTumblrBlogEntry** blogs, int blogs_length1, const gchar* username);
PublishingTumblrTumblrPublisherPublishingOptionsPane* publishing_tumblr_tumblr_publisher_publishing_options_pane_construct (GType object_type, PublishingTumblrTumblrPublisher* publisher, SpitPublishingPublisherMediaType media_type, PublishingTumblrSizeEntry** sizes, int sizes_length1, PublishingTumblrBlogEntry** blogs, int blogs_length1, const gchar* username);
static void publishing_tumblr_tumblr_publisher_on_publishing_options_pane_publish (PublishingTumblrTumblrPublisher* self);
static void _publishing_tumblr_tumblr_publisher_on_publishing_options_pane_publish_publishing_tumblr_tumblr_publisher_publishing_options_pane_publish (PublishingTumblrTumblrPublisherPublishingOptionsPane* _sender, gpointer self);
static void publishing_tumblr_tumblr_publisher_on_publishing_options_pane_logout (PublishingTumblrTumblrPublisher* self);
static void _publishing_tumblr_tumblr_publisher_on_publishing_options_pane_logout_publishing_tumblr_tumblr_publisher_publishing_options_pane_logout (PublishingTumblrTumblrPublisherPublishingOptionsPane* _sender, gpointer self);
static void publishing_tumblr_tumblr_publisher_do_publish (PublishingTumblrTumblrPublisher* self);
static void publishing_tumblr_tumblr_publisher_do_logout (PublishingTumblrTumblrPublisher* self);
gint publishing_tumblr_tumblr_publisher_tumblr_date_time_compare_func (SpitPublishingPublishable* a, SpitPublishingPublishable* b);
static gint _publishing_tumblr_tumblr_publisher_tumblr_date_time_compare_func_gcompare_data_func (gconstpointer a, gconstpointer b, gpointer self);
GType publishing_tumblr_tumblr_publisher_uploader_get_type (void) G_GNUC_CONST;
PublishingTumblrTumblrPublisherUploader* publishing_tumblr_tumblr_publisher_uploader_new (PublishingTumblrTumblrPublisherSession* session, SpitPublishingPublishable** publishables, int publishables_length1, const gchar* blog_url);
PublishingTumblrTumblrPublisherUploader* publishing_tumblr_tumblr_publisher_uploader_construct (GType object_type, PublishingTumblrTumblrPublisherSession* session, SpitPublishingPublishable** publishables, int publishables_length1, const gchar* blog_url);
static void publishing_tumblr_tumblr_publisher_on_upload_complete (PublishingTumblrTumblrPublisher* self, PublishingRESTSupportBatchUploader* uploader, gint num_published);
static void _publishing_tumblr_tumblr_publisher_on_upload_complete_publishing_rest_support_batch_uploader_upload_complete (PublishingRESTSupportBatchUploader* _sender, gint num_photos_published, gpointer self);
static void publishing_tumblr_tumblr_publisher_on_upload_error (PublishingTumblrTumblrPublisher* self, PublishingRESTSupportBatchUploader* uploader, GError* err);
static void _publishing_tumblr_tumblr_publisher_on_upload_error_publishing_rest_support_batch_uploader_upload_error (PublishingRESTSupportBatchUploader* _sender, GError* err, gpointer self);
static void publishing_tumblr_tumblr_publisher_on_upload_status_updated (PublishingTumblrTumblrPublisher* self, gint file_number, gdouble completed_fraction);
static void _publishing_tumblr_tumblr_publisher_on_upload_status_updated_spit_publishing_progress_callback (gint file_number, gdouble fraction_complete, gpointer self);
static void publishing_tumblr_tumblr_publisher_do_show_success_pane (PublishingTumblrTumblrPublisher* self);
void publishing_tumblr_tumblr_publisher_attempt_start (PublishingTumblrTumblrPublisher* self);
void publishing_tumblr_tumblr_publisher_session_authenticate_from_persistent_credentials (PublishingTumblrTumblrPublisherSession* self, const gchar* token, const gchar* secret);
static void publishing_tumblr_tumblr_publisher_real_start (SpitPublishingPublisher* base);
static void publishing_tumblr_tumblr_publisher_real_stop (SpitPublishingPublisher* base);
#define PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_AUTHENTICATION_PANE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_AUTHENTICATION_PANE, PublishingTumblrTumblrPublisherAuthenticationPanePrivate))
enum  {
	PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_AUTHENTICATION_PANE_DUMMY_PROPERTY
};
static void publishing_tumblr_tumblr_publisher_authentication_pane_on_user_changed (PublishingTumblrTumblrPublisherAuthenticationPane* self);
static void _publishing_tumblr_tumblr_publisher_authentication_pane_on_user_changed_gtk_editable_changed (GtkEditable* _sender, gpointer self);
static void publishing_tumblr_tumblr_publisher_authentication_pane_on_password_changed (PublishingTumblrTumblrPublisherAuthenticationPane* self);
static void _publishing_tumblr_tumblr_publisher_authentication_pane_on_password_changed_gtk_editable_changed (GtkEditable* _sender, gpointer self);
static void publishing_tumblr_tumblr_publisher_authentication_pane_on_login_button_clicked (PublishingTumblrTumblrPublisherAuthenticationPane* self);
static void _publishing_tumblr_tumblr_publisher_authentication_pane_on_login_button_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self);
static void publishing_tumblr_tumblr_publisher_authentication_pane_update_login_button_sensitivity (PublishingTumblrTumblrPublisherAuthenticationPane* self);
static GtkWidget* publishing_tumblr_tumblr_publisher_authentication_pane_real_get_widget (SpitPublishingDialogPane* base);
static SpitPublishingDialogPaneGeometryOptions publishing_tumblr_tumblr_publisher_authentication_pane_real_get_preferred_geometry (SpitPublishingDialogPane* base);
static void publishing_tumblr_tumblr_publisher_authentication_pane_real_on_pane_installed (SpitPublishingDialogPane* base);
static void publishing_tumblr_tumblr_publisher_authentication_pane_real_on_pane_uninstalled (SpitPublishingDialogPane* base);
static void g_cclosure_user_marshal_VOID__STRING_STRING (GClosure * closure, GValue * return_value, guint n_param_values, const GValue * param_values, gpointer invocation_hint, gpointer marshal_data);
static void publishing_tumblr_tumblr_publisher_authentication_pane_finalize (GObject* obj);
#define PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_PUBLISHING_OPTIONS_PANE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_PUBLISHING_OPTIONS_PANE, PublishingTumblrTumblrPublisherPublishingOptionsPanePrivate))
enum  {
	PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_PUBLISHING_OPTIONS_PANE_DUMMY_PROPERTY
};
static PublishingTumblrSizeEntry** _vala_array_dup7 (PublishingTumblrSizeEntry** self, int length);
static PublishingTumblrBlogEntry** _vala_array_dup8 (PublishingTumblrBlogEntry** self, int length);
static void publishing_tumblr_tumblr_publisher_publishing_options_pane_populate_blog_combo (PublishingTumblrTumblrPublisherPublishingOptionsPane* self);
static void publishing_tumblr_tumblr_publisher_publishing_options_pane_on_blog_changed (PublishingTumblrTumblrPublisherPublishingOptionsPane* self);
static void _publishing_tumblr_tumblr_publisher_publishing_options_pane_on_blog_changed_gtk_combo_box_changed (GtkComboBox* _sender, gpointer self);
static void publishing_tumblr_tumblr_publisher_publishing_options_pane_populate_size_combo (PublishingTumblrTumblrPublisherPublishingOptionsPane* self);
static void publishing_tumblr_tumblr_publisher_publishing_options_pane_on_size_changed (PublishingTumblrTumblrPublisherPublishingOptionsPane* self);
static void _publishing_tumblr_tumblr_publisher_publishing_options_pane_on_size_changed_gtk_combo_box_changed (GtkComboBox* _sender, gpointer self);
static void publishing_tumblr_tumblr_publisher_publishing_options_pane_on_logout_clicked (PublishingTumblrTumblrPublisherPublishingOptionsPane* self);
static void _publishing_tumblr_tumblr_publisher_publishing_options_pane_on_logout_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self);
static void publishing_tumblr_tumblr_publisher_publishing_options_pane_on_publish_clicked (PublishingTumblrTumblrPublisherPublishingOptionsPane* self);
static void _publishing_tumblr_tumblr_publisher_publishing_options_pane_on_publish_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self);
void publishing_tumblr_tumblr_publisher_publishing_options_pane_notify_publish (PublishingTumblrTumblrPublisherPublishingOptionsPane* self);
void publishing_tumblr_tumblr_publisher_publishing_options_pane_notify_logout (PublishingTumblrTumblrPublisherPublishingOptionsPane* self);
static GtkWidget* publishing_tumblr_tumblr_publisher_publishing_options_pane_real_get_widget (SpitPublishingDialogPane* base);
static SpitPublishingDialogPaneGeometryOptions publishing_tumblr_tumblr_publisher_publishing_options_pane_real_get_preferred_geometry (SpitPublishingDialogPane* base);
static void publishing_tumblr_tumblr_publisher_publishing_options_pane_real_on_pane_installed (SpitPublishingDialogPane* base);
static void _publishing_tumblr_tumblr_publisher_publishing_options_pane_notify_publish_publishing_tumblr_tumblr_publisher_publishing_options_pane_publish (PublishingTumblrTumblrPublisherPublishingOptionsPane* _sender, gpointer self);
static void _publishing_tumblr_tumblr_publisher_publishing_options_pane_notify_logout_publishing_tumblr_tumblr_publisher_publishing_options_pane_logout (PublishingTumblrTumblrPublisherPublishingOptionsPane* _sender, gpointer self);
static void publishing_tumblr_tumblr_publisher_publishing_options_pane_real_on_pane_uninstalled (SpitPublishingDialogPane* base);
static void publishing_tumblr_tumblr_publisher_publishing_options_pane_finalize (GObject* obj);
enum  {
	PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TRANSACTION_DUMMY_PROPERTY
};
PublishingTumblrTumblrPublisherTransaction* publishing_tumblr_tumblr_publisher_transaction_new (PublishingTumblrTumblrPublisherSession* session, PublishingRESTSupportHttpMethod method);
PublishingTumblrTumblrPublisherTransaction* publishing_tumblr_tumblr_publisher_transaction_construct (GType object_type, PublishingTumblrTumblrPublisherSession* session, PublishingRESTSupportHttpMethod method);
PublishingTumblrTumblrPublisherTransaction* publishing_tumblr_tumblr_publisher_transaction_new_with_uri (PublishingTumblrTumblrPublisherSession* session, const gchar* uri, PublishingRESTSupportHttpMethod method);
PublishingTumblrTumblrPublisherTransaction* publishing_tumblr_tumblr_publisher_transaction_construct_with_uri (GType object_type, PublishingTumblrTumblrPublisherSession* session, const gchar* uri, PublishingRESTSupportHttpMethod method);
gchar* publishing_tumblr_tumblr_publisher_session_get_oauth_nonce (PublishingTumblrTumblrPublisherSession* self);
gchar* publishing_tumblr_tumblr_publisher_session_get_oauth_timestamp (PublishingTumblrTumblrPublisherSession* self);
static void publishing_tumblr_tumblr_publisher_transaction_real_execute (PublishingRESTSupportTransaction* base, GError** error);
void publishing_tumblr_tumblr_publisher_session_sign_transaction (PublishingTumblrTumblrPublisherSession* self, PublishingRESTSupportTransaction* txn);
enum  {
	PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_ACCESS_TOKEN_FETCH_TRANSACTION_DUMMY_PROPERTY
};
enum  {
	PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_USER_INFO_FETCH_TRANSACTION_DUMMY_PROPERTY
};
GType publishing_tumblr_tumblr_publisher_upload_transaction_get_type (void) G_GNUC_CONST;
#define PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_UPLOAD_TRANSACTION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_UPLOAD_TRANSACTION, PublishingTumblrTumblrPublisherUploadTransactionPrivate))
enum  {
	PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_UPLOAD_TRANSACTION_DUMMY_PROPERTY
};
static gchar* publishing_tumblr_tumblr_publisher_upload_transaction_encode (PublishingTumblrTumblrPublisherUploadTransaction* self, guint8* data, int data_length1);
PublishingTumblrTumblrPublisherUploadTransaction* publishing_tumblr_tumblr_publisher_upload_transaction_new (PublishingTumblrTumblrPublisherSession* session, SpitPublishingPublishable* publishable, const gchar* blog_url);
PublishingTumblrTumblrPublisherUploadTransaction* publishing_tumblr_tumblr_publisher_upload_transaction_construct (GType object_type, PublishingTumblrTumblrPublisherSession* session, SpitPublishingPublishable* publishable, const gchar* blog_url);
void publishing_tumblr_tumblr_publisher_upload_transaction_add_authorization_header_field (PublishingTumblrTumblrPublisherUploadTransaction* self, const gchar* key, const gchar* value);
static void _vala_array_add22 (PublishingRESTSupportArgument*** array, int* length, int* size, PublishingRESTSupportArgument* value);
PublishingRESTSupportArgument** publishing_tumblr_tumblr_publisher_upload_transaction_get_authorization_header_fields (PublishingTumblrTumblrPublisherUploadTransaction* self, int* result_length1);
static PublishingRESTSupportArgument** _vala_array_dup9 (PublishingRESTSupportArgument** self, int length);
gchar* publishing_tumblr_tumblr_publisher_upload_transaction_get_authorization_header_string (PublishingTumblrTumblrPublisherUploadTransaction* self);
static void publishing_tumblr_tumblr_publisher_upload_transaction_real_execute (PublishingRESTSupportTransaction* base, GError** error);
static void publishing_tumblr_tumblr_publisher_upload_transaction_finalize (PublishingRESTSupportTransaction* obj);
#define PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_UPLOADER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_UPLOADER, PublishingTumblrTumblrPublisherUploaderPrivate))
enum  {
	PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_UPLOADER_DUMMY_PROPERTY
};
static PublishingRESTSupportTransaction* publishing_tumblr_tumblr_publisher_uploader_real_create_transaction (PublishingRESTSupportBatchUploader* base, SpitPublishingPublishable* publishable);
static void publishing_tumblr_tumblr_publisher_uploader_finalize (PublishingRESTSupportBatchUploader* obj);
#define PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_SESSION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_SESSION, PublishingTumblrTumblrPublisherSessionPrivate))
enum  {
	PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_SESSION_DUMMY_PROPERTY
};
static gboolean publishing_tumblr_tumblr_publisher_session_real_is_authenticated (PublishingRESTSupportSession* base);
static void _vala_array_add23 (PublishingRESTSupportArgument*** array, int* length, int* size, PublishingRESTSupportArgument* value);
static void publishing_tumblr_tumblr_publisher_session_finalize (PublishingRESTSupportSession* obj);
static void publishing_tumblr_tumblr_publisher_finalize (GObject* obj);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
static gint _vala_array_length (gpointer array);


TumblrService* tumblr_service_construct (GType object_type, GFile* resource_directory) {
	TumblrService * self = NULL;
	GdkPixbuf** _tmp0_ = NULL;
	gint _tmp0__length1 = 0;
#line 14 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_val_if_fail (G_IS_FILE (resource_directory), NULL);
#line 14 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self = (TumblrService*) g_object_new (object_type, NULL);
#line 15 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = tumblr_service_icon_pixbuf_set;
#line 15 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0__length1 = tumblr_service_icon_pixbuf_set_length1;
#line 15 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	if (_tmp0_ == NULL) {
#line 649 "TumblrPublishing.c"
		gint _tmp1_ = 0;
		GdkPixbuf** _tmp2_ = NULL;
#line 16 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp2_ = resources_load_from_resource (PLUGIN_RESOURCE_PATH "/" TUMBLR_SERVICE_ICON_FILENAME, &_tmp1_);
#line 16 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		tumblr_service_icon_pixbuf_set = (_vala_array_free (tumblr_service_icon_pixbuf_set, tumblr_service_icon_pixbuf_set_length1, (GDestroyNotify) g_object_unref), NULL);
#line 16 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		tumblr_service_icon_pixbuf_set = _tmp2_;
#line 16 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		tumblr_service_icon_pixbuf_set_length1 = _tmp1_;
#line 16 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tumblr_service_icon_pixbuf_set_size_ = tumblr_service_icon_pixbuf_set_length1;
#line 662 "TumblrPublishing.c"
	}
#line 14 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return self;
#line 666 "TumblrPublishing.c"
}


TumblrService* tumblr_service_new (GFile* resource_directory) {
#line 14 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return tumblr_service_construct (TYPE_TUMBLR_SERVICE, resource_directory);
#line 673 "TumblrPublishing.c"
}


static gint tumblr_service_real_get_pluggable_interface (SpitPluggable* base, gint min_host_interface, gint max_host_interface) {
	TumblrService * self;
	gint result = 0;
	gint _tmp0_ = 0;
	gint _tmp1_ = 0;
	gint _tmp2_ = 0;
#line 21 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_TUMBLR_SERVICE, TumblrService);
#line 22 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = min_host_interface;
#line 22 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp1_ = max_host_interface;
#line 22 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp2_ = spit_negotiate_interfaces (_tmp0_, _tmp1_, SPIT_PUBLISHING_CURRENT_INTERFACE);
#line 22 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	result = _tmp2_;
#line 22 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return result;
#line 695 "TumblrPublishing.c"
}


static const gchar* tumblr_service_real_get_id (SpitPluggable* base) {
	TumblrService * self;
	const gchar* result = NULL;
#line 26 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_TUMBLR_SERVICE, TumblrService);
#line 27 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	result = "org.yorba.shotwell.publishing.tumblr";
#line 27 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return result;
#line 708 "TumblrPublishing.c"
}


static const gchar* tumblr_service_real_get_pluggable_name (SpitPluggable* base) {
	TumblrService * self;
	const gchar* result = NULL;
#line 30 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_TUMBLR_SERVICE, TumblrService);
#line 31 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	result = "Tumblr";
#line 31 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return result;
#line 721 "TumblrPublishing.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 43 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return self ? g_object_ref (self) : NULL;
#line 728 "TumblrPublishing.c"
}


static GdkPixbuf** _vala_array_dup6 (GdkPixbuf** self, int length) {
	GdkPixbuf** result;
	int i;
#line 43 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	result = g_new0 (GdkPixbuf*, length + 1);
#line 43 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	for (i = 0; i < length; i++) {
#line 739 "TumblrPublishing.c"
		GdkPixbuf* _tmp0_ = NULL;
#line 43 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp0_ = _g_object_ref0 (self[i]);
#line 43 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		result[i] = _tmp0_;
#line 745 "TumblrPublishing.c"
	}
#line 43 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return result;
#line 749 "TumblrPublishing.c"
}


static void tumblr_service_real_get_info (SpitPluggable* base, SpitPluggableInfo* info) {
	TumblrService * self;
	gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
	GdkPixbuf** _tmp8_ = NULL;
	gint _tmp8__length1 = 0;
	GdkPixbuf** _tmp9_ = NULL;
	gint _tmp9__length1 = 0;
#line 34 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_TUMBLR_SERVICE, TumblrService);
#line 34 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_if_fail (info != NULL);
#line 35 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = g_strdup ("Jeroen Arnoldus");
#line 35 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_free0 ((*info).authors);
#line 35 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	(*info).authors = _tmp0_;
#line 36 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp1_ = _ ("Copyright 2012 BJA Electronics");
#line 36 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp2_ = g_strdup (_tmp1_);
#line 36 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_free0 ((*info).copyright);
#line 36 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	(*info).copyright = _tmp2_;
#line 37 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp3_ = g_strdup (RESOURCES_TRANSLATORS);
#line 37 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_free0 ((*info).translators);
#line 37 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	(*info).translators = _tmp3_;
#line 38 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp4_ = g_strdup (_VERSION);
#line 38 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_free0 ((*info).version);
#line 38 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	(*info).version = _tmp4_;
#line 39 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp5_ = g_strdup (RESOURCES_WEBSITE_NAME);
#line 39 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_free0 ((*info).website_name);
#line 39 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	(*info).website_name = _tmp5_;
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp6_ = g_strdup (RESOURCES_WEBSITE_URL);
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_free0 ((*info).website_url);
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	(*info).website_url = _tmp6_;
#line 41 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	(*info).is_license_wordwrapped = FALSE;
#line 42 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp7_ = g_strdup (RESOURCES_LICENSE);
#line 42 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_free0 ((*info).license);
#line 42 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	(*info).license = _tmp7_;
#line 43 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp8_ = tumblr_service_icon_pixbuf_set;
#line 43 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp8__length1 = tumblr_service_icon_pixbuf_set_length1;
#line 43 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp9_ = (_tmp8_ != NULL) ? _vala_array_dup6 (_tmp8_, _tmp8__length1) : ((gpointer) _tmp8_);
#line 43 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp9__length1 = _tmp8__length1;
#line 43 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	(*info).icons = (_vala_array_free ((*info).icons, (*info).icons_length1, (GDestroyNotify) g_object_unref), NULL);
#line 43 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	(*info).icons = _tmp9_;
#line 43 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	(*info).icons_length1 = _tmp9__length1;
#line 831 "TumblrPublishing.c"
}


static void tumblr_service_real_activation (SpitPluggable* base, gboolean enabled) {
	TumblrService * self;
#line 46 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_TUMBLR_SERVICE, TumblrService);
#line 839 "TumblrPublishing.c"
}


static SpitPublishingPublisher* tumblr_service_real_create_publisher (SpitPublishingService* base, SpitPublishingPluginHost* host) {
	TumblrService * self;
	SpitPublishingPublisher* result = NULL;
	SpitPublishingPluginHost* _tmp0_ = NULL;
	PublishingTumblrTumblrPublisher* _tmp1_ = NULL;
#line 49 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_TUMBLR_SERVICE, TumblrService);
#line 49 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_val_if_fail (SPIT_PUBLISHING_IS_PLUGIN_HOST (host), NULL);
#line 50 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = host;
#line 50 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp1_ = publishing_tumblr_tumblr_publisher_new (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_SERVICE, SpitPublishingService), _tmp0_);
#line 50 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	result = G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher);
#line 50 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return result;
#line 860 "TumblrPublishing.c"
}


static SpitPublishingPublisherMediaType tumblr_service_real_get_supported_media (SpitPublishingService* base) {
	TumblrService * self;
	SpitPublishingPublisherMediaType result = 0;
#line 53 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_TUMBLR_SERVICE, TumblrService);
#line 54 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	result = SPIT_PUBLISHING_PUBLISHER_MEDIA_TYPE_PHOTO | SPIT_PUBLISHING_PUBLISHER_MEDIA_TYPE_VIDEO;
#line 54 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return result;
#line 873 "TumblrPublishing.c"
}


static void tumblr_service_class_init (TumblrServiceClass * klass) {
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	tumblr_service_parent_class = g_type_class_peek_parent (klass);
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	G_OBJECT_CLASS (klass)->finalize = tumblr_service_finalize;
#line 882 "TumblrPublishing.c"
}


static void tumblr_service_spit_pluggable_interface_init (SpitPluggableIface * iface) {
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	tumblr_service_spit_pluggable_parent_iface = g_type_interface_peek_parent (iface);
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	iface->get_pluggable_interface = (gint (*)(SpitPluggable*, gint, gint)) tumblr_service_real_get_pluggable_interface;
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	iface->get_id = (const gchar* (*)(SpitPluggable*)) tumblr_service_real_get_id;
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	iface->get_pluggable_name = (const gchar* (*)(SpitPluggable*)) tumblr_service_real_get_pluggable_name;
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	iface->get_info = (void (*)(SpitPluggable*, SpitPluggableInfo*)) tumblr_service_real_get_info;
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	iface->activation = (void (*)(SpitPluggable*, gboolean)) tumblr_service_real_activation;
#line 899 "TumblrPublishing.c"
}


static void tumblr_service_spit_publishing_service_interface_init (SpitPublishingServiceIface * iface) {
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	tumblr_service_spit_publishing_service_parent_iface = g_type_interface_peek_parent (iface);
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	iface->create_publisher = (SpitPublishingPublisher* (*)(SpitPublishingService*, SpitPublishingPluginHost*)) tumblr_service_real_create_publisher;
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	iface->get_supported_media = (SpitPublishingPublisherMediaType (*)(SpitPublishingService*)) tumblr_service_real_get_supported_media;
#line 910 "TumblrPublishing.c"
}


static void tumblr_service_instance_init (TumblrService * self) {
}


static void tumblr_service_finalize (GObject* obj) {
	TumblrService * self;
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_TUMBLR_SERVICE, TumblrService);
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	G_OBJECT_CLASS (tumblr_service_parent_class)->finalize (obj);
#line 924 "TumblrPublishing.c"
}


GType tumblr_service_get_type (void) {
	static volatile gsize tumblr_service_type_id__volatile = 0;
	if (g_once_init_enter (&tumblr_service_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (TumblrServiceClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tumblr_service_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TumblrService), 0, (GInstanceInitFunc) tumblr_service_instance_init, NULL };
		static const GInterfaceInfo spit_pluggable_info = { (GInterfaceInitFunc) tumblr_service_spit_pluggable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo spit_publishing_service_info = { (GInterfaceInitFunc) tumblr_service_spit_publishing_service_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType tumblr_service_type_id;
		tumblr_service_type_id = g_type_register_static (G_TYPE_OBJECT, "TumblrService", &g_define_type_info, 0);
		g_type_add_interface_static (tumblr_service_type_id, SPIT_TYPE_PLUGGABLE, &spit_pluggable_info);
		g_type_add_interface_static (tumblr_service_type_id, SPIT_PUBLISHING_TYPE_SERVICE, &spit_publishing_service_info);
		g_once_init_leave (&tumblr_service_type_id__volatile, tumblr_service_type_id);
	}
	return tumblr_service_type_id__volatile;
}


PublishingTumblrBlogEntry* publishing_tumblr_blog_entry_construct (GType object_type, const gchar* creator_blog, const gchar* creator_url) {
	PublishingTumblrBlogEntry* self = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
#line 73 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_val_if_fail (creator_blog != NULL, NULL);
#line 73 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_val_if_fail (creator_url != NULL, NULL);
#line 73 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self = (PublishingTumblrBlogEntry*) g_type_create_instance (object_type);
#line 74 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = creator_blog;
#line 74 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 74 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_free0 (self->blog);
#line 74 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->blog = _tmp1_;
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp2_ = creator_url;
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp3_ = g_strdup (_tmp2_);
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_free0 (self->url);
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->url = _tmp3_;
#line 73 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return self;
#line 974 "TumblrPublishing.c"
}


PublishingTumblrBlogEntry* publishing_tumblr_blog_entry_new (const gchar* creator_blog, const gchar* creator_url) {
#line 73 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return publishing_tumblr_blog_entry_construct (PUBLISHING_TUMBLR_TYPE_BLOG_ENTRY, creator_blog, creator_url);
#line 981 "TumblrPublishing.c"
}


static void publishing_tumblr_value_blog_entry_init (GValue* value) {
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	value->data[0].v_pointer = NULL;
#line 988 "TumblrPublishing.c"
}


static void publishing_tumblr_value_blog_entry_free_value (GValue* value) {
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	if (value->data[0].v_pointer) {
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		publishing_tumblr_blog_entry_unref (value->data[0].v_pointer);
#line 997 "TumblrPublishing.c"
	}
}


static void publishing_tumblr_value_blog_entry_copy_value (const GValue* src_value, GValue* dest_value) {
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	if (src_value->data[0].v_pointer) {
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		dest_value->data[0].v_pointer = publishing_tumblr_blog_entry_ref (src_value->data[0].v_pointer);
#line 1007 "TumblrPublishing.c"
	} else {
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		dest_value->data[0].v_pointer = NULL;
#line 1011 "TumblrPublishing.c"
	}
}


static gpointer publishing_tumblr_value_blog_entry_peek_pointer (const GValue* value) {
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return value->data[0].v_pointer;
#line 1019 "TumblrPublishing.c"
}


static gchar* publishing_tumblr_value_blog_entry_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	if (collect_values[0].v_pointer) {
#line 1026 "TumblrPublishing.c"
		PublishingTumblrBlogEntry* object;
		object = collect_values[0].v_pointer;
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		if (object->parent_instance.g_class == NULL) {
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 1033 "TumblrPublishing.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 1037 "TumblrPublishing.c"
		}
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		value->data[0].v_pointer = publishing_tumblr_blog_entry_ref (object);
#line 1041 "TumblrPublishing.c"
	} else {
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 1045 "TumblrPublishing.c"
	}
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return NULL;
#line 1049 "TumblrPublishing.c"
}


static gchar* publishing_tumblr_value_blog_entry_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	PublishingTumblrBlogEntry** object_p;
	object_p = collect_values[0].v_pointer;
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	if (!object_p) {
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 1060 "TumblrPublishing.c"
	}
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	if (!value->data[0].v_pointer) {
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		*object_p = NULL;
#line 1066 "TumblrPublishing.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		*object_p = value->data[0].v_pointer;
#line 1070 "TumblrPublishing.c"
	} else {
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		*object_p = publishing_tumblr_blog_entry_ref (value->data[0].v_pointer);
#line 1074 "TumblrPublishing.c"
	}
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return NULL;
#line 1078 "TumblrPublishing.c"
}


GParamSpec* publishing_tumblr_param_spec_blog_entry (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
	PublishingTumblrParamSpecBlogEntry* spec;
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_val_if_fail (g_type_is_a (object_type, PUBLISHING_TUMBLR_TYPE_BLOG_ENTRY), NULL);
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return G_PARAM_SPEC (spec);
#line 1092 "TumblrPublishing.c"
}


gpointer publishing_tumblr_value_get_blog_entry (const GValue* value) {
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_TUMBLR_TYPE_BLOG_ENTRY), NULL);
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return value->data[0].v_pointer;
#line 1101 "TumblrPublishing.c"
}


void publishing_tumblr_value_set_blog_entry (GValue* value, gpointer v_object) {
	PublishingTumblrBlogEntry* old;
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_TUMBLR_TYPE_BLOG_ENTRY));
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	old = value->data[0].v_pointer;
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	if (v_object) {
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PUBLISHING_TUMBLR_TYPE_BLOG_ENTRY));
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		value->data[0].v_pointer = v_object;
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		publishing_tumblr_blog_entry_ref (value->data[0].v_pointer);
#line 1121 "TumblrPublishing.c"
	} else {
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 1125 "TumblrPublishing.c"
	}
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	if (old) {
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		publishing_tumblr_blog_entry_unref (old);
#line 1131 "TumblrPublishing.c"
	}
}


void publishing_tumblr_value_take_blog_entry (GValue* value, gpointer v_object) {
	PublishingTumblrBlogEntry* old;
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_TUMBLR_TYPE_BLOG_ENTRY));
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	old = value->data[0].v_pointer;
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	if (v_object) {
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PUBLISHING_TUMBLR_TYPE_BLOG_ENTRY));
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		value->data[0].v_pointer = v_object;
#line 1150 "TumblrPublishing.c"
	} else {
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 1154 "TumblrPublishing.c"
	}
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	if (old) {
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		publishing_tumblr_blog_entry_unref (old);
#line 1160 "TumblrPublishing.c"
	}
}


static void publishing_tumblr_blog_entry_class_init (PublishingTumblrBlogEntryClass * klass) {
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_tumblr_blog_entry_parent_class = g_type_class_peek_parent (klass);
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	((PublishingTumblrBlogEntryClass *) klass)->finalize = publishing_tumblr_blog_entry_finalize;
#line 1170 "TumblrPublishing.c"
}


static void publishing_tumblr_blog_entry_instance_init (PublishingTumblrBlogEntry * self) {
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->ref_count = 1;
#line 1177 "TumblrPublishing.c"
}


static void publishing_tumblr_blog_entry_finalize (PublishingTumblrBlogEntry* obj) {
	PublishingTumblrBlogEntry * self;
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_TUMBLR_TYPE_BLOG_ENTRY, PublishingTumblrBlogEntry);
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_signal_handlers_destroy (self);
#line 71 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_free0 (self->blog);
#line 72 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_free0 (self->url);
#line 1191 "TumblrPublishing.c"
}


GType publishing_tumblr_blog_entry_get_type (void) {
	static volatile gsize publishing_tumblr_blog_entry_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_tumblr_blog_entry_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { publishing_tumblr_value_blog_entry_init, publishing_tumblr_value_blog_entry_free_value, publishing_tumblr_value_blog_entry_copy_value, publishing_tumblr_value_blog_entry_peek_pointer, "p", publishing_tumblr_value_blog_entry_collect_value, "p", publishing_tumblr_value_blog_entry_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (PublishingTumblrBlogEntryClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_tumblr_blog_entry_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingTumblrBlogEntry), 0, (GInstanceInitFunc) publishing_tumblr_blog_entry_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType publishing_tumblr_blog_entry_type_id;
		publishing_tumblr_blog_entry_type_id = g_type_register_fundamental (g_type_fundamental_next (), "PublishingTumblrBlogEntry", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&publishing_tumblr_blog_entry_type_id__volatile, publishing_tumblr_blog_entry_type_id);
	}
	return publishing_tumblr_blog_entry_type_id__volatile;
}


gpointer publishing_tumblr_blog_entry_ref (gpointer instance) {
	PublishingTumblrBlogEntry* self;
	self = instance;
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_atomic_int_inc (&self->ref_count);
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return instance;
#line 1216 "TumblrPublishing.c"
}


void publishing_tumblr_blog_entry_unref (gpointer instance) {
	PublishingTumblrBlogEntry* self;
	self = instance;
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		PUBLISHING_TUMBLR_BLOG_ENTRY_GET_CLASS (self)->finalize (self);
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 1229 "TumblrPublishing.c"
	}
}


PublishingTumblrSizeEntry* publishing_tumblr_size_entry_construct (GType object_type, const gchar* creator_title, gint creator_size) {
	PublishingTumblrSizeEntry* self = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	gint _tmp2_ = 0;
#line 83 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_val_if_fail (creator_title != NULL, NULL);
#line 83 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self = (PublishingTumblrSizeEntry*) g_type_create_instance (object_type);
#line 84 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = creator_title;
#line 84 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 84 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_free0 (self->title);
#line 84 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->title = _tmp1_;
#line 85 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp2_ = creator_size;
#line 85 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->size = _tmp2_;
#line 83 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return self;
#line 1257 "TumblrPublishing.c"
}


PublishingTumblrSizeEntry* publishing_tumblr_size_entry_new (const gchar* creator_title, gint creator_size) {
#line 83 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return publishing_tumblr_size_entry_construct (PUBLISHING_TUMBLR_TYPE_SIZE_ENTRY, creator_title, creator_size);
#line 1264 "TumblrPublishing.c"
}


static void publishing_tumblr_value_size_entry_init (GValue* value) {
#line 79 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	value->data[0].v_pointer = NULL;
#line 1271 "TumblrPublishing.c"
}


static void publishing_tumblr_value_size_entry_free_value (GValue* value) {
#line 79 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	if (value->data[0].v_pointer) {
#line 79 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		publishing_tumblr_size_entry_unref (value->data[0].v_pointer);
#line 1280 "TumblrPublishing.c"
	}
}


static void publishing_tumblr_value_size_entry_copy_value (const GValue* src_value, GValue* dest_value) {
#line 79 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	if (src_value->data[0].v_pointer) {
#line 79 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		dest_value->data[0].v_pointer = publishing_tumblr_size_entry_ref (src_value->data[0].v_pointer);
#line 1290 "TumblrPublishing.c"
	} else {
#line 79 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		dest_value->data[0].v_pointer = NULL;
#line 1294 "TumblrPublishing.c"
	}
}


static gpointer publishing_tumblr_value_size_entry_peek_pointer (const GValue* value) {
#line 79 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return value->data[0].v_pointer;
#line 1302 "TumblrPublishing.c"
}


static gchar* publishing_tumblr_value_size_entry_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
#line 79 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	if (collect_values[0].v_pointer) {
#line 1309 "TumblrPublishing.c"
		PublishingTumblrSizeEntry* object;
		object = collect_values[0].v_pointer;
#line 79 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		if (object->parent_instance.g_class == NULL) {
#line 79 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 1316 "TumblrPublishing.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 79 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 1320 "TumblrPublishing.c"
		}
#line 79 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		value->data[0].v_pointer = publishing_tumblr_size_entry_ref (object);
#line 1324 "TumblrPublishing.c"
	} else {
#line 79 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 1328 "TumblrPublishing.c"
	}
#line 79 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return NULL;
#line 1332 "TumblrPublishing.c"
}


static gchar* publishing_tumblr_value_size_entry_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	PublishingTumblrSizeEntry** object_p;
	object_p = collect_values[0].v_pointer;
#line 79 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	if (!object_p) {
#line 79 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 1343 "TumblrPublishing.c"
	}
#line 79 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	if (!value->data[0].v_pointer) {
#line 79 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		*object_p = NULL;
#line 1349 "TumblrPublishing.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 79 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		*object_p = value->data[0].v_pointer;
#line 1353 "TumblrPublishing.c"
	} else {
#line 79 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		*object_p = publishing_tumblr_size_entry_ref (value->data[0].v_pointer);
#line 1357 "TumblrPublishing.c"
	}
#line 79 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return NULL;
#line 1361 "TumblrPublishing.c"
}


GParamSpec* publishing_tumblr_param_spec_size_entry (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
	PublishingTumblrParamSpecSizeEntry* spec;
#line 79 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_val_if_fail (g_type_is_a (object_type, PUBLISHING_TUMBLR_TYPE_SIZE_ENTRY), NULL);
#line 79 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 79 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 79 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return G_PARAM_SPEC (spec);
#line 1375 "TumblrPublishing.c"
}


gpointer publishing_tumblr_value_get_size_entry (const GValue* value) {
#line 79 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_TUMBLR_TYPE_SIZE_ENTRY), NULL);
#line 79 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return value->data[0].v_pointer;
#line 1384 "TumblrPublishing.c"
}


void publishing_tumblr_value_set_size_entry (GValue* value, gpointer v_object) {
	PublishingTumblrSizeEntry* old;
#line 79 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_TUMBLR_TYPE_SIZE_ENTRY));
#line 79 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	old = value->data[0].v_pointer;
#line 79 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	if (v_object) {
#line 79 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PUBLISHING_TUMBLR_TYPE_SIZE_ENTRY));
#line 79 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 79 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		value->data[0].v_pointer = v_object;
#line 79 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		publishing_tumblr_size_entry_ref (value->data[0].v_pointer);
#line 1404 "TumblrPublishing.c"
	} else {
#line 79 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 1408 "TumblrPublishing.c"
	}
#line 79 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	if (old) {
#line 79 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		publishing_tumblr_size_entry_unref (old);
#line 1414 "TumblrPublishing.c"
	}
}


void publishing_tumblr_value_take_size_entry (GValue* value, gpointer v_object) {
	PublishingTumblrSizeEntry* old;
#line 79 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_TUMBLR_TYPE_SIZE_ENTRY));
#line 79 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	old = value->data[0].v_pointer;
#line 79 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	if (v_object) {
#line 79 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PUBLISHING_TUMBLR_TYPE_SIZE_ENTRY));
#line 79 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 79 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		value->data[0].v_pointer = v_object;
#line 1433 "TumblrPublishing.c"
	} else {
#line 79 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 1437 "TumblrPublishing.c"
	}
#line 79 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	if (old) {
#line 79 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		publishing_tumblr_size_entry_unref (old);
#line 1443 "TumblrPublishing.c"
	}
}


static void publishing_tumblr_size_entry_class_init (PublishingTumblrSizeEntryClass * klass) {
#line 79 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_tumblr_size_entry_parent_class = g_type_class_peek_parent (klass);
#line 79 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	((PublishingTumblrSizeEntryClass *) klass)->finalize = publishing_tumblr_size_entry_finalize;
#line 1453 "TumblrPublishing.c"
}


static void publishing_tumblr_size_entry_instance_init (PublishingTumblrSizeEntry * self) {
#line 79 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->ref_count = 1;
#line 1460 "TumblrPublishing.c"
}


static void publishing_tumblr_size_entry_finalize (PublishingTumblrSizeEntry* obj) {
	PublishingTumblrSizeEntry * self;
#line 79 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_TUMBLR_TYPE_SIZE_ENTRY, PublishingTumblrSizeEntry);
#line 79 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_signal_handlers_destroy (self);
#line 80 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_free0 (self->title);
#line 1472 "TumblrPublishing.c"
}


GType publishing_tumblr_size_entry_get_type (void) {
	static volatile gsize publishing_tumblr_size_entry_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_tumblr_size_entry_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { publishing_tumblr_value_size_entry_init, publishing_tumblr_value_size_entry_free_value, publishing_tumblr_value_size_entry_copy_value, publishing_tumblr_value_size_entry_peek_pointer, "p", publishing_tumblr_value_size_entry_collect_value, "p", publishing_tumblr_value_size_entry_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (PublishingTumblrSizeEntryClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_tumblr_size_entry_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingTumblrSizeEntry), 0, (GInstanceInitFunc) publishing_tumblr_size_entry_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType publishing_tumblr_size_entry_type_id;
		publishing_tumblr_size_entry_type_id = g_type_register_fundamental (g_type_fundamental_next (), "PublishingTumblrSizeEntry", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&publishing_tumblr_size_entry_type_id__volatile, publishing_tumblr_size_entry_type_id);
	}
	return publishing_tumblr_size_entry_type_id__volatile;
}


gpointer publishing_tumblr_size_entry_ref (gpointer instance) {
	PublishingTumblrSizeEntry* self;
	self = instance;
#line 79 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_atomic_int_inc (&self->ref_count);
#line 79 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return instance;
#line 1497 "TumblrPublishing.c"
}


void publishing_tumblr_size_entry_unref (gpointer instance) {
	PublishingTumblrSizeEntry* self;
	self = instance;
#line 79 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 79 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		PUBLISHING_TUMBLR_SIZE_ENTRY_GET_CLASS (self)->finalize (self);
#line 79 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 1510 "TumblrPublishing.c"
	}
}


static void _publishing_tumblr_tumblr_publisher_on_session_authenticated_publishing_rest_support_session_authenticated (PublishingRESTSupportSession* _sender, gpointer self) {
#line 135 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_tumblr_tumblr_publisher_on_session_authenticated ((PublishingTumblrTumblrPublisher*) self);
#line 1518 "TumblrPublishing.c"
}


static void _vala_array_add18 (PublishingTumblrSizeEntry*** array, int* length, int* size, PublishingTumblrSizeEntry* value) {
#line 105 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	if ((*length) == (*size)) {
#line 105 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 105 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		*array = g_renew (PublishingTumblrSizeEntry*, *array, (*size) + 1);
#line 1529 "TumblrPublishing.c"
	}
#line 105 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	(*array)[(*length)++] = value;
#line 105 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	(*array)[*length] = NULL;
#line 1535 "TumblrPublishing.c"
}


static void _vala_array_add19 (PublishingTumblrSizeEntry*** array, int* length, int* size, PublishingTumblrSizeEntry* value) {
#line 106 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	if ((*length) == (*size)) {
#line 106 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 106 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		*array = g_renew (PublishingTumblrSizeEntry*, *array, (*size) + 1);
#line 1546 "TumblrPublishing.c"
	}
#line 106 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	(*array)[(*length)++] = value;
#line 106 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	(*array)[*length] = NULL;
#line 1552 "TumblrPublishing.c"
}


static void _vala_array_add20 (PublishingTumblrSizeEntry*** array, int* length, int* size, PublishingTumblrSizeEntry* value) {
#line 107 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	if ((*length) == (*size)) {
#line 107 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 107 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		*array = g_renew (PublishingTumblrSizeEntry*, *array, (*size) + 1);
#line 1563 "TumblrPublishing.c"
	}
#line 107 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	(*array)[(*length)++] = value;
#line 107 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	(*array)[*length] = NULL;
#line 1569 "TumblrPublishing.c"
}


static PublishingTumblrSizeEntry** publishing_tumblr_tumblr_publisher_create_sizes (PublishingTumblrTumblrPublisher* self, int* result_length1) {
	PublishingTumblrSizeEntry** result = NULL;
	PublishingTumblrSizeEntry** _result_ = NULL;
	PublishingTumblrSizeEntry** _tmp0_ = NULL;
	gint _result__length1 = 0;
	gint __result__size_ = 0;
	PublishingTumblrSizeEntry** _tmp1_ = NULL;
	gint _tmp1__length1 = 0;
	const gchar* _tmp2_ = NULL;
	PublishingTumblrSizeEntry* _tmp3_ = NULL;
	PublishingTumblrSizeEntry** _tmp4_ = NULL;
	gint _tmp4__length1 = 0;
	const gchar* _tmp5_ = NULL;
	PublishingTumblrSizeEntry* _tmp6_ = NULL;
	PublishingTumblrSizeEntry** _tmp7_ = NULL;
	gint _tmp7__length1 = 0;
	const gchar* _tmp8_ = NULL;
	PublishingTumblrSizeEntry* _tmp9_ = NULL;
	PublishingTumblrSizeEntry** _tmp10_ = NULL;
	gint _tmp10__length1 = 0;
#line 102 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_val_if_fail (PUBLISHING_TUMBLR_IS_TUMBLR_PUBLISHER (self), NULL);
#line 103 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = g_new0 (PublishingTumblrSizeEntry*, 0 + 1);
#line 103 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_result_ = _tmp0_;
#line 103 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_result__length1 = 0;
#line 103 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	__result__size_ = _result__length1;
#line 105 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp1_ = _result_;
#line 105 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp1__length1 = _result__length1;
#line 105 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp2_ = _ ("500 x 375 pixels");
#line 105 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp3_ = publishing_tumblr_size_entry_new (_tmp2_, 500);
#line 105 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_vala_array_add18 (&_result_, &_result__length1, &__result__size_, _tmp3_);
#line 106 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp4_ = _result_;
#line 106 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp4__length1 = _result__length1;
#line 106 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp5_ = _ ("1024 x 768 pixels");
#line 106 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp6_ = publishing_tumblr_size_entry_new (_tmp5_, 1024);
#line 106 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_vala_array_add19 (&_result_, &_result__length1, &__result__size_, _tmp6_);
#line 107 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp7_ = _result_;
#line 107 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp7__length1 = _result__length1;
#line 107 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp8_ = _ ("1280 x 853 pixels");
#line 107 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp9_ = publishing_tumblr_size_entry_new (_tmp8_, 1280);
#line 107 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_vala_array_add20 (&_result_, &_result__length1, &__result__size_, _tmp9_);
#line 113 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp10_ = _result_;
#line 113 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp10__length1 = _result__length1;
#line 113 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	if (result_length1) {
#line 113 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		*result_length1 = _tmp10__length1;
#line 1641 "TumblrPublishing.c"
	}
#line 113 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	result = _tmp10_;
#line 113 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return result;
#line 1647 "TumblrPublishing.c"
}


static PublishingTumblrBlogEntry** publishing_tumblr_tumblr_publisher_create_blogs (PublishingTumblrTumblrPublisher* self, int* result_length1) {
	PublishingTumblrBlogEntry** result = NULL;
	PublishingTumblrBlogEntry** _result_ = NULL;
	PublishingTumblrBlogEntry** _tmp0_ = NULL;
	gint _result__length1 = 0;
	gint __result__size_ = 0;
	PublishingTumblrBlogEntry** _tmp1_ = NULL;
	gint _tmp1__length1 = 0;
#line 116 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_val_if_fail (PUBLISHING_TUMBLR_IS_TUMBLR_PUBLISHER (self), NULL);
#line 117 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = g_new0 (PublishingTumblrBlogEntry*, 0 + 1);
#line 117 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_result_ = _tmp0_;
#line 117 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_result__length1 = 0;
#line 117 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	__result__size_ = _result__length1;
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp1_ = _result_;
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp1__length1 = _result__length1;
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	if (result_length1) {
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		*result_length1 = _tmp1__length1;
#line 1677 "TumblrPublishing.c"
	}
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	result = _tmp1_;
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return result;
#line 1683 "TumblrPublishing.c"
}


PublishingTumblrTumblrPublisher* publishing_tumblr_tumblr_publisher_construct (GType object_type, SpitPublishingService* service, SpitPublishingPluginHost* host) {
	PublishingTumblrTumblrPublisher * self = NULL;
	SpitPublishingService* _tmp0_ = NULL;
	SpitPublishingService* _tmp1_ = NULL;
	SpitPublishingPluginHost* _tmp2_ = NULL;
	SpitPublishingPluginHost* _tmp3_ = NULL;
	PublishingTumblrTumblrPublisherSession* _tmp4_ = NULL;
	gint _tmp5_ = 0;
	PublishingTumblrSizeEntry** _tmp6_ = NULL;
	gint _tmp7_ = 0;
	PublishingTumblrBlogEntry** _tmp8_ = NULL;
	PublishingTumblrTumblrPublisherSession* _tmp9_ = NULL;
#line 123 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_val_if_fail (SPIT_PUBLISHING_IS_SERVICE (service), NULL);
#line 123 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_val_if_fail (SPIT_PUBLISHING_IS_PLUGIN_HOST (host), NULL);
#line 123 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self = (PublishingTumblrTumblrPublisher*) g_object_new (object_type, NULL);
#line 125 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_debug ("TumblrPublishing.vala:125: TumblrPublisher instantiated.");
#line 126 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = service;
#line 126 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 126 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_object_unref0 (self->priv->service);
#line 126 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->service = _tmp1_;
#line 127 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp2_ = host;
#line 127 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 127 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_object_unref0 (self->priv->host);
#line 127 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->host = _tmp3_;
#line 128 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp4_ = publishing_tumblr_tumblr_publisher_session_new ();
#line 128 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_publishing_rest_support_session_unref0 (self->priv->session);
#line 128 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->session = _tmp4_;
#line 129 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp6_ = publishing_tumblr_tumblr_publisher_create_sizes (self, &_tmp5_);
#line 129 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->sizes = (_vala_array_free (self->priv->sizes, self->priv->sizes_length1, (GDestroyNotify) publishing_tumblr_size_entry_unref), NULL);
#line 129 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->sizes = _tmp6_;
#line 129 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->sizes_length1 = _tmp5_;
#line 129 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->_sizes_size_ = self->priv->sizes_length1;
#line 130 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp8_ = publishing_tumblr_tumblr_publisher_create_blogs (self, &_tmp7_);
#line 130 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->blogs = (_vala_array_free (self->priv->blogs, self->priv->blogs_length1, (GDestroyNotify) publishing_tumblr_blog_entry_unref), NULL);
#line 130 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->blogs = _tmp8_;
#line 130 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->blogs_length1 = _tmp7_;
#line 130 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->_blogs_size_ = self->priv->blogs_length1;
#line 131 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp9_ = self->priv->session;
#line 131 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession), "authenticated", (GCallback) _publishing_tumblr_tumblr_publisher_on_session_authenticated_publishing_rest_support_session_authenticated, self, 0);
#line 123 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return self;
#line 1755 "TumblrPublishing.c"
}


PublishingTumblrTumblrPublisher* publishing_tumblr_tumblr_publisher_new (SpitPublishingService* service, SpitPublishingPluginHost* host) {
#line 123 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return publishing_tumblr_tumblr_publisher_construct (PUBLISHING_TUMBLR_TYPE_TUMBLR_PUBLISHER, service, host);
#line 1762 "TumblrPublishing.c"
}


static void publishing_tumblr_tumblr_publisher_invalidate_persistent_session (PublishingTumblrTumblrPublisher* self) {
#line 138 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_if_fail (PUBLISHING_TUMBLR_IS_TUMBLR_PUBLISHER (self));
#line 139 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_tumblr_tumblr_publisher_set_persistent_access_phase_token (self, "");
#line 140 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_tumblr_tumblr_publisher_set_persistent_access_phase_token_secret (self, "");
#line 1773 "TumblrPublishing.c"
}


static SpitPublishingService* publishing_tumblr_tumblr_publisher_real_get_service (SpitPublishingPublisher* base) {
	PublishingTumblrTumblrPublisher * self;
	SpitPublishingService* result = NULL;
	SpitPublishingService* _tmp0_ = NULL;
	SpitPublishingService* _tmp1_ = NULL;
#line 144 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_TUMBLR_TYPE_TUMBLR_PUBLISHER, PublishingTumblrTumblrPublisher);
#line 145 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = self->priv->service;
#line 145 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 145 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	result = _tmp1_;
#line 145 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return result;
#line 1792 "TumblrPublishing.c"
}


SpitPublishingPluginHost* publishing_tumblr_tumblr_publisher_get_host (PublishingTumblrTumblrPublisher* self) {
	SpitPublishingPluginHost* result = NULL;
	SpitPublishingPluginHost* _tmp0_ = NULL;
	SpitPublishingPluginHost* _tmp1_ = NULL;
#line 148 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_val_if_fail (PUBLISHING_TUMBLR_IS_TUMBLR_PUBLISHER (self), NULL);
#line 149 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = self->priv->host;
#line 149 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 149 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	result = _tmp1_;
#line 149 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return result;
#line 1810 "TumblrPublishing.c"
}


static gboolean publishing_tumblr_tumblr_publisher_real_is_running (SpitPublishingPublisher* base) {
	PublishingTumblrTumblrPublisher * self;
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
#line 152 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_TUMBLR_TYPE_TUMBLR_PUBLISHER, PublishingTumblrTumblrPublisher);
#line 153 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = self->priv->running;
#line 153 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	result = _tmp0_;
#line 153 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return result;
#line 1826 "TumblrPublishing.c"
}


static gboolean publishing_tumblr_tumblr_publisher_is_persistent_session_valid (PublishingTumblrTumblrPublisher* self) {
	gboolean result = FALSE;
	gchar* access_phase_token = NULL;
	gchar* _tmp0_ = NULL;
	gchar* access_phase_token_secret = NULL;
	gchar* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	const gchar* _tmp3_ = NULL;
	gboolean valid = FALSE;
	gboolean _tmp5_ = FALSE;
#line 156 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_val_if_fail (PUBLISHING_TUMBLR_IS_TUMBLR_PUBLISHER (self), FALSE);
#line 157 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = publishing_tumblr_tumblr_publisher_get_persistent_access_phase_token (self);
#line 157 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	access_phase_token = _tmp0_;
#line 158 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp1_ = publishing_tumblr_tumblr_publisher_get_persistent_access_phase_token_secret (self);
#line 158 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	access_phase_token_secret = _tmp1_;
#line 160 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp3_ = access_phase_token;
#line 160 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	if (_tmp3_ != NULL) {
#line 1854 "TumblrPublishing.c"
		const gchar* _tmp4_ = NULL;
#line 160 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp4_ = access_phase_token_secret;
#line 160 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp2_ = _tmp4_ != NULL;
#line 1860 "TumblrPublishing.c"
	} else {
#line 160 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp2_ = FALSE;
#line 1864 "TumblrPublishing.c"
	}
#line 160 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	valid = _tmp2_;
#line 162 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp5_ = valid;
#line 162 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	if (_tmp5_) {
#line 163 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		g_debug ("TumblrPublishing.vala:163: existing Tumblr session found in configurat" \
"ion database; using it.");
#line 1874 "TumblrPublishing.c"
	} else {
#line 165 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		g_debug ("TumblrPublishing.vala:165: no persisted Tumblr session exists.");
#line 1878 "TumblrPublishing.c"
	}
#line 167 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	result = valid;
#line 167 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_free0 (access_phase_token_secret);
#line 167 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_free0 (access_phase_token);
#line 167 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return result;
#line 1888 "TumblrPublishing.c"
}


gchar* publishing_tumblr_tumblr_publisher_get_persistent_access_phase_token (PublishingTumblrTumblrPublisher* self) {
	gchar* result = NULL;
	SpitPublishingPluginHost* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 173 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_val_if_fail (PUBLISHING_TUMBLR_IS_TUMBLR_PUBLISHER (self), NULL);
#line 174 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = self->priv->host;
#line 174 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp1_ = spit_host_interface_get_config_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "token", NULL);
#line 174 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	result = _tmp1_;
#line 174 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return result;
#line 1906 "TumblrPublishing.c"
}


static void publishing_tumblr_tumblr_publisher_set_persistent_access_phase_token (PublishingTumblrTumblrPublisher* self, const gchar* token) {
	SpitPublishingPluginHost* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
#line 177 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_if_fail (PUBLISHING_TUMBLR_IS_TUMBLR_PUBLISHER (self));
#line 178 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = self->priv->host;
#line 178 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp1_ = token;
#line 178 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	spit_host_interface_set_config_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "token", _tmp1_);
#line 1921 "TumblrPublishing.c"
}


gchar* publishing_tumblr_tumblr_publisher_get_persistent_access_phase_token_secret (PublishingTumblrTumblrPublisher* self) {
	gchar* result = NULL;
	SpitPublishingPluginHost* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 181 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_val_if_fail (PUBLISHING_TUMBLR_IS_TUMBLR_PUBLISHER (self), NULL);
#line 182 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = self->priv->host;
#line 182 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp1_ = spit_host_interface_get_config_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "token_secret", NULL);
#line 182 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	result = _tmp1_;
#line 182 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return result;
#line 1939 "TumblrPublishing.c"
}


static void publishing_tumblr_tumblr_publisher_set_persistent_access_phase_token_secret (PublishingTumblrTumblrPublisher* self, const gchar* token_secret) {
	SpitPublishingPluginHost* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
#line 185 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_if_fail (PUBLISHING_TUMBLR_IS_TUMBLR_PUBLISHER (self));
#line 186 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = self->priv->host;
#line 186 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp1_ = token_secret;
#line 186 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	spit_host_interface_set_config_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "token_secret", _tmp1_);
#line 1954 "TumblrPublishing.c"
}


gint publishing_tumblr_tumblr_publisher_get_persistent_default_size (PublishingTumblrTumblrPublisher* self) {
	gint result = 0;
	SpitPublishingPluginHost* _tmp0_ = NULL;
	gint _tmp1_ = 0;
#line 189 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_val_if_fail (PUBLISHING_TUMBLR_IS_TUMBLR_PUBLISHER (self), 0);
#line 190 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = self->priv->host;
#line 190 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp1_ = spit_host_interface_get_config_int (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "default_size", 1);
#line 190 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	result = _tmp1_;
#line 190 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return result;
#line 1972 "TumblrPublishing.c"
}


void publishing_tumblr_tumblr_publisher_set_persistent_default_size (PublishingTumblrTumblrPublisher* self, gint size) {
	SpitPublishingPluginHost* _tmp0_ = NULL;
	gint _tmp1_ = 0;
#line 193 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_if_fail (PUBLISHING_TUMBLR_IS_TUMBLR_PUBLISHER (self));
#line 194 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = self->priv->host;
#line 194 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp1_ = size;
#line 194 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	spit_host_interface_set_config_int (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "default_size", _tmp1_);
#line 1987 "TumblrPublishing.c"
}


gint publishing_tumblr_tumblr_publisher_get_persistent_default_blog (PublishingTumblrTumblrPublisher* self) {
	gint result = 0;
	SpitPublishingPluginHost* _tmp0_ = NULL;
	gint _tmp1_ = 0;
#line 197 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_val_if_fail (PUBLISHING_TUMBLR_IS_TUMBLR_PUBLISHER (self), 0);
#line 198 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = self->priv->host;
#line 198 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp1_ = spit_host_interface_get_config_int (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "default_blog", 0);
#line 198 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	result = _tmp1_;
#line 198 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return result;
#line 2005 "TumblrPublishing.c"
}


void publishing_tumblr_tumblr_publisher_set_persistent_default_blog (PublishingTumblrTumblrPublisher* self, gint blog) {
	SpitPublishingPluginHost* _tmp0_ = NULL;
	gint _tmp1_ = 0;
#line 201 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_if_fail (PUBLISHING_TUMBLR_IS_TUMBLR_PUBLISHER (self));
#line 202 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = self->priv->host;
#line 202 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp1_ = blog;
#line 202 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	spit_host_interface_set_config_int (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "default_blog", _tmp1_);
#line 2020 "TumblrPublishing.c"
}


/**
     * Action that shows the authentication pane.
     *
     * This action method shows the authentication pane. It is shown at the
     * very beginning of the interaction when no persistent parameters are found
     * or after a failed login attempt using persisted parameters. It can be
     * given a mode flag to specify whether it should be displayed in initial
     * mode or in any of the error modes that it supports.
     *
     * @param mode the mode for the authentication pane
     */
static void _publishing_tumblr_tumblr_publisher_on_authentication_pane_login_clicked_publishing_tumblr_tumblr_publisher_authentication_pane_login (PublishingTumblrTumblrPublisherAuthenticationPane* _sender, const gchar* user, const gchar* password, gpointer self) {
#line 224 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_tumblr_tumblr_publisher_on_authentication_pane_login_clicked ((PublishingTumblrTumblrPublisher*) self, user, password);
#line 2038 "TumblrPublishing.c"
}


static void publishing_tumblr_tumblr_publisher_do_show_authentication_pane (PublishingTumblrTumblrPublisher* self, PublishingTumblrTumblrPublisherAuthenticationPaneMode mode) {
	SpitPublishingPluginHost* _tmp0_ = NULL;
	PublishingTumblrTumblrPublisherAuthenticationPane* authentication_pane = NULL;
	PublishingTumblrTumblrPublisherAuthenticationPaneMode _tmp1_ = 0;
	PublishingTumblrTumblrPublisherAuthenticationPane* _tmp2_ = NULL;
	SpitPublishingPluginHost* _tmp3_ = NULL;
	SpitPublishingPluginHost* _tmp4_ = NULL;
	GtkWidget* _tmp5_ = NULL;
	GtkWidget* _tmp6_ = NULL;
#line 218 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_if_fail (PUBLISHING_TUMBLR_IS_TUMBLR_PUBLISHER (self));
#line 219 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_debug ("TumblrPublishing.vala:219: ACTION: installing authentication pane");
#line 221 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = self->priv->host;
#line 221 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	spit_publishing_plugin_host_set_service_locked (_tmp0_, FALSE);
#line 222 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp1_ = mode;
#line 222 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp2_ = publishing_tumblr_tumblr_publisher_authentication_pane_new (self, _tmp1_);
#line 222 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	authentication_pane = _tmp2_;
#line 224 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_signal_connect_object (authentication_pane, "login", (GCallback) _publishing_tumblr_tumblr_publisher_on_authentication_pane_login_clicked_publishing_tumblr_tumblr_publisher_authentication_pane_login, self, 0);
#line 225 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp3_ = self->priv->host;
#line 225 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	spit_publishing_plugin_host_install_dialog_pane (_tmp3_, G_TYPE_CHECK_INSTANCE_CAST (authentication_pane, SPIT_PUBLISHING_TYPE_DIALOG_PANE, SpitPublishingDialogPane), SPIT_PUBLISHING_PLUGIN_HOST_BUTTON_MODE_CLOSE);
#line 226 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp4_ = self->priv->host;
#line 226 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp5_ = publishing_tumblr_tumblr_publisher_authentication_pane_get_default_widget (authentication_pane);
#line 226 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp6_ = _tmp5_;
#line 226 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	spit_publishing_plugin_host_set_dialog_default_widget (_tmp4_, _tmp6_);
#line 226 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_object_unref0 (_tmp6_);
#line 218 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_object_unref0 (authentication_pane);
#line 2083 "TumblrPublishing.c"
}


/**
     * Event triggered when the login button in the authentication panel is
     * clicked.
     *
     * This event is triggered when the login button in the authentication
     * panel is clicked. It then triggers a network login interaction.
     *
     * @param username the name of the Tumblr user as entered in the dialog
     * @param password the password of the Tumblr as entered in the dialog
     */
static void publishing_tumblr_tumblr_publisher_on_authentication_pane_login_clicked (PublishingTumblrTumblrPublisher* self, const gchar* username, const gchar* password) {
	gboolean _tmp0_ = FALSE;
	const gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
#line 239 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_if_fail (PUBLISHING_TUMBLR_IS_TUMBLR_PUBLISHER (self));
#line 239 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_if_fail (username != NULL);
#line 239 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_if_fail (password != NULL);
#line 240 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_debug ("TumblrPublishing.vala:240: EVENT: on_authentication_pane_login_clicked");
#line 241 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = self->priv->running;
#line 241 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	if (!_tmp0_) {
#line 242 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		return;
#line 2115 "TumblrPublishing.c"
	}
#line 244 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp1_ = username;
#line 244 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp2_ = password;
#line 244 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_tumblr_tumblr_publisher_do_network_login (self, _tmp1_, _tmp2_);
#line 2123 "TumblrPublishing.c"
}


/**
     * Action to perform a network login to a Tumblr blog.
     *
     * This action performs a network login a Tumblr blog specified the given user name and password as credentials.
     *
     * @param username the name of the Tumblr user used to login
     * @param password the password of the Tumblr user used to login
     */
static void _publishing_tumblr_tumblr_publisher_on_auth_request_txn_completed_publishing_rest_support_transaction_completed (PublishingRESTSupportTransaction* _sender, gpointer self) {
#line 262 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_tumblr_tumblr_publisher_on_auth_request_txn_completed ((PublishingTumblrTumblrPublisher*) self, _sender);
#line 2138 "TumblrPublishing.c"
}


static void _publishing_tumblr_tumblr_publisher_on_auth_request_txn_error_publishing_rest_support_transaction_network_error (PublishingRESTSupportTransaction* _sender, GError* err, gpointer self) {
#line 263 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_tumblr_tumblr_publisher_on_auth_request_txn_error ((PublishingTumblrTumblrPublisher*) self, _sender, err);
#line 2145 "TumblrPublishing.c"
}


static void publishing_tumblr_tumblr_publisher_do_network_login (PublishingTumblrTumblrPublisher* self, const gchar* username, const gchar* password) {
	SpitPublishingPluginHost* _tmp0_ = NULL;
	SpitPublishingPluginHost* _tmp1_ = NULL;
	PublishingTumblrTumblrPublisherAccessTokenFetchTransaction* txn = NULL;
	PublishingTumblrTumblrPublisherSession* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	PublishingTumblrTumblrPublisherAccessTokenFetchTransaction* _tmp5_ = NULL;
	GError * _inner_error_ = NULL;
#line 255 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_if_fail (PUBLISHING_TUMBLR_IS_TUMBLR_PUBLISHER (self));
#line 255 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_if_fail (username != NULL);
#line 255 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_if_fail (password != NULL);
#line 256 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_debug ("TumblrPublishing.vala:256: ACTION: logging in");
#line 257 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = self->priv->host;
#line 257 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	spit_publishing_plugin_host_set_service_locked (_tmp0_, TRUE);
#line 258 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp1_ = self->priv->host;
#line 258 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	spit_publishing_plugin_host_install_login_wait_pane (_tmp1_);
#line 261 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp2_ = self->priv->session;
#line 261 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp3_ = username;
#line 261 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp4_ = password;
#line 261 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp5_ = publishing_tumblr_tumblr_publisher_access_token_fetch_transaction_new (_tmp2_, _tmp3_, _tmp4_);
#line 261 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	txn = _tmp5_;
#line 262 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (txn, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "completed", (GCallback) _publishing_tumblr_tumblr_publisher_on_auth_request_txn_completed_publishing_rest_support_transaction_completed, self, 0);
#line 263 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (txn, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "network-error", (GCallback) _publishing_tumblr_tumblr_publisher_on_auth_request_txn_error_publishing_rest_support_transaction_network_error, self, 0);
#line 2188 "TumblrPublishing.c"
	{
#line 266 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		publishing_rest_support_transaction_execute (G_TYPE_CHECK_INSTANCE_CAST (txn, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), &_inner_error_);
#line 266 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 266 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 2196 "TumblrPublishing.c"
				goto __catch32_spit_publishing_publishing_error;
			}
#line 266 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			_publishing_rest_support_transaction_unref0 (txn);
#line 266 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 266 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			g_clear_error (&_inner_error_);
#line 266 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			return;
#line 2207 "TumblrPublishing.c"
		}
	}
	goto __finally32;
	__catch32_spit_publishing_publishing_error:
	{
		GError* err = NULL;
		SpitPublishingPluginHost* _tmp6_ = NULL;
		GError* _tmp7_ = NULL;
#line 265 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		err = _inner_error_;
#line 265 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_inner_error_ = NULL;
#line 268 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp6_ = self->priv->host;
#line 268 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp7_ = err;
#line 268 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		spit_publishing_plugin_host_post_error (_tmp6_, _tmp7_);
#line 265 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_g_error_free0 (err);
#line 2228 "TumblrPublishing.c"
	}
	__finally32:
#line 265 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 265 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_publishing_rest_support_transaction_unref0 (txn);
#line 265 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 265 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		g_clear_error (&_inner_error_);
#line 265 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		return;
#line 2241 "TumblrPublishing.c"
	}
#line 255 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_publishing_rest_support_transaction_unref0 (txn);
#line 2245 "TumblrPublishing.c"
}


static void publishing_tumblr_tumblr_publisher_on_auth_request_txn_completed (PublishingTumblrTumblrPublisher* self, PublishingRESTSupportTransaction* txn) {
	PublishingRESTSupportTransaction* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
	PublishingRESTSupportTransaction* _tmp2_ = NULL;
	guint _tmp3_ = 0U;
	gboolean _tmp4_ = FALSE;
	PublishingRESTSupportTransaction* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
	PublishingRESTSupportTransaction* _tmp8_ = NULL;
	gchar* _tmp9_ = NULL;
	gchar* _tmp10_ = NULL;
#line 273 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_if_fail (PUBLISHING_TUMBLR_IS_TUMBLR_PUBLISHER (self));
#line 273 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_TRANSACTION (txn));
#line 274 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = txn;
#line 274 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_signal_parse_name ("completed", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp1_, NULL, FALSE);
#line 274 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_tumblr_tumblr_publisher_on_auth_request_txn_completed_publishing_rest_support_transaction_completed, self);
#line 275 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp2_ = txn;
#line 275 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_signal_parse_name ("network-error", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp3_, NULL, FALSE);
#line 275 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp2_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _publishing_tumblr_tumblr_publisher_on_auth_request_txn_error_publishing_rest_support_transaction_network_error, self);
#line 277 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp4_ = spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher));
#line 277 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	if (!_tmp4_) {
#line 278 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		return;
#line 2283 "TumblrPublishing.c"
	}
#line 280 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp5_ = txn;
#line 280 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp6_ = publishing_rest_support_transaction_get_response (_tmp5_);
#line 280 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp7_ = _tmp6_;
#line 280 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_debug ("TumblrPublishing.vala:280: EVENT: OAuth authentication request transac" \
"tion completed; response = '%s'", _tmp7_);
#line 280 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_free0 (_tmp7_);
#line 283 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp8_ = txn;
#line 283 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp9_ = publishing_rest_support_transaction_get_response (_tmp8_);
#line 283 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp10_ = _tmp9_;
#line 283 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_tumblr_tumblr_publisher_do_parse_token_info_from_auth_request (self, _tmp10_);
#line 283 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_free0 (_tmp10_);
#line 2305 "TumblrPublishing.c"
}


static void publishing_tumblr_tumblr_publisher_on_auth_request_txn_error (PublishingTumblrTumblrPublisher* self, PublishingRESTSupportTransaction* txn, GError* err) {
	PublishingRESTSupportTransaction* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
	PublishingRESTSupportTransaction* _tmp2_ = NULL;
	guint _tmp3_ = 0U;
	gboolean _tmp4_ = FALSE;
	SpitPublishingPluginHost* _tmp5_ = NULL;
	GError* _tmp6_ = NULL;
#line 286 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_if_fail (PUBLISHING_TUMBLR_IS_TUMBLR_PUBLISHER (self));
#line 286 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_TRANSACTION (txn));
#line 288 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = txn;
#line 288 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_signal_parse_name ("completed", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp1_, NULL, FALSE);
#line 288 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_tumblr_tumblr_publisher_on_auth_request_txn_completed_publishing_rest_support_transaction_completed, self);
#line 289 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp2_ = txn;
#line 289 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_signal_parse_name ("network-error", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp3_, NULL, FALSE);
#line 289 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp2_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _publishing_tumblr_tumblr_publisher_on_auth_request_txn_error_publishing_rest_support_transaction_network_error, self);
#line 291 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp4_ = spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher));
#line 291 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	if (!_tmp4_) {
#line 292 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		return;
#line 2339 "TumblrPublishing.c"
	}
#line 294 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_debug ("TumblrPublishing.vala:294: EVENT: OAuth authentication request transac" \
"tion caused a network error");
#line 295 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp5_ = self->priv->host;
#line 295 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp6_ = err;
#line 295 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	spit_publishing_plugin_host_post_error (_tmp5_, _tmp6_);
#line 2349 "TumblrPublishing.c"
}


static void publishing_tumblr_tumblr_publisher_do_parse_token_info_from_auth_request (PublishingTumblrTumblrPublisher* self, const gchar* response) {
	const gchar* _tmp0_ = NULL;
	gchar* oauth_token = NULL;
	gchar* oauth_token_secret = NULL;
	gchar** key_value_pairs = NULL;
	const gchar* _tmp1_ = NULL;
	gchar** _tmp2_ = NULL;
	gchar** _tmp3_ = NULL;
	gint key_value_pairs_length1 = 0;
	gint _key_value_pairs_size_ = 0;
	gchar** _tmp4_ = NULL;
	gint _tmp4__length1 = 0;
	gboolean _tmp24_ = FALSE;
	const gchar* _tmp25_ = NULL;
	PublishingTumblrTumblrPublisherSession* _tmp31_ = NULL;
	const gchar* _tmp32_ = NULL;
	const gchar* _tmp33_ = NULL;
#line 299 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_if_fail (PUBLISHING_TUMBLR_IS_TUMBLR_PUBLISHER (self));
#line 299 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_if_fail (response != NULL);
#line 300 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = response;
#line 300 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_debug ("TumblrPublishing.vala:300: ACTION: parsing authorization request respo" \
"nse '%s' into token and secret", _tmp0_);
#line 302 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	oauth_token = NULL;
#line 303 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	oauth_token_secret = NULL;
#line 305 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp1_ = response;
#line 305 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp3_ = _tmp2_ = g_strsplit (_tmp1_, "&", 0);
#line 305 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	key_value_pairs = _tmp3_;
#line 305 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	key_value_pairs_length1 = _vala_array_length (_tmp2_);
#line 305 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_key_value_pairs_size_ = key_value_pairs_length1;
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp4_ = key_value_pairs;
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp4__length1 = key_value_pairs_length1;
#line 2396 "TumblrPublishing.c"
	{
		gchar** pair_collection = NULL;
		gint pair_collection_length1 = 0;
		gint _pair_collection_size_ = 0;
		gint pair_it = 0;
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		pair_collection = _tmp4_;
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		pair_collection_length1 = _tmp4__length1;
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		for (pair_it = 0; pair_it < _tmp4__length1; pair_it = pair_it + 1) {
#line 2408 "TumblrPublishing.c"
			gchar* _tmp5_ = NULL;
			gchar* pair = NULL;
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			_tmp5_ = g_strdup (pair_collection[pair_it]);
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			pair = _tmp5_;
#line 2415 "TumblrPublishing.c"
			{
				gchar** split_pair = NULL;
				const gchar* _tmp6_ = NULL;
				gchar** _tmp7_ = NULL;
				gchar** _tmp8_ = NULL;
				gint split_pair_length1 = 0;
				gint _split_pair_size_ = 0;
				gchar** _tmp9_ = NULL;
				gint _tmp9__length1 = 0;
				gchar** _tmp14_ = NULL;
				gint _tmp14__length1 = 0;
				const gchar* _tmp15_ = NULL;
#line 307 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp6_ = pair;
#line 307 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp8_ = _tmp7_ = g_strsplit (_tmp6_, "=", 0);
#line 307 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				split_pair = _tmp8_;
#line 307 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				split_pair_length1 = _vala_array_length (_tmp7_);
#line 307 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_split_pair_size_ = split_pair_length1;
#line 309 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp9_ = split_pair;
#line 309 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp9__length1 = split_pair_length1;
#line 309 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				if (_tmp9__length1 != 2) {
#line 2444 "TumblrPublishing.c"
					SpitPublishingPluginHost* _tmp10_ = NULL;
					const gchar* _tmp11_ = NULL;
					GError* _tmp12_ = NULL;
					GError* _tmp13_ = NULL;
#line 310 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					_tmp10_ = self->priv->host;
#line 310 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					_tmp11_ = _ ("'%s' isn't a valid response to an OAuth authentication request");
#line 310 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					_tmp12_ = g_error_new_literal (SPIT_PUBLISHING_PUBLISHING_ERROR, SPIT_PUBLISHING_PUBLISHING_ERROR_MALFORMED_RESPONSE, _tmp11_);
#line 310 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					_tmp13_ = _tmp12_;
#line 310 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					spit_publishing_plugin_host_post_error (_tmp10_, _tmp13_);
#line 310 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					_g_error_free0 (_tmp13_);
#line 2461 "TumblrPublishing.c"
				}
#line 313 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp14_ = split_pair;
#line 313 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp14__length1 = split_pair_length1;
#line 313 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp15_ = _tmp14_[0];
#line 313 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				if (g_strcmp0 (_tmp15_, "oauth_token") == 0) {
#line 2471 "TumblrPublishing.c"
					gchar** _tmp16_ = NULL;
					gint _tmp16__length1 = 0;
					const gchar* _tmp17_ = NULL;
					gchar* _tmp18_ = NULL;
#line 314 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					_tmp16_ = split_pair;
#line 314 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					_tmp16__length1 = split_pair_length1;
#line 314 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					_tmp17_ = _tmp16_[1];
#line 314 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					_tmp18_ = g_strdup (_tmp17_);
#line 314 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					_g_free0 (oauth_token);
#line 314 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					oauth_token = _tmp18_;
#line 2488 "TumblrPublishing.c"
				} else {
					gchar** _tmp19_ = NULL;
					gint _tmp19__length1 = 0;
					const gchar* _tmp20_ = NULL;
#line 315 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					_tmp19_ = split_pair;
#line 315 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					_tmp19__length1 = split_pair_length1;
#line 315 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					_tmp20_ = _tmp19_[0];
#line 315 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					if (g_strcmp0 (_tmp20_, "oauth_token_secret") == 0) {
#line 2501 "TumblrPublishing.c"
						gchar** _tmp21_ = NULL;
						gint _tmp21__length1 = 0;
						const gchar* _tmp22_ = NULL;
						gchar* _tmp23_ = NULL;
#line 316 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
						_tmp21_ = split_pair;
#line 316 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
						_tmp21__length1 = split_pair_length1;
#line 316 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
						_tmp22_ = _tmp21_[1];
#line 316 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
						_tmp23_ = g_strdup (_tmp22_);
#line 316 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
						_g_free0 (oauth_token_secret);
#line 316 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
						oauth_token_secret = _tmp23_;
#line 2518 "TumblrPublishing.c"
					}
				}
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				split_pair = (_vala_array_free (split_pair, split_pair_length1, (GDestroyNotify) g_free), NULL);
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_g_free0 (pair);
#line 2525 "TumblrPublishing.c"
			}
		}
	}
#line 319 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp25_ = oauth_token;
#line 319 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	if (_tmp25_ == NULL) {
#line 319 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp24_ = TRUE;
#line 2535 "TumblrPublishing.c"
	} else {
		const gchar* _tmp26_ = NULL;
#line 319 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp26_ = oauth_token_secret;
#line 319 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp24_ = _tmp26_ == NULL;
#line 2542 "TumblrPublishing.c"
	}
#line 319 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	if (_tmp24_) {
#line 2546 "TumblrPublishing.c"
		SpitPublishingPluginHost* _tmp27_ = NULL;
		const gchar* _tmp28_ = NULL;
		GError* _tmp29_ = NULL;
		GError* _tmp30_ = NULL;
#line 320 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp27_ = self->priv->host;
#line 320 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp28_ = _ ("'%s' isn't a valid response to an OAuth authentication request");
#line 320 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp29_ = g_error_new_literal (SPIT_PUBLISHING_PUBLISHING_ERROR, SPIT_PUBLISHING_PUBLISHING_ERROR_MALFORMED_RESPONSE, _tmp28_);
#line 320 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp30_ = _tmp29_;
#line 320 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		spit_publishing_plugin_host_post_error (_tmp27_, _tmp30_);
#line 320 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_g_error_free0 (_tmp30_);
#line 2563 "TumblrPublishing.c"
	}
#line 323 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp31_ = self->priv->session;
#line 323 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp32_ = oauth_token;
#line 323 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp33_ = oauth_token_secret;
#line 323 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_tumblr_tumblr_publisher_session_set_access_phase_credentials (_tmp31_, _tmp32_, _tmp33_);
#line 299 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	key_value_pairs = (_vala_array_free (key_value_pairs, key_value_pairs_length1, (GDestroyNotify) g_free), NULL);
#line 299 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_free0 (oauth_token_secret);
#line 299 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_free0 (oauth_token);
#line 2579 "TumblrPublishing.c"
}


static void publishing_tumblr_tumblr_publisher_on_session_authenticated (PublishingTumblrTumblrPublisher* self) {
	gboolean _tmp0_ = FALSE;
	PublishingTumblrTumblrPublisherSession* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	PublishingTumblrTumblrPublisherSession* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
#line 328 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_if_fail (PUBLISHING_TUMBLR_IS_TUMBLR_PUBLISHER (self));
#line 329 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher));
#line 329 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	if (!_tmp0_) {
#line 330 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		return;
#line 2599 "TumblrPublishing.c"
	}
#line 332 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_debug ("TumblrPublishing.vala:332: EVENT: a fully authenticated session has be" \
"come available");
#line 333 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp1_ = self->priv->session;
#line 333 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp2_ = publishing_tumblr_tumblr_publisher_session_get_access_phase_token (_tmp1_);
#line 333 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp3_ = _tmp2_;
#line 333 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_tumblr_tumblr_publisher_set_persistent_access_phase_token (self, _tmp3_);
#line 333 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_free0 (_tmp3_);
#line 334 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp4_ = self->priv->session;
#line 334 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp5_ = publishing_tumblr_tumblr_publisher_session_get_access_phase_token_secret (_tmp4_);
#line 334 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp6_ = _tmp5_;
#line 334 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_tumblr_tumblr_publisher_set_persistent_access_phase_token_secret (self, _tmp6_);
#line 334 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_free0 (_tmp6_);
#line 335 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_tumblr_tumblr_publisher_do_get_blogs (self);
#line 2625 "TumblrPublishing.c"
}


static void _publishing_tumblr_tumblr_publisher_on_info_request_txn_completed_publishing_rest_support_transaction_completed (PublishingRESTSupportTransaction* _sender, gpointer self) {
#line 342 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_tumblr_tumblr_publisher_on_info_request_txn_completed ((PublishingTumblrTumblrPublisher*) self, _sender);
#line 2632 "TumblrPublishing.c"
}


static void _publishing_tumblr_tumblr_publisher_on_info_request_txn_error_publishing_rest_support_transaction_network_error (PublishingRESTSupportTransaction* _sender, GError* err, gpointer self) {
#line 343 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_tumblr_tumblr_publisher_on_info_request_txn_error ((PublishingTumblrTumblrPublisher*) self, _sender, err);
#line 2639 "TumblrPublishing.c"
}


static void publishing_tumblr_tumblr_publisher_do_get_blogs (PublishingTumblrTumblrPublisher* self) {
	PublishingTumblrTumblrPublisherUserInfoFetchTransaction* txn = NULL;
	PublishingTumblrTumblrPublisherSession* _tmp0_ = NULL;
	PublishingTumblrTumblrPublisherUserInfoFetchTransaction* _tmp1_ = NULL;
	GError * _inner_error_ = NULL;
#line 339 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_if_fail (PUBLISHING_TUMBLR_IS_TUMBLR_PUBLISHER (self));
#line 340 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_debug ("TumblrPublishing.vala:340: ACTION: obtain all blogs of the tumblr user");
#line 341 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = self->priv->session;
#line 341 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp1_ = publishing_tumblr_tumblr_publisher_user_info_fetch_transaction_new (_tmp0_);
#line 341 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	txn = _tmp1_;
#line 342 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (txn, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "completed", (GCallback) _publishing_tumblr_tumblr_publisher_on_info_request_txn_completed_publishing_rest_support_transaction_completed, self, 0);
#line 343 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (txn, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "network-error", (GCallback) _publishing_tumblr_tumblr_publisher_on_info_request_txn_error_publishing_rest_support_transaction_network_error, self, 0);
#line 2662 "TumblrPublishing.c"
	{
#line 346 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		publishing_rest_support_transaction_execute (G_TYPE_CHECK_INSTANCE_CAST (txn, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), &_inner_error_);
#line 346 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 346 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 2670 "TumblrPublishing.c"
				goto __catch33_spit_publishing_publishing_error;
			}
#line 346 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			_publishing_rest_support_transaction_unref0 (txn);
#line 346 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 346 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			g_clear_error (&_inner_error_);
#line 346 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			return;
#line 2681 "TumblrPublishing.c"
		}
	}
	goto __finally33;
	__catch33_spit_publishing_publishing_error:
	{
		GError* err = NULL;
		SpitPublishingPluginHost* _tmp2_ = NULL;
		GError* _tmp3_ = NULL;
#line 345 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		err = _inner_error_;
#line 345 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_inner_error_ = NULL;
#line 348 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp2_ = self->priv->host;
#line 348 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp3_ = err;
#line 348 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		spit_publishing_plugin_host_post_error (_tmp2_, _tmp3_);
#line 345 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_g_error_free0 (err);
#line 2702 "TumblrPublishing.c"
	}
	__finally33:
#line 345 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 345 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_publishing_rest_support_transaction_unref0 (txn);
#line 345 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 345 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		g_clear_error (&_inner_error_);
#line 345 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		return;
#line 2715 "TumblrPublishing.c"
	}
#line 339 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_publishing_rest_support_transaction_unref0 (txn);
#line 2719 "TumblrPublishing.c"
}


static void publishing_tumblr_tumblr_publisher_on_info_request_txn_completed (PublishingTumblrTumblrPublisher* self, PublishingRESTSupportTransaction* txn) {
	PublishingRESTSupportTransaction* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
	PublishingRESTSupportTransaction* _tmp2_ = NULL;
	guint _tmp3_ = 0U;
	gboolean _tmp4_ = FALSE;
	PublishingRESTSupportTransaction* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
	PublishingRESTSupportTransaction* _tmp8_ = NULL;
	gchar* _tmp9_ = NULL;
	gchar* _tmp10_ = NULL;
#line 355 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_if_fail (PUBLISHING_TUMBLR_IS_TUMBLR_PUBLISHER (self));
#line 355 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_TRANSACTION (txn));
#line 356 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = txn;
#line 356 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_signal_parse_name ("completed", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp1_, NULL, FALSE);
#line 356 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_tumblr_tumblr_publisher_on_info_request_txn_completed_publishing_rest_support_transaction_completed, self);
#line 357 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp2_ = txn;
#line 357 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_signal_parse_name ("network-error", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp3_, NULL, FALSE);
#line 357 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp2_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _publishing_tumblr_tumblr_publisher_on_info_request_txn_error_publishing_rest_support_transaction_network_error, self);
#line 359 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp4_ = spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher));
#line 359 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	if (!_tmp4_) {
#line 360 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		return;
#line 2757 "TumblrPublishing.c"
	}
#line 362 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp5_ = txn;
#line 362 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp6_ = publishing_rest_support_transaction_get_response (_tmp5_);
#line 362 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp7_ = _tmp6_;
#line 362 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_debug ("TumblrPublishing.vala:362: EVENT: user info request transaction comple" \
"ted; response = '%s'", _tmp7_);
#line 362 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_free0 (_tmp7_);
#line 364 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp8_ = txn;
#line 364 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp9_ = publishing_rest_support_transaction_get_response (_tmp8_);
#line 364 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp10_ = _tmp9_;
#line 364 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_tumblr_tumblr_publisher_do_parse_token_info_from_user_request (self, _tmp10_);
#line 364 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_free0 (_tmp10_);
#line 365 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_tumblr_tumblr_publisher_do_show_publishing_options_pane (self);
#line 2781 "TumblrPublishing.c"
}


static gpointer _json_object_ref0 (gpointer self) {
#line 374 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return self ? json_object_ref (self) : NULL;
#line 2788 "TumblrPublishing.c"
}


static gchar* string_replace (const gchar* self, const gchar* old, const gchar* replacement) {
	gchar* result = NULL;
	GError * _inner_error_ = NULL;
#line 1380 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1380 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	g_return_val_if_fail (old != NULL, NULL);
#line 1380 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	g_return_val_if_fail (replacement != NULL, NULL);
#line 2801 "TumblrPublishing.c"
	{
		GRegex* regex = NULL;
		const gchar* _tmp0_ = NULL;
		gchar* _tmp1_ = NULL;
		gchar* _tmp2_ = NULL;
		GRegex* _tmp3_ = NULL;
		GRegex* _tmp4_ = NULL;
		gchar* _tmp5_ = NULL;
		GRegex* _tmp6_ = NULL;
		const gchar* _tmp7_ = NULL;
		gchar* _tmp8_ = NULL;
		gchar* _tmp9_ = NULL;
#line 1382 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp0_ = old;
#line 1382 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp1_ = g_regex_escape_string (_tmp0_, -1);
#line 1382 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp2_ = _tmp1_;
#line 1382 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp3_ = g_regex_new (_tmp2_, 0, 0, &_inner_error_);
#line 1382 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp4_ = _tmp3_;
#line 1382 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_g_free0 (_tmp2_);
#line 1382 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		regex = _tmp4_;
#line 1382 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1382 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
			if (_inner_error_->domain == G_REGEX_ERROR) {
#line 2832 "TumblrPublishing.c"
				goto __catch35_g_regex_error;
			}
#line 1382 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1382 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
			g_clear_error (&_inner_error_);
#line 1382 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
			return NULL;
#line 2841 "TumblrPublishing.c"
		}
#line 1383 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp6_ = regex;
#line 1383 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp7_ = replacement;
#line 1383 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp8_ = g_regex_replace_literal (_tmp6_, self, (gssize) -1, 0, _tmp7_, 0, &_inner_error_);
#line 1383 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp5_ = _tmp8_;
#line 1383 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1383 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
			_g_regex_unref0 (regex);
#line 1383 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
			if (_inner_error_->domain == G_REGEX_ERROR) {
#line 2857 "TumblrPublishing.c"
				goto __catch35_g_regex_error;
			}
#line 1383 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
			_g_regex_unref0 (regex);
#line 1383 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1383 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
			g_clear_error (&_inner_error_);
#line 1383 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
			return NULL;
#line 2868 "TumblrPublishing.c"
		}
#line 1383 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp9_ = _tmp5_;
#line 1383 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp5_ = NULL;
#line 1383 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		result = _tmp9_;
#line 1383 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_g_free0 (_tmp5_);
#line 1383 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_g_regex_unref0 (regex);
#line 1383 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		return result;
#line 2882 "TumblrPublishing.c"
	}
	goto __finally35;
	__catch35_g_regex_error:
	{
		GError* e = NULL;
#line 1381 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		e = _inner_error_;
#line 1381 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_inner_error_ = NULL;
#line 1385 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		g_assert_not_reached ();
#line 1381 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_g_error_free0 (e);
#line 2896 "TumblrPublishing.c"
	}
	__finally35:
#line 1381 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1381 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1381 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		g_clear_error (&_inner_error_);
#line 1381 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		return NULL;
#line 2907 "TumblrPublishing.c"
	}
}


static void _vala_array_add21 (PublishingTumblrBlogEntry*** array, int* length, int* size, PublishingTumblrBlogEntry* value) {
#line 382 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	if ((*length) == (*size)) {
#line 382 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 382 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		*array = g_renew (PublishingTumblrBlogEntry*, *array, (*size) + 1);
#line 2919 "TumblrPublishing.c"
	}
#line 382 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	(*array)[(*length)++] = value;
#line 382 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	(*array)[*length] = NULL;
#line 2925 "TumblrPublishing.c"
}


static void publishing_tumblr_tumblr_publisher_do_parse_token_info_from_user_request (PublishingTumblrTumblrPublisher* self, const gchar* response) {
	const gchar* _tmp0_ = NULL;
	GError * _inner_error_ = NULL;
#line 369 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_if_fail (PUBLISHING_TUMBLR_IS_TUMBLR_PUBLISHER (self));
#line 369 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_if_fail (response != NULL);
#line 370 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = response;
#line 370 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_debug ("TumblrPublishing.vala:370: ACTION: parsing info request response '%s' " \
"into list of available blogs", _tmp0_);
#line 2940 "TumblrPublishing.c"
	{
		JsonParser* parser = NULL;
		JsonParser* _tmp1_ = NULL;
		const gchar* _tmp2_ = NULL;
		JsonObject* root_object = NULL;
		JsonNode* _tmp3_ = NULL;
		JsonObject* _tmp4_ = NULL;
		JsonObject* _tmp5_ = NULL;
		JsonObject* _tmp6_ = NULL;
		JsonObject* _tmp7_ = NULL;
		JsonObject* _tmp8_ = NULL;
		const gchar* _tmp9_ = NULL;
		gchar* _tmp10_ = NULL;
		const gchar* _tmp11_ = NULL;
		JsonObject* _tmp12_ = NULL;
		JsonObject* _tmp13_ = NULL;
		JsonObject* _tmp14_ = NULL;
		JsonArray* _tmp15_ = NULL;
		GList* _tmp16_ = NULL;
#line 372 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp1_ = json_parser_new ();
#line 372 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		parser = _tmp1_;
#line 373 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp2_ = response;
#line 373 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		json_parser_load_from_data (parser, _tmp2_, (gssize) -1, &_inner_error_);
#line 373 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 373 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			_g_object_unref0 (parser);
#line 2972 "TumblrPublishing.c"
			goto __catch34_g_error;
		}
#line 374 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp3_ = json_parser_get_root (parser);
#line 374 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp4_ = json_node_get_object (_tmp3_);
#line 374 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp5_ = _json_object_ref0 (_tmp4_);
#line 374 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		root_object = _tmp5_;
#line 375 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp6_ = root_object;
#line 375 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp7_ = json_object_get_object_member (_tmp6_, "response");
#line 375 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp8_ = json_object_get_object_member (_tmp7_, "user");
#line 375 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp9_ = json_object_get_string_member (_tmp8_, "name");
#line 375 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp10_ = g_strdup (_tmp9_);
#line 375 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_g_free0 (self->priv->username);
#line 375 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		self->priv->username = _tmp10_;
#line 376 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp11_ = self->priv->username;
#line 376 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		g_debug ("TumblrPublishing.vala:376: Got user name: %s", _tmp11_);
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp12_ = root_object;
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp13_ = json_object_get_object_member (_tmp12_, "response");
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp14_ = json_object_get_object_member (_tmp13_, "user");
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp15_ = json_object_get_array_member (_tmp14_, "blogs");
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp16_ = json_array_get_elements (_tmp15_);
#line 3011 "TumblrPublishing.c"
		{
			GList* blognode_collection = NULL;
			GList* blognode_it = NULL;
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			blognode_collection = _tmp16_;
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			for (blognode_it = blognode_collection; blognode_it != NULL; blognode_it = blognode_it->next) {
#line 3019 "TumblrPublishing.c"
				JsonNode* blognode = NULL;
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				blognode = (JsonNode*) blognode_it->data;
#line 3023 "TumblrPublishing.c"
				{
					JsonObject* blog = NULL;
					JsonNode* _tmp17_ = NULL;
					JsonObject* _tmp18_ = NULL;
					JsonObject* _tmp19_ = NULL;
					gchar* name = NULL;
					JsonObject* _tmp20_ = NULL;
					const gchar* _tmp21_ = NULL;
					gchar* _tmp22_ = NULL;
					gchar* url = NULL;
					JsonObject* _tmp23_ = NULL;
					const gchar* _tmp24_ = NULL;
					gchar* _tmp25_ = NULL;
					gchar* _tmp26_ = NULL;
					gchar* _tmp27_ = NULL;
					gchar* _tmp28_ = NULL;
					const gchar* _tmp29_ = NULL;
					const gchar* _tmp30_ = NULL;
					PublishingTumblrBlogEntry** _tmp31_ = NULL;
					gint _tmp31__length1 = 0;
					const gchar* _tmp32_ = NULL;
					const gchar* _tmp33_ = NULL;
					PublishingTumblrBlogEntry* _tmp34_ = NULL;
#line 378 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					_tmp17_ = blognode;
#line 378 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					_tmp18_ = json_node_get_object (_tmp17_);
#line 378 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					_tmp19_ = _json_object_ref0 (_tmp18_);
#line 378 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					blog = _tmp19_;
#line 379 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					_tmp20_ = blog;
#line 379 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					_tmp21_ = json_object_get_string_member (_tmp20_, "name");
#line 379 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					_tmp22_ = g_strdup (_tmp21_);
#line 379 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					name = _tmp22_;
#line 380 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					_tmp23_ = blog;
#line 380 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					_tmp24_ = json_object_get_string_member (_tmp23_, "url");
#line 380 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					_tmp25_ = string_replace (_tmp24_, "http://", "");
#line 380 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					_tmp26_ = _tmp25_;
#line 380 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					_tmp27_ = string_replace (_tmp26_, "/", "");
#line 380 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					_tmp28_ = _tmp27_;
#line 380 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					_g_free0 (_tmp26_);
#line 380 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					url = _tmp28_;
#line 381 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					_tmp29_ = name;
#line 381 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					_tmp30_ = url;
#line 381 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					g_debug ("TumblrPublishing.vala:381: Got blog name: %s and url: %s", _tmp29_, _tmp30_);
#line 382 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					_tmp31_ = self->priv->blogs;
#line 382 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					_tmp31__length1 = self->priv->blogs_length1;
#line 382 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					_tmp32_ = name;
#line 382 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					_tmp33_ = url;
#line 382 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					_tmp34_ = publishing_tumblr_blog_entry_new (_tmp32_, _tmp33_);
#line 382 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					_vala_array_add21 (&self->priv->blogs, &self->priv->blogs_length1, &self->priv->_blogs_size_, _tmp34_);
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					_g_free0 (url);
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					_g_free0 (name);
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					_json_object_unref0 (blog);
#line 3103 "TumblrPublishing.c"
				}
			}
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			_g_list_free0 (blognode_collection);
#line 3108 "TumblrPublishing.c"
		}
#line 371 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_json_object_unref0 (root_object);
#line 371 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_g_object_unref0 (parser);
#line 3114 "TumblrPublishing.c"
	}
	goto __finally34;
	__catch34_g_error:
	{
		GError* err = NULL;
		SpitPublishingPluginHost* _tmp35_ = NULL;
		GError* _tmp36_ = NULL;
#line 371 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		err = _inner_error_;
#line 371 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_inner_error_ = NULL;
#line 385 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp35_ = self->priv->host;
#line 385 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp36_ = err;
#line 385 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		spit_publishing_plugin_host_post_error (_tmp35_, _tmp36_);
#line 371 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_g_error_free0 (err);
#line 3134 "TumblrPublishing.c"
	}
	__finally34:
#line 371 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 371 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 371 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		g_clear_error (&_inner_error_);
#line 371 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		return;
#line 3145 "TumblrPublishing.c"
	}
}


static void publishing_tumblr_tumblr_publisher_on_info_request_txn_error (PublishingTumblrTumblrPublisher* self, PublishingRESTSupportTransaction* txn, GError* err) {
	PublishingRESTSupportTransaction* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
	PublishingRESTSupportTransaction* _tmp2_ = NULL;
	guint _tmp3_ = 0U;
	gboolean _tmp4_ = FALSE;
	PublishingTumblrTumblrPublisherSession* _tmp5_ = NULL;
	SpitPublishingPluginHost* _tmp6_ = NULL;
	GError* _tmp7_ = NULL;
#line 389 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_if_fail (PUBLISHING_TUMBLR_IS_TUMBLR_PUBLISHER (self));
#line 389 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_TRANSACTION (txn));
#line 391 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = txn;
#line 391 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_signal_parse_name ("completed", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp1_, NULL, FALSE);
#line 391 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_tumblr_tumblr_publisher_on_info_request_txn_completed_publishing_rest_support_transaction_completed, self);
#line 392 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp2_ = txn;
#line 392 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_signal_parse_name ("network-error", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp3_, NULL, FALSE);
#line 392 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp2_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _publishing_tumblr_tumblr_publisher_on_info_request_txn_error_publishing_rest_support_transaction_network_error, self);
#line 394 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp4_ = spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher));
#line 394 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	if (!_tmp4_) {
#line 395 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		return;
#line 3181 "TumblrPublishing.c"
	}
#line 397 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp5_ = self->priv->session;
#line 397 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_tumblr_tumblr_publisher_session_deauthenticate (_tmp5_);
#line 398 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_tumblr_tumblr_publisher_invalidate_persistent_session (self);
#line 399 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_debug ("TumblrPublishing.vala:399: EVENT: user info request transaction caused" \
" a network error");
#line 400 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp6_ = self->priv->host;
#line 400 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp7_ = err;
#line 400 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	spit_publishing_plugin_host_post_error (_tmp6_, _tmp7_);
#line 3197 "TumblrPublishing.c"
}


static void _publishing_tumblr_tumblr_publisher_on_publishing_options_pane_publish_publishing_tumblr_tumblr_publisher_publishing_options_pane_publish (PublishingTumblrTumblrPublisherPublishingOptionsPane* _sender, gpointer self) {
#line 408 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_tumblr_tumblr_publisher_on_publishing_options_pane_publish ((PublishingTumblrTumblrPublisher*) self);
#line 3204 "TumblrPublishing.c"
}


static void _publishing_tumblr_tumblr_publisher_on_publishing_options_pane_logout_publishing_tumblr_tumblr_publisher_publishing_options_pane_logout (PublishingTumblrTumblrPublisherPublishingOptionsPane* _sender, gpointer self) {
#line 409 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_tumblr_tumblr_publisher_on_publishing_options_pane_logout ((PublishingTumblrTumblrPublisher*) self);
#line 3211 "TumblrPublishing.c"
}


static void publishing_tumblr_tumblr_publisher_do_show_publishing_options_pane (PublishingTumblrTumblrPublisher* self) {
	SpitPublishingPluginHost* _tmp0_ = NULL;
	PublishingTumblrTumblrPublisherPublishingOptionsPane* publishing_options_pane = NULL;
	SpitPublishingPluginHost* _tmp1_ = NULL;
	SpitPublishingPublisherMediaType _tmp2_ = 0;
	PublishingTumblrSizeEntry** _tmp3_ = NULL;
	gint _tmp3__length1 = 0;
	PublishingTumblrBlogEntry** _tmp4_ = NULL;
	gint _tmp4__length1 = 0;
	const gchar* _tmp5_ = NULL;
	PublishingTumblrTumblrPublisherPublishingOptionsPane* _tmp6_ = NULL;
	SpitPublishingPluginHost* _tmp7_ = NULL;
#line 403 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_if_fail (PUBLISHING_TUMBLR_IS_TUMBLR_PUBLISHER (self));
#line 404 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_debug ("TumblrPublishing.vala:404: ACTION: displaying publishing options pane");
#line 405 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = self->priv->host;
#line 405 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	spit_publishing_plugin_host_set_service_locked (_tmp0_, FALSE);
#line 406 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp1_ = self->priv->host;
#line 406 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp2_ = spit_publishing_plugin_host_get_publishable_media_type (_tmp1_);
#line 406 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp3_ = self->priv->sizes;
#line 406 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp3__length1 = self->priv->sizes_length1;
#line 406 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp4_ = self->priv->blogs;
#line 406 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp4__length1 = self->priv->blogs_length1;
#line 406 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp5_ = self->priv->username;
#line 406 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp6_ = publishing_tumblr_tumblr_publisher_publishing_options_pane_new (self, _tmp2_, _tmp3_, _tmp3__length1, _tmp4_, _tmp4__length1, _tmp5_);
#line 406 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_options_pane = _tmp6_;
#line 408 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_signal_connect_object (publishing_options_pane, "publish", (GCallback) _publishing_tumblr_tumblr_publisher_on_publishing_options_pane_publish_publishing_tumblr_tumblr_publisher_publishing_options_pane_publish, self, 0);
#line 409 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_signal_connect_object (publishing_options_pane, "logout", (GCallback) _publishing_tumblr_tumblr_publisher_on_publishing_options_pane_logout_publishing_tumblr_tumblr_publisher_publishing_options_pane_logout, self, 0);
#line 410 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp7_ = self->priv->host;
#line 410 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	spit_publishing_plugin_host_install_dialog_pane (_tmp7_, G_TYPE_CHECK_INSTANCE_CAST (publishing_options_pane, SPIT_PUBLISHING_TYPE_DIALOG_PANE, SpitPublishingDialogPane), SPIT_PUBLISHING_PLUGIN_HOST_BUTTON_MODE_CANCEL);
#line 403 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_object_unref0 (publishing_options_pane);
#line 3263 "TumblrPublishing.c"
}


static void publishing_tumblr_tumblr_publisher_on_publishing_options_pane_publish (PublishingTumblrTumblrPublisher* self) {
	PublishingTumblrTumblrPublisherPublishingOptionsPane* _tmp0_ = NULL;
	gboolean _tmp5_ = FALSE;
#line 415 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_if_fail (PUBLISHING_TUMBLR_IS_TUMBLR_PUBLISHER (self));
#line 416 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = self->priv->publishing_options_pane;
#line 416 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	if (_tmp0_ != NULL) {
#line 3276 "TumblrPublishing.c"
		PublishingTumblrTumblrPublisherPublishingOptionsPane* _tmp1_ = NULL;
		guint _tmp2_ = 0U;
		PublishingTumblrTumblrPublisherPublishingOptionsPane* _tmp3_ = NULL;
		guint _tmp4_ = 0U;
#line 417 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp1_ = self->priv->publishing_options_pane;
#line 417 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		g_signal_parse_name ("publish", PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_PUBLISHING_OPTIONS_PANE, &_tmp2_, NULL, FALSE);
#line 417 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		g_signal_handlers_disconnect_matched (_tmp1_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp2_, 0, NULL, (GCallback) _publishing_tumblr_tumblr_publisher_on_publishing_options_pane_publish_publishing_tumblr_tumblr_publisher_publishing_options_pane_publish, self);
#line 418 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp3_ = self->priv->publishing_options_pane;
#line 418 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		g_signal_parse_name ("logout", PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_PUBLISHING_OPTIONS_PANE, &_tmp4_, NULL, FALSE);
#line 418 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		g_signal_handlers_disconnect_matched (_tmp3_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp4_, 0, NULL, (GCallback) _publishing_tumblr_tumblr_publisher_on_publishing_options_pane_logout_publishing_tumblr_tumblr_publisher_publishing_options_pane_logout, self);
#line 3293 "TumblrPublishing.c"
	}
#line 421 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp5_ = spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher));
#line 421 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	if (!_tmp5_) {
#line 422 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		return;
#line 3301 "TumblrPublishing.c"
	}
#line 424 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_debug ("TumblrPublishing.vala:424: EVENT: user clicked the 'Publish' button in" \
" the publishing options pane");
#line 425 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_tumblr_tumblr_publisher_do_publish (self);
#line 3307 "TumblrPublishing.c"
}


static void publishing_tumblr_tumblr_publisher_on_publishing_options_pane_logout (PublishingTumblrTumblrPublisher* self) {
	PublishingTumblrTumblrPublisherPublishingOptionsPane* _tmp0_ = NULL;
	gboolean _tmp5_ = FALSE;
#line 428 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_if_fail (PUBLISHING_TUMBLR_IS_TUMBLR_PUBLISHER (self));
#line 429 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = self->priv->publishing_options_pane;
#line 429 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	if (_tmp0_ != NULL) {
#line 3320 "TumblrPublishing.c"
		PublishingTumblrTumblrPublisherPublishingOptionsPane* _tmp1_ = NULL;
		guint _tmp2_ = 0U;
		PublishingTumblrTumblrPublisherPublishingOptionsPane* _tmp3_ = NULL;
		guint _tmp4_ = 0U;
#line 430 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp1_ = self->priv->publishing_options_pane;
#line 430 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		g_signal_parse_name ("publish", PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_PUBLISHING_OPTIONS_PANE, &_tmp2_, NULL, FALSE);
#line 430 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		g_signal_handlers_disconnect_matched (_tmp1_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp2_, 0, NULL, (GCallback) _publishing_tumblr_tumblr_publisher_on_publishing_options_pane_publish_publishing_tumblr_tumblr_publisher_publishing_options_pane_publish, self);
#line 431 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp3_ = self->priv->publishing_options_pane;
#line 431 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		g_signal_parse_name ("logout", PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_PUBLISHING_OPTIONS_PANE, &_tmp4_, NULL, FALSE);
#line 431 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		g_signal_handlers_disconnect_matched (_tmp3_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp4_, 0, NULL, (GCallback) _publishing_tumblr_tumblr_publisher_on_publishing_options_pane_logout_publishing_tumblr_tumblr_publisher_publishing_options_pane_logout, self);
#line 3337 "TumblrPublishing.c"
	}
#line 434 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp5_ = spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher));
#line 434 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	if (!_tmp5_) {
#line 435 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		return;
#line 3345 "TumblrPublishing.c"
	}
#line 437 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_debug ("TumblrPublishing.vala:437: EVENT: user clicked the 'Logout' button in " \
"the publishing options pane");
#line 439 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_tumblr_tumblr_publisher_do_logout (self);
#line 3351 "TumblrPublishing.c"
}


gint publishing_tumblr_tumblr_publisher_tumblr_date_time_compare_func (SpitPublishingPublishable* a, SpitPublishingPublishable* b) {
	gint result = 0;
	SpitPublishingPublishable* _tmp0_ = NULL;
	GDateTime* _tmp1_ = NULL;
	GDateTime* _tmp2_ = NULL;
	SpitPublishingPublishable* _tmp3_ = NULL;
	GDateTime* _tmp4_ = NULL;
	GDateTime* _tmp5_ = NULL;
	gint _tmp6_ = 0;
	gint _tmp7_ = 0;
#line 442 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_val_if_fail (SPIT_PUBLISHING_IS_PUBLISHABLE (a), 0);
#line 442 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_val_if_fail (SPIT_PUBLISHING_IS_PUBLISHABLE (b), 0);
#line 444 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = a;
#line 444 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp1_ = spit_publishing_publishable_get_exposure_date_time (_tmp0_);
#line 444 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp2_ = _tmp1_;
#line 444 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp3_ = b;
#line 444 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp4_ = spit_publishing_publishable_get_exposure_date_time (_tmp3_);
#line 444 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp5_ = _tmp4_;
#line 444 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp6_ = g_date_time_compare (_tmp2_, _tmp5_);
#line 444 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp7_ = _tmp6_;
#line 444 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_date_time_unref0 (_tmp5_);
#line 444 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_date_time_unref0 (_tmp2_);
#line 444 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	result = _tmp7_;
#line 444 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return result;
#line 3393 "TumblrPublishing.c"
}


static gint _publishing_tumblr_tumblr_publisher_tumblr_date_time_compare_func_gcompare_data_func (gconstpointer a, gconstpointer b, gpointer self) {
	gint result;
	result = publishing_tumblr_tumblr_publisher_tumblr_date_time_compare_func ((SpitPublishingPublishable*) a, (SpitPublishingPublishable*) b);
#line 469 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return result;
#line 3402 "TumblrPublishing.c"
}


static void _publishing_tumblr_tumblr_publisher_on_upload_complete_publishing_rest_support_batch_uploader_upload_complete (PublishingRESTSupportBatchUploader* _sender, gint num_photos_published, gpointer self) {
#line 473 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_tumblr_tumblr_publisher_on_upload_complete ((PublishingTumblrTumblrPublisher*) self, _sender, num_photos_published);
#line 3409 "TumblrPublishing.c"
}


static void _publishing_tumblr_tumblr_publisher_on_upload_error_publishing_rest_support_batch_uploader_upload_error (PublishingRESTSupportBatchUploader* _sender, GError* err, gpointer self) {
#line 474 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_tumblr_tumblr_publisher_on_upload_error ((PublishingTumblrTumblrPublisher*) self, _sender, err);
#line 3416 "TumblrPublishing.c"
}


static void _publishing_tumblr_tumblr_publisher_on_upload_status_updated_spit_publishing_progress_callback (gint file_number, gdouble fraction_complete, gpointer self) {
#line 475 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_tumblr_tumblr_publisher_on_upload_status_updated ((PublishingTumblrTumblrPublisher*) self, file_number, fraction_complete);
#line 3423 "TumblrPublishing.c"
}


static void publishing_tumblr_tumblr_publisher_do_publish (PublishingTumblrTumblrPublisher* self) {
	SpitPublishingPluginHost* _tmp0_ = NULL;
	SpitPublishingPluginHost* _tmp1_ = NULL;
	PublishingTumblrSizeEntry** _tmp2_ = NULL;
	gint _tmp2__length1 = 0;
	gint _tmp3_ = 0;
	PublishingTumblrSizeEntry* _tmp4_ = NULL;
	gint _tmp5_ = 0;
	void* _tmp6_ = NULL;
	GDestroyNotify _tmp7_ = NULL;
	SpitPublishingProgressCallback _tmp8_ = NULL;
	gboolean _tmp9_ = FALSE;
	SpitPublishingPublishable** publishables = NULL;
	SpitPublishingPluginHost* _tmp10_ = NULL;
	gint _tmp11_ = 0;
	SpitPublishingPublishable** _tmp12_ = NULL;
	gint publishables_length1 = 0;
	gint _publishables_size_ = 0;
	GeeArrayList* sorted_list = NULL;
	GeeArrayList* _tmp13_ = NULL;
	SpitPublishingPublishable** _tmp14_ = NULL;
	gint _tmp14__length1 = 0;
	GeeArrayList* _tmp18_ = NULL;
	gchar* blog_url = NULL;
	PublishingTumblrBlogEntry** _tmp19_ = NULL;
	gint _tmp19__length1 = 0;
	gint _tmp20_ = 0;
	PublishingTumblrBlogEntry* _tmp21_ = NULL;
	const gchar* _tmp22_ = NULL;
	gchar* _tmp23_ = NULL;
	PublishingTumblrTumblrPublisherUploader* uploader = NULL;
	PublishingTumblrTumblrPublisherSession* _tmp24_ = NULL;
	GeeArrayList* _tmp25_ = NULL;
	gint _tmp26_ = 0;
	gpointer* _tmp27_ = NULL;
	SpitPublishingPublishable** _tmp28_ = NULL;
	gint _tmp28__length1 = 0;
	const gchar* _tmp29_ = NULL;
	PublishingTumblrTumblrPublisherUploader* _tmp30_ = NULL;
	PublishingTumblrTumblrPublisherUploader* _tmp31_ = NULL;
	PublishingTumblrTumblrPublisherUploader* _tmp32_ = NULL;
	PublishingTumblrTumblrPublisherUploader* _tmp33_ = NULL;
	PublishingTumblrTumblrPublisherUploader* _tmp34_ = NULL;
#line 447 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_if_fail (PUBLISHING_TUMBLR_IS_TUMBLR_PUBLISHER (self));
#line 448 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_debug ("TumblrPublishing.vala:448: ACTION: uploading media items to remote ser" \
"ver.");
#line 450 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = self->priv->host;
#line 450 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	spit_publishing_plugin_host_set_service_locked (_tmp0_, TRUE);
#line 452 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp1_ = self->priv->host;
#line 452 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp2_ = self->priv->sizes;
#line 452 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp2__length1 = self->priv->sizes_length1;
#line 452 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp3_ = publishing_tumblr_tumblr_publisher_get_persistent_default_size (self);
#line 452 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp4_ = _tmp2_[_tmp3_];
#line 452 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp5_ = _tmp4_->size;
#line 452 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp8_ = spit_publishing_plugin_host_serialize_publishables (_tmp1_, _tmp5_, FALSE, &_tmp6_, &_tmp7_);
#line 452 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	(self->priv->progress_reporter_target_destroy_notify == NULL) ? NULL : (self->priv->progress_reporter_target_destroy_notify (self->priv->progress_reporter_target), NULL);
#line 452 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->progress_reporter = NULL;
#line 452 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->progress_reporter_target = NULL;
#line 452 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->progress_reporter_target_destroy_notify = NULL;
#line 452 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->progress_reporter = _tmp8_;
#line 452 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->progress_reporter_target = _tmp6_;
#line 452 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->progress_reporter_target_destroy_notify = _tmp7_;
#line 458 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp9_ = spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher));
#line 458 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	if (!_tmp9_) {
#line 459 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		return;
#line 3512 "TumblrPublishing.c"
	}
#line 462 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp10_ = self->priv->host;
#line 462 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp12_ = spit_publishing_plugin_host_get_publishables (_tmp10_, &_tmp11_);
#line 462 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishables = _tmp12_;
#line 462 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishables_length1 = _tmp11_;
#line 462 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_publishables_size_ = publishables_length1;
#line 463 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp13_ = gee_array_list_new (SPIT_PUBLISHING_TYPE_PUBLISHABLE, (GBoxedCopyFunc) g_object_ref, g_object_unref, NULL, NULL, NULL);
#line 463 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	sorted_list = _tmp13_;
#line 465 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp14_ = publishables;
#line 465 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp14__length1 = publishables_length1;
#line 3532 "TumblrPublishing.c"
	{
		SpitPublishingPublishable** p_collection = NULL;
		gint p_collection_length1 = 0;
		gint _p_collection_size_ = 0;
		gint p_it = 0;
#line 465 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		p_collection = _tmp14_;
#line 465 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		p_collection_length1 = _tmp14__length1;
#line 465 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		for (p_it = 0; p_it < _tmp14__length1; p_it = p_it + 1) {
#line 3544 "TumblrPublishing.c"
			SpitPublishingPublishable* _tmp15_ = NULL;
			SpitPublishingPublishable* p = NULL;
#line 465 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			_tmp15_ = _g_object_ref0 (p_collection[p_it]);
#line 465 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			p = _tmp15_;
#line 3551 "TumblrPublishing.c"
			{
				GeeArrayList* _tmp16_ = NULL;
				SpitPublishingPublishable* _tmp17_ = NULL;
#line 466 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				g_debug ("TumblrPublishing.vala:466: ACTION: add publishable");
#line 467 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp16_ = sorted_list;
#line 467 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp17_ = p;
#line 467 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				gee_abstract_collection_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp16_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection), _tmp17_);
#line 465 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_g_object_unref0 (p);
#line 3565 "TumblrPublishing.c"
			}
		}
	}
#line 469 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp18_ = sorted_list;
#line 469 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	gee_list_sort (G_TYPE_CHECK_INSTANCE_CAST (_tmp18_, GEE_TYPE_LIST, GeeList), _publishing_tumblr_tumblr_publisher_tumblr_date_time_compare_func_gcompare_data_func, NULL, NULL);
#line 470 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp19_ = self->priv->blogs;
#line 470 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp19__length1 = self->priv->blogs_length1;
#line 470 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp20_ = publishing_tumblr_tumblr_publisher_get_persistent_default_blog (self);
#line 470 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp21_ = _tmp19_[_tmp20_];
#line 470 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp22_ = _tmp21_->url;
#line 470 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp23_ = g_strdup (_tmp22_);
#line 470 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	blog_url = _tmp23_;
#line 472 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp24_ = self->priv->session;
#line 472 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp25_ = sorted_list;
#line 472 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp27_ = gee_collection_to_array (G_TYPE_CHECK_INSTANCE_CAST (_tmp25_, GEE_TYPE_COLLECTION, GeeCollection), &_tmp26_);
#line 472 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp28_ = _tmp27_;
#line 472 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp28__length1 = _tmp26_;
#line 472 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp29_ = blog_url;
#line 472 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp30_ = publishing_tumblr_tumblr_publisher_uploader_new (_tmp24_, _tmp28_, _tmp26_, _tmp29_);
#line 472 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp31_ = _tmp30_;
#line 472 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp28_ = (_vala_array_free (_tmp28_, _tmp28__length1, (GDestroyNotify) g_object_unref), NULL);
#line 472 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	uploader = _tmp31_;
#line 473 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp32_ = uploader;
#line 473 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp32_, PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, PublishingRESTSupportBatchUploader), "upload-complete", (GCallback) _publishing_tumblr_tumblr_publisher_on_upload_complete_publishing_rest_support_batch_uploader_upload_complete, self, 0);
#line 474 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp33_ = uploader;
#line 474 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp33_, PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, PublishingRESTSupportBatchUploader), "upload-error", (GCallback) _publishing_tumblr_tumblr_publisher_on_upload_error_publishing_rest_support_batch_uploader_upload_error, self, 0);
#line 475 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp34_ = uploader;
#line 475 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_rest_support_batch_uploader_upload (G_TYPE_CHECK_INSTANCE_CAST (_tmp34_, PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, PublishingRESTSupportBatchUploader), _publishing_tumblr_tumblr_publisher_on_upload_status_updated_spit_publishing_progress_callback, self);
#line 447 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_publishing_rest_support_batch_uploader_unref0 (uploader);
#line 447 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_free0 (blog_url);
#line 447 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_object_unref0 (sorted_list);
#line 447 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishables = (_vala_array_free (publishables, publishables_length1, (GDestroyNotify) g_object_unref), NULL);
#line 3627 "TumblrPublishing.c"
}


static void publishing_tumblr_tumblr_publisher_do_show_success_pane (PublishingTumblrTumblrPublisher* self) {
	SpitPublishingPluginHost* _tmp0_ = NULL;
	SpitPublishingPluginHost* _tmp1_ = NULL;
#line 478 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_if_fail (PUBLISHING_TUMBLR_IS_TUMBLR_PUBLISHER (self));
#line 479 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_debug ("TumblrPublishing.vala:479: ACTION: showing success pane.");
#line 481 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = self->priv->host;
#line 481 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	spit_publishing_plugin_host_set_service_locked (_tmp0_, FALSE);
#line 482 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp1_ = self->priv->host;
#line 482 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	spit_publishing_plugin_host_install_success_pane (_tmp1_);
#line 3646 "TumblrPublishing.c"
}


static void publishing_tumblr_tumblr_publisher_on_upload_status_updated (PublishingTumblrTumblrPublisher* self, gint file_number, gdouble completed_fraction) {
	gboolean _tmp0_ = FALSE;
	gdouble _tmp1_ = 0.0;
	SpitPublishingProgressCallback _tmp2_ = NULL;
	void* _tmp2__target = NULL;
	SpitPublishingProgressCallback _tmp3_ = NULL;
	void* _tmp3__target = NULL;
	gint _tmp4_ = 0;
	gdouble _tmp5_ = 0.0;
#line 486 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_if_fail (PUBLISHING_TUMBLR_IS_TUMBLR_PUBLISHER (self));
#line 487 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher));
#line 487 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	if (!_tmp0_) {
#line 488 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		return;
#line 3667 "TumblrPublishing.c"
	}
#line 490 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp1_ = completed_fraction;
#line 490 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_debug ("TumblrPublishing.vala:490: EVENT: uploader reports upload %.2f percent" \
" complete.", 100.0 * _tmp1_);
#line 492 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp2_ = self->priv->progress_reporter;
#line 492 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp2__target = self->priv->progress_reporter_target;
#line 492 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_vala_assert (_tmp2_ != NULL, "progress_reporter != null");
#line 494 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp3_ = self->priv->progress_reporter;
#line 494 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp3__target = self->priv->progress_reporter_target;
#line 494 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp4_ = file_number;
#line 494 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp5_ = completed_fraction;
#line 494 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp3_ (_tmp4_, _tmp5_, _tmp3__target);
#line 3689 "TumblrPublishing.c"
}


static void publishing_tumblr_tumblr_publisher_on_upload_complete (PublishingTumblrTumblrPublisher* self, PublishingRESTSupportBatchUploader* uploader, gint num_published) {
	gboolean _tmp0_ = FALSE;
	gint _tmp1_ = 0;
	PublishingRESTSupportBatchUploader* _tmp2_ = NULL;
	guint _tmp3_ = 0U;
	PublishingRESTSupportBatchUploader* _tmp4_ = NULL;
	guint _tmp5_ = 0U;
#line 497 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_if_fail (PUBLISHING_TUMBLR_IS_TUMBLR_PUBLISHER (self));
#line 497 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_BATCH_UPLOADER (uploader));
#line 499 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher));
#line 499 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	if (!_tmp0_) {
#line 500 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		return;
#line 3710 "TumblrPublishing.c"
	}
#line 502 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp1_ = num_published;
#line 502 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_debug ("TumblrPublishing.vala:502: EVENT: uploader reports upload complete; %d" \
" items published.", _tmp1_);
#line 504 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp2_ = uploader;
#line 504 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_signal_parse_name ("upload-complete", PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, &_tmp3_, NULL, FALSE);
#line 504 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp2_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _publishing_tumblr_tumblr_publisher_on_upload_complete_publishing_rest_support_batch_uploader_upload_complete, self);
#line 505 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp4_ = uploader;
#line 505 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_signal_parse_name ("upload-error", PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, &_tmp5_, NULL, FALSE);
#line 505 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp4_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp5_, 0, NULL, (GCallback) _publishing_tumblr_tumblr_publisher_on_upload_error_publishing_rest_support_batch_uploader_upload_error, self);
#line 507 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_tumblr_tumblr_publisher_do_show_success_pane (self);
#line 3730 "TumblrPublishing.c"
}


static void publishing_tumblr_tumblr_publisher_on_upload_error (PublishingTumblrTumblrPublisher* self, PublishingRESTSupportBatchUploader* uploader, GError* err) {
	gboolean _tmp0_ = FALSE;
	GError* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	PublishingRESTSupportBatchUploader* _tmp3_ = NULL;
	guint _tmp4_ = 0U;
	PublishingRESTSupportBatchUploader* _tmp5_ = NULL;
	guint _tmp6_ = 0U;
	SpitPublishingPluginHost* _tmp7_ = NULL;
	GError* _tmp8_ = NULL;
#line 510 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_if_fail (PUBLISHING_TUMBLR_IS_TUMBLR_PUBLISHER (self));
#line 510 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_BATCH_UPLOADER (uploader));
#line 512 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher));
#line 512 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	if (!_tmp0_) {
#line 513 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		return;
#line 3754 "TumblrPublishing.c"
	}
#line 515 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp1_ = err;
#line 515 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp2_ = _tmp1_->message;
#line 515 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_debug ("TumblrPublishing.vala:515: EVENT: uploader reports upload error = '%s'" \
".", _tmp2_);
#line 517 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp3_ = uploader;
#line 517 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_signal_parse_name ("upload-complete", PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, &_tmp4_, NULL, FALSE);
#line 517 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp3_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp4_, 0, NULL, (GCallback) _publishing_tumblr_tumblr_publisher_on_upload_complete_publishing_rest_support_batch_uploader_upload_complete, self);
#line 518 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp5_ = uploader;
#line 518 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_signal_parse_name ("upload-error", PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, &_tmp6_, NULL, FALSE);
#line 518 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp5_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp6_, 0, NULL, (GCallback) _publishing_tumblr_tumblr_publisher_on_upload_error_publishing_rest_support_batch_uploader_upload_error, self);
#line 520 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp7_ = self->priv->host;
#line 520 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp8_ = err;
#line 520 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	spit_publishing_plugin_host_post_error (_tmp7_, _tmp8_);
#line 3780 "TumblrPublishing.c"
}


static void publishing_tumblr_tumblr_publisher_do_logout (PublishingTumblrTumblrPublisher* self) {
	PublishingTumblrTumblrPublisherSession* _tmp0_ = NULL;
#line 524 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_if_fail (PUBLISHING_TUMBLR_IS_TUMBLR_PUBLISHER (self));
#line 525 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_debug ("TumblrPublishing.vala:525: ACTION: logging user out, deauthenticating " \
"session, and erasing stored credentials");
#line 527 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = self->priv->session;
#line 527 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_tumblr_tumblr_publisher_session_deauthenticate (_tmp0_);
#line 528 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_tumblr_tumblr_publisher_invalidate_persistent_session (self);
#line 530 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->running = FALSE;
#line 532 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_tumblr_tumblr_publisher_attempt_start (self);
#line 3800 "TumblrPublishing.c"
}


void publishing_tumblr_tumblr_publisher_attempt_start (PublishingTumblrTumblrPublisher* self) {
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
#line 535 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_if_fail (PUBLISHING_TUMBLR_IS_TUMBLR_PUBLISHER (self));
#line 536 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher));
#line 536 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	if (_tmp0_) {
#line 537 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		return;
#line 3815 "TumblrPublishing.c"
	}
#line 539 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_debug ("TumblrPublishing.vala:539: TumblrPublisher: starting interaction.");
#line 541 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->running = TRUE;
#line 542 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp1_ = publishing_tumblr_tumblr_publisher_is_persistent_session_valid (self);
#line 542 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	if (_tmp1_) {
#line 3825 "TumblrPublishing.c"
		PublishingTumblrTumblrPublisherSession* _tmp2_ = NULL;
		gchar* _tmp3_ = NULL;
		gchar* _tmp4_ = NULL;
		gchar* _tmp5_ = NULL;
		gchar* _tmp6_ = NULL;
#line 543 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		g_debug ("TumblrPublishing.vala:543: attempt start: a persistent session is avai" \
"lable; using it");
#line 545 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp2_ = self->priv->session;
#line 545 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp3_ = publishing_tumblr_tumblr_publisher_get_persistent_access_phase_token (self);
#line 545 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp4_ = _tmp3_;
#line 545 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp5_ = publishing_tumblr_tumblr_publisher_get_persistent_access_phase_token_secret (self);
#line 545 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp6_ = _tmp5_;
#line 545 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		publishing_tumblr_tumblr_publisher_session_authenticate_from_persistent_credentials (_tmp2_, _tmp4_, _tmp6_);
#line 545 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_g_free0 (_tmp6_);
#line 545 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_g_free0 (_tmp4_);
#line 3849 "TumblrPublishing.c"
	} else {
#line 548 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		g_debug ("TumblrPublishing.vala:548: attempt start: no persistent session availa" \
"ble; showing login welcome pane");
#line 550 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		publishing_tumblr_tumblr_publisher_do_show_authentication_pane (self, PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_AUTHENTICATION_PANE_MODE_INTRO);
#line 3855 "TumblrPublishing.c"
	}
}


static void publishing_tumblr_tumblr_publisher_real_start (SpitPublishingPublisher* base) {
	PublishingTumblrTumblrPublisher * self;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
#line 554 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_TUMBLR_TYPE_TUMBLR_PUBLISHER, PublishingTumblrTumblrPublisher);
#line 555 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher));
#line 555 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	if (_tmp0_) {
#line 556 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		return;
#line 3872 "TumblrPublishing.c"
	}
#line 558 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp1_ = self->priv->was_started;
#line 558 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	if (_tmp1_) {
#line 3878 "TumblrPublishing.c"
		const gchar* _tmp2_ = NULL;
#line 559 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp2_ = _ ("TumblrPublisher: start( ): can't start; this publisher is not restarta" \
"ble.");
#line 559 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		g_error ("TumblrPublishing.vala:559: %s", _tmp2_);
#line 3884 "TumblrPublishing.c"
	}
#line 561 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_debug ("TumblrPublishing.vala:561: TumblrPublisher: starting interaction.");
#line 563 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_tumblr_tumblr_publisher_attempt_start (self);
#line 3890 "TumblrPublishing.c"
}


static void publishing_tumblr_tumblr_publisher_real_stop (SpitPublishingPublisher* base) {
	PublishingTumblrTumblrPublisher * self;
#line 566 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_TUMBLR_TYPE_TUMBLR_PUBLISHER, PublishingTumblrTumblrPublisher);
#line 567 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_debug ("TumblrPublishing.vala:567: TumblrPublisher: stop( ) invoked.");
#line 572 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->running = FALSE;
#line 3902 "TumblrPublishing.c"
}


GType publishing_tumblr_tumblr_publisher_authentication_pane_mode_get_type (void) {
	static volatile gsize publishing_tumblr_tumblr_publisher_authentication_pane_mode_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_tumblr_tumblr_publisher_authentication_pane_mode_type_id__volatile)) {
		static const GEnumValue values[] = {{PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_AUTHENTICATION_PANE_MODE_INTRO, "PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_AUTHENTICATION_PANE_MODE_INTRO", "intro"}, {PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_AUTHENTICATION_PANE_MODE_FAILED_RETRY_USER, "PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_AUTHENTICATION_PANE_MODE_FAILED_RETRY_USER", "failed-retry-user"}, {0, NULL, NULL}};
		GType publishing_tumblr_tumblr_publisher_authentication_pane_mode_type_id;
		publishing_tumblr_tumblr_publisher_authentication_pane_mode_type_id = g_enum_register_static ("PublishingTumblrTumblrPublisherAuthenticationPaneMode", values);
		g_once_init_leave (&publishing_tumblr_tumblr_publisher_authentication_pane_mode_type_id__volatile, publishing_tumblr_tumblr_publisher_authentication_pane_mode_type_id);
	}
	return publishing_tumblr_tumblr_publisher_authentication_pane_mode_type_id__volatile;
}


static void _publishing_tumblr_tumblr_publisher_authentication_pane_on_user_changed_gtk_editable_changed (GtkEditable* _sender, gpointer self) {
#line 627 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_tumblr_tumblr_publisher_authentication_pane_on_user_changed ((PublishingTumblrTumblrPublisherAuthenticationPane*) self);
#line 3921 "TumblrPublishing.c"
}


static void _publishing_tumblr_tumblr_publisher_authentication_pane_on_password_changed_gtk_editable_changed (GtkEditable* _sender, gpointer self) {
#line 628 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_tumblr_tumblr_publisher_authentication_pane_on_password_changed ((PublishingTumblrTumblrPublisherAuthenticationPane*) self);
#line 3928 "TumblrPublishing.c"
}


static void _publishing_tumblr_tumblr_publisher_authentication_pane_on_login_button_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 629 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_tumblr_tumblr_publisher_authentication_pane_on_login_button_clicked ((PublishingTumblrTumblrPublisherAuthenticationPane*) self);
#line 3935 "TumblrPublishing.c"
}


PublishingTumblrTumblrPublisherAuthenticationPane* publishing_tumblr_tumblr_publisher_authentication_pane_construct (GType object_type, PublishingTumblrTumblrPublisher* publisher, PublishingTumblrTumblrPublisherAuthenticationPaneMode mode) {
	PublishingTumblrTumblrPublisherAuthenticationPane * self = NULL;
	GtkBox* _tmp0_ = NULL;
	GError * _inner_error_ = NULL;
#line 598 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_val_if_fail (PUBLISHING_TUMBLR_IS_TUMBLR_PUBLISHER (publisher), NULL);
#line 598 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self = (PublishingTumblrTumblrPublisherAuthenticationPane*) g_object_new (object_type, NULL);
#line 599 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
#line 599 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_object_ref_sink (_tmp0_);
#line 599 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_object_unref0 (self->priv->pane_widget);
#line 599 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->pane_widget = _tmp0_;
#line 3955 "TumblrPublishing.c"
	{
		GtkBuilder* _tmp1_ = NULL;
		GtkBuilder* _tmp2_ = NULL;
		GtkBuilder* _tmp3_ = NULL;
		GtkAlignment* align = NULL;
		GtkBuilder* _tmp4_ = NULL;
		GObject* _tmp5_ = NULL;
		GtkAlignment* _tmp6_ = NULL;
		GtkLabel* message_label = NULL;
		GtkBuilder* _tmp7_ = NULL;
		GObject* _tmp8_ = NULL;
		GtkLabel* _tmp9_ = NULL;
		PublishingTumblrTumblrPublisherAuthenticationPaneMode _tmp10_ = 0;
		GtkBuilder* _tmp18_ = NULL;
		GObject* _tmp19_ = NULL;
		GtkEntry* _tmp20_ = NULL;
		GtkBuilder* _tmp21_ = NULL;
		GObject* _tmp22_ = NULL;
		GtkEntry* _tmp23_ = NULL;
		GtkBuilder* _tmp24_ = NULL;
		GObject* _tmp25_ = NULL;
		GtkButton* _tmp26_ = NULL;
		GtkEntry* _tmp27_ = NULL;
		GtkEntry* _tmp28_ = NULL;
		GtkButton* _tmp29_ = NULL;
		GtkAlignment* _tmp30_ = NULL;
		GtkBox* _tmp31_ = NULL;
		PublishingTumblrTumblrPublisher* _tmp32_ = NULL;
		SpitPublishingPluginHost* _tmp33_ = NULL;
		SpitPublishingPluginHost* _tmp34_ = NULL;
		GtkButton* _tmp35_ = NULL;
#line 602 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp1_ = gtk_builder_new ();
#line 602 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_g_object_unref0 (self->priv->builder);
#line 602 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		self->priv->builder = _tmp1_;
#line 603 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp2_ = self->priv->builder;
#line 603 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		gtk_builder_add_from_resource (_tmp2_, PLUGIN_RESOURCE_PATH "/tumblr_authentication_pane.ui", &_inner_error_);
#line 603 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3999 "TumblrPublishing.c"
			goto __catch36_g_error;
		}
#line 604 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp3_ = self->priv->builder;
#line 604 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		gtk_builder_connect_signals (_tmp3_, NULL);
#line 605 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp4_ = self->priv->builder;
#line 605 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp5_ = gtk_builder_get_object (_tmp4_, "alignment");
#line 605 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp6_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp5_, gtk_alignment_get_type ()) ? ((GtkAlignment*) _tmp5_) : NULL);
#line 605 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		align = _tmp6_;
#line 607 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp7_ = self->priv->builder;
#line 607 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp8_ = gtk_builder_get_object (_tmp7_, "message_label");
#line 607 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp9_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp8_, gtk_label_get_type ()) ? ((GtkLabel*) _tmp8_) : NULL);
#line 607 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		message_label = _tmp9_;
#line 608 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp10_ = mode;
#line 608 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		switch (_tmp10_) {
#line 608 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			case PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_AUTHENTICATION_PANE_MODE_INTRO:
#line 4028 "TumblrPublishing.c"
			{
				GtkLabel* _tmp11_ = NULL;
				const gchar* _tmp12_ = NULL;
#line 610 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp11_ = message_label;
#line 610 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp12_ = publishing_tumblr_tumblr_publisher_authentication_pane_INTRO_MESSAGE;
#line 610 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				gtk_label_set_text (_tmp11_, _tmp12_);
#line 611 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				break;
#line 4040 "TumblrPublishing.c"
			}
#line 608 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			case PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_AUTHENTICATION_PANE_MODE_FAILED_RETRY_USER:
#line 4044 "TumblrPublishing.c"
			{
				GtkLabel* _tmp13_ = NULL;
				const gchar* _tmp14_ = NULL;
				const gchar* _tmp15_ = NULL;
				gchar* _tmp16_ = NULL;
				gchar* _tmp17_ = NULL;
#line 614 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp13_ = message_label;
#line 614 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp14_ = _ ("Invalid User Name or Password");
#line 614 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp15_ = publishing_tumblr_tumblr_publisher_authentication_pane_FAILED_RETRY_USER_MESSAGE;
#line 614 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp16_ = g_strdup_printf ("<b>%s</b>\n\n%s", _tmp14_, _tmp15_);
#line 614 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp17_ = _tmp16_;
#line 614 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				gtk_label_set_markup (_tmp13_, _tmp17_);
#line 614 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_g_free0 (_tmp17_);
#line 616 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				break;
#line 4067 "TumblrPublishing.c"
			}
			default:
#line 608 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			break;
#line 4072 "TumblrPublishing.c"
		}
#line 619 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp18_ = self->priv->builder;
#line 619 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp19_ = gtk_builder_get_object (_tmp18_, "username_entry");
#line 619 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp20_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp19_, gtk_entry_get_type ()) ? ((GtkEntry*) _tmp19_) : NULL);
#line 619 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_g_object_unref0 (self->priv->username_entry);
#line 619 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		self->priv->username_entry = _tmp20_;
#line 621 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp21_ = self->priv->builder;
#line 621 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp22_ = gtk_builder_get_object (_tmp21_, "password_entry");
#line 621 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp23_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp22_, gtk_entry_get_type ()) ? ((GtkEntry*) _tmp22_) : NULL);
#line 621 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_g_object_unref0 (self->priv->password_entry);
#line 621 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		self->priv->password_entry = _tmp23_;
#line 625 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp24_ = self->priv->builder;
#line 625 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp25_ = gtk_builder_get_object (_tmp24_, "login_button");
#line 625 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp26_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp25_, gtk_button_get_type ()) ? ((GtkButton*) _tmp25_) : NULL);
#line 625 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_g_object_unref0 (self->priv->login_button);
#line 625 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		self->priv->login_button = _tmp26_;
#line 627 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp27_ = self->priv->username_entry;
#line 627 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp27_, GTK_TYPE_EDITABLE, GtkEditable), "changed", (GCallback) _publishing_tumblr_tumblr_publisher_authentication_pane_on_user_changed_gtk_editable_changed, self, 0);
#line 628 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp28_ = self->priv->password_entry;
#line 628 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp28_, GTK_TYPE_EDITABLE, GtkEditable), "changed", (GCallback) _publishing_tumblr_tumblr_publisher_authentication_pane_on_password_changed_gtk_editable_changed, self, 0);
#line 629 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp29_ = self->priv->login_button;
#line 629 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		g_signal_connect_object (_tmp29_, "clicked", (GCallback) _publishing_tumblr_tumblr_publisher_authentication_pane_on_login_button_clicked_gtk_button_clicked, self, 0);
#line 631 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp30_ = align;
#line 631 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp31_ = self->priv->pane_widget;
#line 631 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		gtk_widget_reparent (G_TYPE_CHECK_INSTANCE_CAST (_tmp30_, gtk_widget_get_type (), GtkWidget), G_TYPE_CHECK_INSTANCE_CAST (_tmp31_, gtk_widget_get_type (), GtkWidget));
#line 632 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp32_ = publisher;
#line 632 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp33_ = publishing_tumblr_tumblr_publisher_get_host (_tmp32_);
#line 632 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp34_ = _tmp33_;
#line 632 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp35_ = self->priv->login_button;
#line 632 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		spit_publishing_plugin_host_set_dialog_default_widget (_tmp34_, G_TYPE_CHECK_INSTANCE_CAST (_tmp35_, gtk_widget_get_type (), GtkWidget));
#line 632 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_g_object_unref0 (_tmp34_);
#line 601 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_g_object_unref0 (message_label);
#line 601 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_g_object_unref0 (align);
#line 4138 "TumblrPublishing.c"
	}
	goto __finally36;
	__catch36_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp36_ = NULL;
		GError* _tmp37_ = NULL;
		const gchar* _tmp38_ = NULL;
#line 601 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		e = _inner_error_;
#line 601 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_inner_error_ = NULL;
#line 634 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp36_ = _ ("Could not load UI: %s");
#line 634 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp37_ = e;
#line 634 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp38_ = _tmp37_->message;
#line 634 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		g_warning (_tmp36_, _tmp38_);
#line 601 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_g_error_free0 (e);
#line 4161 "TumblrPublishing.c"
	}
	__finally36:
#line 601 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 601 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 601 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		g_clear_error (&_inner_error_);
#line 601 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		return NULL;
#line 4172 "TumblrPublishing.c"
	}
#line 598 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return self;
#line 4176 "TumblrPublishing.c"
}


PublishingTumblrTumblrPublisherAuthenticationPane* publishing_tumblr_tumblr_publisher_authentication_pane_new (PublishingTumblrTumblrPublisher* publisher, PublishingTumblrTumblrPublisherAuthenticationPaneMode mode) {
#line 598 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return publishing_tumblr_tumblr_publisher_authentication_pane_construct (PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_AUTHENTICATION_PANE, publisher, mode);
#line 4183 "TumblrPublishing.c"
}


GtkWidget* publishing_tumblr_tumblr_publisher_authentication_pane_get_default_widget (PublishingTumblrTumblrPublisherAuthenticationPane* self) {
	GtkWidget* result = NULL;
	GtkButton* _tmp0_ = NULL;
	GtkWidget* _tmp1_ = NULL;
#line 638 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_val_if_fail (PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_IS_AUTHENTICATION_PANE (self), NULL);
#line 639 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = self->priv->login_button;
#line 639 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_widget_get_type (), GtkWidget));
#line 639 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	result = _tmp1_;
#line 639 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return result;
#line 4201 "TumblrPublishing.c"
}


static void publishing_tumblr_tumblr_publisher_authentication_pane_on_login_button_clicked (PublishingTumblrTumblrPublisherAuthenticationPane* self) {
	GtkEntry* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	GtkEntry* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
#line 642 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_if_fail (PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_IS_AUTHENTICATION_PANE (self));
#line 643 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = self->priv->username_entry;
#line 643 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp1_ = gtk_entry_get_text (_tmp0_);
#line 643 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp2_ = self->priv->password_entry;
#line 643 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp3_ = gtk_entry_get_text (_tmp2_);
#line 643 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_signal_emit_by_name (self, "login", _tmp1_, _tmp3_);
#line 4222 "TumblrPublishing.c"
}


static void publishing_tumblr_tumblr_publisher_authentication_pane_on_user_changed (PublishingTumblrTumblrPublisherAuthenticationPane* self) {
#line 648 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_if_fail (PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_IS_AUTHENTICATION_PANE (self));
#line 649 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_tumblr_tumblr_publisher_authentication_pane_update_login_button_sensitivity (self);
#line 4231 "TumblrPublishing.c"
}


static void publishing_tumblr_tumblr_publisher_authentication_pane_on_password_changed (PublishingTumblrTumblrPublisherAuthenticationPane* self) {
#line 652 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_if_fail (PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_IS_AUTHENTICATION_PANE (self));
#line 653 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_tumblr_tumblr_publisher_authentication_pane_update_login_button_sensitivity (self);
#line 4240 "TumblrPublishing.c"
}


static void publishing_tumblr_tumblr_publisher_authentication_pane_update_login_button_sensitivity (PublishingTumblrTumblrPublisherAuthenticationPane* self) {
	gboolean _tmp0_ = FALSE;
	GtkEntry* _tmp1_ = NULL;
	guint _tmp2_ = 0U;
	guint _tmp3_ = 0U;
	GtkButton* _tmp7_ = NULL;
#line 656 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_if_fail (PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_IS_AUTHENTICATION_PANE (self));
#line 657 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp1_ = self->priv->username_entry;
#line 657 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp2_ = gtk_entry_get_text_length (_tmp1_);
#line 657 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp3_ = _tmp2_;
#line 657 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	if (_tmp3_ > ((guint) 0)) {
#line 4260 "TumblrPublishing.c"
		GtkEntry* _tmp4_ = NULL;
		guint _tmp5_ = 0U;
		guint _tmp6_ = 0U;
#line 658 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp4_ = self->priv->password_entry;
#line 658 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp5_ = gtk_entry_get_text_length (_tmp4_);
#line 658 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp6_ = _tmp5_;
#line 658 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp0_ = _tmp6_ > ((guint) 0);
#line 4272 "TumblrPublishing.c"
	} else {
#line 657 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp0_ = FALSE;
#line 4276 "TumblrPublishing.c"
	}
#line 657 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp7_ = self->priv->login_button;
#line 657 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, gtk_widget_get_type (), GtkWidget), _tmp0_);
#line 4282 "TumblrPublishing.c"
}


static GtkWidget* publishing_tumblr_tumblr_publisher_authentication_pane_real_get_widget (SpitPublishingDialogPane* base) {
	PublishingTumblrTumblrPublisherAuthenticationPane * self;
	GtkWidget* result = NULL;
	GtkBox* _tmp0_ = NULL;
	GtkWidget* _tmp1_ = NULL;
#line 661 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_AUTHENTICATION_PANE, PublishingTumblrTumblrPublisherAuthenticationPane);
#line 662 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = self->priv->pane_widget;
#line 662 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_widget_get_type (), GtkWidget));
#line 662 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	result = _tmp1_;
#line 662 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return result;
#line 4301 "TumblrPublishing.c"
}


static SpitPublishingDialogPaneGeometryOptions publishing_tumblr_tumblr_publisher_authentication_pane_real_get_preferred_geometry (SpitPublishingDialogPane* base) {
	PublishingTumblrTumblrPublisherAuthenticationPane * self;
	SpitPublishingDialogPaneGeometryOptions result = 0;
#line 665 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_AUTHENTICATION_PANE, PublishingTumblrTumblrPublisherAuthenticationPane);
#line 666 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	result = SPIT_PUBLISHING_DIALOG_PANE_GEOMETRY_OPTIONS_NONE;
#line 666 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return result;
#line 4314 "TumblrPublishing.c"
}


static void publishing_tumblr_tumblr_publisher_authentication_pane_real_on_pane_installed (SpitPublishingDialogPane* base) {
	PublishingTumblrTumblrPublisherAuthenticationPane * self;
	GtkEntry* _tmp0_ = NULL;
	GtkEntry* _tmp1_ = NULL;
	GtkButton* _tmp2_ = NULL;
#line 669 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_AUTHENTICATION_PANE, PublishingTumblrTumblrPublisherAuthenticationPane);
#line 670 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = self->priv->username_entry;
#line 670 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	gtk_widget_grab_focus (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_widget_get_type (), GtkWidget));
#line 671 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp1_ = self->priv->password_entry;
#line 671 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	gtk_entry_set_activates_default (_tmp1_, TRUE);
#line 672 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp2_ = self->priv->login_button;
#line 672 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	gtk_widget_set_can_default (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, gtk_widget_get_type (), GtkWidget), TRUE);
#line 673 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_tumblr_tumblr_publisher_authentication_pane_update_login_button_sensitivity (self);
#line 4339 "TumblrPublishing.c"
}


static void publishing_tumblr_tumblr_publisher_authentication_pane_real_on_pane_uninstalled (SpitPublishingDialogPane* base) {
	PublishingTumblrTumblrPublisherAuthenticationPane * self;
#line 676 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_AUTHENTICATION_PANE, PublishingTumblrTumblrPublisherAuthenticationPane);
#line 4347 "TumblrPublishing.c"
}


static void g_cclosure_user_marshal_VOID__STRING_STRING (GClosure * closure, GValue * return_value, guint n_param_values, const GValue * param_values, gpointer invocation_hint, gpointer marshal_data) {
	typedef void (*GMarshalFunc_VOID__STRING_STRING) (gpointer data1, const char* arg_1, const char* arg_2, gpointer data2);
	register GMarshalFunc_VOID__STRING_STRING callback;
	register GCClosure * cc;
	register gpointer data1;
	register gpointer data2;
	cc = (GCClosure *) closure;
#line 582 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_if_fail (n_param_values == 3);
#line 582 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	if (G_CCLOSURE_SWAP_DATA (closure)) {
#line 582 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		data1 = closure->data;
#line 582 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		data2 = param_values->data[0].v_pointer;
#line 4366 "TumblrPublishing.c"
	} else {
#line 582 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		data1 = param_values->data[0].v_pointer;
#line 582 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		data2 = closure->data;
#line 4372 "TumblrPublishing.c"
	}
#line 582 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	callback = (GMarshalFunc_VOID__STRING_STRING) (marshal_data ? marshal_data : cc->callback);
#line 582 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	callback (data1, g_value_get_string (param_values + 1), g_value_get_string (param_values + 2), data2);
#line 4378 "TumblrPublishing.c"
}


static void publishing_tumblr_tumblr_publisher_authentication_pane_class_init (PublishingTumblrTumblrPublisherAuthenticationPaneClass * klass) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
#line 582 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_tumblr_tumblr_publisher_authentication_pane_parent_class = g_type_class_peek_parent (klass);
#line 582 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_type_class_add_private (klass, sizeof (PublishingTumblrTumblrPublisherAuthenticationPanePrivate));
#line 582 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	G_OBJECT_CLASS (klass)->finalize = publishing_tumblr_tumblr_publisher_authentication_pane_finalize;
#line 582 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_signal_new ("login", PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_AUTHENTICATION_PANE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_user_marshal_VOID__STRING_STRING, G_TYPE_NONE, 2, G_TYPE_STRING, G_TYPE_STRING);
#line 587 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = _ ("Enter the username and password associated with your Tumblr account.");
#line 587 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 587 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_tumblr_tumblr_publisher_authentication_pane_INTRO_MESSAGE = _tmp1_;
#line 588 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp2_ = _ ("Username and/or password invalid. Please try again");
#line 588 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp3_ = g_strdup (_tmp2_);
#line 588 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_tumblr_tumblr_publisher_authentication_pane_FAILED_RETRY_USER_MESSAGE = _tmp3_;
#line 4407 "TumblrPublishing.c"
}


static void publishing_tumblr_tumblr_publisher_authentication_pane_spit_publishing_dialog_pane_interface_init (SpitPublishingDialogPaneIface * iface) {
#line 582 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_tumblr_tumblr_publisher_authentication_pane_spit_publishing_dialog_pane_parent_iface = g_type_interface_peek_parent (iface);
#line 582 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	iface->get_widget = (GtkWidget* (*)(SpitPublishingDialogPane*)) publishing_tumblr_tumblr_publisher_authentication_pane_real_get_widget;
#line 582 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	iface->get_preferred_geometry = (SpitPublishingDialogPaneGeometryOptions (*)(SpitPublishingDialogPane*)) publishing_tumblr_tumblr_publisher_authentication_pane_real_get_preferred_geometry;
#line 582 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	iface->on_pane_installed = (void (*)(SpitPublishingDialogPane*)) publishing_tumblr_tumblr_publisher_authentication_pane_real_on_pane_installed;
#line 582 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	iface->on_pane_uninstalled = (void (*)(SpitPublishingDialogPane*)) publishing_tumblr_tumblr_publisher_authentication_pane_real_on_pane_uninstalled;
#line 4422 "TumblrPublishing.c"
}


static void publishing_tumblr_tumblr_publisher_authentication_pane_instance_init (PublishingTumblrTumblrPublisherAuthenticationPane * self) {
#line 582 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv = PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_AUTHENTICATION_PANE_GET_PRIVATE (self);
#line 590 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->pane_widget = NULL;
#line 4431 "TumblrPublishing.c"
}


static void publishing_tumblr_tumblr_publisher_authentication_pane_finalize (GObject* obj) {
	PublishingTumblrTumblrPublisherAuthenticationPane * self;
#line 582 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_AUTHENTICATION_PANE, PublishingTumblrTumblrPublisherAuthenticationPane);
#line 590 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_object_unref0 (self->priv->pane_widget);
#line 591 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_object_unref0 (self->priv->builder);
#line 592 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_object_unref0 (self->priv->username_entry);
#line 593 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_object_unref0 (self->priv->password_entry);
#line 594 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_object_unref0 (self->priv->login_button);
#line 582 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	G_OBJECT_CLASS (publishing_tumblr_tumblr_publisher_authentication_pane_parent_class)->finalize (obj);
#line 4451 "TumblrPublishing.c"
}


/**
 * The authentication pane used when asking service URL, user name and password
 * from the user.
 */
GType publishing_tumblr_tumblr_publisher_authentication_pane_get_type (void) {
	static volatile gsize publishing_tumblr_tumblr_publisher_authentication_pane_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_tumblr_tumblr_publisher_authentication_pane_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingTumblrTumblrPublisherAuthenticationPaneClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_tumblr_tumblr_publisher_authentication_pane_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingTumblrTumblrPublisherAuthenticationPane), 0, (GInstanceInitFunc) publishing_tumblr_tumblr_publisher_authentication_pane_instance_init, NULL };
		static const GInterfaceInfo spit_publishing_dialog_pane_info = { (GInterfaceInitFunc) publishing_tumblr_tumblr_publisher_authentication_pane_spit_publishing_dialog_pane_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType publishing_tumblr_tumblr_publisher_authentication_pane_type_id;
		publishing_tumblr_tumblr_publisher_authentication_pane_type_id = g_type_register_static (G_TYPE_OBJECT, "PublishingTumblrTumblrPublisherAuthenticationPane", &g_define_type_info, 0);
		g_type_add_interface_static (publishing_tumblr_tumblr_publisher_authentication_pane_type_id, SPIT_PUBLISHING_TYPE_DIALOG_PANE, &spit_publishing_dialog_pane_info);
		g_once_init_leave (&publishing_tumblr_tumblr_publisher_authentication_pane_type_id__volatile, publishing_tumblr_tumblr_publisher_authentication_pane_type_id);
	}
	return publishing_tumblr_tumblr_publisher_authentication_pane_type_id__volatile;
}


static gpointer _publishing_tumblr_size_entry_ref0 (gpointer self) {
#line 714 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return self ? publishing_tumblr_size_entry_ref (self) : NULL;
#line 4476 "TumblrPublishing.c"
}


static PublishingTumblrSizeEntry** _vala_array_dup7 (PublishingTumblrSizeEntry** self, int length) {
	PublishingTumblrSizeEntry** result;
	int i;
#line 714 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	result = g_new0 (PublishingTumblrSizeEntry*, length + 1);
#line 714 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	for (i = 0; i < length; i++) {
#line 4487 "TumblrPublishing.c"
		PublishingTumblrSizeEntry* _tmp0_ = NULL;
#line 714 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp0_ = _publishing_tumblr_size_entry_ref0 (self[i]);
#line 714 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		result[i] = _tmp0_;
#line 4493 "TumblrPublishing.c"
	}
#line 714 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return result;
#line 4497 "TumblrPublishing.c"
}


static gpointer _publishing_tumblr_blog_entry_ref0 (gpointer self) {
#line 715 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return self ? publishing_tumblr_blog_entry_ref (self) : NULL;
#line 4504 "TumblrPublishing.c"
}


static PublishingTumblrBlogEntry** _vala_array_dup8 (PublishingTumblrBlogEntry** self, int length) {
	PublishingTumblrBlogEntry** result;
	int i;
#line 715 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	result = g_new0 (PublishingTumblrBlogEntry*, length + 1);
#line 715 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	for (i = 0; i < length; i++) {
#line 4515 "TumblrPublishing.c"
		PublishingTumblrBlogEntry* _tmp0_ = NULL;
#line 715 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp0_ = _publishing_tumblr_blog_entry_ref0 (self[i]);
#line 715 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		result[i] = _tmp0_;
#line 4521 "TumblrPublishing.c"
	}
#line 715 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return result;
#line 4525 "TumblrPublishing.c"
}


static void _publishing_tumblr_tumblr_publisher_publishing_options_pane_on_blog_changed_gtk_combo_box_changed (GtkComboBox* _sender, gpointer self) {
#line 738 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_tumblr_tumblr_publisher_publishing_options_pane_on_blog_changed ((PublishingTumblrTumblrPublisherPublishingOptionsPane*) self);
#line 4532 "TumblrPublishing.c"
}


static void _publishing_tumblr_tumblr_publisher_publishing_options_pane_on_size_changed_gtk_combo_box_changed (GtkComboBox* _sender, gpointer self) {
#line 742 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_tumblr_tumblr_publisher_publishing_options_pane_on_size_changed ((PublishingTumblrTumblrPublisherPublishingOptionsPane*) self);
#line 4539 "TumblrPublishing.c"
}


static void _publishing_tumblr_tumblr_publisher_publishing_options_pane_on_logout_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 749 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_tumblr_tumblr_publisher_publishing_options_pane_on_logout_clicked ((PublishingTumblrTumblrPublisherPublishingOptionsPane*) self);
#line 4546 "TumblrPublishing.c"
}


static void _publishing_tumblr_tumblr_publisher_publishing_options_pane_on_publish_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 750 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_tumblr_tumblr_publisher_publishing_options_pane_on_publish_clicked ((PublishingTumblrTumblrPublisherPublishingOptionsPane*) self);
#line 4553 "TumblrPublishing.c"
}


PublishingTumblrTumblrPublisherPublishingOptionsPane* publishing_tumblr_tumblr_publisher_publishing_options_pane_construct (GType object_type, PublishingTumblrTumblrPublisher* publisher, SpitPublishingPublisherMediaType media_type, PublishingTumblrSizeEntry** sizes, int sizes_length1, PublishingTumblrBlogEntry** blogs, int blogs_length1, const gchar* username) {
	PublishingTumblrTumblrPublisherPublishingOptionsPane * self = NULL;
	GtkBox* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	PublishingTumblrTumblrPublisher* _tmp3_ = NULL;
	PublishingTumblrTumblrPublisher* _tmp4_ = NULL;
	SpitPublishingPublisherMediaType _tmp5_ = 0;
	PublishingTumblrSizeEntry** _tmp6_ = NULL;
	gint _tmp6__length1 = 0;
	PublishingTumblrSizeEntry** _tmp7_ = NULL;
	gint _tmp7__length1 = 0;
	PublishingTumblrBlogEntry** _tmp8_ = NULL;
	gint _tmp8__length1 = 0;
	PublishingTumblrBlogEntry** _tmp9_ = NULL;
	gint _tmp9__length1 = 0;
	GError * _inner_error_ = NULL;
#line 708 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_val_if_fail (PUBLISHING_TUMBLR_IS_TUMBLR_PUBLISHER (publisher), NULL);
#line 708 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_val_if_fail (username != NULL, NULL);
#line 708 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self = (PublishingTumblrTumblrPublisherPublishingOptionsPane*) g_object_new (object_type, NULL);
#line 710 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
#line 710 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_object_ref_sink (_tmp0_);
#line 710 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_object_unref0 (self->priv->pane_widget);
#line 710 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->pane_widget = _tmp0_;
#line 711 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp1_ = username;
#line 711 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp2_ = g_strdup (_tmp1_);
#line 711 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_free0 (self->priv->username);
#line 711 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->username = _tmp2_;
#line 712 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp3_ = publisher;
#line 712 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp4_ = _g_object_ref0 (_tmp3_);
#line 712 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_object_unref0 (self->priv->publisher);
#line 712 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->publisher = _tmp4_;
#line 713 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp5_ = media_type;
#line 713 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->media_type = _tmp5_;
#line 714 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp6_ = sizes;
#line 714 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp6__length1 = sizes_length1;
#line 714 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp7_ = (_tmp6_ != NULL) ? _vala_array_dup7 (_tmp6_, _tmp6__length1) : ((gpointer) _tmp6_);
#line 714 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp7__length1 = _tmp6__length1;
#line 714 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->sizes = (_vala_array_free (self->priv->sizes, self->priv->sizes_length1, (GDestroyNotify) publishing_tumblr_size_entry_unref), NULL);
#line 714 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->sizes = _tmp7_;
#line 714 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->sizes_length1 = _tmp7__length1;
#line 714 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->_sizes_size_ = self->priv->sizes_length1;
#line 715 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp8_ = blogs;
#line 715 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp8__length1 = blogs_length1;
#line 715 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp9_ = (_tmp8_ != NULL) ? _vala_array_dup8 (_tmp8_, _tmp8__length1) : ((gpointer) _tmp8_);
#line 715 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp9__length1 = _tmp8__length1;
#line 715 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->blogs = (_vala_array_free (self->priv->blogs, self->priv->blogs_length1, (GDestroyNotify) publishing_tumblr_blog_entry_unref), NULL);
#line 715 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->blogs = _tmp9_;
#line 715 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->blogs_length1 = _tmp9__length1;
#line 715 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->_blogs_size_ = self->priv->blogs_length1;
#line 4640 "TumblrPublishing.c"
	{
		GtkBuilder* _tmp10_ = NULL;
		GtkBuilder* _tmp11_ = NULL;
		GtkBuilder* _tmp12_ = NULL;
		GtkBuilder* _tmp13_ = NULL;
		GObject* _tmp14_ = NULL;
		GtkBox* _tmp15_ = NULL;
		GtkBuilder* _tmp16_ = NULL;
		GObject* _tmp17_ = NULL;
		GtkLabel* _tmp18_ = NULL;
		GtkBuilder* _tmp19_ = NULL;
		GObject* _tmp20_ = NULL;
		GtkButton* _tmp21_ = NULL;
		GtkBuilder* _tmp22_ = NULL;
		GObject* _tmp23_ = NULL;
		GtkButton* _tmp24_ = NULL;
		GtkBuilder* _tmp25_ = NULL;
		GObject* _tmp26_ = NULL;
		GtkComboBoxText* _tmp27_ = NULL;
		GtkBuilder* _tmp28_ = NULL;
		GObject* _tmp29_ = NULL;
		GtkLabel* _tmp30_ = NULL;
		GtkBuilder* _tmp31_ = NULL;
		GObject* _tmp32_ = NULL;
		GtkComboBoxText* _tmp33_ = NULL;
		GtkBuilder* _tmp34_ = NULL;
		GObject* _tmp35_ = NULL;
		GtkLabel* _tmp36_ = NULL;
		gchar* upload_label_text = NULL;
		const gchar* _tmp37_ = NULL;
		const gchar* _tmp38_ = NULL;
		gchar* _tmp39_ = NULL;
		GtkLabel* _tmp40_ = NULL;
		const gchar* _tmp41_ = NULL;
		GtkComboBoxText* _tmp42_ = NULL;
		SpitPublishingPublisherMediaType _tmp43_ = 0;
		GtkButton* _tmp47_ = NULL;
		GtkButton* _tmp48_ = NULL;
#line 718 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp10_ = gtk_builder_new ();
#line 718 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_g_object_unref0 (self->priv->builder);
#line 718 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		self->priv->builder = _tmp10_;
#line 719 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp11_ = self->priv->builder;
#line 719 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		gtk_builder_add_from_resource (_tmp11_, PLUGIN_RESOURCE_PATH "/tumblr_publishing_options_pane.ui", &_inner_error_);
#line 719 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 4691 "TumblrPublishing.c"
			goto __catch37_g_error;
		}
#line 721 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp12_ = self->priv->builder;
#line 721 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		gtk_builder_connect_signals (_tmp12_, NULL);
#line 724 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp13_ = self->priv->builder;
#line 724 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp14_ = gtk_builder_get_object (_tmp13_, "tumblr_pane");
#line 724 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp15_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp14_, gtk_box_get_type (), GtkBox));
#line 724 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_g_object_unref0 (self->priv->pane_widget);
#line 724 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		self->priv->pane_widget = _tmp15_;
#line 725 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp16_ = self->priv->builder;
#line 725 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp17_ = gtk_builder_get_object (_tmp16_, "upload_info_label");
#line 725 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp18_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp17_, gtk_label_get_type (), GtkLabel));
#line 725 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_g_object_unref0 (self->priv->upload_info_label);
#line 725 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		self->priv->upload_info_label = _tmp18_;
#line 726 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp19_ = self->priv->builder;
#line 726 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp20_ = gtk_builder_get_object (_tmp19_, "logout_button");
#line 726 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp21_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp20_, gtk_button_get_type (), GtkButton));
#line 726 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_g_object_unref0 (self->priv->logout_button);
#line 726 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		self->priv->logout_button = _tmp21_;
#line 727 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp22_ = self->priv->builder;
#line 727 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp23_ = gtk_builder_get_object (_tmp22_, "publish_button");
#line 727 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp24_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp23_, gtk_button_get_type (), GtkButton));
#line 727 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_g_object_unref0 (self->priv->publish_button);
#line 727 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		self->priv->publish_button = _tmp24_;
#line 728 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp25_ = self->priv->builder;
#line 728 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp26_ = gtk_builder_get_object (_tmp25_, "size_combo");
#line 728 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp27_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp26_, gtk_combo_box_text_get_type (), GtkComboBoxText));
#line 728 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_g_object_unref0 (self->priv->size_combo);
#line 728 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		self->priv->size_combo = _tmp27_;
#line 729 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp28_ = self->priv->builder;
#line 729 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp29_ = gtk_builder_get_object (_tmp28_, "size_label");
#line 729 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp30_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp29_, gtk_label_get_type (), GtkLabel));
#line 729 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_g_object_unref0 (self->priv->size_label);
#line 729 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		self->priv->size_label = _tmp30_;
#line 730 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp31_ = self->priv->builder;
#line 730 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp32_ = gtk_builder_get_object (_tmp31_, "blog_combo");
#line 730 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp33_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp32_, gtk_combo_box_text_get_type (), GtkComboBoxText));
#line 730 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_g_object_unref0 (self->priv->blog_combo);
#line 730 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		self->priv->blog_combo = _tmp33_;
#line 731 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp34_ = self->priv->builder;
#line 731 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp35_ = gtk_builder_get_object (_tmp34_, "blog_label");
#line 731 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp36_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp35_, gtk_label_get_type (), GtkLabel));
#line 731 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_g_object_unref0 (self->priv->blog_label);
#line 731 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		self->priv->blog_label = _tmp36_;
#line 734 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp37_ = _ ("You are logged into Tumblr as %s.\n\n");
#line 734 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp38_ = self->priv->username;
#line 734 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp39_ = g_strdup_printf (_tmp37_, _tmp38_);
#line 734 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		upload_label_text = _tmp39_;
#line 735 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp40_ = self->priv->upload_info_label;
#line 735 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp41_ = upload_label_text;
#line 735 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		gtk_label_set_label (_tmp40_, _tmp41_);
#line 737 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		publishing_tumblr_tumblr_publisher_publishing_options_pane_populate_blog_combo (self);
#line 738 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp42_ = self->priv->blog_combo;
#line 738 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp42_, gtk_combo_box_get_type (), GtkComboBox), "changed", (GCallback) _publishing_tumblr_tumblr_publisher_publishing_options_pane_on_blog_changed_gtk_combo_box_changed, self, 0);
#line 740 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp43_ = media_type;
#line 740 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		if (_tmp43_ != SPIT_PUBLISHING_PUBLISHER_MEDIA_TYPE_VIDEO) {
#line 4802 "TumblrPublishing.c"
			GtkComboBoxText* _tmp44_ = NULL;
#line 741 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			publishing_tumblr_tumblr_publisher_publishing_options_pane_populate_size_combo (self);
#line 742 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			_tmp44_ = self->priv->size_combo;
#line 742 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp44_, gtk_combo_box_get_type (), GtkComboBox), "changed", (GCallback) _publishing_tumblr_tumblr_publisher_publishing_options_pane_on_size_changed_gtk_combo_box_changed, self, 0);
#line 4810 "TumblrPublishing.c"
		} else {
			GtkComboBoxText* _tmp45_ = NULL;
			GtkLabel* _tmp46_ = NULL;
#line 745 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			_tmp45_ = self->priv->size_combo;
#line 745 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp45_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 746 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			_tmp46_ = self->priv->size_label;
#line 746 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp46_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 4822 "TumblrPublishing.c"
		}
#line 749 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp47_ = self->priv->logout_button;
#line 749 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		g_signal_connect_object (_tmp47_, "clicked", (GCallback) _publishing_tumblr_tumblr_publisher_publishing_options_pane_on_logout_clicked_gtk_button_clicked, self, 0);
#line 750 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp48_ = self->priv->publish_button;
#line 750 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		g_signal_connect_object (_tmp48_, "clicked", (GCallback) _publishing_tumblr_tumblr_publisher_publishing_options_pane_on_publish_clicked_gtk_button_clicked, self, 0);
#line 717 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_g_free0 (upload_label_text);
#line 4834 "TumblrPublishing.c"
	}
	goto __finally37;
	__catch37_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp49_ = NULL;
		GError* _tmp50_ = NULL;
		const gchar* _tmp51_ = NULL;
#line 717 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		e = _inner_error_;
#line 717 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_inner_error_ = NULL;
#line 752 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp49_ = _ ("Could not load UI: %s");
#line 752 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp50_ = e;
#line 752 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp51_ = _tmp50_->message;
#line 752 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		g_warning (_tmp49_, _tmp51_);
#line 717 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_g_error_free0 (e);
#line 4857 "TumblrPublishing.c"
	}
	__finally37:
#line 717 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 717 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 717 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		g_clear_error (&_inner_error_);
#line 717 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		return NULL;
#line 4868 "TumblrPublishing.c"
	}
#line 708 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return self;
#line 4872 "TumblrPublishing.c"
}


PublishingTumblrTumblrPublisherPublishingOptionsPane* publishing_tumblr_tumblr_publisher_publishing_options_pane_new (PublishingTumblrTumblrPublisher* publisher, SpitPublishingPublisherMediaType media_type, PublishingTumblrSizeEntry** sizes, int sizes_length1, PublishingTumblrBlogEntry** blogs, int blogs_length1, const gchar* username) {
#line 708 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return publishing_tumblr_tumblr_publisher_publishing_options_pane_construct (PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_PUBLISHING_OPTIONS_PANE, publisher, media_type, sizes, sizes_length1, blogs, blogs_length1, username);
#line 4879 "TumblrPublishing.c"
}


static void publishing_tumblr_tumblr_publisher_publishing_options_pane_on_logout_clicked (PublishingTumblrTumblrPublisherPublishingOptionsPane* self) {
#line 760 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_if_fail (PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_IS_PUBLISHING_OPTIONS_PANE (self));
#line 761 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_signal_emit_by_name (self, "logout");
#line 4888 "TumblrPublishing.c"
}


static void publishing_tumblr_tumblr_publisher_publishing_options_pane_on_publish_clicked (PublishingTumblrTumblrPublisherPublishingOptionsPane* self) {
#line 764 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_if_fail (PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_IS_PUBLISHING_OPTIONS_PANE (self));
#line 767 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_signal_emit_by_name (self, "publish");
#line 4897 "TumblrPublishing.c"
}


static void publishing_tumblr_tumblr_publisher_publishing_options_pane_populate_blog_combo (PublishingTumblrTumblrPublisherPublishingOptionsPane* self) {
	PublishingTumblrBlogEntry** _tmp0_ = NULL;
	gint _tmp0__length1 = 0;
#line 771 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_if_fail (PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_IS_PUBLISHING_OPTIONS_PANE (self));
#line 772 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = self->priv->blogs;
#line 772 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0__length1 = self->priv->blogs_length1;
#line 772 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	if (_tmp0_ != NULL) {
#line 4912 "TumblrPublishing.c"
		PublishingTumblrBlogEntry** _tmp1_ = NULL;
		gint _tmp1__length1 = 0;
		GtkComboBoxText* _tmp6_ = NULL;
		PublishingTumblrTumblrPublisher* _tmp7_ = NULL;
		gint _tmp8_ = 0;
#line 773 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp1_ = self->priv->blogs;
#line 773 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp1__length1 = self->priv->blogs_length1;
#line 4922 "TumblrPublishing.c"
		{
			PublishingTumblrBlogEntry** b_collection = NULL;
			gint b_collection_length1 = 0;
			gint _b_collection_size_ = 0;
			gint b_it = 0;
#line 773 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			b_collection = _tmp1_;
#line 773 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			b_collection_length1 = _tmp1__length1;
#line 773 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			for (b_it = 0; b_it < _tmp1__length1; b_it = b_it + 1) {
#line 4934 "TumblrPublishing.c"
				PublishingTumblrBlogEntry* _tmp2_ = NULL;
				PublishingTumblrBlogEntry* b = NULL;
#line 773 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp2_ = _publishing_tumblr_blog_entry_ref0 (b_collection[b_it]);
#line 773 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				b = _tmp2_;
#line 4941 "TumblrPublishing.c"
				{
					GtkComboBoxText* _tmp3_ = NULL;
					PublishingTumblrBlogEntry* _tmp4_ = NULL;
					const gchar* _tmp5_ = NULL;
#line 774 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					_tmp3_ = self->priv->blog_combo;
#line 774 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					_tmp4_ = b;
#line 774 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					_tmp5_ = _tmp4_->blog;
#line 774 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					gtk_combo_box_text_append_text (_tmp3_, _tmp5_);
#line 773 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					_publishing_tumblr_blog_entry_unref0 (b);
#line 4956 "TumblrPublishing.c"
				}
			}
		}
#line 775 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp6_ = self->priv->blog_combo;
#line 775 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp7_ = self->priv->publisher;
#line 775 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp8_ = publishing_tumblr_tumblr_publisher_get_persistent_default_blog (_tmp7_);
#line 775 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		gtk_combo_box_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, gtk_combo_box_get_type (), GtkComboBox), _tmp8_);
#line 4968 "TumblrPublishing.c"
	}
}


static void publishing_tumblr_tumblr_publisher_publishing_options_pane_on_blog_changed (PublishingTumblrTumblrPublisherPublishingOptionsPane* self) {
	PublishingTumblrTumblrPublisher* _tmp0_ = NULL;
	GtkComboBoxText* _tmp1_ = NULL;
	gint _tmp2_ = 0;
#line 779 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_if_fail (PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_IS_PUBLISHING_OPTIONS_PANE (self));
#line 780 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = self->priv->publisher;
#line 780 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp1_ = self->priv->blog_combo;
#line 780 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp2_ = gtk_combo_box_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, gtk_combo_box_get_type (), GtkComboBox));
#line 780 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_tumblr_tumblr_publisher_set_persistent_default_blog (_tmp0_, _tmp2_);
#line 4987 "TumblrPublishing.c"
}


static void publishing_tumblr_tumblr_publisher_publishing_options_pane_populate_size_combo (PublishingTumblrTumblrPublisherPublishingOptionsPane* self) {
	PublishingTumblrSizeEntry** _tmp0_ = NULL;
	gint _tmp0__length1 = 0;
#line 783 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_if_fail (PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_IS_PUBLISHING_OPTIONS_PANE (self));
#line 784 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = self->priv->sizes;
#line 784 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0__length1 = self->priv->sizes_length1;
#line 784 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	if (_tmp0_ != NULL) {
#line 5002 "TumblrPublishing.c"
		PublishingTumblrSizeEntry** _tmp1_ = NULL;
		gint _tmp1__length1 = 0;
		GtkComboBoxText* _tmp6_ = NULL;
		PublishingTumblrTumblrPublisher* _tmp7_ = NULL;
		gint _tmp8_ = 0;
#line 785 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp1_ = self->priv->sizes;
#line 785 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp1__length1 = self->priv->sizes_length1;
#line 5012 "TumblrPublishing.c"
		{
			PublishingTumblrSizeEntry** e_collection = NULL;
			gint e_collection_length1 = 0;
			gint _e_collection_size_ = 0;
			gint e_it = 0;
#line 785 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			e_collection = _tmp1_;
#line 785 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			e_collection_length1 = _tmp1__length1;
#line 785 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			for (e_it = 0; e_it < _tmp1__length1; e_it = e_it + 1) {
#line 5024 "TumblrPublishing.c"
				PublishingTumblrSizeEntry* _tmp2_ = NULL;
				PublishingTumblrSizeEntry* e = NULL;
#line 785 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp2_ = _publishing_tumblr_size_entry_ref0 (e_collection[e_it]);
#line 785 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				e = _tmp2_;
#line 5031 "TumblrPublishing.c"
				{
					GtkComboBoxText* _tmp3_ = NULL;
					PublishingTumblrSizeEntry* _tmp4_ = NULL;
					const gchar* _tmp5_ = NULL;
#line 786 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					_tmp3_ = self->priv->size_combo;
#line 786 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					_tmp4_ = e;
#line 786 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					_tmp5_ = _tmp4_->title;
#line 786 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					gtk_combo_box_text_append_text (_tmp3_, _tmp5_);
#line 785 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					_publishing_tumblr_size_entry_unref0 (e);
#line 5046 "TumblrPublishing.c"
				}
			}
		}
#line 787 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp6_ = self->priv->size_combo;
#line 787 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp7_ = self->priv->publisher;
#line 787 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp8_ = publishing_tumblr_tumblr_publisher_get_persistent_default_size (_tmp7_);
#line 787 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		gtk_combo_box_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, gtk_combo_box_get_type (), GtkComboBox), _tmp8_);
#line 5058 "TumblrPublishing.c"
	}
}


static void publishing_tumblr_tumblr_publisher_publishing_options_pane_on_size_changed (PublishingTumblrTumblrPublisherPublishingOptionsPane* self) {
	PublishingTumblrTumblrPublisher* _tmp0_ = NULL;
	GtkComboBoxText* _tmp1_ = NULL;
	gint _tmp2_ = 0;
#line 791 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_if_fail (PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_IS_PUBLISHING_OPTIONS_PANE (self));
#line 792 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = self->priv->publisher;
#line 792 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp1_ = self->priv->size_combo;
#line 792 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp2_ = gtk_combo_box_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, gtk_combo_box_get_type (), GtkComboBox));
#line 792 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_tumblr_tumblr_publisher_set_persistent_default_size (_tmp0_, _tmp2_);
#line 5077 "TumblrPublishing.c"
}


void publishing_tumblr_tumblr_publisher_publishing_options_pane_notify_publish (PublishingTumblrTumblrPublisherPublishingOptionsPane* self) {
#line 796 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_if_fail (PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_IS_PUBLISHING_OPTIONS_PANE (self));
#line 797 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_signal_emit_by_name (self, "publish");
#line 5086 "TumblrPublishing.c"
}


void publishing_tumblr_tumblr_publisher_publishing_options_pane_notify_logout (PublishingTumblrTumblrPublisherPublishingOptionsPane* self) {
#line 800 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_if_fail (PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_IS_PUBLISHING_OPTIONS_PANE (self));
#line 801 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_signal_emit_by_name (self, "logout");
#line 5095 "TumblrPublishing.c"
}


static GtkWidget* publishing_tumblr_tumblr_publisher_publishing_options_pane_real_get_widget (SpitPublishingDialogPane* base) {
	PublishingTumblrTumblrPublisherPublishingOptionsPane * self;
	GtkWidget* result = NULL;
	GtkBox* _tmp0_ = NULL;
	GtkWidget* _tmp1_ = NULL;
#line 804 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_PUBLISHING_OPTIONS_PANE, PublishingTumblrTumblrPublisherPublishingOptionsPane);
#line 805 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = self->priv->pane_widget;
#line 805 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_widget_get_type (), GtkWidget));
#line 805 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	result = _tmp1_;
#line 805 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return result;
#line 5114 "TumblrPublishing.c"
}


static SpitPublishingDialogPaneGeometryOptions publishing_tumblr_tumblr_publisher_publishing_options_pane_real_get_preferred_geometry (SpitPublishingDialogPane* base) {
	PublishingTumblrTumblrPublisherPublishingOptionsPane * self;
	SpitPublishingDialogPaneGeometryOptions result = 0;
#line 808 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_PUBLISHING_OPTIONS_PANE, PublishingTumblrTumblrPublisherPublishingOptionsPane);
#line 809 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	result = SPIT_PUBLISHING_DIALOG_PANE_GEOMETRY_OPTIONS_NONE;
#line 809 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return result;
#line 5127 "TumblrPublishing.c"
}


static void _publishing_tumblr_tumblr_publisher_publishing_options_pane_notify_publish_publishing_tumblr_tumblr_publisher_publishing_options_pane_publish (PublishingTumblrTumblrPublisherPublishingOptionsPane* _sender, gpointer self) {
#line 813 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_tumblr_tumblr_publisher_publishing_options_pane_notify_publish ((PublishingTumblrTumblrPublisherPublishingOptionsPane*) self);
#line 5134 "TumblrPublishing.c"
}


static void _publishing_tumblr_tumblr_publisher_publishing_options_pane_notify_logout_publishing_tumblr_tumblr_publisher_publishing_options_pane_logout (PublishingTumblrTumblrPublisherPublishingOptionsPane* _sender, gpointer self) {
#line 814 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_tumblr_tumblr_publisher_publishing_options_pane_notify_logout ((PublishingTumblrTumblrPublisherPublishingOptionsPane*) self);
#line 5141 "TumblrPublishing.c"
}


static void publishing_tumblr_tumblr_publisher_publishing_options_pane_real_on_pane_installed (SpitPublishingDialogPane* base) {
	PublishingTumblrTumblrPublisherPublishingOptionsPane * self;
#line 812 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_PUBLISHING_OPTIONS_PANE, PublishingTumblrTumblrPublisherPublishingOptionsPane);
#line 813 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_signal_connect_object (self, "publish", (GCallback) _publishing_tumblr_tumblr_publisher_publishing_options_pane_notify_publish_publishing_tumblr_tumblr_publisher_publishing_options_pane_publish, self, 0);
#line 814 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_signal_connect_object (self, "logout", (GCallback) _publishing_tumblr_tumblr_publisher_publishing_options_pane_notify_logout_publishing_tumblr_tumblr_publisher_publishing_options_pane_logout, self, 0);
#line 5153 "TumblrPublishing.c"
}


static void publishing_tumblr_tumblr_publisher_publishing_options_pane_real_on_pane_uninstalled (SpitPublishingDialogPane* base) {
	PublishingTumblrTumblrPublisherPublishingOptionsPane * self;
	guint _tmp0_ = 0U;
	guint _tmp1_ = 0U;
#line 817 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_PUBLISHING_OPTIONS_PANE, PublishingTumblrTumblrPublisherPublishingOptionsPane);
#line 818 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_signal_parse_name ("publish", PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_PUBLISHING_OPTIONS_PANE, &_tmp0_, NULL, FALSE);
#line 818 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_signal_handlers_disconnect_matched (self, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp0_, 0, NULL, (GCallback) _publishing_tumblr_tumblr_publisher_publishing_options_pane_notify_publish_publishing_tumblr_tumblr_publisher_publishing_options_pane_publish, self);
#line 819 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_signal_parse_name ("logout", PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_PUBLISHING_OPTIONS_PANE, &_tmp1_, NULL, FALSE);
#line 819 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_signal_handlers_disconnect_matched (self, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_tumblr_tumblr_publisher_publishing_options_pane_notify_logout_publishing_tumblr_tumblr_publisher_publishing_options_pane_logout, self);
#line 5171 "TumblrPublishing.c"
}


static void publishing_tumblr_tumblr_publisher_publishing_options_pane_class_init (PublishingTumblrTumblrPublisherPublishingOptionsPaneClass * klass) {
#line 686 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_tumblr_tumblr_publisher_publishing_options_pane_parent_class = g_type_class_peek_parent (klass);
#line 686 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_type_class_add_private (klass, sizeof (PublishingTumblrTumblrPublisherPublishingOptionsPanePrivate));
#line 686 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	G_OBJECT_CLASS (klass)->finalize = publishing_tumblr_tumblr_publisher_publishing_options_pane_finalize;
#line 686 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_signal_new ("publish", PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_PUBLISHING_OPTIONS_PANE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
#line 686 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_signal_new ("logout", PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_PUBLISHING_OPTIONS_PANE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
#line 5186 "TumblrPublishing.c"
}


static void publishing_tumblr_tumblr_publisher_publishing_options_pane_spit_publishing_dialog_pane_interface_init (SpitPublishingDialogPaneIface * iface) {
#line 686 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_tumblr_tumblr_publisher_publishing_options_pane_spit_publishing_dialog_pane_parent_iface = g_type_interface_peek_parent (iface);
#line 686 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	iface->get_widget = (GtkWidget* (*)(SpitPublishingDialogPane*)) publishing_tumblr_tumblr_publisher_publishing_options_pane_real_get_widget;
#line 686 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	iface->get_preferred_geometry = (SpitPublishingDialogPaneGeometryOptions (*)(SpitPublishingDialogPane*)) publishing_tumblr_tumblr_publisher_publishing_options_pane_real_get_preferred_geometry;
#line 686 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	iface->on_pane_installed = (void (*)(SpitPublishingDialogPane*)) publishing_tumblr_tumblr_publisher_publishing_options_pane_real_on_pane_installed;
#line 686 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	iface->on_pane_uninstalled = (void (*)(SpitPublishingDialogPane*)) publishing_tumblr_tumblr_publisher_publishing_options_pane_real_on_pane_uninstalled;
#line 5201 "TumblrPublishing.c"
}


static void publishing_tumblr_tumblr_publisher_publishing_options_pane_instance_init (PublishingTumblrTumblrPublisherPublishingOptionsPane * self) {
	gchar* _tmp0_ = NULL;
#line 686 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv = PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_PUBLISHING_OPTIONS_PANE_GET_PRIVATE (self);
#line 691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->pane_widget = NULL;
#line 692 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->upload_info_label = NULL;
#line 693 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->size_label = NULL;
#line 694 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->blog_label = NULL;
#line 695 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->logout_button = NULL;
#line 696 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->publish_button = NULL;
#line 697 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->size_combo = NULL;
#line 698 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->blog_combo = NULL;
#line 699 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->sizes = NULL;
#line 699 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->sizes_length1 = 0;
#line 699 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->_sizes_size_ = self->priv->sizes_length1;
#line 700 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->blogs = NULL;
#line 700 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->blogs_length1 = 0;
#line 700 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->_blogs_size_ = self->priv->blogs_length1;
#line 701 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = g_strdup ("");
#line 701 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->username = _tmp0_;
#line 702 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->publisher = NULL;
#line 5243 "TumblrPublishing.c"
}


static void publishing_tumblr_tumblr_publisher_publishing_options_pane_finalize (GObject* obj) {
	PublishingTumblrTumblrPublisherPublishingOptionsPane * self;
#line 686 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_PUBLISHING_OPTIONS_PANE, PublishingTumblrTumblrPublisherPublishingOptionsPane);
#line 690 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_object_unref0 (self->priv->builder);
#line 691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_object_unref0 (self->priv->pane_widget);
#line 692 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_object_unref0 (self->priv->upload_info_label);
#line 693 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_object_unref0 (self->priv->size_label);
#line 694 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_object_unref0 (self->priv->blog_label);
#line 695 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_object_unref0 (self->priv->logout_button);
#line 696 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_object_unref0 (self->priv->publish_button);
#line 697 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_object_unref0 (self->priv->size_combo);
#line 698 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_object_unref0 (self->priv->blog_combo);
#line 699 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->sizes = (_vala_array_free (self->priv->sizes, self->priv->sizes_length1, (GDestroyNotify) publishing_tumblr_size_entry_unref), NULL);
#line 700 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->blogs = (_vala_array_free (self->priv->blogs, self->priv->blogs_length1, (GDestroyNotify) publishing_tumblr_blog_entry_unref), NULL);
#line 701 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_free0 (self->priv->username);
#line 702 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_object_unref0 (self->priv->publisher);
#line 686 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	G_OBJECT_CLASS (publishing_tumblr_tumblr_publisher_publishing_options_pane_parent_class)->finalize (obj);
#line 5279 "TumblrPublishing.c"
}


/**
 * The publishing options pane.
 */
GType publishing_tumblr_tumblr_publisher_publishing_options_pane_get_type (void) {
	static volatile gsize publishing_tumblr_tumblr_publisher_publishing_options_pane_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_tumblr_tumblr_publisher_publishing_options_pane_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingTumblrTumblrPublisherPublishingOptionsPaneClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_tumblr_tumblr_publisher_publishing_options_pane_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingTumblrTumblrPublisherPublishingOptionsPane), 0, (GInstanceInitFunc) publishing_tumblr_tumblr_publisher_publishing_options_pane_instance_init, NULL };
		static const GInterfaceInfo spit_publishing_dialog_pane_info = { (GInterfaceInitFunc) publishing_tumblr_tumblr_publisher_publishing_options_pane_spit_publishing_dialog_pane_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType publishing_tumblr_tumblr_publisher_publishing_options_pane_type_id;
		publishing_tumblr_tumblr_publisher_publishing_options_pane_type_id = g_type_register_static (G_TYPE_OBJECT, "PublishingTumblrTumblrPublisherPublishingOptionsPane", &g_define_type_info, 0);
		g_type_add_interface_static (publishing_tumblr_tumblr_publisher_publishing_options_pane_type_id, SPIT_PUBLISHING_TYPE_DIALOG_PANE, &spit_publishing_dialog_pane_info);
		g_once_init_leave (&publishing_tumblr_tumblr_publisher_publishing_options_pane_type_id__volatile, publishing_tumblr_tumblr_publisher_publishing_options_pane_type_id);
	}
	return publishing_tumblr_tumblr_publisher_publishing_options_pane_type_id__volatile;
}


PublishingTumblrTumblrPublisherTransaction* publishing_tumblr_tumblr_publisher_transaction_construct (GType object_type, PublishingTumblrTumblrPublisherSession* session, PublishingRESTSupportHttpMethod method) {
	PublishingTumblrTumblrPublisherTransaction* self = NULL;
	PublishingTumblrTumblrPublisherSession* _tmp0_ = NULL;
	PublishingRESTSupportHttpMethod _tmp1_ = 0;
#line 826 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_val_if_fail (PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_IS_SESSION (session), NULL);
#line 828 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = session;
#line 828 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp1_ = method;
#line 828 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self = (PublishingTumblrTumblrPublisherTransaction*) publishing_rest_support_transaction_construct (object_type, G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession), _tmp1_);
#line 826 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return self;
#line 5314 "TumblrPublishing.c"
}


PublishingTumblrTumblrPublisherTransaction* publishing_tumblr_tumblr_publisher_transaction_new (PublishingTumblrTumblrPublisherSession* session, PublishingRESTSupportHttpMethod method) {
#line 826 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return publishing_tumblr_tumblr_publisher_transaction_construct (PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_TRANSACTION, session, method);
#line 5321 "TumblrPublishing.c"
}


PublishingTumblrTumblrPublisherTransaction* publishing_tumblr_tumblr_publisher_transaction_construct_with_uri (GType object_type, PublishingTumblrTumblrPublisherSession* session, const gchar* uri, PublishingRESTSupportHttpMethod method) {
	PublishingTumblrTumblrPublisherTransaction* self = NULL;
	PublishingTumblrTumblrPublisherSession* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	PublishingRESTSupportHttpMethod _tmp2_ = 0;
	PublishingTumblrTumblrPublisherSession* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	PublishingTumblrTumblrPublisherSession* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
	gchar* _tmp8_ = NULL;
	PublishingTumblrTumblrPublisherSession* _tmp9_ = NULL;
	gchar* _tmp10_ = NULL;
	gchar* _tmp11_ = NULL;
	gboolean _tmp12_ = FALSE;
#line 832 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_val_if_fail (PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_IS_SESSION (session), NULL);
#line 832 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_val_if_fail (uri != NULL, NULL);
#line 834 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = session;
#line 834 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp1_ = uri;
#line 834 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp2_ = method;
#line 834 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self = (PublishingTumblrTumblrPublisherTransaction*) publishing_rest_support_transaction_construct_with_endpoint_url (object_type, G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession), _tmp1_, _tmp2_);
#line 836 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp3_ = session;
#line 836 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp4_ = publishing_tumblr_tumblr_publisher_session_get_oauth_nonce (_tmp3_);
#line 836 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp5_ = _tmp4_;
#line 836 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "oauth_nonce", _tmp5_);
#line 836 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_free0 (_tmp5_);
#line 837 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "oauth_signature_method", "HMAC-SHA1");
#line 838 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "oauth_version", "1.0");
#line 839 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp6_ = session;
#line 839 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp7_ = publishing_tumblr_tumblr_publisher_session_get_oauth_timestamp (_tmp6_);
#line 839 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp8_ = _tmp7_;
#line 839 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "oauth_timestamp", _tmp8_);
#line 839 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_free0 (_tmp8_);
#line 840 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "oauth_consumer_key", PUBLISHING_TUMBLR_API_KEY);
#line 841 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp9_ = session;
#line 841 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp10_ = publishing_tumblr_tumblr_publisher_session_get_access_phase_token (_tmp9_);
#line 841 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp11_ = _tmp10_;
#line 841 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp12_ = _tmp11_ != NULL;
#line 841 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_free0 (_tmp11_);
#line 841 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	if (_tmp12_) {
#line 5390 "TumblrPublishing.c"
		PublishingTumblrTumblrPublisherSession* _tmp13_ = NULL;
		gchar* _tmp14_ = NULL;
		gchar* _tmp15_ = NULL;
#line 842 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp13_ = session;
#line 842 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp14_ = publishing_tumblr_tumblr_publisher_session_get_access_phase_token (_tmp13_);
#line 842 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp15_ = _tmp14_;
#line 842 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "oauth_token", _tmp15_);
#line 842 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_g_free0 (_tmp15_);
#line 5404 "TumblrPublishing.c"
	}
#line 832 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return self;
#line 5408 "TumblrPublishing.c"
}


PublishingTumblrTumblrPublisherTransaction* publishing_tumblr_tumblr_publisher_transaction_new_with_uri (PublishingTumblrTumblrPublisherSession* session, const gchar* uri, PublishingRESTSupportHttpMethod method) {
#line 832 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return publishing_tumblr_tumblr_publisher_transaction_construct_with_uri (PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_TRANSACTION, session, uri, method);
#line 5415 "TumblrPublishing.c"
}


static void publishing_tumblr_tumblr_publisher_transaction_real_execute (PublishingRESTSupportTransaction* base, GError** error) {
	PublishingTumblrTumblrPublisherTransaction * self;
	PublishingRESTSupportSession* _tmp0_ = NULL;
	PublishingTumblrTumblrPublisherSession* _tmp1_ = NULL;
	GError * _inner_error_ = NULL;
#line 846 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_TRANSACTION, PublishingTumblrTumblrPublisherTransaction);
#line 847 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = publishing_rest_support_transaction_get_parent_session (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction));
#line 847 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp1_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_SESSION, PublishingTumblrTumblrPublisherSession);
#line 847 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_tumblr_tumblr_publisher_session_sign_transaction (_tmp1_, G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction));
#line 847 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_publishing_rest_support_session_unref0 (_tmp1_);
#line 849 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	PUBLISHING_REST_SUPPORT_TRANSACTION_CLASS (publishing_tumblr_tumblr_publisher_transaction_parent_class)->execute (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), &_inner_error_);
#line 849 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 849 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 849 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			g_propagate_error (error, _inner_error_);
#line 849 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			return;
#line 5444 "TumblrPublishing.c"
		} else {
#line 849 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 849 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			g_clear_error (&_inner_error_);
#line 849 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			return;
#line 5452 "TumblrPublishing.c"
		}
	}
}


static void publishing_tumblr_tumblr_publisher_transaction_class_init (PublishingTumblrTumblrPublisherTransactionClass * klass) {
#line 825 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_tumblr_tumblr_publisher_transaction_parent_class = g_type_class_peek_parent (klass);
#line 825 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	((PublishingRESTSupportTransactionClass *) klass)->execute = publishing_tumblr_tumblr_publisher_transaction_real_execute;
#line 5463 "TumblrPublishing.c"
}


static void publishing_tumblr_tumblr_publisher_transaction_instance_init (PublishingTumblrTumblrPublisherTransaction * self) {
}


GType publishing_tumblr_tumblr_publisher_transaction_get_type (void) {
	static volatile gsize publishing_tumblr_tumblr_publisher_transaction_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_tumblr_tumblr_publisher_transaction_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingTumblrTumblrPublisherTransactionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_tumblr_tumblr_publisher_transaction_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingTumblrTumblrPublisherTransaction), 0, (GInstanceInitFunc) publishing_tumblr_tumblr_publisher_transaction_instance_init, NULL };
		GType publishing_tumblr_tumblr_publisher_transaction_type_id;
		publishing_tumblr_tumblr_publisher_transaction_type_id = g_type_register_static (PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, "PublishingTumblrTumblrPublisherTransaction", &g_define_type_info, 0);
		g_once_init_leave (&publishing_tumblr_tumblr_publisher_transaction_type_id__volatile, publishing_tumblr_tumblr_publisher_transaction_type_id);
	}
	return publishing_tumblr_tumblr_publisher_transaction_type_id__volatile;
}


PublishingTumblrTumblrPublisherAccessTokenFetchTransaction* publishing_tumblr_tumblr_publisher_access_token_fetch_transaction_construct (GType object_type, PublishingTumblrTumblrPublisherSession* session, const gchar* username, const gchar* password) {
	PublishingTumblrTumblrPublisherAccessTokenFetchTransaction* self = NULL;
	PublishingTumblrTumblrPublisherSession* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
#line 856 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_val_if_fail (PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_IS_SESSION (session), NULL);
#line 856 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_val_if_fail (username != NULL, NULL);
#line 856 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_val_if_fail (password != NULL, NULL);
#line 857 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = session;
#line 857 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self = (PublishingTumblrTumblrPublisherAccessTokenFetchTransaction*) publishing_tumblr_tumblr_publisher_transaction_construct_with_uri (object_type, _tmp0_, "https://www.tumblr.com/oauth/access_token", PUBLISHING_REST_SUPPORT_HTTP_METHOD_POST);
#line 859 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp1_ = username;
#line 859 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp2_ = soup_uri_encode (_tmp1_, PUBLISHING_TUMBLR_ENCODE_RFC_3986_EXTRA);
#line 859 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp3_ = _tmp2_;
#line 859 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "x_auth_username", _tmp3_);
#line 859 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_free0 (_tmp3_);
#line 860 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp4_ = password;
#line 860 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "x_auth_password", _tmp4_);
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "x_auth_mode", "client_auth");
#line 856 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return self;
#line 5518 "TumblrPublishing.c"
}


PublishingTumblrTumblrPublisherAccessTokenFetchTransaction* publishing_tumblr_tumblr_publisher_access_token_fetch_transaction_new (PublishingTumblrTumblrPublisherSession* session, const gchar* username, const gchar* password) {
#line 856 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return publishing_tumblr_tumblr_publisher_access_token_fetch_transaction_construct (PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_ACCESS_TOKEN_FETCH_TRANSACTION, session, username, password);
#line 5525 "TumblrPublishing.c"
}


static void publishing_tumblr_tumblr_publisher_access_token_fetch_transaction_class_init (PublishingTumblrTumblrPublisherAccessTokenFetchTransactionClass * klass) {
#line 855 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_tumblr_tumblr_publisher_access_token_fetch_transaction_parent_class = g_type_class_peek_parent (klass);
#line 5532 "TumblrPublishing.c"
}


static void publishing_tumblr_tumblr_publisher_access_token_fetch_transaction_instance_init (PublishingTumblrTumblrPublisherAccessTokenFetchTransaction * self) {
}


GType publishing_tumblr_tumblr_publisher_access_token_fetch_transaction_get_type (void) {
	static volatile gsize publishing_tumblr_tumblr_publisher_access_token_fetch_transaction_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_tumblr_tumblr_publisher_access_token_fetch_transaction_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingTumblrTumblrPublisherAccessTokenFetchTransactionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_tumblr_tumblr_publisher_access_token_fetch_transaction_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingTumblrTumblrPublisherAccessTokenFetchTransaction), 0, (GInstanceInitFunc) publishing_tumblr_tumblr_publisher_access_token_fetch_transaction_instance_init, NULL };
		GType publishing_tumblr_tumblr_publisher_access_token_fetch_transaction_type_id;
		publishing_tumblr_tumblr_publisher_access_token_fetch_transaction_type_id = g_type_register_static (PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_TRANSACTION, "PublishingTumblrTumblrPublisherAccessTokenFetchTransaction", &g_define_type_info, 0);
		g_once_init_leave (&publishing_tumblr_tumblr_publisher_access_token_fetch_transaction_type_id__volatile, publishing_tumblr_tumblr_publisher_access_token_fetch_transaction_type_id);
	}
	return publishing_tumblr_tumblr_publisher_access_token_fetch_transaction_type_id__volatile;
}


PublishingTumblrTumblrPublisherUserInfoFetchTransaction* publishing_tumblr_tumblr_publisher_user_info_fetch_transaction_construct (GType object_type, PublishingTumblrTumblrPublisherSession* session) {
	PublishingTumblrTumblrPublisherUserInfoFetchTransaction* self = NULL;
	PublishingTumblrTumblrPublisherSession* _tmp0_ = NULL;
#line 866 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_val_if_fail (PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_IS_SESSION (session), NULL);
#line 867 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = session;
#line 867 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self = (PublishingTumblrTumblrPublisherUserInfoFetchTransaction*) publishing_tumblr_tumblr_publisher_transaction_construct_with_uri (object_type, _tmp0_, "http://api.tumblr.com/v2/user/info", PUBLISHING_REST_SUPPORT_HTTP_METHOD_POST);
#line 866 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return self;
#line 5563 "TumblrPublishing.c"
}


PublishingTumblrTumblrPublisherUserInfoFetchTransaction* publishing_tumblr_tumblr_publisher_user_info_fetch_transaction_new (PublishingTumblrTumblrPublisherSession* session) {
#line 866 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return publishing_tumblr_tumblr_publisher_user_info_fetch_transaction_construct (PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_USER_INFO_FETCH_TRANSACTION, session);
#line 5570 "TumblrPublishing.c"
}


static void publishing_tumblr_tumblr_publisher_user_info_fetch_transaction_class_init (PublishingTumblrTumblrPublisherUserInfoFetchTransactionClass * klass) {
#line 865 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_tumblr_tumblr_publisher_user_info_fetch_transaction_parent_class = g_type_class_peek_parent (klass);
#line 5577 "TumblrPublishing.c"
}


static void publishing_tumblr_tumblr_publisher_user_info_fetch_transaction_instance_init (PublishingTumblrTumblrPublisherUserInfoFetchTransaction * self) {
}


GType publishing_tumblr_tumblr_publisher_user_info_fetch_transaction_get_type (void) {
	static volatile gsize publishing_tumblr_tumblr_publisher_user_info_fetch_transaction_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_tumblr_tumblr_publisher_user_info_fetch_transaction_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingTumblrTumblrPublisherUserInfoFetchTransactionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_tumblr_tumblr_publisher_user_info_fetch_transaction_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingTumblrTumblrPublisherUserInfoFetchTransaction), 0, (GInstanceInitFunc) publishing_tumblr_tumblr_publisher_user_info_fetch_transaction_instance_init, NULL };
		GType publishing_tumblr_tumblr_publisher_user_info_fetch_transaction_type_id;
		publishing_tumblr_tumblr_publisher_user_info_fetch_transaction_type_id = g_type_register_static (PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_TRANSACTION, "PublishingTumblrTumblrPublisherUserInfoFetchTransaction", &g_define_type_info, 0);
		g_once_init_leave (&publishing_tumblr_tumblr_publisher_user_info_fetch_transaction_type_id__volatile, publishing_tumblr_tumblr_publisher_user_info_fetch_transaction_type_id);
	}
	return publishing_tumblr_tumblr_publisher_user_info_fetch_transaction_type_id__volatile;
}


static gchar* publishing_tumblr_tumblr_publisher_upload_transaction_encode (PublishingTumblrTumblrPublisherUploadTransaction* self, guint8* data, int data_length1) {
	gchar* result = NULL;
	GString* s = NULL;
	GString* _tmp0_ = NULL;
	gchar* bytes = NULL;
	gchar* _tmp1_ = NULL;
	gint bytes_length1 = 0;
	gint _bytes_size_ = 0;
	gchar* _tmp2_ = NULL;
	gint _tmp2__length1 = 0;
	gchar _tmp3_ = '\0';
	guint8* _tmp4_ = NULL;
	gint _tmp4__length1 = 0;
	GString* _tmp14_ = NULL;
	const gchar* _tmp15_ = NULL;
	gchar* _tmp16_ = NULL;
#line 879 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_val_if_fail (PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_IS_UPLOAD_TRANSACTION (self), NULL);
#line 880 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = g_string_new ("");
#line 880 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	s = _tmp0_;
#line 881 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp1_ = g_new0 (gchar, 2);
#line 881 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	bytes = _tmp1_;
#line 881 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	bytes_length1 = 2;
#line 881 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_bytes_size_ = bytes_length1;
#line 882 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp2_ = bytes;
#line 882 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp2__length1 = bytes_length1;
#line 882 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp2_[1] = (gchar) 0;
#line 882 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp3_ = _tmp2_[1];
#line 883 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp4_ = data;
#line 883 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp4__length1 = data_length1;
#line 5639 "TumblrPublishing.c"
	{
		guint8* byte_collection = NULL;
		gint byte_collection_length1 = 0;
		gint _byte_collection_size_ = 0;
		gint byte_it = 0;
#line 883 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		byte_collection = _tmp4_;
#line 883 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		byte_collection_length1 = _tmp4__length1;
#line 883 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		for (byte_it = 0; byte_it < _tmp4__length1; byte_it = byte_it + 1) {
#line 5651 "TumblrPublishing.c"
			guint8 byte = 0U;
#line 883 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			byte = byte_collection[byte_it];
#line 5655 "TumblrPublishing.c"
			{
				guint8 _tmp5_ = 0U;
#line 885 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp5_ = byte;
#line 885 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				if (((gint) _tmp5_) == 0) {
#line 5662 "TumblrPublishing.c"
					GString* _tmp6_ = NULL;
#line 886 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					_tmp6_ = s;
#line 886 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					g_string_append (_tmp6_, "%00");
#line 5668 "TumblrPublishing.c"
				} else {
					gchar* _tmp7_ = NULL;
					gint _tmp7__length1 = 0;
					guint8 _tmp8_ = 0U;
					gchar _tmp9_ = '\0';
					GString* _tmp10_ = NULL;
					gchar* _tmp11_ = NULL;
					gint _tmp11__length1 = 0;
					gchar* _tmp12_ = NULL;
					gchar* _tmp13_ = NULL;
#line 888 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					_tmp7_ = bytes;
#line 888 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					_tmp7__length1 = bytes_length1;
#line 888 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					_tmp8_ = byte;
#line 888 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					_tmp7_[0] = (gchar) _tmp8_;
#line 888 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					_tmp9_ = _tmp7_[0];
#line 889 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					_tmp10_ = s;
#line 889 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					_tmp11_ = bytes;
#line 889 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					_tmp11__length1 = bytes_length1;
#line 889 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					_tmp12_ = soup_uri_encode ((const gchar*) _tmp11_, PUBLISHING_TUMBLR_ENCODE_RFC_3986_EXTRA);
#line 889 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					_tmp13_ = _tmp12_;
#line 889 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					g_string_append (_tmp10_, _tmp13_);
#line 889 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					_g_free0 (_tmp13_);
#line 5703 "TumblrPublishing.c"
				}
			}
		}
	}
#line 892 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp14_ = s;
#line 892 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp15_ = _tmp14_->str;
#line 892 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp16_ = g_strdup (_tmp15_);
#line 892 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	result = _tmp16_;
#line 892 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	bytes = (g_free (bytes), NULL);
#line 892 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_string_free0 (s);
#line 892 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return result;
#line 5722 "TumblrPublishing.c"
}


static gpointer _publishing_rest_support_session_ref0 (gpointer self) {
#line 899 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return self ? publishing_rest_support_session_ref (self) : NULL;
#line 5729 "TumblrPublishing.c"
}


PublishingTumblrTumblrPublisherUploadTransaction* publishing_tumblr_tumblr_publisher_upload_transaction_construct (GType object_type, PublishingTumblrTumblrPublisherSession* session, SpitPublishingPublishable* publishable, const gchar* blog_url) {
	PublishingTumblrTumblrPublisherUploadTransaction* self = NULL;
	PublishingTumblrTumblrPublisherSession* _tmp0_ = NULL;
	SpitPublishingPublishable* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	PublishingTumblrTumblrPublisherSession* _tmp5_ = NULL;
	PublishingTumblrTumblrPublisherSession* _tmp6_ = NULL;
#line 896 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_val_if_fail (PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_IS_SESSION (session), NULL);
#line 896 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_val_if_fail (SPIT_PUBLISHING_IS_PUBLISHABLE (publishable), NULL);
#line 896 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_val_if_fail (blog_url != NULL, NULL);
#line 897 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_debug ("TumblrPublishing.vala:897: Init upload transaction");
#line 898 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = session;
#line 898 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp1_ = publishable;
#line 898 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp2_ = blog_url;
#line 898 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp3_ = g_strdup_printf ("http://api.tumblr.com/v2/blog/%s/post", _tmp2_);
#line 898 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp4_ = _tmp3_;
#line 898 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self = (PublishingTumblrTumblrPublisherUploadTransaction*) publishing_rest_support_upload_transaction_construct_with_endpoint_url (object_type, G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession), _tmp1_, _tmp4_);
#line 898 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_free0 (_tmp4_);
#line 899 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp5_ = session;
#line 899 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp6_ = _publishing_rest_support_session_ref0 (_tmp5_);
#line 899 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_publishing_rest_support_session_unref0 (self->priv->session);
#line 899 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->session = _tmp6_;
#line 896 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return self;
#line 5774 "TumblrPublishing.c"
}


PublishingTumblrTumblrPublisherUploadTransaction* publishing_tumblr_tumblr_publisher_upload_transaction_new (PublishingTumblrTumblrPublisherSession* session, SpitPublishingPublishable* publishable, const gchar* blog_url) {
#line 896 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return publishing_tumblr_tumblr_publisher_upload_transaction_construct (PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_UPLOAD_TRANSACTION, session, publishable, blog_url);
#line 5781 "TumblrPublishing.c"
}


static void _vala_array_add22 (PublishingRESTSupportArgument*** array, int* length, int* size, PublishingRESTSupportArgument* value) {
#line 906 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	if ((*length) == (*size)) {
#line 906 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 906 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		*array = g_renew (PublishingRESTSupportArgument*, *array, (*size) + 1);
#line 5792 "TumblrPublishing.c"
	}
#line 906 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	(*array)[(*length)++] = value;
#line 906 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	(*array)[*length] = NULL;
#line 5798 "TumblrPublishing.c"
}


void publishing_tumblr_tumblr_publisher_upload_transaction_add_authorization_header_field (PublishingTumblrTumblrPublisherUploadTransaction* self, const gchar* key, const gchar* value) {
	PublishingRESTSupportArgument** _tmp0_ = NULL;
	gint _tmp0__length1 = 0;
	const gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	PublishingRESTSupportArgument* _tmp3_ = NULL;
#line 905 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_if_fail (PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_IS_UPLOAD_TRANSACTION (self));
#line 905 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_if_fail (key != NULL);
#line 905 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_if_fail (value != NULL);
#line 906 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = self->priv->auth_header_fields;
#line 906 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0__length1 = self->priv->auth_header_fields_length1;
#line 906 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp1_ = key;
#line 906 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp2_ = value;
#line 906 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp3_ = publishing_rest_support_argument_new (_tmp1_, _tmp2_);
#line 906 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_vala_array_add22 (&self->priv->auth_header_fields, &self->priv->auth_header_fields_length1, &self->priv->_auth_header_fields_size_, _tmp3_);
#line 5826 "TumblrPublishing.c"
}


static gpointer _publishing_rest_support_argument_ref0 (gpointer self) {
#line 910 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return self ? publishing_rest_support_argument_ref (self) : NULL;
#line 5833 "TumblrPublishing.c"
}


static PublishingRESTSupportArgument** _vala_array_dup9 (PublishingRESTSupportArgument** self, int length) {
	PublishingRESTSupportArgument** result;
	int i;
#line 910 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	result = g_new0 (PublishingRESTSupportArgument*, length + 1);
#line 910 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	for (i = 0; i < length; i++) {
#line 5844 "TumblrPublishing.c"
		PublishingRESTSupportArgument* _tmp0_ = NULL;
#line 910 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp0_ = _publishing_rest_support_argument_ref0 (self[i]);
#line 910 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		result[i] = _tmp0_;
#line 5850 "TumblrPublishing.c"
	}
#line 910 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return result;
#line 5854 "TumblrPublishing.c"
}


PublishingRESTSupportArgument** publishing_tumblr_tumblr_publisher_upload_transaction_get_authorization_header_fields (PublishingTumblrTumblrPublisherUploadTransaction* self, int* result_length1) {
	PublishingRESTSupportArgument** result = NULL;
	PublishingRESTSupportArgument** _tmp0_ = NULL;
	gint _tmp0__length1 = 0;
	PublishingRESTSupportArgument** _tmp1_ = NULL;
	gint _tmp1__length1 = 0;
	PublishingRESTSupportArgument** _tmp2_ = NULL;
	gint _tmp2__length1 = 0;
#line 909 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_val_if_fail (PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_IS_UPLOAD_TRANSACTION (self), NULL);
#line 910 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = self->priv->auth_header_fields;
#line 910 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0__length1 = self->priv->auth_header_fields_length1;
#line 910 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp1_ = (_tmp0_ != NULL) ? _vala_array_dup9 (_tmp0_, _tmp0__length1) : ((gpointer) _tmp0_);
#line 910 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp1__length1 = _tmp0__length1;
#line 910 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp2_ = _tmp1_;
#line 910 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp2__length1 = _tmp1__length1;
#line 910 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	if (result_length1) {
#line 910 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		*result_length1 = _tmp2__length1;
#line 5884 "TumblrPublishing.c"
	}
#line 910 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	result = _tmp2_;
#line 910 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return result;
#line 5890 "TumblrPublishing.c"
}


gchar* publishing_tumblr_tumblr_publisher_upload_transaction_get_authorization_header_string (PublishingTumblrTumblrPublisherUploadTransaction* self) {
	gchar* result = NULL;
	gchar* _result_ = NULL;
	gchar* _tmp0_ = NULL;
#line 913 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_val_if_fail (PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_IS_UPLOAD_TRANSACTION (self), NULL);
#line 914 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = g_strdup ("OAuth ");
#line 914 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_result_ = _tmp0_;
#line 5904 "TumblrPublishing.c"
	{
		gint i = 0;
#line 916 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		i = 0;
#line 5909 "TumblrPublishing.c"
		{
			gboolean _tmp1_ = FALSE;
#line 916 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			_tmp1_ = TRUE;
#line 916 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			while (TRUE) {
#line 5916 "TumblrPublishing.c"
				gint _tmp3_ = 0;
				PublishingRESTSupportArgument** _tmp4_ = NULL;
				gint _tmp4__length1 = 0;
				const gchar* _tmp5_ = NULL;
				PublishingRESTSupportArgument** _tmp6_ = NULL;
				gint _tmp6__length1 = 0;
				gint _tmp7_ = 0;
				PublishingRESTSupportArgument* _tmp8_ = NULL;
				const gchar* _tmp9_ = NULL;
				gchar* _tmp10_ = NULL;
				const gchar* _tmp11_ = NULL;
				gchar* _tmp12_ = NULL;
				const gchar* _tmp13_ = NULL;
				PublishingRESTSupportArgument** _tmp14_ = NULL;
				gint _tmp14__length1 = 0;
				gint _tmp15_ = 0;
				PublishingRESTSupportArgument* _tmp16_ = NULL;
				const gchar* _tmp17_ = NULL;
				gchar* _tmp18_ = NULL;
				gchar* _tmp19_ = NULL;
				gchar* _tmp20_ = NULL;
				gchar* _tmp21_ = NULL;
				gchar* _tmp22_ = NULL;
				gint _tmp23_ = 0;
				PublishingRESTSupportArgument** _tmp24_ = NULL;
				gint _tmp24__length1 = 0;
#line 916 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				if (!_tmp1_) {
#line 5945 "TumblrPublishing.c"
					gint _tmp2_ = 0;
#line 916 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					_tmp2_ = i;
#line 916 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					i = _tmp2_ + 1;
#line 5951 "TumblrPublishing.c"
				}
#line 916 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp1_ = FALSE;
#line 916 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp3_ = i;
#line 916 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp4_ = self->priv->auth_header_fields;
#line 916 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp4__length1 = self->priv->auth_header_fields_length1;
#line 916 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				if (!(_tmp3_ < _tmp4__length1)) {
#line 916 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					break;
#line 5965 "TumblrPublishing.c"
				}
#line 917 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp5_ = _result_;
#line 917 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp6_ = self->priv->auth_header_fields;
#line 917 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp6__length1 = self->priv->auth_header_fields_length1;
#line 917 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp7_ = i;
#line 917 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp8_ = _tmp6_[_tmp7_];
#line 917 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp9_ = _tmp8_->key;
#line 917 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp10_ = g_strconcat (_tmp5_, _tmp9_, NULL);
#line 917 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_g_free0 (_result_);
#line 917 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_result_ = _tmp10_;
#line 918 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp11_ = _result_;
#line 918 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp12_ = g_strconcat (_tmp11_, "=", NULL);
#line 918 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_g_free0 (_result_);
#line 918 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_result_ = _tmp12_;
#line 919 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp13_ = _result_;
#line 919 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp14_ = self->priv->auth_header_fields;
#line 919 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp14__length1 = self->priv->auth_header_fields_length1;
#line 919 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp15_ = i;
#line 919 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp16_ = _tmp14_[_tmp15_];
#line 919 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp17_ = _tmp16_->value;
#line 919 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp18_ = g_strconcat ("\"", _tmp17_, NULL);
#line 919 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp19_ = _tmp18_;
#line 919 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp20_ = g_strconcat (_tmp19_, "\"", NULL);
#line 919 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp21_ = _tmp20_;
#line 919 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp22_ = g_strconcat (_tmp13_, _tmp21_, NULL);
#line 919 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_g_free0 (_result_);
#line 919 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_result_ = _tmp22_;
#line 919 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_g_free0 (_tmp21_);
#line 919 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_g_free0 (_tmp19_);
#line 921 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp23_ = i;
#line 921 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp24_ = self->priv->auth_header_fields;
#line 921 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp24__length1 = self->priv->auth_header_fields_length1;
#line 921 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				if (_tmp23_ < (_tmp24__length1 - 1)) {
#line 6031 "TumblrPublishing.c"
					const gchar* _tmp25_ = NULL;
					gchar* _tmp26_ = NULL;
#line 922 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					_tmp25_ = _result_;
#line 922 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					_tmp26_ = g_strconcat (_tmp25_, ", ", NULL);
#line 922 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					_g_free0 (_result_);
#line 922 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					_result_ = _tmp26_;
#line 6042 "TumblrPublishing.c"
				}
			}
		}
	}
#line 925 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	result = _result_;
#line 925 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return result;
#line 6051 "TumblrPublishing.c"
}


static guint8* string_get_data (const gchar* self, int* result_length1) {
	guint8* result;
	guint8* res = NULL;
	gint res_length1 = 0;
	gint _res_size_ = 0;
	gint _tmp0_ = 0;
	gint _tmp1_ = 0;
	gint _tmp2_ = 0;
	guint8* _tmp3_ = NULL;
	gint _tmp3__length1 = 0;
	guint8* _tmp4_ = NULL;
	gint _tmp4__length1 = 0;
#line 1398 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1399 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	res = (guint8*) self;
#line 1399 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	res_length1 = -1;
#line 1399 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_res_size_ = res_length1;
#line 1400 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp0_ = strlen (self);
#line 1400 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp1_ = _tmp0_;
#line 1400 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	res_length1 = (gint) _tmp1_;
#line 1400 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp2_ = res_length1;
#line 1401 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp3_ = res;
#line 1401 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp3__length1 = res_length1;
#line 1401 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp4_ = _tmp3_;
#line 1401 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp4__length1 = _tmp3__length1;
#line 1401 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	if (result_length1) {
#line 1401 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		*result_length1 = _tmp4__length1;
#line 6095 "TumblrPublishing.c"
	}
#line 1401 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	result = _tmp4_;
#line 1401 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	return result;
#line 6101 "TumblrPublishing.c"
}


static gchar* _vala_g_strjoinv (const gchar* separator, gchar** str_array, int str_array_length1) {
	gchar* result = NULL;
	const gchar* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_ = FALSE;
	gchar** _tmp3_ = NULL;
	gint _tmp3__length1 = 0;
#line 1054 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp0_ = separator;
#line 1054 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	if (_tmp0_ == NULL) {
#line 1055 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		separator = "";
#line 6118 "TumblrPublishing.c"
	}
#line 1057 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp3_ = str_array;
#line 1057 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp3__length1 = str_array_length1;
#line 1057 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	if (_tmp3_ != NULL) {
#line 1057 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp2_ = TRUE;
#line 6128 "TumblrPublishing.c"
	} else {
		gchar** _tmp4_ = NULL;
		gint _tmp4__length1 = 0;
#line 1057 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp4_ = str_array;
#line 1057 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp4__length1 = str_array_length1;
#line 1057 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp2_ = _tmp4__length1 > 0;
#line 6138 "TumblrPublishing.c"
	}
#line 1057 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	if (_tmp2_) {
#line 1057 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp1_ = TRUE;
#line 6144 "TumblrPublishing.c"
	} else {
		gboolean _tmp5_ = FALSE;
		gchar** _tmp6_ = NULL;
		gint _tmp6__length1 = 0;
#line 1057 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp6_ = str_array;
#line 1057 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp6__length1 = str_array_length1;
#line 1057 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		if (_tmp6__length1 == -1) {
#line 6155 "TumblrPublishing.c"
			gchar** _tmp7_ = NULL;
			gint _tmp7__length1 = 0;
			const gchar* _tmp8_ = NULL;
#line 1057 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
			_tmp7_ = str_array;
#line 1057 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
			_tmp7__length1 = str_array_length1;
#line 1057 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
			_tmp8_ = _tmp7_[0];
#line 1057 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
			_tmp5_ = _tmp8_ != NULL;
#line 6167 "TumblrPublishing.c"
		} else {
#line 1057 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
			_tmp5_ = FALSE;
#line 6171 "TumblrPublishing.c"
		}
#line 1057 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp1_ = _tmp5_;
#line 6175 "TumblrPublishing.c"
	}
#line 1057 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	if (_tmp1_) {
#line 6179 "TumblrPublishing.c"
		gint i = 0;
		gsize len = 0UL;
		gint _tmp31_ = 0;
		gint _tmp33_ = 0;
		gint _tmp34_ = 0;
		gsize _tmp35_ = 0UL;
		const gchar* _tmp36_ = NULL;
		gint _tmp37_ = 0;
		gint _tmp38_ = 0;
		gint _tmp39_ = 0;
		const gchar* res = NULL;
		gsize _tmp40_ = 0UL;
		void* _tmp41_ = NULL;
		void* ptr = NULL;
		const gchar* _tmp42_ = NULL;
		gchar** _tmp43_ = NULL;
		gint _tmp43__length1 = 0;
		const gchar* _tmp44_ = NULL;
		void* _tmp45_ = NULL;
		const gchar* _tmp62_ = NULL;
#line 1059 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		len = (gsize) 1;
#line 6202 "TumblrPublishing.c"
		{
			gboolean _tmp9_ = FALSE;
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
			i = 0;
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
			_tmp9_ = TRUE;
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
			while (TRUE) {
#line 6211 "TumblrPublishing.c"
				gboolean _tmp11_ = FALSE;
				gboolean _tmp12_ = FALSE;
				gchar** _tmp13_ = NULL;
				gint _tmp13__length1 = 0;
				gint _tmp21_ = 0;
				gchar** _tmp22_ = NULL;
				gint _tmp22__length1 = 0;
				gint _tmp23_ = 0;
				const gchar* _tmp24_ = NULL;
				gsize _tmp30_ = 0UL;
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				if (!_tmp9_) {
#line 6224 "TumblrPublishing.c"
					gint _tmp10_ = 0;
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp10_ = i;
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					i = _tmp10_ + 1;
#line 6230 "TumblrPublishing.c"
				}
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp9_ = FALSE;
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp13_ = str_array;
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp13__length1 = str_array_length1;
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				if (_tmp13__length1 != -1) {
#line 6240 "TumblrPublishing.c"
					gint _tmp14_ = 0;
					gchar** _tmp15_ = NULL;
					gint _tmp15__length1 = 0;
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp14_ = i;
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp15_ = str_array;
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp15__length1 = str_array_length1;
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp12_ = _tmp14_ < _tmp15__length1;
#line 6252 "TumblrPublishing.c"
				} else {
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp12_ = FALSE;
#line 6256 "TumblrPublishing.c"
				}
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				if (_tmp12_) {
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp11_ = TRUE;
#line 6262 "TumblrPublishing.c"
				} else {
					gboolean _tmp16_ = FALSE;
					gchar** _tmp17_ = NULL;
					gint _tmp17__length1 = 0;
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp17_ = str_array;
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp17__length1 = str_array_length1;
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					if (_tmp17__length1 == -1) {
#line 6273 "TumblrPublishing.c"
						gchar** _tmp18_ = NULL;
						gint _tmp18__length1 = 0;
						gint _tmp19_ = 0;
						const gchar* _tmp20_ = NULL;
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
						_tmp18_ = str_array;
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
						_tmp18__length1 = str_array_length1;
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
						_tmp19_ = i;
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
						_tmp20_ = _tmp18_[_tmp19_];
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
						_tmp16_ = _tmp20_ != NULL;
#line 6288 "TumblrPublishing.c"
					} else {
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
						_tmp16_ = FALSE;
#line 6292 "TumblrPublishing.c"
					}
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp11_ = _tmp16_;
#line 6296 "TumblrPublishing.c"
				}
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				if (!_tmp11_) {
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					break;
#line 6302 "TumblrPublishing.c"
				}
#line 1061 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp22_ = str_array;
#line 1061 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp22__length1 = str_array_length1;
#line 1061 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp23_ = i;
#line 1061 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp24_ = _tmp22_[_tmp23_];
#line 1061 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				if (_tmp24_ != NULL) {
#line 6314 "TumblrPublishing.c"
					gchar** _tmp25_ = NULL;
					gint _tmp25__length1 = 0;
					gint _tmp26_ = 0;
					const gchar* _tmp27_ = NULL;
					gint _tmp28_ = 0;
					gint _tmp29_ = 0;
#line 1061 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp25_ = str_array;
#line 1061 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp25__length1 = str_array_length1;
#line 1061 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp26_ = i;
#line 1061 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp27_ = _tmp25_[_tmp26_];
#line 1061 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp28_ = strlen ((const gchar*) _tmp27_);
#line 1061 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp29_ = _tmp28_;
#line 1061 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp21_ = _tmp29_;
#line 6335 "TumblrPublishing.c"
				} else {
#line 1061 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp21_ = 0;
#line 6339 "TumblrPublishing.c"
				}
#line 1061 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp30_ = len;
#line 1061 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				len = _tmp30_ + _tmp21_;
#line 6345 "TumblrPublishing.c"
			}
		}
#line 1063 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp31_ = i;
#line 1063 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		if (_tmp31_ == 0) {
#line 6352 "TumblrPublishing.c"
			gchar* _tmp32_ = NULL;
#line 1064 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
			_tmp32_ = g_strdup ("");
#line 1064 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
			result = _tmp32_;
#line 1064 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
			return result;
#line 6360 "TumblrPublishing.c"
		}
#line 1066 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp33_ = i;
#line 1066 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		str_array_length1 = _tmp33_;
#line 1066 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp34_ = str_array_length1;
#line 1067 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp35_ = len;
#line 1067 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp36_ = separator;
#line 1067 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp37_ = strlen ((const gchar*) _tmp36_);
#line 1067 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp38_ = _tmp37_;
#line 1067 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp39_ = i;
#line 1067 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		len = _tmp35_ + (_tmp38_ * (_tmp39_ - 1));
#line 1069 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp40_ = len;
#line 1069 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp41_ = g_malloc (_tmp40_);
#line 1069 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		res = _tmp41_;
#line 1070 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp42_ = res;
#line 1070 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp43_ = str_array;
#line 1070 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp43__length1 = str_array_length1;
#line 1070 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp44_ = _tmp43_[0];
#line 1070 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp45_ = g_stpcpy ((void*) _tmp42_, (const gchar*) _tmp44_);
#line 1070 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		ptr = _tmp45_;
#line 6398 "TumblrPublishing.c"
		{
			gboolean _tmp46_ = FALSE;
#line 1071 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
			i = 1;
#line 1071 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
			_tmp46_ = TRUE;
#line 1071 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
			while (TRUE) {
#line 6407 "TumblrPublishing.c"
				gint _tmp48_ = 0;
				gchar** _tmp49_ = NULL;
				gint _tmp49__length1 = 0;
				void* _tmp50_ = NULL;
				const gchar* _tmp51_ = NULL;
				void* _tmp52_ = NULL;
				const gchar* _tmp53_ = NULL;
				gchar** _tmp54_ = NULL;
				gint _tmp54__length1 = 0;
				gint _tmp55_ = 0;
				const gchar* _tmp56_ = NULL;
				void* _tmp60_ = NULL;
				void* _tmp61_ = NULL;
#line 1071 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				if (!_tmp46_) {
#line 6423 "TumblrPublishing.c"
					gint _tmp47_ = 0;
#line 1071 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp47_ = i;
#line 1071 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					i = _tmp47_ + 1;
#line 6429 "TumblrPublishing.c"
				}
#line 1071 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp46_ = FALSE;
#line 1071 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp48_ = i;
#line 1071 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp49_ = str_array;
#line 1071 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp49__length1 = str_array_length1;
#line 1071 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				if (!(_tmp48_ < _tmp49__length1)) {
#line 1071 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					break;
#line 6443 "TumblrPublishing.c"
				}
#line 1072 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp50_ = ptr;
#line 1072 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp51_ = separator;
#line 1072 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp52_ = g_stpcpy (_tmp50_, (const gchar*) _tmp51_);
#line 1072 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				ptr = _tmp52_;
#line 1073 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp54_ = str_array;
#line 1073 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp54__length1 = str_array_length1;
#line 1073 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp55_ = i;
#line 1073 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp56_ = _tmp54_[_tmp55_];
#line 1073 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				if (_tmp56_ != NULL) {
#line 6463 "TumblrPublishing.c"
					gchar** _tmp57_ = NULL;
					gint _tmp57__length1 = 0;
					gint _tmp58_ = 0;
					const gchar* _tmp59_ = NULL;
#line 1073 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp57_ = str_array;
#line 1073 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp57__length1 = str_array_length1;
#line 1073 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp58_ = i;
#line 1073 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp59_ = _tmp57_[_tmp58_];
#line 1073 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp53_ = (const gchar*) _tmp59_;
#line 6478 "TumblrPublishing.c"
				} else {
#line 1073 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp53_ = "";
#line 6482 "TumblrPublishing.c"
				}
#line 1073 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp60_ = ptr;
#line 1073 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp61_ = g_stpcpy (_tmp60_, _tmp53_);
#line 1073 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				ptr = _tmp61_;
#line 6490 "TumblrPublishing.c"
			}
		}
#line 1076 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp62_ = res;
#line 1076 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		res = NULL;
#line 1076 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		result = (gchar*) _tmp62_;
#line 1076 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		return result;
#line 6501 "TumblrPublishing.c"
	} else {
		gchar* _tmp63_ = NULL;
#line 1078 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp63_ = g_strdup ("");
#line 1078 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		result = _tmp63_;
#line 1078 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		return result;
#line 6510 "TumblrPublishing.c"
	}
}


static void publishing_tumblr_tumblr_publisher_upload_transaction_real_execute (PublishingRESTSupportTransaction* base, GError** error) {
	PublishingTumblrTumblrPublisherUploadTransaction * self;
	PublishingTumblrTumblrPublisherSession* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	PublishingTumblrTumblrPublisherSession* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	PublishingTumblrTumblrPublisherSession* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
	gchar* _tmp8_ = NULL;
	gchar* payload = NULL;
	gsize payload_length = 0UL;
	PublishingTumblrTumblrPublisherSession* _tmp34_ = NULL;
	gchar* authorization_header = NULL;
	gchar* _tmp35_ = NULL;
	const gchar* _tmp36_ = NULL;
	const gchar* _tmp37_ = NULL;
	PublishingRESTSupportArgument** request_arguments = NULL;
	gint _tmp38_ = 0;
	PublishingRESTSupportArgument** _tmp39_ = NULL;
	gint request_arguments_length1 = 0;
	gint _request_arguments_size_ = 0;
	PublishingRESTSupportArgument** _tmp40_ = NULL;
	gint _tmp40__length1 = 0;
	gchar* request_data = NULL;
	gchar* _tmp41_ = NULL;
	SoupMessage* outbound_message = NULL;
	gchar* _tmp64_ = NULL;
	gchar* _tmp65_ = NULL;
	SoupMessage* _tmp66_ = NULL;
	SoupMessage* _tmp67_ = NULL;
	SoupMessage* _tmp68_ = NULL;
	const gchar* _tmp69_ = NULL;
	guint8* _tmp70_ = NULL;
	gint _tmp70__length1 = 0;
	guint8* _tmp71_ = NULL;
	gint _tmp71__length1 = 0;
	GeeMapIterator* i = NULL;
	GeeHashMap* _tmp72_ = NULL;
	GeeMapIterator* _tmp73_ = NULL;
	gboolean cont = FALSE;
	GeeMapIterator* _tmp74_ = NULL;
	gboolean _tmp75_ = FALSE;
	SoupMessage* _tmp87_ = NULL;
	GError * _inner_error_ = NULL;
#line 928 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_UPLOAD_TRANSACTION, PublishingTumblrTumblrPublisherUploadTransaction);
#line 929 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = self->priv->session;
#line 929 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp1_ = publishing_tumblr_tumblr_publisher_session_get_oauth_nonce (_tmp0_);
#line 929 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp2_ = _tmp1_;
#line 929 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_tumblr_tumblr_publisher_upload_transaction_add_authorization_header_field (self, "oauth_nonce", _tmp2_);
#line 929 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_free0 (_tmp2_);
#line 930 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_tumblr_tumblr_publisher_upload_transaction_add_authorization_header_field (self, "oauth_signature_method", "HMAC-SHA1");
#line 931 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_tumblr_tumblr_publisher_upload_transaction_add_authorization_header_field (self, "oauth_version", "1.0");
#line 932 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp3_ = self->priv->session;
#line 932 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp4_ = publishing_tumblr_tumblr_publisher_session_get_oauth_timestamp (_tmp3_);
#line 932 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp5_ = _tmp4_;
#line 932 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_tumblr_tumblr_publisher_upload_transaction_add_authorization_header_field (self, "oauth_timestamp", _tmp5_);
#line 932 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_free0 (_tmp5_);
#line 933 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_tumblr_tumblr_publisher_upload_transaction_add_authorization_header_field (self, "oauth_consumer_key", PUBLISHING_TUMBLR_API_KEY);
#line 934 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp6_ = self->priv->session;
#line 934 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp7_ = publishing_tumblr_tumblr_publisher_session_get_access_phase_token (_tmp6_);
#line 934 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp8_ = _tmp7_;
#line 934 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_tumblr_tumblr_publisher_upload_transaction_add_authorization_header_field (self, "oauth_token", _tmp8_);
#line 934 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_free0 (_tmp8_);
#line 6599 "TumblrPublishing.c"
	{
		SpitPublishingPublishable* _tmp9_ = NULL;
		GFile* _tmp10_ = NULL;
		GFile* _tmp11_ = NULL;
		gchar* _tmp12_ = NULL;
		gchar* _tmp13_ = NULL;
		gchar* _tmp14_ = NULL;
		gsize _tmp15_ = 0UL;
		gchar* reqdata = NULL;
		const gchar* _tmp16_ = NULL;
		guint8* _tmp17_ = NULL;
		gint _tmp17__length1 = 0;
		guint8* _tmp18_ = NULL;
		gint _tmp18__length1 = 0;
		gsize _tmp19_ = 0UL;
		gchar* _tmp20_ = NULL;
		const gchar* _tmp21_ = NULL;
		gchar** keywords = NULL;
		SpitPublishingPublishable* _tmp22_ = NULL;
		gint _tmp23_ = 0;
		gchar** _tmp24_ = NULL;
		gint keywords_length1 = 0;
		gint _keywords_size_ = 0;
		gchar* tags = NULL;
		gchar* _tmp25_ = NULL;
		gchar** _tmp26_ = NULL;
		gint _tmp26__length1 = 0;
		const gchar* _tmp29_ = NULL;
		gchar* _tmp30_ = NULL;
		gchar* _tmp31_ = NULL;
#line 940 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp9_ = G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_UPLOAD_TRANSACTION, PublishingRESTSupportUploadTransaction)->publishable;
#line 940 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp10_ = spit_publishing_publishable_get_serialized_file (_tmp9_);
#line 940 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp11_ = _tmp10_;
#line 940 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp12_ = g_file_get_path (_tmp11_);
#line 940 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp13_ = _tmp12_;
#line 940 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		g_file_get_contents (_tmp13_, &_tmp14_, &_tmp15_, &_inner_error_);
#line 940 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_g_free0 (payload);
#line 940 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		payload = _tmp14_;
#line 940 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		payload_length = _tmp15_;
#line 940 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_g_free0 (_tmp13_);
#line 940 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_g_object_unref0 (_tmp11_);
#line 940 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 940 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			if (_inner_error_->domain == G_FILE_ERROR) {
#line 6656 "TumblrPublishing.c"
				goto __catch38_g_file_error;
			}
#line 940 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			_g_free0 (payload);
#line 940 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 940 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			g_clear_error (&_inner_error_);
#line 940 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			return;
#line 6667 "TumblrPublishing.c"
		}
#line 943 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp16_ = payload;
#line 943 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp17_ = string_get_data (_tmp16_, &_tmp17__length1);
#line 943 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp18_ = _tmp17_;
#line 943 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp18__length1 = _tmp17__length1;
#line 943 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp19_ = payload_length;
#line 943 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp20_ = publishing_tumblr_tumblr_publisher_upload_transaction_encode (self, _tmp18_ + 0, ((gint) _tmp19_) - 0);
#line 943 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		reqdata = _tmp20_;
#line 947 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp21_ = reqdata;
#line 947 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "data[0]", _tmp21_);
#line 948 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "type", "photo");
#line 949 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp22_ = G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_UPLOAD_TRANSACTION, PublishingRESTSupportUploadTransaction)->publishable;
#line 949 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp24_ = spit_publishing_publishable_get_publishing_keywords (_tmp22_, &_tmp23_);
#line 949 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		keywords = _tmp24_;
#line 949 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		keywords_length1 = _tmp23_;
#line 949 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_keywords_size_ = keywords_length1;
#line 950 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp25_ = g_strdup ("");
#line 950 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		tags = _tmp25_;
#line 951 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp26_ = keywords;
#line 951 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp26__length1 = keywords_length1;
#line 951 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		if (_tmp26_ != NULL) {
#line 6709 "TumblrPublishing.c"
			gchar** _tmp27_ = NULL;
			gint _tmp27__length1 = 0;
			gchar* _tmp28_ = NULL;
#line 952 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			_tmp27_ = keywords;
#line 952 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			_tmp27__length1 = keywords_length1;
#line 952 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			_tmp28_ = _vala_g_strjoinv (",", _tmp27_, _tmp27__length1);
#line 952 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			_g_free0 (tags);
#line 952 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			tags = _tmp28_;
#line 6723 "TumblrPublishing.c"
		}
#line 954 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp29_ = tags;
#line 954 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp30_ = soup_uri_encode (_tmp29_, PUBLISHING_TUMBLR_ENCODE_RFC_3986_EXTRA);
#line 954 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp31_ = _tmp30_;
#line 954 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "tags", _tmp31_);
#line 954 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_g_free0 (_tmp31_);
#line 939 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_g_free0 (tags);
#line 939 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		keywords = (_vala_array_free (keywords, keywords_length1, (GDestroyNotify) g_free), NULL);
#line 939 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_g_free0 (reqdata);
#line 6741 "TumblrPublishing.c"
	}
	goto __finally38;
	__catch38_g_file_error:
	{
		GError* e = NULL;
		const gchar* _tmp32_ = NULL;
		GError* _tmp33_ = NULL;
#line 939 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		e = _inner_error_;
#line 939 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_inner_error_ = NULL;
#line 957 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp32_ = _ ("A temporary file needed for publishing is unavailable");
#line 957 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp33_ = g_error_new_literal (SPIT_PUBLISHING_PUBLISHING_ERROR, SPIT_PUBLISHING_PUBLISHING_ERROR_LOCAL_FILE_ERROR, _tmp32_);
#line 957 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_inner_error_ = _tmp33_;
#line 957 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_g_error_free0 (e);
#line 6761 "TumblrPublishing.c"
		goto __finally38;
	}
	__finally38:
#line 939 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 939 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 939 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			g_propagate_error (error, _inner_error_);
#line 939 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			_g_free0 (payload);
#line 939 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			return;
#line 6775 "TumblrPublishing.c"
		} else {
#line 939 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			_g_free0 (payload);
#line 939 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 939 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			g_clear_error (&_inner_error_);
#line 939 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			return;
#line 6785 "TumblrPublishing.c"
		}
	}
#line 963 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp34_ = self->priv->session;
#line 963 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_tumblr_tumblr_publisher_session_sign_transaction (_tmp34_, G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction));
#line 965 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp35_ = publishing_tumblr_tumblr_publisher_upload_transaction_get_authorization_header_string (self);
#line 965 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	authorization_header = _tmp35_;
#line 967 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp36_ = authorization_header;
#line 967 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_debug ("TumblrPublishing.vala:967: executing upload transaction: authorization" \
" header string = '%s'", _tmp36_);
#line 969 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp37_ = authorization_header;
#line 969 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_rest_support_transaction_add_header (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "Authorization", _tmp37_);
#line 971 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp39_ = publishing_rest_support_transaction_get_arguments (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), &_tmp38_);
#line 971 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	request_arguments = _tmp39_;
#line 971 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	request_arguments_length1 = _tmp38_;
#line 971 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_request_arguments_size_ = request_arguments_length1;
#line 972 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp40_ = request_arguments;
#line 972 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp40__length1 = request_arguments_length1;
#line 972 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_vala_assert (_tmp40__length1 > 0, "request_arguments.length > 0");
#line 974 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp41_ = g_strdup ("");
#line 974 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	request_data = _tmp41_;
#line 6822 "TumblrPublishing.c"
	{
		gint i = 0;
#line 975 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		i = 0;
#line 6827 "TumblrPublishing.c"
		{
			gboolean _tmp42_ = FALSE;
#line 975 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			_tmp42_ = TRUE;
#line 975 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			while (TRUE) {
#line 6834 "TumblrPublishing.c"
				gint _tmp44_ = 0;
				PublishingRESTSupportArgument** _tmp45_ = NULL;
				gint _tmp45__length1 = 0;
				const gchar* _tmp46_ = NULL;
				PublishingRESTSupportArgument** _tmp47_ = NULL;
				gint _tmp47__length1 = 0;
				gint _tmp48_ = 0;
				PublishingRESTSupportArgument* _tmp49_ = NULL;
				const gchar* _tmp50_ = NULL;
				gchar* _tmp51_ = NULL;
				gchar* _tmp52_ = NULL;
				PublishingRESTSupportArgument** _tmp53_ = NULL;
				gint _tmp53__length1 = 0;
				gint _tmp54_ = 0;
				PublishingRESTSupportArgument* _tmp55_ = NULL;
				const gchar* _tmp56_ = NULL;
				gchar* _tmp57_ = NULL;
				gchar* _tmp58_ = NULL;
				gchar* _tmp59_ = NULL;
				gint _tmp60_ = 0;
				PublishingRESTSupportArgument** _tmp61_ = NULL;
				gint _tmp61__length1 = 0;
#line 975 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				if (!_tmp42_) {
#line 6859 "TumblrPublishing.c"
					gint _tmp43_ = 0;
#line 975 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					_tmp43_ = i;
#line 975 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					i = _tmp43_ + 1;
#line 6865 "TumblrPublishing.c"
				}
#line 975 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp42_ = FALSE;
#line 975 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp44_ = i;
#line 975 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp45_ = request_arguments;
#line 975 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp45__length1 = request_arguments_length1;
#line 975 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				if (!(_tmp44_ < _tmp45__length1)) {
#line 975 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					break;
#line 6879 "TumblrPublishing.c"
				}
#line 976 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp46_ = request_data;
#line 976 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp47_ = request_arguments;
#line 976 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp47__length1 = request_arguments_length1;
#line 976 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp48_ = i;
#line 976 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp49_ = _tmp47_[_tmp48_];
#line 976 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp50_ = _tmp49_->key;
#line 976 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp51_ = g_strconcat (_tmp50_, "=", NULL);
#line 976 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp52_ = _tmp51_;
#line 976 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp53_ = request_arguments;
#line 976 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp53__length1 = request_arguments_length1;
#line 976 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp54_ = i;
#line 976 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp55_ = _tmp53_[_tmp54_];
#line 976 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp56_ = _tmp55_->value;
#line 976 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp57_ = g_strconcat (_tmp52_, _tmp56_, NULL);
#line 976 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp58_ = _tmp57_;
#line 976 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp59_ = g_strconcat (_tmp46_, _tmp58_, NULL);
#line 976 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_g_free0 (request_data);
#line 976 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				request_data = _tmp59_;
#line 976 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_g_free0 (_tmp58_);
#line 976 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_g_free0 (_tmp52_);
#line 977 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp60_ = i;
#line 977 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp61_ = request_arguments;
#line 977 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp61__length1 = request_arguments_length1;
#line 977 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				if (_tmp60_ < (_tmp61__length1 - 1)) {
#line 6929 "TumblrPublishing.c"
					const gchar* _tmp62_ = NULL;
					gchar* _tmp63_ = NULL;
#line 978 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					_tmp62_ = request_data;
#line 978 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					_tmp63_ = g_strconcat (_tmp62_, "&", NULL);
#line 978 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					_g_free0 (request_data);
#line 978 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					request_data = _tmp63_;
#line 6940 "TumblrPublishing.c"
				}
			}
		}
	}
#line 980 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp64_ = publishing_rest_support_transaction_get_endpoint_url (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction));
#line 980 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp65_ = _tmp64_;
#line 980 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp66_ = soup_message_new ("POST", _tmp65_);
#line 980 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp67_ = _tmp66_;
#line 980 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_free0 (_tmp65_);
#line 980 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	outbound_message = _tmp67_;
#line 981 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp68_ = outbound_message;
#line 981 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp69_ = request_data;
#line 981 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp70_ = string_get_data (_tmp69_, &_tmp70__length1);
#line 981 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp71_ = _tmp70_;
#line 981 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp71__length1 = _tmp70__length1;
#line 981 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	soup_message_set_request (_tmp68_, "application/x-www-form-urlencoded", SOUP_MEMORY_COPY, _tmp71_, (gsize) _tmp71__length1);
#line 984 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp72_ = G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_UPLOAD_TRANSACTION, PublishingRESTSupportUploadTransaction)->message_headers;
#line 984 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp73_ = gee_abstract_map_map_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp72_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap));
#line 984 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	i = _tmp73_;
#line 985 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp74_ = i;
#line 985 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp75_ = gee_map_iterator_next (_tmp74_);
#line 985 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	cont = _tmp75_;
#line 986 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	while (TRUE) {
#line 6983 "TumblrPublishing.c"
		gboolean _tmp76_ = FALSE;
		SoupMessage* _tmp77_ = NULL;
		SoupMessageHeaders* _tmp78_ = NULL;
		GeeMapIterator* _tmp79_ = NULL;
		gpointer _tmp80_ = NULL;
		gchar* _tmp81_ = NULL;
		GeeMapIterator* _tmp82_ = NULL;
		gpointer _tmp83_ = NULL;
		gchar* _tmp84_ = NULL;
		GeeMapIterator* _tmp85_ = NULL;
		gboolean _tmp86_ = FALSE;
#line 986 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp76_ = cont;
#line 986 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		if (!_tmp76_) {
#line 986 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			break;
#line 7001 "TumblrPublishing.c"
		}
#line 987 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp77_ = outbound_message;
#line 987 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp78_ = _tmp77_->request_headers;
#line 987 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp79_ = i;
#line 987 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp80_ = gee_map_iterator_get_key (_tmp79_);
#line 987 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp81_ = (gchar*) _tmp80_;
#line 987 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp82_ = i;
#line 987 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp83_ = gee_map_iterator_get_value (_tmp82_);
#line 987 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp84_ = (gchar*) _tmp83_;
#line 987 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		soup_message_headers_append (_tmp78_, _tmp81_, _tmp84_);
#line 987 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_g_free0 (_tmp84_);
#line 987 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_g_free0 (_tmp81_);
#line 988 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp85_ = i;
#line 988 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp86_ = gee_map_iterator_next (_tmp85_);
#line 988 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		cont = _tmp86_;
#line 7031 "TumblrPublishing.c"
	}
#line 990 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp87_ = outbound_message;
#line 990 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_rest_support_transaction_set_message (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), _tmp87_);
#line 992 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_rest_support_transaction_set_is_executed (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), TRUE);
#line 994 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_rest_support_transaction_send (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), &_inner_error_);
#line 994 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 994 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 994 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			g_propagate_error (error, _inner_error_);
#line 994 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			_g_object_unref0 (i);
#line 994 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			_g_object_unref0 (outbound_message);
#line 994 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			_g_free0 (request_data);
#line 994 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			request_arguments = (_vala_array_free (request_arguments, request_arguments_length1, (GDestroyNotify) publishing_rest_support_argument_unref), NULL);
#line 994 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			_g_free0 (authorization_header);
#line 994 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			_g_free0 (payload);
#line 994 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			return;
#line 7061 "TumblrPublishing.c"
		} else {
#line 994 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			_g_object_unref0 (i);
#line 994 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			_g_object_unref0 (outbound_message);
#line 994 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			_g_free0 (request_data);
#line 994 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			request_arguments = (_vala_array_free (request_arguments, request_arguments_length1, (GDestroyNotify) publishing_rest_support_argument_unref), NULL);
#line 994 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			_g_free0 (authorization_header);
#line 994 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			_g_free0 (payload);
#line 994 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 994 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			g_clear_error (&_inner_error_);
#line 994 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			return;
#line 7081 "TumblrPublishing.c"
		}
	}
#line 928 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_object_unref0 (i);
#line 928 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_object_unref0 (outbound_message);
#line 928 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_free0 (request_data);
#line 928 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	request_arguments = (_vala_array_free (request_arguments, request_arguments_length1, (GDestroyNotify) publishing_rest_support_argument_unref), NULL);
#line 928 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_free0 (authorization_header);
#line 928 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_free0 (payload);
#line 7096 "TumblrPublishing.c"
}


static void publishing_tumblr_tumblr_publisher_upload_transaction_class_init (PublishingTumblrTumblrPublisherUploadTransactionClass * klass) {
#line 873 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_tumblr_tumblr_publisher_upload_transaction_parent_class = g_type_class_peek_parent (klass);
#line 873 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	((PublishingRESTSupportTransactionClass *) klass)->finalize = publishing_tumblr_tumblr_publisher_upload_transaction_finalize;
#line 873 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_type_class_add_private (klass, sizeof (PublishingTumblrTumblrPublisherUploadTransactionPrivate));
#line 873 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	((PublishingRESTSupportTransactionClass *) klass)->execute = publishing_tumblr_tumblr_publisher_upload_transaction_real_execute;
#line 7109 "TumblrPublishing.c"
}


static void publishing_tumblr_tumblr_publisher_upload_transaction_instance_init (PublishingTumblrTumblrPublisherUploadTransaction * self) {
#line 873 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv = PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_UPLOAD_TRANSACTION_GET_PRIVATE (self);
#line 7116 "TumblrPublishing.c"
}


static void publishing_tumblr_tumblr_publisher_upload_transaction_finalize (PublishingRESTSupportTransaction* obj) {
	PublishingTumblrTumblrPublisherUploadTransaction * self;
#line 873 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_UPLOAD_TRANSACTION, PublishingTumblrTumblrPublisherUploadTransaction);
#line 874 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_publishing_rest_support_session_unref0 (self->priv->session);
#line 875 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->auth_header_fields = (_vala_array_free (self->priv->auth_header_fields, self->priv->auth_header_fields_length1, (GDestroyNotify) publishing_rest_support_argument_unref), NULL);
#line 873 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	PUBLISHING_REST_SUPPORT_TRANSACTION_CLASS (publishing_tumblr_tumblr_publisher_upload_transaction_parent_class)->finalize (obj);
#line 7130 "TumblrPublishing.c"
}


GType publishing_tumblr_tumblr_publisher_upload_transaction_get_type (void) {
	static volatile gsize publishing_tumblr_tumblr_publisher_upload_transaction_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_tumblr_tumblr_publisher_upload_transaction_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingTumblrTumblrPublisherUploadTransactionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_tumblr_tumblr_publisher_upload_transaction_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingTumblrTumblrPublisherUploadTransaction), 0, (GInstanceInitFunc) publishing_tumblr_tumblr_publisher_upload_transaction_instance_init, NULL };
		GType publishing_tumblr_tumblr_publisher_upload_transaction_type_id;
		publishing_tumblr_tumblr_publisher_upload_transaction_type_id = g_type_register_static (PUBLISHING_REST_SUPPORT_TYPE_UPLOAD_TRANSACTION, "PublishingTumblrTumblrPublisherUploadTransaction", &g_define_type_info, 0);
		g_once_init_leave (&publishing_tumblr_tumblr_publisher_upload_transaction_type_id__volatile, publishing_tumblr_tumblr_publisher_upload_transaction_type_id);
	}
	return publishing_tumblr_tumblr_publisher_upload_transaction_type_id__volatile;
}


PublishingTumblrTumblrPublisherUploader* publishing_tumblr_tumblr_publisher_uploader_construct (GType object_type, PublishingTumblrTumblrPublisherSession* session, SpitPublishingPublishable** publishables, int publishables_length1, const gchar* blog_url) {
	PublishingTumblrTumblrPublisherUploader* self = NULL;
	PublishingTumblrTumblrPublisherSession* _tmp0_ = NULL;
	SpitPublishingPublishable** _tmp1_ = NULL;
	gint _tmp1__length1 = 0;
	const gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
#line 1002 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_val_if_fail (PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_IS_SESSION (session), NULL);
#line 1002 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_val_if_fail (blog_url != NULL, NULL);
#line 1003 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = session;
#line 1003 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp1_ = publishables;
#line 1003 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp1__length1 = publishables_length1;
#line 1003 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self = (PublishingTumblrTumblrPublisherUploader*) publishing_rest_support_batch_uploader_construct (object_type, G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession), _tmp1_, _tmp1__length1);
#line 1004 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp2_ = blog_url;
#line 1004 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp3_ = g_strdup (_tmp2_);
#line 1004 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_free0 (self->priv->blog_url);
#line 1004 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->blog_url = _tmp3_;
#line 1002 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return self;
#line 7175 "TumblrPublishing.c"
}


PublishingTumblrTumblrPublisherUploader* publishing_tumblr_tumblr_publisher_uploader_new (PublishingTumblrTumblrPublisherSession* session, SpitPublishingPublishable** publishables, int publishables_length1, const gchar* blog_url) {
#line 1002 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return publishing_tumblr_tumblr_publisher_uploader_construct (PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_UPLOADER, session, publishables, publishables_length1, blog_url);
#line 7182 "TumblrPublishing.c"
}


static PublishingRESTSupportTransaction* publishing_tumblr_tumblr_publisher_uploader_real_create_transaction (PublishingRESTSupportBatchUploader* base, SpitPublishingPublishable* publishable) {
	PublishingTumblrTumblrPublisherUploader * self;
	PublishingRESTSupportTransaction* result = NULL;
	PublishingRESTSupportSession* _tmp0_ = NULL;
	PublishingTumblrTumblrPublisherSession* _tmp1_ = NULL;
	SpitPublishingPublishable* _tmp2_ = NULL;
	SpitPublishingPublishable* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	PublishingTumblrTumblrPublisherUploadTransaction* _tmp5_ = NULL;
	PublishingRESTSupportTransaction* _tmp6_ = NULL;
#line 1009 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_UPLOADER, PublishingTumblrTumblrPublisherUploader);
#line 1009 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_val_if_fail (SPIT_PUBLISHING_IS_PUBLISHABLE (publishable), NULL);
#line 1011 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_debug ("TumblrPublishing.vala:1011: Create upload transaction");
#line 1012 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = publishing_rest_support_batch_uploader_get_session (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, PublishingRESTSupportBatchUploader));
#line 1012 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp1_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_SESSION, PublishingTumblrTumblrPublisherSession);
#line 1012 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp2_ = publishing_rest_support_batch_uploader_get_current_publishable (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, PublishingRESTSupportBatchUploader));
#line 1012 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp3_ = _tmp2_;
#line 1012 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp4_ = self->priv->blog_url;
#line 1012 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp5_ = publishing_tumblr_tumblr_publisher_upload_transaction_new (_tmp1_, _tmp3_, _tmp4_);
#line 1012 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp6_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction);
#line 1012 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_object_unref0 (_tmp3_);
#line 1012 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_publishing_rest_support_session_unref0 (_tmp1_);
#line 1012 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	result = _tmp6_;
#line 1012 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return result;
#line 7224 "TumblrPublishing.c"
}


static void publishing_tumblr_tumblr_publisher_uploader_class_init (PublishingTumblrTumblrPublisherUploaderClass * klass) {
#line 1000 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_tumblr_tumblr_publisher_uploader_parent_class = g_type_class_peek_parent (klass);
#line 1000 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	((PublishingRESTSupportBatchUploaderClass *) klass)->finalize = publishing_tumblr_tumblr_publisher_uploader_finalize;
#line 1000 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_type_class_add_private (klass, sizeof (PublishingTumblrTumblrPublisherUploaderPrivate));
#line 1000 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	((PublishingRESTSupportBatchUploaderClass *) klass)->create_transaction = publishing_tumblr_tumblr_publisher_uploader_real_create_transaction;
#line 7237 "TumblrPublishing.c"
}


static void publishing_tumblr_tumblr_publisher_uploader_instance_init (PublishingTumblrTumblrPublisherUploader * self) {
	gchar* _tmp0_ = NULL;
#line 1000 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv = PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_UPLOADER_GET_PRIVATE (self);
#line 1001 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = g_strdup ("");
#line 1001 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->blog_url = _tmp0_;
#line 7249 "TumblrPublishing.c"
}


static void publishing_tumblr_tumblr_publisher_uploader_finalize (PublishingRESTSupportBatchUploader* obj) {
	PublishingTumblrTumblrPublisherUploader * self;
#line 1000 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_UPLOADER, PublishingTumblrTumblrPublisherUploader);
#line 1001 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_free0 (self->priv->blog_url);
#line 1000 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	PUBLISHING_REST_SUPPORT_BATCH_UPLOADER_CLASS (publishing_tumblr_tumblr_publisher_uploader_parent_class)->finalize (obj);
#line 7261 "TumblrPublishing.c"
}


GType publishing_tumblr_tumblr_publisher_uploader_get_type (void) {
	static volatile gsize publishing_tumblr_tumblr_publisher_uploader_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_tumblr_tumblr_publisher_uploader_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingTumblrTumblrPublisherUploaderClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_tumblr_tumblr_publisher_uploader_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingTumblrTumblrPublisherUploader), 0, (GInstanceInitFunc) publishing_tumblr_tumblr_publisher_uploader_instance_init, NULL };
		GType publishing_tumblr_tumblr_publisher_uploader_type_id;
		publishing_tumblr_tumblr_publisher_uploader_type_id = g_type_register_static (PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, "PublishingTumblrTumblrPublisherUploader", &g_define_type_info, 0);
		g_once_init_leave (&publishing_tumblr_tumblr_publisher_uploader_type_id__volatile, publishing_tumblr_tumblr_publisher_uploader_type_id);
	}
	return publishing_tumblr_tumblr_publisher_uploader_type_id__volatile;
}


PublishingTumblrTumblrPublisherSession* publishing_tumblr_tumblr_publisher_session_construct (GType object_type) {
	PublishingTumblrTumblrPublisherSession* self = NULL;
#line 1027 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self = (PublishingTumblrTumblrPublisherSession*) publishing_rest_support_session_construct (object_type, PUBLISHING_TUMBLR_ENDPOINT_URL);
#line 1026 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return self;
#line 7283 "TumblrPublishing.c"
}


PublishingTumblrTumblrPublisherSession* publishing_tumblr_tumblr_publisher_session_new (void) {
#line 1026 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return publishing_tumblr_tumblr_publisher_session_construct (PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_SESSION);
#line 7290 "TumblrPublishing.c"
}


static gboolean publishing_tumblr_tumblr_publisher_session_real_is_authenticated (PublishingRESTSupportSession* base) {
	PublishingTumblrTumblrPublisherSession * self;
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
	const gchar* _tmp1_ = NULL;
#line 1030 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_SESSION, PublishingTumblrTumblrPublisherSession);
#line 1031 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp1_ = self->priv->access_phase_token;
#line 1031 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	if (_tmp1_ != NULL) {
#line 7305 "TumblrPublishing.c"
		const gchar* _tmp2_ = NULL;
#line 1031 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp2_ = self->priv->access_phase_token_secret;
#line 1031 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp0_ = _tmp2_ != NULL;
#line 7311 "TumblrPublishing.c"
	} else {
#line 1031 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp0_ = FALSE;
#line 7315 "TumblrPublishing.c"
	}
#line 1031 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	result = _tmp0_;
#line 1031 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return result;
#line 7321 "TumblrPublishing.c"
}


void publishing_tumblr_tumblr_publisher_session_authenticate_from_persistent_credentials (PublishingTumblrTumblrPublisherSession* self, const gchar* token, const gchar* secret) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
#line 1034 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_if_fail (PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_IS_SESSION (self));
#line 1034 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_if_fail (token != NULL);
#line 1034 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_if_fail (secret != NULL);
#line 1035 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = token;
#line 1035 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 1035 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_free0 (self->priv->access_phase_token);
#line 1035 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->access_phase_token = _tmp1_;
#line 1036 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp2_ = secret;
#line 1036 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp3_ = g_strdup (_tmp2_);
#line 1036 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_free0 (self->priv->access_phase_token_secret);
#line 1036 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->access_phase_token_secret = _tmp3_;
#line 1039 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_signal_emit_by_name (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession), "authenticated");
#line 7354 "TumblrPublishing.c"
}


void publishing_tumblr_tumblr_publisher_session_deauthenticate (PublishingTumblrTumblrPublisherSession* self) {
#line 1042 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_if_fail (PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_IS_SESSION (self));
#line 1043 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_free0 (self->priv->access_phase_token);
#line 1043 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->access_phase_token = NULL;
#line 1044 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_free0 (self->priv->access_phase_token_secret);
#line 1044 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->access_phase_token_secret = NULL;
#line 7369 "TumblrPublishing.c"
}


static gpointer _publishing_rest_support_transaction_ref0 (gpointer self) {
#line 1067 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return self ? publishing_rest_support_transaction_ref (self) : NULL;
#line 7376 "TumblrPublishing.c"
}


static void _vala_array_add23 (PublishingRESTSupportArgument*** array, int* length, int* size, PublishingRESTSupportArgument* value) {
#line 1076 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	if ((*length) == (*size)) {
#line 1076 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 1076 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		*array = g_renew (PublishingRESTSupportArgument*, *array, (*size) + 1);
#line 7387 "TumblrPublishing.c"
	}
#line 1076 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	(*array)[(*length)++] = value;
#line 1076 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	(*array)[*length] = NULL;
#line 7393 "TumblrPublishing.c"
}


void publishing_tumblr_tumblr_publisher_session_sign_transaction (PublishingTumblrTumblrPublisherSession* self, PublishingRESTSupportTransaction* txn) {
	gchar* http_method = NULL;
	PublishingRESTSupportTransaction* _tmp0_ = NULL;
	PublishingRESTSupportHttpMethod _tmp1_ = 0;
	gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	gchar* signing_key = NULL;
	const gchar* _tmp6_ = NULL;
	PublishingRESTSupportArgument** base_string_arguments = NULL;
	PublishingRESTSupportTransaction* _tmp11_ = NULL;
	gint _tmp12_ = 0;
	PublishingRESTSupportArgument** _tmp13_ = NULL;
	gint base_string_arguments_length1 = 0;
	gint _base_string_arguments_size_ = 0;
	PublishingTumblrTumblrPublisherUploadTransaction* upload_txn = NULL;
	PublishingRESTSupportTransaction* _tmp14_ = NULL;
	PublishingTumblrTumblrPublisherUploadTransaction* _tmp15_ = NULL;
	PublishingTumblrTumblrPublisherUploadTransaction* _tmp16_ = NULL;
	PublishingRESTSupportArgument** sorted_args = NULL;
	PublishingRESTSupportArgument** _tmp25_ = NULL;
	gint _tmp25__length1 = 0;
	gint _tmp26_ = 0;
	PublishingRESTSupportArgument** _tmp27_ = NULL;
	gint sorted_args_length1 = 0;
	gint _sorted_args_size_ = 0;
	gchar* arguments_string = NULL;
	gchar* _tmp28_ = NULL;
	gchar* signature_base_string = NULL;
	const gchar* _tmp51_ = NULL;
	gchar* _tmp52_ = NULL;
	gchar* _tmp53_ = NULL;
	PublishingRESTSupportTransaction* _tmp54_ = NULL;
	gchar* _tmp55_ = NULL;
	gchar* _tmp56_ = NULL;
	gchar* _tmp57_ = NULL;
	gchar* _tmp58_ = NULL;
	gchar* _tmp59_ = NULL;
	gchar* _tmp60_ = NULL;
	gchar* _tmp61_ = NULL;
	gchar* _tmp62_ = NULL;
	const gchar* _tmp63_ = NULL;
	gchar* _tmp64_ = NULL;
	gchar* _tmp65_ = NULL;
	gchar* _tmp66_ = NULL;
	gchar* _tmp67_ = NULL;
	const gchar* _tmp68_ = NULL;
	const gchar* _tmp69_ = NULL;
	gchar* signature = NULL;
	const gchar* _tmp70_ = NULL;
	const gchar* _tmp71_ = NULL;
	gchar* _tmp72_ = NULL;
	const gchar* _tmp73_ = NULL;
	const gchar* _tmp74_ = NULL;
	gchar* _tmp75_ = NULL;
	const gchar* _tmp76_ = NULL;
	PublishingTumblrTumblrPublisherUploadTransaction* _tmp77_ = NULL;
#line 1047 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_if_fail (PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_IS_SESSION (self));
#line 1047 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_TRANSACTION (txn));
#line 1048 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = txn;
#line 1048 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp1_ = publishing_rest_support_transaction_get_method (_tmp0_);
#line 1048 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp2_ = publishing_rest_support_http_method_to_string (_tmp1_);
#line 1048 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	http_method = _tmp2_;
#line 1050 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_debug ("TumblrPublishing.vala:1050: signing transaction with parameters:");
#line 1051 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp3_ = http_method;
#line 1051 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp4_ = g_strconcat ("HTTP method = ", _tmp3_, NULL);
#line 1051 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp5_ = _tmp4_;
#line 1051 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_debug ("TumblrPublishing.vala:1051: %s", _tmp5_);
#line 1051 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_free0 (_tmp5_);
#line 1052 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	signing_key = NULL;
#line 1053 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp6_ = self->priv->access_phase_token_secret;
#line 1053 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	if (_tmp6_ != NULL) {
#line 7485 "TumblrPublishing.c"
		gchar* _tmp7_ = NULL;
		gchar* _tmp8_ = NULL;
		gchar* _tmp9_ = NULL;
#line 1054 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		g_debug ("TumblrPublishing.vala:1054: access phase token secret available; using" \
" it as signing key");
#line 1056 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp7_ = publishing_tumblr_tumblr_publisher_session_get_access_phase_token_secret (self);
#line 1056 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp8_ = _tmp7_;
#line 1056 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp9_ = g_strconcat (PUBLISHING_TUMBLR_API_SECRET "&", _tmp8_, NULL);
#line 1056 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_g_free0 (signing_key);
#line 1056 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		signing_key = _tmp9_;
#line 1056 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_g_free0 (_tmp8_);
#line 7503 "TumblrPublishing.c"
	} else {
		gchar* _tmp10_ = NULL;
#line 1058 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		g_debug ("TumblrPublishing.vala:1058: %s", "Access phase token secret not available; using API " "key as signing key");
#line 1061 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp10_ = g_strdup (PUBLISHING_TUMBLR_API_SECRET "&");
#line 1061 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_g_free0 (signing_key);
#line 1061 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		signing_key = _tmp10_;
#line 7514 "TumblrPublishing.c"
	}
#line 1065 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp11_ = txn;
#line 1065 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp13_ = publishing_rest_support_transaction_get_arguments (_tmp11_, &_tmp12_);
#line 1065 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	base_string_arguments = _tmp13_;
#line 1065 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	base_string_arguments_length1 = _tmp12_;
#line 1065 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_base_string_arguments_size_ = base_string_arguments_length1;
#line 1067 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp14_ = txn;
#line 1067 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp15_ = _publishing_rest_support_transaction_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp14_, PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_UPLOAD_TRANSACTION) ? ((PublishingTumblrTumblrPublisherUploadTransaction*) _tmp14_) : NULL);
#line 1067 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	upload_txn = _tmp15_;
#line 1068 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp16_ = upload_txn;
#line 1068 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	if (_tmp16_ != NULL) {
#line 7536 "TumblrPublishing.c"
		PublishingRESTSupportArgument** auth_header_args = NULL;
		PublishingTumblrTumblrPublisherUploadTransaction* _tmp17_ = NULL;
		gint _tmp18_ = 0;
		PublishingRESTSupportArgument** _tmp19_ = NULL;
		gint auth_header_args_length1 = 0;
		gint _auth_header_args_size_ = 0;
		PublishingRESTSupportArgument** _tmp20_ = NULL;
		gint _tmp20__length1 = 0;
#line 1069 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		g_debug ("TumblrPublishing.vala:1069: %s", "this transaction is an UploadTransaction; including Authorization head" \
"er " "fields in signature base string");
#line 1072 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp17_ = upload_txn;
#line 1072 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp19_ = publishing_tumblr_tumblr_publisher_upload_transaction_get_authorization_header_fields (_tmp17_, &_tmp18_);
#line 1072 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		auth_header_args = _tmp19_;
#line 1072 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		auth_header_args_length1 = _tmp18_;
#line 1072 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_auth_header_args_size_ = auth_header_args_length1;
#line 1075 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp20_ = auth_header_args;
#line 1075 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp20__length1 = auth_header_args_length1;
#line 7561 "TumblrPublishing.c"
		{
			PublishingRESTSupportArgument** arg_collection = NULL;
			gint arg_collection_length1 = 0;
			gint _arg_collection_size_ = 0;
			gint arg_it = 0;
#line 1075 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			arg_collection = _tmp20_;
#line 1075 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			arg_collection_length1 = _tmp20__length1;
#line 1075 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			for (arg_it = 0; arg_it < _tmp20__length1; arg_it = arg_it + 1) {
#line 7573 "TumblrPublishing.c"
				PublishingRESTSupportArgument* _tmp21_ = NULL;
				PublishingRESTSupportArgument* arg = NULL;
#line 1075 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp21_ = _publishing_rest_support_argument_ref0 (arg_collection[arg_it]);
#line 1075 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				arg = _tmp21_;
#line 7580 "TumblrPublishing.c"
				{
					PublishingRESTSupportArgument** _tmp22_ = NULL;
					gint _tmp22__length1 = 0;
					PublishingRESTSupportArgument* _tmp23_ = NULL;
					PublishingRESTSupportArgument* _tmp24_ = NULL;
#line 1076 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					_tmp22_ = base_string_arguments;
#line 1076 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					_tmp22__length1 = base_string_arguments_length1;
#line 1076 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					_tmp23_ = arg;
#line 1076 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					_tmp24_ = _publishing_rest_support_argument_ref0 (_tmp23_);
#line 1076 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					_vala_array_add23 (&base_string_arguments, &base_string_arguments_length1, &_base_string_arguments_size_, _tmp24_);
#line 1075 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					_publishing_rest_support_argument_unref0 (arg);
#line 7598 "TumblrPublishing.c"
				}
			}
		}
#line 1068 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		auth_header_args = (_vala_array_free (auth_header_args, auth_header_args_length1, (GDestroyNotify) publishing_rest_support_argument_unref), NULL);
#line 7604 "TumblrPublishing.c"
	}
#line 1079 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp25_ = base_string_arguments;
#line 1079 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp25__length1 = base_string_arguments_length1;
#line 1079 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp27_ = publishing_rest_support_argument_sort (_tmp25_, _tmp25__length1, &_tmp26_);
#line 1079 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	sorted_args = _tmp27_;
#line 1079 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	sorted_args_length1 = _tmp26_;
#line 1079 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_sorted_args_size_ = sorted_args_length1;
#line 1082 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp28_ = g_strdup ("");
#line 1082 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	arguments_string = _tmp28_;
#line 7622 "TumblrPublishing.c"
	{
		gint i = 0;
#line 1083 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		i = 0;
#line 7627 "TumblrPublishing.c"
		{
			gboolean _tmp29_ = FALSE;
#line 1083 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			_tmp29_ = TRUE;
#line 1083 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
			while (TRUE) {
#line 7634 "TumblrPublishing.c"
				gint _tmp31_ = 0;
				PublishingRESTSupportArgument** _tmp32_ = NULL;
				gint _tmp32__length1 = 0;
				const gchar* _tmp33_ = NULL;
				PublishingRESTSupportArgument** _tmp34_ = NULL;
				gint _tmp34__length1 = 0;
				gint _tmp35_ = 0;
				PublishingRESTSupportArgument* _tmp36_ = NULL;
				const gchar* _tmp37_ = NULL;
				gchar* _tmp38_ = NULL;
				gchar* _tmp39_ = NULL;
				PublishingRESTSupportArgument** _tmp40_ = NULL;
				gint _tmp40__length1 = 0;
				gint _tmp41_ = 0;
				PublishingRESTSupportArgument* _tmp42_ = NULL;
				const gchar* _tmp43_ = NULL;
				gchar* _tmp44_ = NULL;
				gchar* _tmp45_ = NULL;
				gchar* _tmp46_ = NULL;
				gint _tmp47_ = 0;
				PublishingRESTSupportArgument** _tmp48_ = NULL;
				gint _tmp48__length1 = 0;
#line 1083 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				if (!_tmp29_) {
#line 7659 "TumblrPublishing.c"
					gint _tmp30_ = 0;
#line 1083 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					_tmp30_ = i;
#line 1083 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					i = _tmp30_ + 1;
#line 7665 "TumblrPublishing.c"
				}
#line 1083 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp29_ = FALSE;
#line 1083 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp31_ = i;
#line 1083 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp32_ = sorted_args;
#line 1083 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp32__length1 = sorted_args_length1;
#line 1083 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				if (!(_tmp31_ < _tmp32__length1)) {
#line 1083 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					break;
#line 7679 "TumblrPublishing.c"
				}
#line 1084 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp33_ = arguments_string;
#line 1084 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp34_ = sorted_args;
#line 1084 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp34__length1 = sorted_args_length1;
#line 1084 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp35_ = i;
#line 1084 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp36_ = _tmp34_[_tmp35_];
#line 1084 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp37_ = _tmp36_->key;
#line 1084 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp38_ = g_strconcat (_tmp37_, "=", NULL);
#line 1084 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp39_ = _tmp38_;
#line 1084 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp40_ = sorted_args;
#line 1084 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp40__length1 = sorted_args_length1;
#line 1084 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp41_ = i;
#line 1084 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp42_ = _tmp40_[_tmp41_];
#line 1084 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp43_ = _tmp42_->value;
#line 1084 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp44_ = g_strconcat (_tmp39_, _tmp43_, NULL);
#line 1084 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp45_ = _tmp44_;
#line 1084 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp46_ = g_strconcat (_tmp33_, _tmp45_, NULL);
#line 1084 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_g_free0 (arguments_string);
#line 1084 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				arguments_string = _tmp46_;
#line 1084 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_g_free0 (_tmp45_);
#line 1084 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_g_free0 (_tmp39_);
#line 1085 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp47_ = i;
#line 1085 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp48_ = sorted_args;
#line 1085 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				_tmp48__length1 = sorted_args_length1;
#line 1085 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
				if (_tmp47_ < (_tmp48__length1 - 1)) {
#line 7729 "TumblrPublishing.c"
					const gchar* _tmp49_ = NULL;
					gchar* _tmp50_ = NULL;
#line 1086 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					_tmp49_ = arguments_string;
#line 1086 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					_tmp50_ = g_strconcat (_tmp49_, "&", NULL);
#line 1086 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					_g_free0 (arguments_string);
#line 1086 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
					arguments_string = _tmp50_;
#line 7740 "TumblrPublishing.c"
				}
			}
		}
	}
#line 1090 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp51_ = http_method;
#line 1090 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp52_ = g_strconcat (_tmp51_, "&", NULL);
#line 1090 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp53_ = _tmp52_;
#line 1090 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp54_ = txn;
#line 1090 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp55_ = publishing_rest_support_transaction_get_endpoint_url (_tmp54_);
#line 1090 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp56_ = _tmp55_;
#line 1090 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp57_ = soup_uri_encode (_tmp56_, PUBLISHING_TUMBLR_ENCODE_RFC_3986_EXTRA);
#line 1090 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp58_ = _tmp57_;
#line 1090 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp59_ = g_strconcat (_tmp53_, _tmp58_, NULL);
#line 1090 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp60_ = _tmp59_;
#line 1090 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp61_ = g_strconcat (_tmp60_, "&", NULL);
#line 1090 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp62_ = _tmp61_;
#line 1090 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp63_ = arguments_string;
#line 1090 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp64_ = soup_uri_encode (_tmp63_, PUBLISHING_TUMBLR_ENCODE_RFC_3986_EXTRA);
#line 1090 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp65_ = _tmp64_;
#line 1090 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp66_ = g_strconcat (_tmp62_, _tmp65_, NULL);
#line 1090 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp67_ = _tmp66_;
#line 1090 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_free0 (_tmp65_);
#line 1090 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_free0 (_tmp62_);
#line 1090 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_free0 (_tmp60_);
#line 1090 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_free0 (_tmp58_);
#line 1090 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_free0 (_tmp56_);
#line 1090 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_free0 (_tmp53_);
#line 1090 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	signature_base_string = _tmp67_;
#line 1094 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp68_ = signature_base_string;
#line 1094 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_debug ("TumblrPublishing.vala:1094: signature base string = '%s'", _tmp68_);
#line 1095 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp69_ = signing_key;
#line 1095 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_debug ("TumblrPublishing.vala:1095: signing key = '%s'", _tmp69_);
#line 1098 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp70_ = signing_key;
#line 1098 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp71_ = signature_base_string;
#line 1098 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp72_ = publishing_rest_support_hmac_sha1 (_tmp70_, _tmp71_);
#line 1098 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	signature = _tmp72_;
#line 1099 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp73_ = signature;
#line 1099 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_debug ("TumblrPublishing.vala:1099: signature = '%s'", _tmp73_);
#line 1100 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp74_ = signature;
#line 1100 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp75_ = soup_uri_encode (_tmp74_, PUBLISHING_TUMBLR_ENCODE_RFC_3986_EXTRA);
#line 1100 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_free0 (signature);
#line 1100 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	signature = _tmp75_;
#line 1102 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp76_ = signature;
#line 1102 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_debug ("TumblrPublishing.vala:1102: signature after RFC encode = '%s'", _tmp76_);
#line 1104 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp77_ = upload_txn;
#line 1104 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	if (_tmp77_ != NULL) {
#line 7829 "TumblrPublishing.c"
		PublishingTumblrTumblrPublisherUploadTransaction* _tmp78_ = NULL;
		const gchar* _tmp79_ = NULL;
#line 1105 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp78_ = upload_txn;
#line 1105 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp79_ = signature;
#line 1105 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		publishing_tumblr_tumblr_publisher_upload_transaction_add_authorization_header_field (_tmp78_, "oauth_signature", _tmp79_);
#line 7838 "TumblrPublishing.c"
	} else {
		PublishingRESTSupportTransaction* _tmp80_ = NULL;
		const gchar* _tmp81_ = NULL;
#line 1107 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp80_ = txn;
#line 1107 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		_tmp81_ = signature;
#line 1107 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
		publishing_rest_support_transaction_add_argument (_tmp80_, "oauth_signature", _tmp81_);
#line 7848 "TumblrPublishing.c"
	}
#line 1047 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_free0 (signature);
#line 1047 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_free0 (signature_base_string);
#line 1047 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_free0 (arguments_string);
#line 1047 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	sorted_args = (_vala_array_free (sorted_args, sorted_args_length1, (GDestroyNotify) publishing_rest_support_argument_unref), NULL);
#line 1047 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_publishing_rest_support_transaction_unref0 (upload_txn);
#line 1047 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	base_string_arguments = (_vala_array_free (base_string_arguments, base_string_arguments_length1, (GDestroyNotify) publishing_rest_support_argument_unref), NULL);
#line 1047 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_free0 (signing_key);
#line 1047 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_free0 (http_method);
#line 7866 "TumblrPublishing.c"
}


void publishing_tumblr_tumblr_publisher_session_set_access_phase_credentials (PublishingTumblrTumblrPublisherSession* self, const gchar* token, const gchar* secret) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
#line 1112 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_if_fail (PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_IS_SESSION (self));
#line 1112 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_if_fail (token != NULL);
#line 1112 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_if_fail (secret != NULL);
#line 1113 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = token;
#line 1113 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 1113 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_free0 (self->priv->access_phase_token);
#line 1113 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->access_phase_token = _tmp1_;
#line 1114 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp2_ = secret;
#line 1114 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp3_ = g_strdup (_tmp2_);
#line 1114 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_free0 (self->priv->access_phase_token_secret);
#line 1114 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->access_phase_token_secret = _tmp3_;
#line 1117 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_signal_emit_by_name (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession), "authenticated");
#line 7899 "TumblrPublishing.c"
}


gchar* publishing_tumblr_tumblr_publisher_session_get_access_phase_token (PublishingTumblrTumblrPublisherSession* self) {
	gchar* result = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 1120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_val_if_fail (PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_IS_SESSION (self), NULL);
#line 1121 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = self->priv->access_phase_token;
#line 1121 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 1121 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	result = _tmp1_;
#line 1121 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return result;
#line 7917 "TumblrPublishing.c"
}


gchar* publishing_tumblr_tumblr_publisher_session_get_access_phase_token_secret (PublishingTumblrTumblrPublisherSession* self) {
	gchar* result = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 1125 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_val_if_fail (PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_IS_SESSION (self), NULL);
#line 1126 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = self->priv->access_phase_token_secret;
#line 1126 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 1126 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	result = _tmp1_;
#line 1126 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return result;
#line 7935 "TumblrPublishing.c"
}


gchar* publishing_tumblr_tumblr_publisher_session_get_oauth_nonce (PublishingTumblrTumblrPublisherSession* self) {
	gchar* result = NULL;
	GTimeVal currtime = {0};
	GTimeVal _tmp0_ = {0};
	glong _tmp1_ = 0L;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	GTimeVal _tmp4_ = {0};
	glong _tmp5_ = 0L;
	gchar* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
	gchar* _tmp8_ = NULL;
	gchar* _tmp9_ = NULL;
	gchar* _tmp10_ = NULL;
	gchar* _tmp11_ = NULL;
#line 1129 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_val_if_fail (PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_IS_SESSION (self), NULL);
#line 1130 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_get_current_time (&currtime);
#line 1131 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_get_current_time (&currtime);
#line 1133 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = currtime;
#line 1133 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp1_ = _tmp0_.tv_sec;
#line 1133 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp2_ = g_strdup_printf ("%li", _tmp1_);
#line 1133 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp3_ = _tmp2_;
#line 1133 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp4_ = currtime;
#line 1133 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp5_ = _tmp4_.tv_usec;
#line 1133 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp6_ = g_strdup_printf ("%li", _tmp5_);
#line 1133 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp7_ = _tmp6_;
#line 1133 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp8_ = g_strconcat (_tmp3_, _tmp7_, NULL);
#line 1133 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp9_ = _tmp8_;
#line 1133 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp10_ = g_compute_checksum_for_string (G_CHECKSUM_MD5, _tmp9_, (gsize) -1);
#line 1133 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp11_ = _tmp10_;
#line 1133 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_free0 (_tmp9_);
#line 1133 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_free0 (_tmp7_);
#line 1133 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_free0 (_tmp3_);
#line 1133 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	result = _tmp11_;
#line 1133 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return result;
#line 7994 "TumblrPublishing.c"
}


static glong string_strnlen (gchar* str, glong maxlen) {
	glong result = 0L;
	gchar* end = NULL;
	gchar* _tmp0_ = NULL;
	glong _tmp1_ = 0L;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
#line 1295 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp0_ = str;
#line 1295 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp1_ = maxlen;
#line 1295 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp2_ = memchr (_tmp0_, 0, (gsize) _tmp1_);
#line 1295 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	end = _tmp2_;
#line 1296 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp3_ = end;
#line 1296 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	if (_tmp3_ == NULL) {
#line 8017 "TumblrPublishing.c"
		glong _tmp4_ = 0L;
#line 1297 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp4_ = maxlen;
#line 1297 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		result = _tmp4_;
#line 1297 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		return result;
#line 8025 "TumblrPublishing.c"
	} else {
		gchar* _tmp5_ = NULL;
		gchar* _tmp6_ = NULL;
#line 1299 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp5_ = end;
#line 1299 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp6_ = str;
#line 1299 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		result = (glong) (_tmp5_ - _tmp6_);
#line 1299 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		return result;
#line 8037 "TumblrPublishing.c"
	}
}


static gchar* string_substring (const gchar* self, glong offset, glong len) {
	gchar* result = NULL;
	glong string_length = 0L;
	gboolean _tmp0_ = FALSE;
	glong _tmp1_ = 0L;
	glong _tmp8_ = 0L;
	glong _tmp14_ = 0L;
	glong _tmp17_ = 0L;
	glong _tmp18_ = 0L;
	glong _tmp19_ = 0L;
	glong _tmp20_ = 0L;
	glong _tmp21_ = 0L;
	gchar* _tmp22_ = NULL;
#line 1306 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1308 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp1_ = offset;
#line 1308 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	if (_tmp1_ >= ((glong) 0)) {
#line 8061 "TumblrPublishing.c"
		glong _tmp2_ = 0L;
#line 1308 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp2_ = len;
#line 1308 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp0_ = _tmp2_ >= ((glong) 0);
#line 8067 "TumblrPublishing.c"
	} else {
#line 1308 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp0_ = FALSE;
#line 8071 "TumblrPublishing.c"
	}
#line 1308 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	if (_tmp0_) {
#line 8075 "TumblrPublishing.c"
		glong _tmp3_ = 0L;
		glong _tmp4_ = 0L;
		glong _tmp5_ = 0L;
#line 1310 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp3_ = offset;
#line 1310 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp4_ = len;
#line 1310 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp5_ = string_strnlen ((gchar*) self, _tmp3_ + _tmp4_);
#line 1310 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		string_length = _tmp5_;
#line 8087 "TumblrPublishing.c"
	} else {
		gint _tmp6_ = 0;
		gint _tmp7_ = 0;
#line 1312 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp6_ = strlen (self);
#line 1312 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp7_ = _tmp6_;
#line 1312 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		string_length = (glong) _tmp7_;
#line 8097 "TumblrPublishing.c"
	}
#line 1315 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp8_ = offset;
#line 1315 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	if (_tmp8_ < ((glong) 0)) {
#line 8103 "TumblrPublishing.c"
		glong _tmp9_ = 0L;
		glong _tmp10_ = 0L;
		glong _tmp11_ = 0L;
#line 1316 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp9_ = string_length;
#line 1316 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp10_ = offset;
#line 1316 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		offset = _tmp9_ + _tmp10_;
#line 1317 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp11_ = offset;
#line 1317 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		g_return_val_if_fail (_tmp11_ >= ((glong) 0), NULL);
#line 8117 "TumblrPublishing.c"
	} else {
		glong _tmp12_ = 0L;
		glong _tmp13_ = 0L;
#line 1319 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp12_ = offset;
#line 1319 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp13_ = string_length;
#line 1319 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		g_return_val_if_fail (_tmp12_ <= _tmp13_, NULL);
#line 8127 "TumblrPublishing.c"
	}
#line 1321 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp14_ = len;
#line 1321 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	if (_tmp14_ < ((glong) 0)) {
#line 8133 "TumblrPublishing.c"
		glong _tmp15_ = 0L;
		glong _tmp16_ = 0L;
#line 1322 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp15_ = string_length;
#line 1322 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp16_ = offset;
#line 1322 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		len = _tmp15_ - _tmp16_;
#line 8142 "TumblrPublishing.c"
	}
#line 1324 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp17_ = offset;
#line 1324 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp18_ = len;
#line 1324 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp19_ = string_length;
#line 1324 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	g_return_val_if_fail ((_tmp17_ + _tmp18_) <= _tmp19_, NULL);
#line 1325 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp20_ = offset;
#line 1325 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp21_ = len;
#line 1325 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp22_ = g_strndup (((gchar*) self) + _tmp20_, (gsize) _tmp21_);
#line 1325 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	result = _tmp22_;
#line 1325 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	return result;
#line 8162 "TumblrPublishing.c"
}


gchar* publishing_tumblr_tumblr_publisher_session_get_oauth_timestamp (PublishingTumblrTumblrPublisherSession* self) {
	gchar* result = NULL;
	gint64 _tmp0_ = 0LL;
	gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
#line 1137 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_return_val_if_fail (PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_IS_SESSION (self), NULL);
#line 1138 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = g_get_real_time ();
#line 1138 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp1_ = g_strdup_printf ("%" G_GINT64_FORMAT, _tmp0_);
#line 1138 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp2_ = _tmp1_;
#line 1138 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp3_ = string_substring (_tmp2_, (glong) 0, (glong) 10);
#line 1138 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp4_ = _tmp3_;
#line 1138 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_free0 (_tmp2_);
#line 1138 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	result = _tmp4_;
#line 1138 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	return result;
#line 8191 "TumblrPublishing.c"
}


static void publishing_tumblr_tumblr_publisher_session_class_init (PublishingTumblrTumblrPublisherSessionClass * klass) {
#line 1021 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_tumblr_tumblr_publisher_session_parent_class = g_type_class_peek_parent (klass);
#line 1021 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	((PublishingRESTSupportSessionClass *) klass)->finalize = publishing_tumblr_tumblr_publisher_session_finalize;
#line 1021 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_type_class_add_private (klass, sizeof (PublishingTumblrTumblrPublisherSessionPrivate));
#line 1021 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	((PublishingRESTSupportSessionClass *) klass)->is_authenticated = publishing_tumblr_tumblr_publisher_session_real_is_authenticated;
#line 8204 "TumblrPublishing.c"
}


static void publishing_tumblr_tumblr_publisher_session_instance_init (PublishingTumblrTumblrPublisherSession * self) {
#line 1021 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv = PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_SESSION_GET_PRIVATE (self);
#line 1022 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->access_phase_token = NULL;
#line 1023 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->access_phase_token_secret = NULL;
#line 8215 "TumblrPublishing.c"
}


static void publishing_tumblr_tumblr_publisher_session_finalize (PublishingRESTSupportSession* obj) {
	PublishingTumblrTumblrPublisherSession * self;
#line 1021 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_TYPE_SESSION, PublishingTumblrTumblrPublisherSession);
#line 1022 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_free0 (self->priv->access_phase_token);
#line 1023 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_free0 (self->priv->access_phase_token_secret);
#line 1021 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	PUBLISHING_REST_SUPPORT_SESSION_CLASS (publishing_tumblr_tumblr_publisher_session_parent_class)->finalize (obj);
#line 8229 "TumblrPublishing.c"
}


/**
 * Session class that keeps track of the authentication status and of the
 * user token tumblr.
 */
GType publishing_tumblr_tumblr_publisher_session_get_type (void) {
	static volatile gsize publishing_tumblr_tumblr_publisher_session_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_tumblr_tumblr_publisher_session_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingTumblrTumblrPublisherSessionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_tumblr_tumblr_publisher_session_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingTumblrTumblrPublisherSession), 0, (GInstanceInitFunc) publishing_tumblr_tumblr_publisher_session_instance_init, NULL };
		GType publishing_tumblr_tumblr_publisher_session_type_id;
		publishing_tumblr_tumblr_publisher_session_type_id = g_type_register_static (PUBLISHING_REST_SUPPORT_TYPE_SESSION, "PublishingTumblrTumblrPublisherSession", &g_define_type_info, 0);
		g_once_init_leave (&publishing_tumblr_tumblr_publisher_session_type_id__volatile, publishing_tumblr_tumblr_publisher_session_type_id);
	}
	return publishing_tumblr_tumblr_publisher_session_type_id__volatile;
}


static void publishing_tumblr_tumblr_publisher_class_init (PublishingTumblrTumblrPublisherClass * klass) {
#line 89 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_tumblr_tumblr_publisher_parent_class = g_type_class_peek_parent (klass);
#line 89 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_type_class_add_private (klass, sizeof (PublishingTumblrTumblrPublisherPrivate));
#line 89 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	G_OBJECT_CLASS (klass)->finalize = publishing_tumblr_tumblr_publisher_finalize;
#line 8256 "TumblrPublishing.c"
}


static void publishing_tumblr_tumblr_publisher_spit_publishing_publisher_interface_init (SpitPublishingPublisherIface * iface) {
#line 89 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	publishing_tumblr_tumblr_publisher_spit_publishing_publisher_parent_iface = g_type_interface_peek_parent (iface);
#line 89 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	iface->get_service = (SpitPublishingService* (*)(SpitPublishingPublisher*)) publishing_tumblr_tumblr_publisher_real_get_service;
#line 89 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	iface->is_running = (gboolean (*)(SpitPublishingPublisher*)) publishing_tumblr_tumblr_publisher_real_is_running;
#line 89 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	iface->start = (void (*)(SpitPublishingPublisher*)) publishing_tumblr_tumblr_publisher_real_start;
#line 89 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	iface->stop = (void (*)(SpitPublishingPublisher*)) publishing_tumblr_tumblr_publisher_real_stop;
#line 8271 "TumblrPublishing.c"
}


static void publishing_tumblr_tumblr_publisher_instance_init (PublishingTumblrTumblrPublisher * self) {
	gchar* _tmp0_ = NULL;
#line 89 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv = PUBLISHING_TUMBLR_TUMBLR_PUBLISHER_GET_PRIVATE (self);
#line 92 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->progress_reporter = NULL;
#line 93 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->running = FALSE;
#line 94 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->was_started = FALSE;
#line 95 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->session = NULL;
#line 96 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->publishing_options_pane = NULL;
#line 97 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->sizes = NULL;
#line 97 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->sizes_length1 = 0;
#line 97 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->_sizes_size_ = self->priv->sizes_length1;
#line 98 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->blogs = NULL;
#line 98 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->blogs_length1 = 0;
#line 98 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->_blogs_size_ = self->priv->blogs_length1;
#line 99 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = g_strdup ("");
#line 99 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->username = _tmp0_;
#line 8305 "TumblrPublishing.c"
}


static void publishing_tumblr_tumblr_publisher_finalize (GObject* obj) {
	PublishingTumblrTumblrPublisher * self;
	PublishingTumblrTumblrPublisherSession* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
#line 89 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_TUMBLR_TYPE_TUMBLR_PUBLISHER, PublishingTumblrTumblrPublisher);
#line 135 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_tmp0_ = self->priv->session;
#line 135 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_signal_parse_name ("authenticated", PUBLISHING_REST_SUPPORT_TYPE_SESSION, &_tmp1_, NULL, FALSE);
#line 135 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	g_signal_handlers_disconnect_matched (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession), G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_tumblr_tumblr_publisher_on_session_authenticated_publishing_rest_support_session_authenticated, self);
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_object_unref0 (self->priv->service);
#line 91 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_object_unref0 (self->priv->host);
#line 92 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	(self->priv->progress_reporter_target_destroy_notify == NULL) ? NULL : (self->priv->progress_reporter_target_destroy_notify (self->priv->progress_reporter_target), NULL);
#line 92 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->progress_reporter = NULL;
#line 92 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->progress_reporter_target = NULL;
#line 92 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->progress_reporter_target_destroy_notify = NULL;
#line 95 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_publishing_rest_support_session_unref0 (self->priv->session);
#line 96 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_object_unref0 (self->priv->publishing_options_pane);
#line 97 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->sizes = (_vala_array_free (self->priv->sizes, self->priv->sizes_length1, (GDestroyNotify) publishing_tumblr_size_entry_unref), NULL);
#line 98 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	self->priv->blogs = (_vala_array_free (self->priv->blogs, self->priv->blogs_length1, (GDestroyNotify) publishing_tumblr_blog_entry_unref), NULL);
#line 99 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	_g_free0 (self->priv->username);
#line 89 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/TumblrPublishing.vala"
	G_OBJECT_CLASS (publishing_tumblr_tumblr_publisher_parent_class)->finalize (obj);
#line 8345 "TumblrPublishing.c"
}


GType publishing_tumblr_tumblr_publisher_get_type (void) {
	static volatile gsize publishing_tumblr_tumblr_publisher_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_tumblr_tumblr_publisher_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingTumblrTumblrPublisherClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_tumblr_tumblr_publisher_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingTumblrTumblrPublisher), 0, (GInstanceInitFunc) publishing_tumblr_tumblr_publisher_instance_init, NULL };
		static const GInterfaceInfo spit_publishing_publisher_info = { (GInterfaceInitFunc) publishing_tumblr_tumblr_publisher_spit_publishing_publisher_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType publishing_tumblr_tumblr_publisher_type_id;
		publishing_tumblr_tumblr_publisher_type_id = g_type_register_static (G_TYPE_OBJECT, "PublishingTumblrTumblrPublisher", &g_define_type_info, 0);
		g_type_add_interface_static (publishing_tumblr_tumblr_publisher_type_id, SPIT_PUBLISHING_TYPE_PUBLISHER, &spit_publishing_publisher_info);
		g_once_init_leave (&publishing_tumblr_tumblr_publisher_type_id__volatile, publishing_tumblr_tumblr_publisher_type_id);
	}
	return publishing_tumblr_tumblr_publisher_type_id__volatile;
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}


static gint _vala_array_length (gpointer array) {
	int length;
	length = 0;
	if (array) {
		while (((gpointer*) array)[length]) {
			length++;
		}
	}
	return length;
}



