/* FacebookPublishing.c generated by valac 0.32.1, the Vala compiler
 * generated from FacebookPublishing.vala, do not modify */

/* Copyright 2016 Software Freedom Conservancy Inc.
 *
 * This software is licensed under the GNU Lesser General Public License
 * (version 2.1 or later).  See the COPYING file in this distribution.
 */

#include <glib.h>
#include <glib-object.h>
#include <shotwell-plugin-dev-1.0.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <stdlib.h>
#include <string.h>
#include <gio/gio.h>
#include "shotwell-plugin-common.h"
#include <glib/gi18n-lib.h>
#include <json-glib/json-glib.h>
#include <gtk/gtk.h>
#include <libsoup/soup.h>
#include <float.h>
#include <math.h>
#include <webkit2/webkit2.h>
#include <gdk/gdk.h>
#include <locale.h>
#include <gobject/gvaluecollector.h>


#define TYPE_FACEBOOK_SERVICE (facebook_service_get_type ())
#define FACEBOOK_SERVICE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_FACEBOOK_SERVICE, FacebookService))
#define FACEBOOK_SERVICE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_FACEBOOK_SERVICE, FacebookServiceClass))
#define IS_FACEBOOK_SERVICE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_FACEBOOK_SERVICE))
#define IS_FACEBOOK_SERVICE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_FACEBOOK_SERVICE))
#define FACEBOOK_SERVICE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_FACEBOOK_SERVICE, FacebookServiceClass))

typedef struct _FacebookService FacebookService;
typedef struct _FacebookServiceClass FacebookServiceClass;
typedef struct _FacebookServicePrivate FacebookServicePrivate;
#define _g_free0(var) (var = (g_free (var), NULL))

#define PUBLISHING_FACEBOOK_TYPE_FACEBOOK_PUBLISHER (publishing_facebook_facebook_publisher_get_type ())
#define PUBLISHING_FACEBOOK_FACEBOOK_PUBLISHER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_FACEBOOK_TYPE_FACEBOOK_PUBLISHER, PublishingFacebookFacebookPublisher))
#define PUBLISHING_FACEBOOK_FACEBOOK_PUBLISHER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_FACEBOOK_TYPE_FACEBOOK_PUBLISHER, PublishingFacebookFacebookPublisherClass))
#define PUBLISHING_FACEBOOK_IS_FACEBOOK_PUBLISHER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_FACEBOOK_TYPE_FACEBOOK_PUBLISHER))
#define PUBLISHING_FACEBOOK_IS_FACEBOOK_PUBLISHER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_FACEBOOK_TYPE_FACEBOOK_PUBLISHER))
#define PUBLISHING_FACEBOOK_FACEBOOK_PUBLISHER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_FACEBOOK_TYPE_FACEBOOK_PUBLISHER, PublishingFacebookFacebookPublisherClass))

typedef struct _PublishingFacebookFacebookPublisher PublishingFacebookFacebookPublisher;
typedef struct _PublishingFacebookFacebookPublisherClass PublishingFacebookFacebookPublisherClass;

#define PUBLISHING_FACEBOOK_TYPE_ALBUM (publishing_facebook_album_get_type ())
#define PUBLISHING_FACEBOOK_ALBUM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_FACEBOOK_TYPE_ALBUM, PublishingFacebookAlbum))
#define PUBLISHING_FACEBOOK_ALBUM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_FACEBOOK_TYPE_ALBUM, PublishingFacebookAlbumClass))
#define PUBLISHING_FACEBOOK_IS_ALBUM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_FACEBOOK_TYPE_ALBUM))
#define PUBLISHING_FACEBOOK_IS_ALBUM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_FACEBOOK_TYPE_ALBUM))
#define PUBLISHING_FACEBOOK_ALBUM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_FACEBOOK_TYPE_ALBUM, PublishingFacebookAlbumClass))

typedef struct _PublishingFacebookAlbum PublishingFacebookAlbum;
typedef struct _PublishingFacebookAlbumClass PublishingFacebookAlbumClass;
typedef struct _PublishingFacebookAlbumPrivate PublishingFacebookAlbumPrivate;
typedef struct _PublishingFacebookParamSpecAlbum PublishingFacebookParamSpecAlbum;

#define PUBLISHING_FACEBOOK_TYPE_RESOLUTION (publishing_facebook_resolution_get_type ())

#define PUBLISHING_FACEBOOK_TYPE_PUBLISHING_PARAMETERS (publishing_facebook_publishing_parameters_get_type ())
#define PUBLISHING_FACEBOOK_PUBLISHING_PARAMETERS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_FACEBOOK_TYPE_PUBLISHING_PARAMETERS, PublishingFacebookPublishingParameters))
#define PUBLISHING_FACEBOOK_PUBLISHING_PARAMETERS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_FACEBOOK_TYPE_PUBLISHING_PARAMETERS, PublishingFacebookPublishingParametersClass))
#define PUBLISHING_FACEBOOK_IS_PUBLISHING_PARAMETERS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_FACEBOOK_TYPE_PUBLISHING_PARAMETERS))
#define PUBLISHING_FACEBOOK_IS_PUBLISHING_PARAMETERS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_FACEBOOK_TYPE_PUBLISHING_PARAMETERS))
#define PUBLISHING_FACEBOOK_PUBLISHING_PARAMETERS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_FACEBOOK_TYPE_PUBLISHING_PARAMETERS, PublishingFacebookPublishingParametersClass))

typedef struct _PublishingFacebookPublishingParameters PublishingFacebookPublishingParameters;
typedef struct _PublishingFacebookPublishingParametersClass PublishingFacebookPublishingParametersClass;
typedef struct _PublishingFacebookPublishingParametersPrivate PublishingFacebookPublishingParametersPrivate;
#define _publishing_facebook_album_unref0(var) ((var == NULL) ? NULL : (var = (publishing_facebook_album_unref (var), NULL)))
typedef struct _PublishingFacebookParamSpecPublishingParameters PublishingFacebookParamSpecPublishingParameters;
typedef struct _PublishingFacebookFacebookPublisherPrivate PublishingFacebookFacebookPublisherPrivate;

#define PUBLISHING_FACEBOOK_TYPE_WEB_AUTHENTICATION_PANE (publishing_facebook_web_authentication_pane_get_type ())
#define PUBLISHING_FACEBOOK_WEB_AUTHENTICATION_PANE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_FACEBOOK_TYPE_WEB_AUTHENTICATION_PANE, PublishingFacebookWebAuthenticationPane))
#define PUBLISHING_FACEBOOK_WEB_AUTHENTICATION_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_FACEBOOK_TYPE_WEB_AUTHENTICATION_PANE, PublishingFacebookWebAuthenticationPaneClass))
#define PUBLISHING_FACEBOOK_IS_WEB_AUTHENTICATION_PANE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_FACEBOOK_TYPE_WEB_AUTHENTICATION_PANE))
#define PUBLISHING_FACEBOOK_IS_WEB_AUTHENTICATION_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_FACEBOOK_TYPE_WEB_AUTHENTICATION_PANE))
#define PUBLISHING_FACEBOOK_WEB_AUTHENTICATION_PANE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_FACEBOOK_TYPE_WEB_AUTHENTICATION_PANE, PublishingFacebookWebAuthenticationPaneClass))

typedef struct _PublishingFacebookWebAuthenticationPane PublishingFacebookWebAuthenticationPane;
typedef struct _PublishingFacebookWebAuthenticationPaneClass PublishingFacebookWebAuthenticationPaneClass;

#define PUBLISHING_FACEBOOK_TYPE_GRAPH_SESSION (publishing_facebook_graph_session_get_type ())
#define PUBLISHING_FACEBOOK_GRAPH_SESSION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_FACEBOOK_TYPE_GRAPH_SESSION, PublishingFacebookGraphSession))
#define PUBLISHING_FACEBOOK_GRAPH_SESSION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_FACEBOOK_TYPE_GRAPH_SESSION, PublishingFacebookGraphSessionClass))
#define PUBLISHING_FACEBOOK_IS_GRAPH_SESSION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_FACEBOOK_TYPE_GRAPH_SESSION))
#define PUBLISHING_FACEBOOK_IS_GRAPH_SESSION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_FACEBOOK_TYPE_GRAPH_SESSION))
#define PUBLISHING_FACEBOOK_GRAPH_SESSION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_FACEBOOK_TYPE_GRAPH_SESSION, PublishingFacebookGraphSessionClass))

typedef struct _PublishingFacebookGraphSession PublishingFacebookGraphSession;
typedef struct _PublishingFacebookGraphSessionClass PublishingFacebookGraphSessionClass;

#define PUBLISHING_FACEBOOK_TYPE_PUBLISHING_OPTIONS_PANE (publishing_facebook_publishing_options_pane_get_type ())
#define PUBLISHING_FACEBOOK_PUBLISHING_OPTIONS_PANE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_FACEBOOK_TYPE_PUBLISHING_OPTIONS_PANE, PublishingFacebookPublishingOptionsPane))
#define PUBLISHING_FACEBOOK_PUBLISHING_OPTIONS_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_FACEBOOK_TYPE_PUBLISHING_OPTIONS_PANE, PublishingFacebookPublishingOptionsPaneClass))
#define PUBLISHING_FACEBOOK_IS_PUBLISHING_OPTIONS_PANE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_FACEBOOK_TYPE_PUBLISHING_OPTIONS_PANE))
#define PUBLISHING_FACEBOOK_IS_PUBLISHING_OPTIONS_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_FACEBOOK_TYPE_PUBLISHING_OPTIONS_PANE))
#define PUBLISHING_FACEBOOK_PUBLISHING_OPTIONS_PANE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_FACEBOOK_TYPE_PUBLISHING_OPTIONS_PANE, PublishingFacebookPublishingOptionsPaneClass))

typedef struct _PublishingFacebookPublishingOptionsPane PublishingFacebookPublishingOptionsPane;
typedef struct _PublishingFacebookPublishingOptionsPaneClass PublishingFacebookPublishingOptionsPaneClass;

#define PUBLISHING_FACEBOOK_TYPE_UPLOADER (publishing_facebook_uploader_get_type ())
#define PUBLISHING_FACEBOOK_UPLOADER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_FACEBOOK_TYPE_UPLOADER, PublishingFacebookUploader))
#define PUBLISHING_FACEBOOK_UPLOADER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_FACEBOOK_TYPE_UPLOADER, PublishingFacebookUploaderClass))
#define PUBLISHING_FACEBOOK_IS_UPLOADER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_FACEBOOK_TYPE_UPLOADER))
#define PUBLISHING_FACEBOOK_IS_UPLOADER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_FACEBOOK_TYPE_UPLOADER))
#define PUBLISHING_FACEBOOK_UPLOADER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_FACEBOOK_TYPE_UPLOADER, PublishingFacebookUploaderClass))

typedef struct _PublishingFacebookUploader PublishingFacebookUploader;
typedef struct _PublishingFacebookUploaderClass PublishingFacebookUploaderClass;
#define _publishing_facebook_publishing_parameters_unref0(var) ((var == NULL) ? NULL : (var = (publishing_facebook_publishing_parameters_unref (var), NULL)))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _publishing_facebook_graph_session_unref0(var) ((var == NULL) ? NULL : (var = (publishing_facebook_graph_session_unref (var), NULL)))
#define _publishing_facebook_uploader_unref0(var) ((var == NULL) ? NULL : (var = (publishing_facebook_uploader_unref (var), NULL)))

#define PUBLISHING_FACEBOOK_TYPE_GRAPH_MESSAGE (publishing_facebook_graph_message_get_type ())
#define PUBLISHING_FACEBOOK_GRAPH_MESSAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_FACEBOOK_TYPE_GRAPH_MESSAGE, PublishingFacebookGraphMessage))
#define PUBLISHING_FACEBOOK_GRAPH_MESSAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_FACEBOOK_TYPE_GRAPH_MESSAGE, PublishingFacebookGraphMessageClass))
#define PUBLISHING_FACEBOOK_IS_GRAPH_MESSAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_FACEBOOK_TYPE_GRAPH_MESSAGE))
#define PUBLISHING_FACEBOOK_IS_GRAPH_MESSAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_FACEBOOK_TYPE_GRAPH_MESSAGE))
#define PUBLISHING_FACEBOOK_GRAPH_MESSAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_FACEBOOK_TYPE_GRAPH_MESSAGE, PublishingFacebookGraphMessageClass))

typedef struct _PublishingFacebookGraphMessage PublishingFacebookGraphMessage;
typedef struct _PublishingFacebookGraphMessageClass PublishingFacebookGraphMessageClass;
#define _publishing_facebook_graph_message_unref0(var) ((var == NULL) ? NULL : (var = (publishing_facebook_graph_message_unref (var), NULL)))
#define _json_object_unref0(var) ((var == NULL) ? NULL : (var = (json_object_unref (var), NULL)))
#define __vala_JsonNode_free0(var) ((var == NULL) ? NULL : (var = (_vala_JsonNode_free (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
#define _json_array_unref0(var) ((var == NULL) ? NULL : (var = (json_array_unref (var), NULL)))
#define _g_regex_unref0(var) ((var == NULL) ? NULL : (var = (g_regex_unref (var), NULL)))
typedef struct _PublishingFacebookWebAuthenticationPanePrivate PublishingFacebookWebAuthenticationPanePrivate;

#define PUBLISHING_FACEBOOK_WEB_AUTHENTICATION_PANE_TYPE_LOCALE_LOOKUP (publishing_facebook_web_authentication_pane_locale_lookup_get_type ())
#define PUBLISHING_FACEBOOK_WEB_AUTHENTICATION_PANE_LOCALE_LOOKUP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_FACEBOOK_WEB_AUTHENTICATION_PANE_TYPE_LOCALE_LOOKUP, PublishingFacebookWebAuthenticationPaneLocaleLookup))
#define PUBLISHING_FACEBOOK_WEB_AUTHENTICATION_PANE_LOCALE_LOOKUP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_FACEBOOK_WEB_AUTHENTICATION_PANE_TYPE_LOCALE_LOOKUP, PublishingFacebookWebAuthenticationPaneLocaleLookupClass))
#define PUBLISHING_FACEBOOK_WEB_AUTHENTICATION_PANE_IS_LOCALE_LOOKUP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_FACEBOOK_WEB_AUTHENTICATION_PANE_TYPE_LOCALE_LOOKUP))
#define PUBLISHING_FACEBOOK_WEB_AUTHENTICATION_PANE_IS_LOCALE_LOOKUP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_FACEBOOK_WEB_AUTHENTICATION_PANE_TYPE_LOCALE_LOOKUP))
#define PUBLISHING_FACEBOOK_WEB_AUTHENTICATION_PANE_LOCALE_LOOKUP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_FACEBOOK_WEB_AUTHENTICATION_PANE_TYPE_LOCALE_LOOKUP, PublishingFacebookWebAuthenticationPaneLocaleLookupClass))

typedef struct _PublishingFacebookWebAuthenticationPaneLocaleLookup PublishingFacebookWebAuthenticationPaneLocaleLookup;
typedef struct _PublishingFacebookWebAuthenticationPaneLocaleLookupClass PublishingFacebookWebAuthenticationPaneLocaleLookupClass;
typedef struct _PublishingFacebookWebAuthenticationPaneLocaleLookupPrivate PublishingFacebookWebAuthenticationPaneLocaleLookupPrivate;
#define _publishing_facebook_web_authentication_pane_locale_lookup_unref0(var) ((var == NULL) ? NULL : (var = (publishing_facebook_web_authentication_pane_locale_lookup_unref (var), NULL)))
typedef struct _PublishingFacebookWebAuthenticationPaneParamSpecLocaleLookup PublishingFacebookWebAuthenticationPaneParamSpecLocaleLookup;
typedef struct _PublishingFacebookPublishingOptionsPanePrivate PublishingFacebookPublishingOptionsPanePrivate;

#define PUBLISHING_FACEBOOK_PUBLISHING_OPTIONS_PANE_TYPE_PRIVACY_DESCRIPTION (publishing_facebook_publishing_options_pane_privacy_description_get_type ())
#define PUBLISHING_FACEBOOK_PUBLISHING_OPTIONS_PANE_PRIVACY_DESCRIPTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_FACEBOOK_PUBLISHING_OPTIONS_PANE_TYPE_PRIVACY_DESCRIPTION, PublishingFacebookPublishingOptionsPanePrivacyDescription))
#define PUBLISHING_FACEBOOK_PUBLISHING_OPTIONS_PANE_PRIVACY_DESCRIPTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_FACEBOOK_PUBLISHING_OPTIONS_PANE_TYPE_PRIVACY_DESCRIPTION, PublishingFacebookPublishingOptionsPanePrivacyDescriptionClass))
#define PUBLISHING_FACEBOOK_PUBLISHING_OPTIONS_PANE_IS_PRIVACY_DESCRIPTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_FACEBOOK_PUBLISHING_OPTIONS_PANE_TYPE_PRIVACY_DESCRIPTION))
#define PUBLISHING_FACEBOOK_PUBLISHING_OPTIONS_PANE_IS_PRIVACY_DESCRIPTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_FACEBOOK_PUBLISHING_OPTIONS_PANE_TYPE_PRIVACY_DESCRIPTION))
#define PUBLISHING_FACEBOOK_PUBLISHING_OPTIONS_PANE_PRIVACY_DESCRIPTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_FACEBOOK_PUBLISHING_OPTIONS_PANE_TYPE_PRIVACY_DESCRIPTION, PublishingFacebookPublishingOptionsPanePrivacyDescriptionClass))

typedef struct _PublishingFacebookPublishingOptionsPanePrivacyDescription PublishingFacebookPublishingOptionsPanePrivacyDescription;
typedef struct _PublishingFacebookPublishingOptionsPanePrivacyDescriptionClass PublishingFacebookPublishingOptionsPanePrivacyDescriptionClass;
#define _g_slist_free0(var) ((var == NULL) ? NULL : (var = (g_slist_free (var), NULL)))
typedef struct _PublishingFacebookPublishingOptionsPanePrivacyDescriptionPrivate PublishingFacebookPublishingOptionsPanePrivacyDescriptionPrivate;
#define _publishing_facebook_publishing_options_pane_privacy_description_unref0(var) ((var == NULL) ? NULL : (var = (publishing_facebook_publishing_options_pane_privacy_description_unref (var), NULL)))
typedef struct _PublishingFacebookPublishingOptionsPaneParamSpecPrivacyDescription PublishingFacebookPublishingOptionsPaneParamSpecPrivacyDescription;

#define PUBLISHING_FACEBOOK_TYPE_ENDPOINT (publishing_facebook_endpoint_get_type ())
typedef struct _PublishingFacebookGraphMessagePrivate PublishingFacebookGraphMessagePrivate;
typedef struct _PublishingFacebookParamSpecGraphMessage PublishingFacebookParamSpecGraphMessage;
typedef struct _PublishingFacebookGraphSessionPrivate PublishingFacebookGraphSessionPrivate;

#define PUBLISHING_FACEBOOK_GRAPH_SESSION_TYPE_GRAPH_MESSAGE_IMPL (publishing_facebook_graph_session_graph_message_impl_get_type ())
#define PUBLISHING_FACEBOOK_GRAPH_SESSION_GRAPH_MESSAGE_IMPL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_FACEBOOK_GRAPH_SESSION_TYPE_GRAPH_MESSAGE_IMPL, PublishingFacebookGraphSessionGraphMessageImpl))
#define PUBLISHING_FACEBOOK_GRAPH_SESSION_GRAPH_MESSAGE_IMPL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_FACEBOOK_GRAPH_SESSION_TYPE_GRAPH_MESSAGE_IMPL, PublishingFacebookGraphSessionGraphMessageImplClass))
#define PUBLISHING_FACEBOOK_GRAPH_SESSION_IS_GRAPH_MESSAGE_IMPL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_FACEBOOK_GRAPH_SESSION_TYPE_GRAPH_MESSAGE_IMPL))
#define PUBLISHING_FACEBOOK_GRAPH_SESSION_IS_GRAPH_MESSAGE_IMPL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_FACEBOOK_GRAPH_SESSION_TYPE_GRAPH_MESSAGE_IMPL))
#define PUBLISHING_FACEBOOK_GRAPH_SESSION_GRAPH_MESSAGE_IMPL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_FACEBOOK_GRAPH_SESSION_TYPE_GRAPH_MESSAGE_IMPL, PublishingFacebookGraphSessionGraphMessageImplClass))

typedef struct _PublishingFacebookGraphSessionGraphMessageImpl PublishingFacebookGraphSessionGraphMessageImpl;
typedef struct _PublishingFacebookGraphSessionGraphMessageImplClass PublishingFacebookGraphSessionGraphMessageImplClass;
typedef struct _PublishingFacebookGraphSessionGraphMessageImplPrivate PublishingFacebookGraphSessionGraphMessageImplPrivate;

#define PUBLISHING_FACEBOOK_GRAPH_SESSION_TYPE_GRAPH_ENDPOINT_PROBE_MESSAGE (publishing_facebook_graph_session_graph_endpoint_probe_message_get_type ())
#define PUBLISHING_FACEBOOK_GRAPH_SESSION_GRAPH_ENDPOINT_PROBE_MESSAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_FACEBOOK_GRAPH_SESSION_TYPE_GRAPH_ENDPOINT_PROBE_MESSAGE, PublishingFacebookGraphSessionGraphEndpointProbeMessage))
#define PUBLISHING_FACEBOOK_GRAPH_SESSION_GRAPH_ENDPOINT_PROBE_MESSAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_FACEBOOK_GRAPH_SESSION_TYPE_GRAPH_ENDPOINT_PROBE_MESSAGE, PublishingFacebookGraphSessionGraphEndpointProbeMessageClass))
#define PUBLISHING_FACEBOOK_GRAPH_SESSION_IS_GRAPH_ENDPOINT_PROBE_MESSAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_FACEBOOK_GRAPH_SESSION_TYPE_GRAPH_ENDPOINT_PROBE_MESSAGE))
#define PUBLISHING_FACEBOOK_GRAPH_SESSION_IS_GRAPH_ENDPOINT_PROBE_MESSAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_FACEBOOK_GRAPH_SESSION_TYPE_GRAPH_ENDPOINT_PROBE_MESSAGE))
#define PUBLISHING_FACEBOOK_GRAPH_SESSION_GRAPH_ENDPOINT_PROBE_MESSAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_FACEBOOK_GRAPH_SESSION_TYPE_GRAPH_ENDPOINT_PROBE_MESSAGE, PublishingFacebookGraphSessionGraphEndpointProbeMessageClass))

typedef struct _PublishingFacebookGraphSessionGraphEndpointProbeMessage PublishingFacebookGraphSessionGraphEndpointProbeMessage;
typedef struct _PublishingFacebookGraphSessionGraphEndpointProbeMessageClass PublishingFacebookGraphSessionGraphEndpointProbeMessageClass;

#define PUBLISHING_FACEBOOK_GRAPH_SESSION_TYPE_GRAPH_QUERY_MESSAGE (publishing_facebook_graph_session_graph_query_message_get_type ())
#define PUBLISHING_FACEBOOK_GRAPH_SESSION_GRAPH_QUERY_MESSAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_FACEBOOK_GRAPH_SESSION_TYPE_GRAPH_QUERY_MESSAGE, PublishingFacebookGraphSessionGraphQueryMessage))
#define PUBLISHING_FACEBOOK_GRAPH_SESSION_GRAPH_QUERY_MESSAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_FACEBOOK_GRAPH_SESSION_TYPE_GRAPH_QUERY_MESSAGE, PublishingFacebookGraphSessionGraphQueryMessageClass))
#define PUBLISHING_FACEBOOK_GRAPH_SESSION_IS_GRAPH_QUERY_MESSAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_FACEBOOK_GRAPH_SESSION_TYPE_GRAPH_QUERY_MESSAGE))
#define PUBLISHING_FACEBOOK_GRAPH_SESSION_IS_GRAPH_QUERY_MESSAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_FACEBOOK_GRAPH_SESSION_TYPE_GRAPH_QUERY_MESSAGE))
#define PUBLISHING_FACEBOOK_GRAPH_SESSION_GRAPH_QUERY_MESSAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_FACEBOOK_GRAPH_SESSION_TYPE_GRAPH_QUERY_MESSAGE, PublishingFacebookGraphSessionGraphQueryMessageClass))

typedef struct _PublishingFacebookGraphSessionGraphQueryMessage PublishingFacebookGraphSessionGraphQueryMessage;
typedef struct _PublishingFacebookGraphSessionGraphQueryMessageClass PublishingFacebookGraphSessionGraphQueryMessageClass;

#define PUBLISHING_FACEBOOK_GRAPH_SESSION_TYPE_GRAPH_UPLOAD_MESSAGE (publishing_facebook_graph_session_graph_upload_message_get_type ())
#define PUBLISHING_FACEBOOK_GRAPH_SESSION_GRAPH_UPLOAD_MESSAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_FACEBOOK_GRAPH_SESSION_TYPE_GRAPH_UPLOAD_MESSAGE, PublishingFacebookGraphSessionGraphUploadMessage))
#define PUBLISHING_FACEBOOK_GRAPH_SESSION_GRAPH_UPLOAD_MESSAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_FACEBOOK_GRAPH_SESSION_TYPE_GRAPH_UPLOAD_MESSAGE, PublishingFacebookGraphSessionGraphUploadMessageClass))
#define PUBLISHING_FACEBOOK_GRAPH_SESSION_IS_GRAPH_UPLOAD_MESSAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_FACEBOOK_GRAPH_SESSION_TYPE_GRAPH_UPLOAD_MESSAGE))
#define PUBLISHING_FACEBOOK_GRAPH_SESSION_IS_GRAPH_UPLOAD_MESSAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_FACEBOOK_GRAPH_SESSION_TYPE_GRAPH_UPLOAD_MESSAGE))
#define PUBLISHING_FACEBOOK_GRAPH_SESSION_GRAPH_UPLOAD_MESSAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_FACEBOOK_GRAPH_SESSION_TYPE_GRAPH_UPLOAD_MESSAGE, PublishingFacebookGraphSessionGraphUploadMessageClass))

typedef struct _PublishingFacebookGraphSessionGraphUploadMessage PublishingFacebookGraphSessionGraphUploadMessage;
typedef struct _PublishingFacebookGraphSessionGraphUploadMessageClass PublishingFacebookGraphSessionGraphUploadMessageClass;

#define PUBLISHING_FACEBOOK_GRAPH_SESSION_TYPE_GRAPH_CREATE_ALBUM_MESSAGE (publishing_facebook_graph_session_graph_create_album_message_get_type ())
#define PUBLISHING_FACEBOOK_GRAPH_SESSION_GRAPH_CREATE_ALBUM_MESSAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_FACEBOOK_GRAPH_SESSION_TYPE_GRAPH_CREATE_ALBUM_MESSAGE, PublishingFacebookGraphSessionGraphCreateAlbumMessage))
#define PUBLISHING_FACEBOOK_GRAPH_SESSION_GRAPH_CREATE_ALBUM_MESSAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_FACEBOOK_GRAPH_SESSION_TYPE_GRAPH_CREATE_ALBUM_MESSAGE, PublishingFacebookGraphSessionGraphCreateAlbumMessageClass))
#define PUBLISHING_FACEBOOK_GRAPH_SESSION_IS_GRAPH_CREATE_ALBUM_MESSAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_FACEBOOK_GRAPH_SESSION_TYPE_GRAPH_CREATE_ALBUM_MESSAGE))
#define PUBLISHING_FACEBOOK_GRAPH_SESSION_IS_GRAPH_CREATE_ALBUM_MESSAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_FACEBOOK_GRAPH_SESSION_TYPE_GRAPH_CREATE_ALBUM_MESSAGE))
#define PUBLISHING_FACEBOOK_GRAPH_SESSION_GRAPH_CREATE_ALBUM_MESSAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_FACEBOOK_GRAPH_SESSION_TYPE_GRAPH_CREATE_ALBUM_MESSAGE, PublishingFacebookGraphSessionGraphCreateAlbumMessageClass))

typedef struct _PublishingFacebookGraphSessionGraphCreateAlbumMessage PublishingFacebookGraphSessionGraphCreateAlbumMessage;
typedef struct _PublishingFacebookGraphSessionGraphCreateAlbumMessageClass PublishingFacebookGraphSessionGraphCreateAlbumMessageClass;
typedef struct _PublishingFacebookGraphSessionGraphQueryMessagePrivate PublishingFacebookGraphSessionGraphQueryMessagePrivate;
#define __vala_SoupURI_free0(var) ((var == NULL) ? NULL : (var = (_vala_SoupURI_free (var), NULL)))
typedef struct _PublishingFacebookGraphSessionGraphEndpointProbeMessagePrivate PublishingFacebookGraphSessionGraphEndpointProbeMessagePrivate;
typedef struct _PublishingFacebookGraphSessionGraphUploadMessagePrivate PublishingFacebookGraphSessionGraphUploadMessagePrivate;
#define _g_mapped_file_unref0(var) ((var == NULL) ? NULL : (var = (g_mapped_file_unref (var), NULL)))
#define _g_date_time_unref0(var) ((var == NULL) ? NULL : (var = (g_date_time_unref (var), NULL)))
#define __vala_SoupMultipart_free0(var) ((var == NULL) ? NULL : (var = (_vala_SoupMultipart_free (var), NULL)))
#define __vala_SoupBuffer_free0(var) ((var == NULL) ? NULL : (var = (_vala_SoupBuffer_free (var), NULL)))
typedef struct _PublishingFacebookGraphSessionGraphCreateAlbumMessagePrivate PublishingFacebookGraphSessionGraphCreateAlbumMessagePrivate;
typedef struct _PublishingFacebookParamSpecGraphSession PublishingFacebookParamSpecGraphSession;
typedef struct _PublishingFacebookUploaderPrivate PublishingFacebookUploaderPrivate;
typedef struct _PublishingFacebookParamSpecUploader PublishingFacebookParamSpecUploader;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _FacebookService {
	GObject parent_instance;
	FacebookServicePrivate * priv;
};

struct _FacebookServiceClass {
	GObjectClass parent_class;
};

struct _PublishingFacebookAlbum {
	GTypeInstance parent_instance;
	volatile int ref_count;
	PublishingFacebookAlbumPrivate * priv;
	gchar* name;
	gchar* id;
};

struct _PublishingFacebookAlbumClass {
	GTypeClass parent_class;
	void (*finalize) (PublishingFacebookAlbum *self);
};

struct _PublishingFacebookParamSpecAlbum {
	GParamSpec parent_instance;
};

typedef enum  {
	PUBLISHING_FACEBOOK_RESOLUTION_STANDARD,
	PUBLISHING_FACEBOOK_RESOLUTION_HIGH
} PublishingFacebookResolution;

struct _PublishingFacebookPublishingParameters {
	GTypeInstance parent_instance;
	volatile int ref_count;
	PublishingFacebookPublishingParametersPrivate * priv;
	gboolean strip_metadata;
	PublishingFacebookAlbum** albums;
	gint albums_length1;
	gint _albums_size_;
	gint target_album;
	gchar* new_album_name;
	gchar* privacy_object;
	PublishingFacebookResolution resolution;
};

struct _PublishingFacebookPublishingParametersClass {
	GTypeClass parent_class;
	void (*finalize) (PublishingFacebookPublishingParameters *self);
};

struct _PublishingFacebookParamSpecPublishingParameters {
	GParamSpec parent_instance;
};

struct _PublishingFacebookFacebookPublisher {
	GObject parent_instance;
	PublishingFacebookFacebookPublisherPrivate * priv;
};

struct _PublishingFacebookFacebookPublisherClass {
	GObjectClass parent_class;
};

struct _PublishingFacebookFacebookPublisherPrivate {
	PublishingFacebookPublishingParameters* publishing_params;
	SpitPublishingPluginHost* host;
	PublishingFacebookWebAuthenticationPane* web_auth_pane;
	SpitPublishingProgressCallback progress_reporter;
	gpointer progress_reporter_target;
	GDestroyNotify progress_reporter_target_destroy_notify;
	SpitPublishingService* service;
	gboolean running;
	PublishingFacebookGraphSession* graph_session;
	PublishingFacebookPublishingOptionsPane* publishing_options_pane;
	PublishingFacebookUploader* uploader;
	gchar* uid;
	gchar* username;
};

struct _PublishingFacebookWebAuthenticationPane {
	GObject parent_instance;
	PublishingFacebookWebAuthenticationPanePrivate * priv;
};

struct _PublishingFacebookWebAuthenticationPaneClass {
	GObjectClass parent_class;
};

struct _PublishingFacebookWebAuthenticationPanePrivate {
	WebKitWebView* webview;
	GtkBox* pane_widget;
	GtkScrolledWindow* webview_frame;
	PublishingFacebookWebAuthenticationPaneLocaleLookup** locale_lookup_table;
	gint locale_lookup_table_length1;
	gint _locale_lookup_table_size_;
};

struct _PublishingFacebookWebAuthenticationPaneLocaleLookup {
	GTypeInstance parent_instance;
	volatile int ref_count;
	PublishingFacebookWebAuthenticationPaneLocaleLookupPrivate * priv;
	gchar* prefix;
	gchar* translation;
	gchar* exception_code;
	gchar* exception_translation;
	gchar* exception_code_2;
	gchar* exception_translation_2;
};

struct _PublishingFacebookWebAuthenticationPaneLocaleLookupClass {
	GTypeClass parent_class;
	void (*finalize) (PublishingFacebookWebAuthenticationPaneLocaleLookup *self);
};

struct _PublishingFacebookWebAuthenticationPaneParamSpecLocaleLookup {
	GParamSpec parent_instance;
};

struct _PublishingFacebookPublishingOptionsPane {
	GObject parent_instance;
	PublishingFacebookPublishingOptionsPanePrivate * priv;
};

struct _PublishingFacebookPublishingOptionsPaneClass {
	GObjectClass parent_class;
};

struct _PublishingFacebookPublishingOptionsPanePrivate {
	GtkBuilder* builder;
	GtkBox* pane_widget;
	GtkRadioButton* use_existing_radio;
	GtkRadioButton* create_new_radio;
	GtkComboBoxText* existing_albums_combo;
	GtkComboBoxText* visibility_combo;
	GtkEntry* new_album_entry;
	GtkCheckButton* strip_metadata_check;
	GtkButton* publish_button;
	GtkButton* logout_button;
	GtkLabel* how_to_label;
	PublishingFacebookAlbum** albums;
	gint albums_length1;
	gint _albums_size_;
	PublishingFacebookFacebookPublisher* publisher;
	PublishingFacebookPublishingOptionsPanePrivacyDescription** privacy_descriptions;
	gint privacy_descriptions_length1;
	gint _privacy_descriptions_size_;
	PublishingFacebookResolution* possible_resolutions;
	gint possible_resolutions_length1;
	gint _possible_resolutions_size_;
	GtkComboBoxText* resolution_combo;
	SpitPublishingPublisherMediaType media_type;
};

struct _PublishingFacebookPublishingOptionsPanePrivacyDescription {
	GTypeInstance parent_instance;
	volatile int ref_count;
	PublishingFacebookPublishingOptionsPanePrivacyDescriptionPrivate * priv;
	gchar* description;
	gchar* privacy_setting;
};

struct _PublishingFacebookPublishingOptionsPanePrivacyDescriptionClass {
	GTypeClass parent_class;
	void (*finalize) (PublishingFacebookPublishingOptionsPanePrivacyDescription *self);
};

struct _PublishingFacebookPublishingOptionsPaneParamSpecPrivacyDescription {
	GParamSpec parent_instance;
};

typedef enum  {
	PUBLISHING_FACEBOOK_ENDPOINT_DEFAULT,
	PUBLISHING_FACEBOOK_ENDPOINT_VIDEO,
	PUBLISHING_FACEBOOK_ENDPOINT_TEST_CONNECTION
} PublishingFacebookEndpoint;

struct _PublishingFacebookGraphMessage {
	GTypeInstance parent_instance;
	volatile int ref_count;
	PublishingFacebookGraphMessagePrivate * priv;
};

struct _PublishingFacebookGraphMessageClass {
	GTypeClass parent_class;
	void (*finalize) (PublishingFacebookGraphMessage *self);
	gchar* (*get_uri) (PublishingFacebookGraphMessage* self);
	gchar* (*get_response_body) (PublishingFacebookGraphMessage* self);
};

struct _PublishingFacebookParamSpecGraphMessage {
	GParamSpec parent_instance;
};

struct _PublishingFacebookGraphSession {
	GTypeInstance parent_instance;
	volatile int ref_count;
	PublishingFacebookGraphSessionPrivate * priv;
};

struct _PublishingFacebookGraphSessionClass {
	GTypeClass parent_class;
	void (*finalize) (PublishingFacebookGraphSession *self);
};

struct _PublishingFacebookGraphSessionPrivate {
	SoupSession* soup_session;
	gchar* access_token;
	PublishingFacebookGraphMessage* current_message;
};

struct _PublishingFacebookGraphSessionGraphMessageImpl {
	PublishingFacebookGraphMessage parent_instance;
	PublishingFacebookGraphSessionGraphMessageImplPrivate * priv;
	PublishingRESTSupportHttpMethod method;
	gchar* uri;
	gchar* access_token;
	SoupMessage* soup_message;
	PublishingFacebookGraphSession* host_session;
	gint bytes_so_far;
};

struct _PublishingFacebookGraphSessionGraphMessageImplClass {
	PublishingFacebookGraphMessageClass parent_class;
	gboolean (*prepare_for_transmission) (PublishingFacebookGraphSessionGraphMessageImpl* self);
};

struct _PublishingFacebookGraphSessionGraphQueryMessage {
	PublishingFacebookGraphSessionGraphMessageImpl parent_instance;
	PublishingFacebookGraphSessionGraphQueryMessagePrivate * priv;
};

struct _PublishingFacebookGraphSessionGraphQueryMessageClass {
	PublishingFacebookGraphSessionGraphMessageImplClass parent_class;
};

struct _PublishingFacebookGraphSessionGraphEndpointProbeMessage {
	PublishingFacebookGraphSessionGraphMessageImpl parent_instance;
	PublishingFacebookGraphSessionGraphEndpointProbeMessagePrivate * priv;
};

struct _PublishingFacebookGraphSessionGraphEndpointProbeMessageClass {
	PublishingFacebookGraphSessionGraphMessageImplClass parent_class;
};

struct _PublishingFacebookGraphSessionGraphUploadMessage {
	PublishingFacebookGraphSessionGraphMessageImpl parent_instance;
	PublishingFacebookGraphSessionGraphUploadMessagePrivate * priv;
};

struct _PublishingFacebookGraphSessionGraphUploadMessageClass {
	PublishingFacebookGraphSessionGraphMessageImplClass parent_class;
};

struct _PublishingFacebookGraphSessionGraphUploadMessagePrivate {
	GMappedFile* mapped_file;
	SpitPublishingPublishable* publishable;
};

struct _PublishingFacebookGraphSessionGraphCreateAlbumMessage {
	PublishingFacebookGraphSessionGraphMessageImpl parent_instance;
	PublishingFacebookGraphSessionGraphCreateAlbumMessagePrivate * priv;
};

struct _PublishingFacebookGraphSessionGraphCreateAlbumMessageClass {
	PublishingFacebookGraphSessionGraphMessageImplClass parent_class;
};

struct _PublishingFacebookParamSpecGraphSession {
	GParamSpec parent_instance;
};

struct _PublishingFacebookUploader {
	GTypeInstance parent_instance;
	volatile int ref_count;
	PublishingFacebookUploaderPrivate * priv;
};

struct _PublishingFacebookUploaderClass {
	GTypeClass parent_class;
	void (*finalize) (PublishingFacebookUploader *self);
};

struct _PublishingFacebookUploaderPrivate {
	gint current_file;
	SpitPublishingPublishable** publishables;
	gint publishables_length1;
	gint _publishables_size_;
	PublishingFacebookGraphSession* session;
	PublishingFacebookPublishingParameters* publishing_params;
	SpitPublishingProgressCallback status_updated;
	gpointer status_updated_target;
};

struct _PublishingFacebookParamSpecUploader {
	GParamSpec parent_instance;
};


static gpointer facebook_service_parent_class = NULL;
static GdkPixbuf** facebook_service_icon_pixbuf_set;
static gint facebook_service_icon_pixbuf_set_length1;
static GdkPixbuf** facebook_service_icon_pixbuf_set = NULL;
static gint facebook_service_icon_pixbuf_set_length1 = 0;
static gint _facebook_service_icon_pixbuf_set_size_ = 0;
static SpitPluggableIface* facebook_service_spit_pluggable_parent_iface = NULL;
static SpitPublishingServiceIface* facebook_service_spit_publishing_service_parent_iface = NULL;
static gpointer publishing_facebook_album_parent_class = NULL;
static gpointer publishing_facebook_publishing_parameters_parent_class = NULL;
static gpointer publishing_facebook_facebook_publisher_parent_class = NULL;
static SpitPublishingPublisherIface* publishing_facebook_facebook_publisher_spit_publishing_publisher_parent_iface = NULL;
static gpointer publishing_facebook_web_authentication_pane_parent_class = NULL;
static gboolean publishing_facebook_web_authentication_pane_cache_dirty;
static gboolean publishing_facebook_web_authentication_pane_cache_dirty = FALSE;
static gpointer publishing_facebook_web_authentication_pane_locale_lookup_parent_class = NULL;
static SpitPublishingDialogPaneIface* publishing_facebook_web_authentication_pane_spit_publishing_dialog_pane_parent_iface = NULL;
static gpointer publishing_facebook_publishing_options_pane_parent_class = NULL;
static gpointer publishing_facebook_publishing_options_pane_privacy_description_parent_class = NULL;
static SpitPublishingDialogPaneIface* publishing_facebook_publishing_options_pane_spit_publishing_dialog_pane_parent_iface = NULL;
static gpointer publishing_facebook_graph_message_parent_class = NULL;
static gpointer publishing_facebook_graph_session_parent_class = NULL;
static gpointer publishing_facebook_graph_session_graph_message_impl_parent_class = NULL;
static gpointer publishing_facebook_graph_session_graph_query_message_parent_class = NULL;
static gpointer publishing_facebook_graph_session_graph_endpoint_probe_message_parent_class = NULL;
static gpointer publishing_facebook_graph_session_graph_upload_message_parent_class = NULL;
static gpointer publishing_facebook_graph_session_graph_create_album_message_parent_class = NULL;
static gpointer publishing_facebook_uploader_parent_class = NULL;

GType facebook_service_get_type (void) G_GNUC_CONST;
enum  {
	FACEBOOK_SERVICE_DUMMY_PROPERTY
};
#define FACEBOOK_SERVICE_ICON_FILENAME "facebook.png"
FacebookService* facebook_service_new (GFile* resource_directory);
FacebookService* facebook_service_construct (GType object_type, GFile* resource_directory);
static gint facebook_service_real_get_pluggable_interface (SpitPluggable* base, gint min_host_interface, gint max_host_interface);
static const gchar* facebook_service_real_get_id (SpitPluggable* base);
static const gchar* facebook_service_real_get_pluggable_name (SpitPluggable* base);
static void facebook_service_real_get_info (SpitPluggable* base, SpitPluggableInfo* info);
static GdkPixbuf** _vala_array_dup1 (GdkPixbuf** self, int length);
static void facebook_service_real_activation (SpitPluggable* base, gboolean enabled);
static SpitPublishingPublisher* facebook_service_real_create_publisher (SpitPublishingService* base, SpitPublishingPluginHost* host);
PublishingFacebookFacebookPublisher* publishing_facebook_facebook_publisher_new (SpitPublishingService* service, SpitPublishingPluginHost* host);
PublishingFacebookFacebookPublisher* publishing_facebook_facebook_publisher_construct (GType object_type, SpitPublishingService* service, SpitPublishingPluginHost* host);
GType publishing_facebook_facebook_publisher_get_type (void) G_GNUC_CONST;
static SpitPublishingPublisherMediaType facebook_service_real_get_supported_media (SpitPublishingService* base);
static void facebook_service_finalize (GObject* obj);
#define PUBLISHING_FACEBOOK_SERVICE_NAME "facebook"
#define PUBLISHING_FACEBOOK_USER_VISIBLE_NAME "Facebook"
#define PUBLISHING_FACEBOOK_APPLICATION_ID "1612018629063184"
#define PUBLISHING_FACEBOOK_DEFAULT_ALBUM_NAME _ ("Shotwell Connect")
#define PUBLISHING_FACEBOOK_SERVICE_WELCOME_MESSAGE _ ("You are not currently logged into Facebook.\n" \
"\n" \
"If you don't yet have a Facebook account, you can create one during th" \
"e login process. During login, Shotwell Connect may ask you for permis" \
"sion to upload photos and publish to your feed. These permissions are " \
"required for Shotwell Connect to function.")
#define PUBLISHING_FACEBOOK_RESTART_ERROR_MESSAGE _ ("You have already logged in and out of Facebook during this Shotwell se" \
"ssion.\n" \
"To continue publishing to Facebook, quit and restart Shotwell, then tr" \
"y publishing again.")
#define PUBLISHING_FACEBOOK_USER_AGENT "Java/1.6.0_16"
#define PUBLISHING_FACEBOOK_EXPIRED_SESSION_STATUS_CODE 400
gpointer publishing_facebook_album_ref (gpointer instance);
void publishing_facebook_album_unref (gpointer instance);
GParamSpec* publishing_facebook_param_spec_album (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void publishing_facebook_value_set_album (GValue* value, gpointer v_object);
void publishing_facebook_value_take_album (GValue* value, gpointer v_object);
gpointer publishing_facebook_value_get_album (const GValue* value);
GType publishing_facebook_album_get_type (void) G_GNUC_CONST;
enum  {
	PUBLISHING_FACEBOOK_ALBUM_DUMMY_PROPERTY
};
PublishingFacebookAlbum* publishing_facebook_album_new (const gchar* name, const gchar* id);
PublishingFacebookAlbum* publishing_facebook_album_construct (GType object_type, const gchar* name, const gchar* id);
static void publishing_facebook_album_finalize (PublishingFacebookAlbum* obj);
GType publishing_facebook_resolution_get_type (void) G_GNUC_CONST;
gchar* publishing_facebook_resolution_get_name (PublishingFacebookResolution self);
const gchar* publishing_facebook_resolution_to_string (PublishingFacebookResolution self);
gint publishing_facebook_resolution_get_pixels (PublishingFacebookResolution self);
gpointer publishing_facebook_publishing_parameters_ref (gpointer instance);
void publishing_facebook_publishing_parameters_unref (gpointer instance);
GParamSpec* publishing_facebook_param_spec_publishing_parameters (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void publishing_facebook_value_set_publishing_parameters (GValue* value, gpointer v_object);
void publishing_facebook_value_take_publishing_parameters (GValue* value, gpointer v_object);
gpointer publishing_facebook_value_get_publishing_parameters (const GValue* value);
GType publishing_facebook_publishing_parameters_get_type (void) G_GNUC_CONST;
enum  {
	PUBLISHING_FACEBOOK_PUBLISHING_PARAMETERS_DUMMY_PROPERTY
};
#define PUBLISHING_FACEBOOK_PUBLISHING_PARAMETERS_UNKNOWN_ALBUM -1
PublishingFacebookPublishingParameters* publishing_facebook_publishing_parameters_new (void);
PublishingFacebookPublishingParameters* publishing_facebook_publishing_parameters_construct (GType object_type);
void publishing_facebook_publishing_parameters_add_album (PublishingFacebookPublishingParameters* self, const gchar* name, const gchar* id);
static void _vala_array_add6 (PublishingFacebookAlbum*** array, int* length, int* size, PublishingFacebookAlbum* value);
void publishing_facebook_publishing_parameters_set_target_album_by_name (PublishingFacebookPublishingParameters* self, const gchar* name);
gchar* publishing_facebook_publishing_parameters_get_target_album_name (PublishingFacebookPublishingParameters* self);
gchar* publishing_facebook_publishing_parameters_get_target_album_id (PublishingFacebookPublishingParameters* self);
static void publishing_facebook_publishing_parameters_finalize (PublishingFacebookPublishingParameters* obj);
GType publishing_facebook_web_authentication_pane_get_type (void) G_GNUC_CONST;
gpointer publishing_facebook_graph_session_ref (gpointer instance);
void publishing_facebook_graph_session_unref (gpointer instance);
GParamSpec* publishing_facebook_param_spec_graph_session (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void publishing_facebook_value_set_graph_session (GValue* value, gpointer v_object);
void publishing_facebook_value_take_graph_session (GValue* value, gpointer v_object);
gpointer publishing_facebook_value_get_graph_session (const GValue* value);
GType publishing_facebook_graph_session_get_type (void) G_GNUC_CONST;
GType publishing_facebook_publishing_options_pane_get_type (void) G_GNUC_CONST;
gpointer publishing_facebook_uploader_ref (gpointer instance);
void publishing_facebook_uploader_unref (gpointer instance);
GParamSpec* publishing_facebook_param_spec_uploader (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void publishing_facebook_value_set_uploader (GValue* value, gpointer v_object);
void publishing_facebook_value_take_uploader (GValue* value, gpointer v_object);
gpointer publishing_facebook_value_get_uploader (const GValue* value);
GType publishing_facebook_uploader_get_type (void) G_GNUC_CONST;
#define PUBLISHING_FACEBOOK_FACEBOOK_PUBLISHER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_FACEBOOK_TYPE_FACEBOOK_PUBLISHER, PublishingFacebookFacebookPublisherPrivate))
enum  {
	PUBLISHING_FACEBOOK_FACEBOOK_PUBLISHER_DUMMY_PROPERTY
};
PublishingFacebookGraphSession* publishing_facebook_graph_session_new (void);
PublishingFacebookGraphSession* publishing_facebook_graph_session_construct (GType object_type);
static void publishing_facebook_facebook_publisher_on_session_authenticated (PublishingFacebookFacebookPublisher* self);
static void _publishing_facebook_facebook_publisher_on_session_authenticated_publishing_facebook_graph_session_authenticated (PublishingFacebookGraphSession* _sender, gpointer self);
static gboolean publishing_facebook_facebook_publisher_is_persistent_session_valid (PublishingFacebookFacebookPublisher* self);
static gchar* publishing_facebook_facebook_publisher_get_persistent_access_token (PublishingFacebookFacebookPublisher* self);
static gboolean publishing_facebook_facebook_publisher_get_persistent_strip_metadata (PublishingFacebookFacebookPublisher* self);
static void publishing_facebook_facebook_publisher_set_persistent_access_token (PublishingFacebookFacebookPublisher* self, const gchar* access_token);
static void publishing_facebook_facebook_publisher_set_persistent_strip_metadata (PublishingFacebookFacebookPublisher* self, gboolean strip_metadata);
gint publishing_facebook_facebook_publisher_get_persistent_default_size (PublishingFacebookFacebookPublisher* self);
void publishing_facebook_facebook_publisher_set_persistent_default_size (PublishingFacebookFacebookPublisher* self, gint size);
static void publishing_facebook_facebook_publisher_invalidate_persistent_session (PublishingFacebookFacebookPublisher* self);
static void publishing_facebook_facebook_publisher_do_show_service_welcome_pane (PublishingFacebookFacebookPublisher* self);
static void publishing_facebook_facebook_publisher_on_login_clicked (PublishingFacebookFacebookPublisher* self);
static void _publishing_facebook_facebook_publisher_on_login_clicked_spit_publishing_login_callback (gpointer self);
static void publishing_facebook_facebook_publisher_do_test_connection_to_endpoint (PublishingFacebookFacebookPublisher* self);
gpointer publishing_facebook_graph_message_ref (gpointer instance);
void publishing_facebook_graph_message_unref (gpointer instance);
GParamSpec* publishing_facebook_param_spec_graph_message (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void publishing_facebook_value_set_graph_message (GValue* value, gpointer v_object);
void publishing_facebook_value_take_graph_message (GValue* value, gpointer v_object);
gpointer publishing_facebook_value_get_graph_message (const GValue* value);
GType publishing_facebook_graph_message_get_type (void) G_GNUC_CONST;
PublishingFacebookGraphMessage* publishing_facebook_graph_session_new_endpoint_test (PublishingFacebookGraphSession* self);
static void publishing_facebook_facebook_publisher_on_endpoint_test_completed (PublishingFacebookFacebookPublisher* self, PublishingFacebookGraphMessage* message);
static void _publishing_facebook_facebook_publisher_on_endpoint_test_completed_publishing_facebook_graph_message_completed (PublishingFacebookGraphMessage* _sender, gpointer self);
static void publishing_facebook_facebook_publisher_on_endpoint_test_error (PublishingFacebookFacebookPublisher* self, PublishingFacebookGraphMessage* message, GError* _error_);
static void _publishing_facebook_facebook_publisher_on_endpoint_test_error_publishing_facebook_graph_message_failed (PublishingFacebookGraphMessage* _sender, GError* err, gpointer self);
void publishing_facebook_graph_session_send_message (PublishingFacebookGraphSession* self, PublishingFacebookGraphMessage* message);
static void publishing_facebook_facebook_publisher_do_fetch_user_info (PublishingFacebookFacebookPublisher* self);
PublishingFacebookGraphMessage* publishing_facebook_graph_session_new_query (PublishingFacebookGraphSession* self, const gchar* resource_path);
static void publishing_facebook_facebook_publisher_on_fetch_user_info_completed (PublishingFacebookFacebookPublisher* self, PublishingFacebookGraphMessage* message);
static void _publishing_facebook_facebook_publisher_on_fetch_user_info_completed_publishing_facebook_graph_message_completed (PublishingFacebookGraphMessage* _sender, gpointer self);
static void publishing_facebook_facebook_publisher_on_fetch_user_info_error (PublishingFacebookFacebookPublisher* self, PublishingFacebookGraphMessage* message, GError* _error_);
static void _publishing_facebook_facebook_publisher_on_fetch_user_info_error_publishing_facebook_graph_message_failed (PublishingFacebookGraphMessage* _sender, GError* err, gpointer self);
static void publishing_facebook_facebook_publisher_do_fetch_album_descriptions (PublishingFacebookFacebookPublisher* self);
static void publishing_facebook_facebook_publisher_on_fetch_albums_completed (PublishingFacebookFacebookPublisher* self, PublishingFacebookGraphMessage* message);
static void _publishing_facebook_facebook_publisher_on_fetch_albums_completed_publishing_facebook_graph_message_completed (PublishingFacebookGraphMessage* _sender, gpointer self);
static void publishing_facebook_facebook_publisher_on_fetch_albums_error (PublishingFacebookFacebookPublisher* self, PublishingFacebookGraphMessage* message, GError* err);
static void _publishing_facebook_facebook_publisher_on_fetch_albums_error_publishing_facebook_graph_message_failed (PublishingFacebookGraphMessage* _sender, GError* err, gpointer self);
static void publishing_facebook_facebook_publisher_do_extract_user_info_from_json (PublishingFacebookFacebookPublisher* self, const gchar* json);
static JsonNode* _vala_JsonNode_copy (JsonNode* self);
static void _vala_JsonNode_free (JsonNode* self);
static void publishing_facebook_facebook_publisher_on_user_info_extracted (PublishingFacebookFacebookPublisher* self);
static void publishing_facebook_facebook_publisher_do_extract_albums_from_json (PublishingFacebookFacebookPublisher* self, const gchar* json);
static void publishing_facebook_facebook_publisher_on_albums_extracted (PublishingFacebookFacebookPublisher* self);
static void publishing_facebook_facebook_publisher_do_create_new_album (PublishingFacebookFacebookPublisher* self);
PublishingFacebookGraphMessage* publishing_facebook_graph_session_new_create_album (PublishingFacebookGraphSession* self, const gchar* album_name, const gchar* privacy);
static void publishing_facebook_facebook_publisher_on_create_album_completed (PublishingFacebookFacebookPublisher* self, PublishingFacebookGraphMessage* message);
static void _publishing_facebook_facebook_publisher_on_create_album_completed_publishing_facebook_graph_message_completed (PublishingFacebookGraphMessage* _sender, gpointer self);
static void publishing_facebook_facebook_publisher_on_create_album_error (PublishingFacebookFacebookPublisher* self, PublishingFacebookGraphMessage* message, GError* err);
static void _publishing_facebook_facebook_publisher_on_create_album_error_publishing_facebook_graph_message_failed (PublishingFacebookGraphMessage* _sender, GError* err, gpointer self);
static void publishing_facebook_facebook_publisher_do_show_publishing_options_pane (PublishingFacebookFacebookPublisher* self);
PublishingFacebookPublishingOptionsPane* publishing_facebook_publishing_options_pane_new (const gchar* username, PublishingFacebookAlbum** albums, int albums_length1, SpitPublishingPublisherMediaType media_type, PublishingFacebookFacebookPublisher* publisher, GtkBuilder* builder, gboolean strip_metadata);
PublishingFacebookPublishingOptionsPane* publishing_facebook_publishing_options_pane_construct (GType object_type, const gchar* username, PublishingFacebookAlbum** albums, int albums_length1, SpitPublishingPublisherMediaType media_type, PublishingFacebookFacebookPublisher* publisher, GtkBuilder* builder, gboolean strip_metadata);
static void publishing_facebook_facebook_publisher_on_publishing_options_pane_logout (PublishingFacebookFacebookPublisher* self);
static void _publishing_facebook_facebook_publisher_on_publishing_options_pane_logout_publishing_facebook_publishing_options_pane_logout (PublishingFacebookPublishingOptionsPane* _sender, gpointer self);
static void publishing_facebook_facebook_publisher_on_publishing_options_pane_publish (PublishingFacebookFacebookPublisher* self, const gchar* target_album, const gchar* privacy_setting, PublishingFacebookResolution resolution, gboolean strip_metadata);
static void _publishing_facebook_facebook_publisher_on_publishing_options_pane_publish_publishing_facebook_publishing_options_pane_publish (PublishingFacebookPublishingOptionsPane* _sender, const gchar* target_album, const gchar* privacy_setting, PublishingFacebookResolution target_resolution, gboolean strip_metadata, gpointer self);
static void publishing_facebook_facebook_publisher_do_logout (PublishingFacebookFacebookPublisher* self);
static void publishing_facebook_facebook_publisher_do_add_new_local_album_from_json (PublishingFacebookFacebookPublisher* self, const gchar* album_name, const gchar* json);
static void publishing_facebook_facebook_publisher_do_upload (PublishingFacebookFacebookPublisher* self);
static void publishing_facebook_facebook_publisher_do_hosted_web_authentication (PublishingFacebookFacebookPublisher* self);
PublishingFacebookWebAuthenticationPane* publishing_facebook_web_authentication_pane_new (void);
PublishingFacebookWebAuthenticationPane* publishing_facebook_web_authentication_pane_construct (GType object_type);
static void publishing_facebook_facebook_publisher_on_web_auth_pane_login_succeeded (PublishingFacebookFacebookPublisher* self, const gchar* success_url);
static void _publishing_facebook_facebook_publisher_on_web_auth_pane_login_succeeded_publishing_facebook_web_authentication_pane_login_succeeded (PublishingFacebookWebAuthenticationPane* _sender, const gchar* success_url, gpointer self);
static void publishing_facebook_facebook_publisher_on_web_auth_pane_login_failed (PublishingFacebookFacebookPublisher* self);
static void _publishing_facebook_facebook_publisher_on_web_auth_pane_login_failed_publishing_facebook_web_authentication_pane_login_failed (PublishingFacebookWebAuthenticationPane* _sender, gpointer self);
static void publishing_facebook_facebook_publisher_do_authenticate_session (PublishingFacebookFacebookPublisher* self, const gchar* good_login_uri);
void publishing_facebook_graph_session_authenticate (PublishingFacebookGraphSession* self, const gchar* access_token);
static void publishing_facebook_facebook_publisher_do_save_session_information (PublishingFacebookFacebookPublisher* self);
gchar* publishing_facebook_graph_session_get_access_token (PublishingFacebookGraphSession* self);
PublishingFacebookUploader* publishing_facebook_uploader_new (PublishingFacebookGraphSession* session, PublishingFacebookPublishingParameters* publishing_params, SpitPublishingPublishable** publishables, int publishables_length1);
PublishingFacebookUploader* publishing_facebook_uploader_construct (GType object_type, PublishingFacebookGraphSession* session, PublishingFacebookPublishingParameters* publishing_params, SpitPublishingPublishable** publishables, int publishables_length1);
static void publishing_facebook_facebook_publisher_on_upload_complete (PublishingFacebookFacebookPublisher* self, PublishingFacebookUploader* uploader, gint num_published);
static void _publishing_facebook_facebook_publisher_on_upload_complete_publishing_facebook_uploader_upload_complete (PublishingFacebookUploader* _sender, gint num_photos_published, gpointer self);
static void publishing_facebook_facebook_publisher_on_upload_error (PublishingFacebookFacebookPublisher* self, PublishingFacebookUploader* uploader, GError* err);
static void _publishing_facebook_facebook_publisher_on_upload_error_publishing_facebook_uploader_upload_error (PublishingFacebookUploader* _sender, GError* err, gpointer self);
void publishing_facebook_uploader_upload (PublishingFacebookUploader* self, SpitPublishingProgressCallback status_updated, void* status_updated_target);
static void publishing_facebook_facebook_publisher_on_upload_status_updated (PublishingFacebookFacebookPublisher* self, gint file_number, gdouble completed_fraction);
static void _publishing_facebook_facebook_publisher_on_upload_status_updated_spit_publishing_progress_callback (gint file_number, gdouble fraction_complete, gpointer self);
static void publishing_facebook_facebook_publisher_do_show_success_pane (PublishingFacebookFacebookPublisher* self);
static void publishing_facebook_facebook_publisher_on_generic_error (PublishingFacebookFacebookPublisher* self, GError* _error_);
gboolean publishing_facebook_graph_session_is_authenticated (PublishingFacebookGraphSession* self);
gchar* publishing_facebook_graph_message_get_response_body (PublishingFacebookGraphMessage* self);
static SpitPublishingService* publishing_facebook_facebook_publisher_real_get_service (SpitPublishingPublisher* base);
gchar* publishing_facebook_facebook_publisher_get_service_name (PublishingFacebookFacebookPublisher* self);
gchar* publishing_facebook_facebook_publisher_get_user_visible_name (PublishingFacebookFacebookPublisher* self);
static void publishing_facebook_facebook_publisher_real_start (SpitPublishingPublisher* base);
gboolean publishing_facebook_web_authentication_pane_is_cache_dirty (void);
static void publishing_facebook_facebook_publisher_real_stop (SpitPublishingPublisher* base);
void publishing_facebook_graph_session_stop_transactions (PublishingFacebookGraphSession* self);
static gboolean publishing_facebook_facebook_publisher_real_is_running (SpitPublishingPublisher* base);
static void publishing_facebook_facebook_publisher_finalize (GObject* obj);
static gpointer publishing_facebook_web_authentication_pane_locale_lookup_ref (gpointer instance);
static void publishing_facebook_web_authentication_pane_locale_lookup_unref (gpointer instance);
static GParamSpec* publishing_facebook_web_authentication_pane_param_spec_locale_lookup (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) G_GNUC_UNUSED;
static void publishing_facebook_web_authentication_pane_value_set_locale_lookup (GValue* value, gpointer v_object) G_GNUC_UNUSED;
static void publishing_facebook_web_authentication_pane_value_take_locale_lookup (GValue* value, gpointer v_object) G_GNUC_UNUSED;
static gpointer publishing_facebook_web_authentication_pane_value_get_locale_lookup (const GValue* value) G_GNUC_UNUSED;
static GType publishing_facebook_web_authentication_pane_locale_lookup_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
#define PUBLISHING_FACEBOOK_WEB_AUTHENTICATION_PANE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_FACEBOOK_TYPE_WEB_AUTHENTICATION_PANE, PublishingFacebookWebAuthenticationPanePrivate))
enum  {
	PUBLISHING_FACEBOOK_WEB_AUTHENTICATION_PANE_DUMMY_PROPERTY
};
static PublishingFacebookWebAuthenticationPaneLocaleLookup* publishing_facebook_web_authentication_pane_locale_lookup_new (const gchar* prefix, const gchar* translation, const gchar* exception_code, const gchar* exception_translation, const gchar* exception_code_2, const gchar* exception_translation_2);
static PublishingFacebookWebAuthenticationPaneLocaleLookup* publishing_facebook_web_authentication_pane_locale_lookup_construct (GType object_type, const gchar* prefix, const gchar* translation, const gchar* exception_code, const gchar* exception_translation, const gchar* exception_code_2, const gchar* exception_translation_2);
static void publishing_facebook_web_authentication_pane_on_page_load_changed (PublishingFacebookWebAuthenticationPane* self, WebKitLoadEvent load_event);
static void _publishing_facebook_web_authentication_pane_on_page_load_changed_webkit_web_view_load_changed (WebKitWebView* _sender, WebKitLoadEvent load_event, gpointer self);
static gboolean __lambda4_ (PublishingFacebookWebAuthenticationPane* self);
static gboolean ___lambda4__webkit_web_view_context_menu (WebKitWebView* _sender, WebKitContextMenu* context_menu, GdkEvent* event, WebKitHitTestResult* hit_test_result, gpointer self);
static gchar* publishing_facebook_web_authentication_pane_get_system_locale_as_facebook_locale (PublishingFacebookWebAuthenticationPane* self);
static gchar* publishing_facebook_web_authentication_pane_get_login_url (PublishingFacebookWebAuthenticationPane* self);
static void publishing_facebook_web_authentication_pane_on_page_load (PublishingFacebookWebAuthenticationPane* self);
static void publishing_facebook_web_authentication_pane_on_load_started (PublishingFacebookWebAuthenticationPane* self);
static GtkWidget* publishing_facebook_web_authentication_pane_real_get_widget (SpitPublishingDialogPane* base);
static SpitPublishingDialogPaneGeometryOptions publishing_facebook_web_authentication_pane_real_get_preferred_geometry (SpitPublishingDialogPane* base);
static void publishing_facebook_web_authentication_pane_real_on_pane_installed (SpitPublishingDialogPane* base);
static void publishing_facebook_web_authentication_pane_real_on_pane_uninstalled (SpitPublishingDialogPane* base);
enum  {
	PUBLISHING_FACEBOOK_WEB_AUTHENTICATION_PANE_LOCALE_LOOKUP_DUMMY_PROPERTY
};
static void publishing_facebook_web_authentication_pane_locale_lookup_finalize (PublishingFacebookWebAuthenticationPaneLocaleLookup* obj);
static void publishing_facebook_web_authentication_pane_finalize (GObject* obj);
static gpointer publishing_facebook_publishing_options_pane_privacy_description_ref (gpointer instance);
static void publishing_facebook_publishing_options_pane_privacy_description_unref (gpointer instance);
static GParamSpec* publishing_facebook_publishing_options_pane_param_spec_privacy_description (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) G_GNUC_UNUSED;
static void publishing_facebook_publishing_options_pane_value_set_privacy_description (GValue* value, gpointer v_object) G_GNUC_UNUSED;
static void publishing_facebook_publishing_options_pane_value_take_privacy_description (GValue* value, gpointer v_object) G_GNUC_UNUSED;
static gpointer publishing_facebook_publishing_options_pane_value_get_privacy_description (const GValue* value) G_GNUC_UNUSED;
static GType publishing_facebook_publishing_options_pane_privacy_description_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
#define PUBLISHING_FACEBOOK_PUBLISHING_OPTIONS_PANE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_FACEBOOK_TYPE_PUBLISHING_OPTIONS_PANE, PublishingFacebookPublishingOptionsPanePrivate))
enum  {
	PUBLISHING_FACEBOOK_PUBLISHING_OPTIONS_PANE_DUMMY_PROPERTY
};
#define PUBLISHING_FACEBOOK_PUBLISHING_OPTIONS_PANE_HEADER_LABEL_TEXT _ ("You are logged into Facebook as %s.\n\n")
#define PUBLISHING_FACEBOOK_PUBLISHING_OPTIONS_PANE_PHOTOS_LABEL_TEXT _ ("Where would you like to publish the selected photos?")
#define PUBLISHING_FACEBOOK_PUBLISHING_OPTIONS_PANE_RESOLUTION_LABEL_TEXT _ ("Upload _size:")
#define PUBLISHING_FACEBOOK_PUBLISHING_OPTIONS_PANE_CONTENT_GROUP_SPACING 32
#define PUBLISHING_FACEBOOK_PUBLISHING_OPTIONS_PANE_STANDARD_ACTION_BUTTON_WIDTH 128
static PublishingFacebookAlbum** _vala_array_dup2 (PublishingFacebookAlbum** self, int length);
static PublishingFacebookPublishingOptionsPanePrivacyDescription** publishing_facebook_publishing_options_pane_create_privacy_descriptions (PublishingFacebookPublishingOptionsPane* self, int* result_length1);
static PublishingFacebookResolution* publishing_facebook_publishing_options_pane_create_resolution_list (PublishingFacebookPublishingOptionsPane* self, int* result_length1);
static void publishing_facebook_publishing_options_pane_on_create_new_toggled (PublishingFacebookPublishingOptionsPane* self);
static void _publishing_facebook_publishing_options_pane_on_create_new_toggled_gtk_button_clicked (GtkButton* _sender, gpointer self);
static void publishing_facebook_publishing_options_pane_on_use_existing_toggled (PublishingFacebookPublishingOptionsPane* self);
static void _publishing_facebook_publishing_options_pane_on_use_existing_toggled_gtk_button_clicked (GtkButton* _sender, gpointer self);
static void publishing_facebook_publishing_options_pane_setup_visibility_combo (PublishingFacebookPublishingOptionsPane* self);
static void publishing_facebook_publishing_options_pane_on_publish_button_clicked (PublishingFacebookPublishingOptionsPane* self);
static void _publishing_facebook_publishing_options_pane_on_publish_button_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self);
static void publishing_facebook_publishing_options_pane_on_logout_button_clicked (PublishingFacebookPublishingOptionsPane* self);
static void _publishing_facebook_publishing_options_pane_on_logout_button_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self);
static void publishing_facebook_publishing_options_pane_setup_resolution_combo (PublishingFacebookPublishingOptionsPane* self);
static void publishing_facebook_publishing_options_pane_on_size_changed (PublishingFacebookPublishingOptionsPane* self);
static void _publishing_facebook_publishing_options_pane_on_size_changed_gtk_combo_box_changed (GtkComboBox* _sender, gpointer self);
static gboolean publishing_facebook_publishing_options_pane_publishing_photos (PublishingFacebookPublishingOptionsPane* self);
static PublishingFacebookPublishingOptionsPanePrivacyDescription* publishing_facebook_publishing_options_pane_privacy_description_new (const gchar* description, const gchar* privacy_setting);
static PublishingFacebookPublishingOptionsPanePrivacyDescription* publishing_facebook_publishing_options_pane_privacy_description_construct (GType object_type, const gchar* description, const gchar* privacy_setting);
static void _vala_array_add7 (PublishingFacebookPublishingOptionsPanePrivacyDescription*** array, int* length, int* size, PublishingFacebookPublishingOptionsPanePrivacyDescription* value);
static void _vala_array_add8 (PublishingFacebookPublishingOptionsPanePrivacyDescription*** array, int* length, int* size, PublishingFacebookPublishingOptionsPanePrivacyDescription* value);
static void _vala_array_add9 (PublishingFacebookPublishingOptionsPanePrivacyDescription*** array, int* length, int* size, PublishingFacebookPublishingOptionsPanePrivacyDescription* value);
static void _vala_array_add10 (PublishingFacebookResolution** array, int* length, int* size, PublishingFacebookResolution value);
static void _vala_array_add11 (PublishingFacebookResolution** array, int* length, int* size, PublishingFacebookResolution value);
void publishing_facebook_publishing_options_pane_installed (PublishingFacebookPublishingOptionsPane* self);
static void publishing_facebook_publishing_options_pane_notify_logout (PublishingFacebookPublishingOptionsPane* self);
static void publishing_facebook_publishing_options_pane_notify_publish (PublishingFacebookPublishingOptionsPane* self, const gchar* target_album, const gchar* privacy_setting, PublishingFacebookResolution target_resolution);
static GtkWidget* publishing_facebook_publishing_options_pane_real_get_widget (SpitPublishingDialogPane* base);
static SpitPublishingDialogPaneGeometryOptions publishing_facebook_publishing_options_pane_real_get_preferred_geometry (SpitPublishingDialogPane* base);
static void publishing_facebook_publishing_options_pane_real_on_pane_installed (SpitPublishingDialogPane* base);
static void _publishing_facebook_publishing_options_pane_notify_logout_publishing_facebook_publishing_options_pane_logout (PublishingFacebookPublishingOptionsPane* _sender, gpointer self);
static void _publishing_facebook_publishing_options_pane_notify_publish_publishing_facebook_publishing_options_pane_publish (PublishingFacebookPublishingOptionsPane* _sender, const gchar* target_album, const gchar* privacy_setting, PublishingFacebookResolution target_resolution, gboolean strip_metadata, gpointer self);
static void publishing_facebook_publishing_options_pane_real_on_pane_uninstalled (SpitPublishingDialogPane* base);
static void g_cclosure_user_marshal_VOID__STRING_STRING_ENUM_BOOLEAN (GClosure * closure, GValue * return_value, guint n_param_values, const GValue * param_values, gpointer invocation_hint, gpointer marshal_data);
enum  {
	PUBLISHING_FACEBOOK_PUBLISHING_OPTIONS_PANE_PRIVACY_DESCRIPTION_DUMMY_PROPERTY
};
static void publishing_facebook_publishing_options_pane_privacy_description_finalize (PublishingFacebookPublishingOptionsPanePrivacyDescription* obj);
static void publishing_facebook_publishing_options_pane_finalize (GObject* obj);
GType publishing_facebook_endpoint_get_type (void) G_GNUC_CONST;
gchar* publishing_facebook_endpoint_to_uri (PublishingFacebookEndpoint self);
enum  {
	PUBLISHING_FACEBOOK_GRAPH_MESSAGE_DUMMY_PROPERTY
};
gchar* publishing_facebook_graph_message_get_uri (PublishingFacebookGraphMessage* self);
static gchar* publishing_facebook_graph_message_real_get_uri (PublishingFacebookGraphMessage* self);
static gchar* publishing_facebook_graph_message_real_get_response_body (PublishingFacebookGraphMessage* self);
PublishingFacebookGraphMessage* publishing_facebook_graph_message_construct (GType object_type);
static void g_cclosure_user_marshal_VOID__INT_INT (GClosure * closure, GValue * return_value, guint n_param_values, const GValue * param_values, gpointer invocation_hint, gpointer marshal_data);
static void publishing_facebook_graph_message_finalize (PublishingFacebookGraphMessage* obj);
#define PUBLISHING_FACEBOOK_GRAPH_SESSION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_FACEBOOK_TYPE_GRAPH_SESSION, PublishingFacebookGraphSessionPrivate))
enum  {
	PUBLISHING_FACEBOOK_GRAPH_SESSION_DUMMY_PROPERTY
};
static void publishing_facebook_graph_session_on_request_unqueued (PublishingFacebookGraphSession* self, SoupMessage* msg);
static void _publishing_facebook_graph_session_on_request_unqueued_soup_session_request_unqueued (SoupSession* _sender, SoupMessage* msg, gpointer self);
static void publishing_facebook_graph_session_manage_message (PublishingFacebookGraphSession* self, PublishingFacebookGraphMessage* msg);
static void publishing_facebook_graph_session_unmanage_message (PublishingFacebookGraphSession* self, PublishingFacebookGraphMessage* msg);
static GType publishing_facebook_graph_session_graph_message_impl_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
static void publishing_facebook_graph_session_graph_message_impl_on_wrote_body_data (PublishingFacebookGraphSessionGraphMessageImpl* self, SoupBuffer* chunk);
static void _publishing_facebook_graph_session_graph_message_impl_on_wrote_body_data_soup_message_wrote_body_data (SoupMessage* _sender, SoupBuffer* chunk, gpointer self);
static PublishingFacebookGraphSessionGraphEndpointProbeMessage* publishing_facebook_graph_session_graph_endpoint_probe_message_new (PublishingFacebookGraphSession* host_session);
static PublishingFacebookGraphSessionGraphEndpointProbeMessage* publishing_facebook_graph_session_graph_endpoint_probe_message_construct (GType object_type, PublishingFacebookGraphSession* host_session);
static GType publishing_facebook_graph_session_graph_endpoint_probe_message_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
static PublishingFacebookGraphSessionGraphQueryMessage* publishing_facebook_graph_session_graph_query_message_new (PublishingFacebookGraphSession* host_session, const gchar* relative_uri, const gchar* access_token);
static PublishingFacebookGraphSessionGraphQueryMessage* publishing_facebook_graph_session_graph_query_message_construct (GType object_type, PublishingFacebookGraphSession* host_session, const gchar* relative_uri, const gchar* access_token);
static GType publishing_facebook_graph_session_graph_query_message_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
PublishingFacebookGraphMessage* publishing_facebook_graph_session_new_upload (PublishingFacebookGraphSession* self, const gchar* resource_path, SpitPublishingPublishable* publishable, gboolean suppress_titling, const gchar* resource_privacy);
static PublishingFacebookGraphSessionGraphUploadMessage* publishing_facebook_graph_session_graph_upload_message_new (PublishingFacebookGraphSession* host_session, const gchar* access_token, const gchar* relative_uri, SpitPublishingPublishable* publishable, gboolean suppress_titling, const gchar* resource_privacy);
static PublishingFacebookGraphSessionGraphUploadMessage* publishing_facebook_graph_session_graph_upload_message_construct (GType object_type, PublishingFacebookGraphSession* host_session, const gchar* access_token, const gchar* relative_uri, SpitPublishingPublishable* publishable, gboolean suppress_titling, const gchar* resource_privacy);
static GType publishing_facebook_graph_session_graph_upload_message_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
static PublishingFacebookGraphSessionGraphCreateAlbumMessage* publishing_facebook_graph_session_graph_create_album_message_new (PublishingFacebookGraphSession* host_session, const gchar* access_token, const gchar* album_name, const gchar* album_privacy);
static PublishingFacebookGraphSessionGraphCreateAlbumMessage* publishing_facebook_graph_session_graph_create_album_message_construct (GType object_type, PublishingFacebookGraphSession* host_session, const gchar* access_token, const gchar* album_name, const gchar* album_privacy);
static GType publishing_facebook_graph_session_graph_create_album_message_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
static gboolean publishing_facebook_graph_session_graph_message_impl_prepare_for_transmission (PublishingFacebookGraphSessionGraphMessageImpl* self);
enum  {
	PUBLISHING_FACEBOOK_GRAPH_SESSION_GRAPH_MESSAGE_IMPL_DUMMY_PROPERTY
};
static PublishingFacebookGraphSessionGraphMessageImpl* publishing_facebook_graph_session_graph_message_impl_construct (GType object_type, PublishingFacebookGraphSession* host_session, PublishingRESTSupportHttpMethod method, const gchar* relative_uri, const gchar* access_token, PublishingFacebookEndpoint endpoint);
static gboolean publishing_facebook_graph_session_graph_message_impl_real_prepare_for_transmission (PublishingFacebookGraphSessionGraphMessageImpl* self);
static gchar* publishing_facebook_graph_session_graph_message_impl_real_get_uri (PublishingFacebookGraphMessage* base);
static gchar* publishing_facebook_graph_session_graph_message_impl_real_get_response_body (PublishingFacebookGraphMessage* base);
static void publishing_facebook_graph_session_graph_message_impl_finalize (PublishingFacebookGraphMessage* obj);
enum  {
	PUBLISHING_FACEBOOK_GRAPH_SESSION_GRAPH_QUERY_MESSAGE_DUMMY_PROPERTY
};
static void _vala_SoupURI_free (SoupURI* self);
enum  {
	PUBLISHING_FACEBOOK_GRAPH_SESSION_GRAPH_ENDPOINT_PROBE_MESSAGE_DUMMY_PROPERTY
};
#define PUBLISHING_FACEBOOK_GRAPH_SESSION_GRAPH_UPLOAD_MESSAGE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_FACEBOOK_GRAPH_SESSION_TYPE_GRAPH_UPLOAD_MESSAGE, PublishingFacebookGraphSessionGraphUploadMessagePrivate))
enum  {
	PUBLISHING_FACEBOOK_GRAPH_SESSION_GRAPH_UPLOAD_MESSAGE_DUMMY_PROPERTY
};
static void _vala_SoupMultipart_free (SoupMultipart* self);
static void _vala_SoupBuffer_free (SoupBuffer* self);
static gboolean publishing_facebook_graph_session_graph_upload_message_real_prepare_for_transmission (PublishingFacebookGraphSessionGraphMessageImpl* base);
static void publishing_facebook_graph_session_graph_upload_message_finalize (PublishingFacebookGraphMessage* obj);
enum  {
	PUBLISHING_FACEBOOK_GRAPH_SESSION_GRAPH_CREATE_ALBUM_MESSAGE_DUMMY_PROPERTY
};
static void publishing_facebook_graph_session_finalize (PublishingFacebookGraphSession* obj);
#define PUBLISHING_FACEBOOK_UPLOADER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_FACEBOOK_TYPE_UPLOADER, PublishingFacebookUploaderPrivate))
enum  {
	PUBLISHING_FACEBOOK_UPLOADER_DUMMY_PROPERTY
};
static SpitPublishingPublishable** _vala_array_dup3 (SpitPublishingPublishable** self, int length);
static void publishing_facebook_uploader_send_current_file (PublishingFacebookUploader* self);
static void publishing_facebook_uploader_on_chunk_transmitted (PublishingFacebookUploader* self, gint bytes_written_so_far, gint total_bytes);
static void _publishing_facebook_uploader_on_chunk_transmitted_publishing_facebook_graph_message_data_transmitted (PublishingFacebookGraphMessage* _sender, gint bytes_sent_so_far, gint total_bytes, gpointer self);
static void publishing_facebook_uploader_on_message_completed (PublishingFacebookUploader* self, PublishingFacebookGraphMessage* message);
static void _publishing_facebook_uploader_on_message_completed_publishing_facebook_graph_message_completed (PublishingFacebookGraphMessage* _sender, gpointer self);
static void publishing_facebook_uploader_on_message_failed (PublishingFacebookUploader* self, PublishingFacebookGraphMessage* message, GError* _error_);
static void _publishing_facebook_uploader_on_message_failed_publishing_facebook_graph_message_failed (PublishingFacebookGraphMessage* _sender, GError* err, gpointer self);
static void publishing_facebook_uploader_send_files (PublishingFacebookUploader* self);
static void publishing_facebook_uploader_finalize (PublishingFacebookUploader* obj);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
static gint _vala_array_length (gpointer array);


FacebookService* facebook_service_construct (GType object_type, GFile* resource_directory) {
	FacebookService * self = NULL;
	GdkPixbuf** _tmp0_ = NULL;
	gint _tmp0__length1 = 0;
#line 12 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_val_if_fail (G_IS_FILE (resource_directory), NULL);
#line 12 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self = (FacebookService*) g_object_new (object_type, NULL);
#line 13 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = facebook_service_icon_pixbuf_set;
#line 13 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0__length1 = facebook_service_icon_pixbuf_set_length1;
#line 13 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (_tmp0_ == NULL) {
#line 927 "FacebookPublishing.c"
		gint _tmp1_ = 0;
		GdkPixbuf** _tmp2_ = NULL;
#line 14 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp2_ = resources_load_from_resource (PLUGIN_RESOURCE_PATH "/" FACEBOOK_SERVICE_ICON_FILENAME, &_tmp1_);
#line 14 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		facebook_service_icon_pixbuf_set = (_vala_array_free (facebook_service_icon_pixbuf_set, facebook_service_icon_pixbuf_set_length1, (GDestroyNotify) g_object_unref), NULL);
#line 14 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		facebook_service_icon_pixbuf_set = _tmp2_;
#line 14 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		facebook_service_icon_pixbuf_set_length1 = _tmp1_;
#line 14 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_facebook_service_icon_pixbuf_set_size_ = facebook_service_icon_pixbuf_set_length1;
#line 940 "FacebookPublishing.c"
	}
#line 12 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return self;
#line 944 "FacebookPublishing.c"
}


FacebookService* facebook_service_new (GFile* resource_directory) {
#line 12 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return facebook_service_construct (TYPE_FACEBOOK_SERVICE, resource_directory);
#line 951 "FacebookPublishing.c"
}


static gint facebook_service_real_get_pluggable_interface (SpitPluggable* base, gint min_host_interface, gint max_host_interface) {
	FacebookService * self;
	gint result = 0;
	gint _tmp0_ = 0;
	gint _tmp1_ = 0;
	gint _tmp2_ = 0;
#line 18 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_FACEBOOK_SERVICE, FacebookService);
#line 19 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = min_host_interface;
#line 19 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp1_ = max_host_interface;
#line 19 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp2_ = spit_negotiate_interfaces (_tmp0_, _tmp1_, SPIT_PUBLISHING_CURRENT_INTERFACE);
#line 19 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	result = _tmp2_;
#line 19 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return result;
#line 973 "FacebookPublishing.c"
}


static const gchar* facebook_service_real_get_id (SpitPluggable* base) {
	FacebookService * self;
	const gchar* result = NULL;
#line 23 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_FACEBOOK_SERVICE, FacebookService);
#line 24 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	result = "org.yorba.shotwell.publishing.facebook";
#line 24 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return result;
#line 986 "FacebookPublishing.c"
}


static const gchar* facebook_service_real_get_pluggable_name (SpitPluggable* base) {
	FacebookService * self;
	const gchar* result = NULL;
#line 27 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_FACEBOOK_SERVICE, FacebookService);
#line 28 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	result = "Facebook";
#line 28 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return result;
#line 999 "FacebookPublishing.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return self ? g_object_ref (self) : NULL;
#line 1006 "FacebookPublishing.c"
}


static GdkPixbuf** _vala_array_dup1 (GdkPixbuf** self, int length) {
	GdkPixbuf** result;
	int i;
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	result = g_new0 (GdkPixbuf*, length + 1);
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	for (i = 0; i < length; i++) {
#line 1017 "FacebookPublishing.c"
		GdkPixbuf* _tmp0_ = NULL;
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp0_ = _g_object_ref0 (self[i]);
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		result[i] = _tmp0_;
#line 1023 "FacebookPublishing.c"
	}
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return result;
#line 1027 "FacebookPublishing.c"
}


static void facebook_service_real_get_info (SpitPluggable* base, SpitPluggableInfo* info) {
	FacebookService * self;
	gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
	GdkPixbuf** _tmp8_ = NULL;
	gint _tmp8__length1 = 0;
	GdkPixbuf** _tmp9_ = NULL;
	gint _tmp9__length1 = 0;
#line 31 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_FACEBOOK_SERVICE, FacebookService);
#line 31 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (info != NULL);
#line 32 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = g_strdup ("Lucas Beeler");
#line 32 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_free0 ((*info).authors);
#line 32 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	(*info).authors = _tmp0_;
#line 33 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp1_ = _ ("Copyright 2016 Software Freedom Conservancy Inc.");
#line 33 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp2_ = g_strdup (_tmp1_);
#line 33 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_free0 ((*info).copyright);
#line 33 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	(*info).copyright = _tmp2_;
#line 34 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp3_ = g_strdup (RESOURCES_TRANSLATORS);
#line 34 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_free0 ((*info).translators);
#line 34 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	(*info).translators = _tmp3_;
#line 35 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp4_ = g_strdup (_VERSION);
#line 35 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_free0 ((*info).version);
#line 35 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	(*info).version = _tmp4_;
#line 36 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp5_ = g_strdup (RESOURCES_WEBSITE_NAME);
#line 36 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_free0 ((*info).website_name);
#line 36 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	(*info).website_name = _tmp5_;
#line 37 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp6_ = g_strdup (RESOURCES_WEBSITE_URL);
#line 37 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_free0 ((*info).website_url);
#line 37 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	(*info).website_url = _tmp6_;
#line 38 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	(*info).is_license_wordwrapped = FALSE;
#line 39 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp7_ = g_strdup (RESOURCES_LICENSE);
#line 39 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_free0 ((*info).license);
#line 39 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	(*info).license = _tmp7_;
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp8_ = facebook_service_icon_pixbuf_set;
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp8__length1 = facebook_service_icon_pixbuf_set_length1;
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp9_ = (_tmp8_ != NULL) ? _vala_array_dup1 (_tmp8_, _tmp8__length1) : ((gpointer) _tmp8_);
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp9__length1 = _tmp8__length1;
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	(*info).icons = (_vala_array_free ((*info).icons, (*info).icons_length1, (GDestroyNotify) g_object_unref), NULL);
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	(*info).icons = _tmp9_;
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	(*info).icons_length1 = _tmp9__length1;
#line 1109 "FacebookPublishing.c"
}


static void facebook_service_real_activation (SpitPluggable* base, gboolean enabled) {
	FacebookService * self;
#line 43 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_FACEBOOK_SERVICE, FacebookService);
#line 1117 "FacebookPublishing.c"
}


static SpitPublishingPublisher* facebook_service_real_create_publisher (SpitPublishingService* base, SpitPublishingPluginHost* host) {
	FacebookService * self;
	SpitPublishingPublisher* result = NULL;
	SpitPublishingPluginHost* _tmp0_ = NULL;
	PublishingFacebookFacebookPublisher* _tmp1_ = NULL;
#line 46 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_FACEBOOK_SERVICE, FacebookService);
#line 46 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_val_if_fail (SPIT_PUBLISHING_IS_PLUGIN_HOST (host), NULL);
#line 47 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = host;
#line 47 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp1_ = publishing_facebook_facebook_publisher_new (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_SERVICE, SpitPublishingService), _tmp0_);
#line 47 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	result = G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher);
#line 47 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return result;
#line 1138 "FacebookPublishing.c"
}


static SpitPublishingPublisherMediaType facebook_service_real_get_supported_media (SpitPublishingService* base) {
	FacebookService * self;
	SpitPublishingPublisherMediaType result = 0;
#line 50 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_FACEBOOK_SERVICE, FacebookService);
#line 51 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	result = SPIT_PUBLISHING_PUBLISHER_MEDIA_TYPE_PHOTO | SPIT_PUBLISHING_PUBLISHER_MEDIA_TYPE_VIDEO;
#line 51 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return result;
#line 1151 "FacebookPublishing.c"
}


static void facebook_service_class_init (FacebookServiceClass * klass) {
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	facebook_service_parent_class = g_type_class_peek_parent (klass);
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	G_OBJECT_CLASS (klass)->finalize = facebook_service_finalize;
#line 1160 "FacebookPublishing.c"
}


static void facebook_service_spit_pluggable_interface_init (SpitPluggableIface * iface) {
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	facebook_service_spit_pluggable_parent_iface = g_type_interface_peek_parent (iface);
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	iface->get_pluggable_interface = (gint (*)(SpitPluggable*, gint, gint)) facebook_service_real_get_pluggable_interface;
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	iface->get_id = (const gchar* (*)(SpitPluggable*)) facebook_service_real_get_id;
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	iface->get_pluggable_name = (const gchar* (*)(SpitPluggable*)) facebook_service_real_get_pluggable_name;
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	iface->get_info = (void (*)(SpitPluggable*, SpitPluggableInfo*)) facebook_service_real_get_info;
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	iface->activation = (void (*)(SpitPluggable*, gboolean)) facebook_service_real_activation;
#line 1177 "FacebookPublishing.c"
}


static void facebook_service_spit_publishing_service_interface_init (SpitPublishingServiceIface * iface) {
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	facebook_service_spit_publishing_service_parent_iface = g_type_interface_peek_parent (iface);
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	iface->create_publisher = (SpitPublishingPublisher* (*)(SpitPublishingService*, SpitPublishingPluginHost*)) facebook_service_real_create_publisher;
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	iface->get_supported_media = (SpitPublishingPublisherMediaType (*)(SpitPublishingService*)) facebook_service_real_get_supported_media;
#line 1188 "FacebookPublishing.c"
}


static void facebook_service_instance_init (FacebookService * self) {
}


static void facebook_service_finalize (GObject* obj) {
	FacebookService * self;
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_FACEBOOK_SERVICE, FacebookService);
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	G_OBJECT_CLASS (facebook_service_parent_class)->finalize (obj);
#line 1202 "FacebookPublishing.c"
}


GType facebook_service_get_type (void) {
	static volatile gsize facebook_service_type_id__volatile = 0;
	if (g_once_init_enter (&facebook_service_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (FacebookServiceClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) facebook_service_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (FacebookService), 0, (GInstanceInitFunc) facebook_service_instance_init, NULL };
		static const GInterfaceInfo spit_pluggable_info = { (GInterfaceInitFunc) facebook_service_spit_pluggable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo spit_publishing_service_info = { (GInterfaceInitFunc) facebook_service_spit_publishing_service_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType facebook_service_type_id;
		facebook_service_type_id = g_type_register_static (G_TYPE_OBJECT, "FacebookService", &g_define_type_info, 0);
		g_type_add_interface_static (facebook_service_type_id, SPIT_TYPE_PLUGGABLE, &spit_pluggable_info);
		g_type_add_interface_static (facebook_service_type_id, SPIT_PUBLISHING_TYPE_SERVICE, &spit_publishing_service_info);
		g_once_init_leave (&facebook_service_type_id__volatile, facebook_service_type_id);
	}
	return facebook_service_type_id__volatile;
}


PublishingFacebookAlbum* publishing_facebook_album_construct (GType object_type, const gchar* name, const gchar* id) {
	PublishingFacebookAlbum* self = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
#line 74 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_val_if_fail (name != NULL, NULL);
#line 74 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_val_if_fail (id != NULL, NULL);
#line 74 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self = (PublishingFacebookAlbum*) g_type_create_instance (object_type);
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = name;
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_free0 (self->name);
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->name = _tmp1_;
#line 76 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp2_ = id;
#line 76 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp3_ = g_strdup (_tmp2_);
#line 76 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_free0 (self->id);
#line 76 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->id = _tmp3_;
#line 74 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return self;
#line 1252 "FacebookPublishing.c"
}


PublishingFacebookAlbum* publishing_facebook_album_new (const gchar* name, const gchar* id) {
#line 74 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return publishing_facebook_album_construct (PUBLISHING_FACEBOOK_TYPE_ALBUM, name, id);
#line 1259 "FacebookPublishing.c"
}


static void publishing_facebook_value_album_init (GValue* value) {
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	value->data[0].v_pointer = NULL;
#line 1266 "FacebookPublishing.c"
}


static void publishing_facebook_value_album_free_value (GValue* value) {
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (value->data[0].v_pointer) {
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		publishing_facebook_album_unref (value->data[0].v_pointer);
#line 1275 "FacebookPublishing.c"
	}
}


static void publishing_facebook_value_album_copy_value (const GValue* src_value, GValue* dest_value) {
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (src_value->data[0].v_pointer) {
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		dest_value->data[0].v_pointer = publishing_facebook_album_ref (src_value->data[0].v_pointer);
#line 1285 "FacebookPublishing.c"
	} else {
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		dest_value->data[0].v_pointer = NULL;
#line 1289 "FacebookPublishing.c"
	}
}


static gpointer publishing_facebook_value_album_peek_pointer (const GValue* value) {
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return value->data[0].v_pointer;
#line 1297 "FacebookPublishing.c"
}


static gchar* publishing_facebook_value_album_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (collect_values[0].v_pointer) {
#line 1304 "FacebookPublishing.c"
		PublishingFacebookAlbum* object;
		object = collect_values[0].v_pointer;
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		if (object->parent_instance.g_class == NULL) {
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 1311 "FacebookPublishing.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 1315 "FacebookPublishing.c"
		}
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		value->data[0].v_pointer = publishing_facebook_album_ref (object);
#line 1319 "FacebookPublishing.c"
	} else {
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 1323 "FacebookPublishing.c"
	}
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return NULL;
#line 1327 "FacebookPublishing.c"
}


static gchar* publishing_facebook_value_album_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	PublishingFacebookAlbum** object_p;
	object_p = collect_values[0].v_pointer;
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (!object_p) {
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 1338 "FacebookPublishing.c"
	}
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (!value->data[0].v_pointer) {
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		*object_p = NULL;
#line 1344 "FacebookPublishing.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		*object_p = value->data[0].v_pointer;
#line 1348 "FacebookPublishing.c"
	} else {
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		*object_p = publishing_facebook_album_ref (value->data[0].v_pointer);
#line 1352 "FacebookPublishing.c"
	}
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return NULL;
#line 1356 "FacebookPublishing.c"
}


GParamSpec* publishing_facebook_param_spec_album (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
	PublishingFacebookParamSpecAlbum* spec;
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_val_if_fail (g_type_is_a (object_type, PUBLISHING_FACEBOOK_TYPE_ALBUM), NULL);
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return G_PARAM_SPEC (spec);
#line 1370 "FacebookPublishing.c"
}


gpointer publishing_facebook_value_get_album (const GValue* value) {
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_FACEBOOK_TYPE_ALBUM), NULL);
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return value->data[0].v_pointer;
#line 1379 "FacebookPublishing.c"
}


void publishing_facebook_value_set_album (GValue* value, gpointer v_object) {
	PublishingFacebookAlbum* old;
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_FACEBOOK_TYPE_ALBUM));
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	old = value->data[0].v_pointer;
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (v_object) {
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PUBLISHING_FACEBOOK_TYPE_ALBUM));
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		value->data[0].v_pointer = v_object;
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		publishing_facebook_album_ref (value->data[0].v_pointer);
#line 1399 "FacebookPublishing.c"
	} else {
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 1403 "FacebookPublishing.c"
	}
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (old) {
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		publishing_facebook_album_unref (old);
#line 1409 "FacebookPublishing.c"
	}
}


void publishing_facebook_value_take_album (GValue* value, gpointer v_object) {
	PublishingFacebookAlbum* old;
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_FACEBOOK_TYPE_ALBUM));
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	old = value->data[0].v_pointer;
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (v_object) {
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PUBLISHING_FACEBOOK_TYPE_ALBUM));
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		value->data[0].v_pointer = v_object;
#line 1428 "FacebookPublishing.c"
	} else {
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 1432 "FacebookPublishing.c"
	}
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (old) {
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		publishing_facebook_album_unref (old);
#line 1438 "FacebookPublishing.c"
	}
}


static void publishing_facebook_album_class_init (PublishingFacebookAlbumClass * klass) {
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_album_parent_class = g_type_class_peek_parent (klass);
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	((PublishingFacebookAlbumClass *) klass)->finalize = publishing_facebook_album_finalize;
#line 1448 "FacebookPublishing.c"
}


static void publishing_facebook_album_instance_init (PublishingFacebookAlbum * self) {
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->ref_count = 1;
#line 1455 "FacebookPublishing.c"
}


static void publishing_facebook_album_finalize (PublishingFacebookAlbum* obj) {
	PublishingFacebookAlbum * self;
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_FACEBOOK_TYPE_ALBUM, PublishingFacebookAlbum);
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_handlers_destroy (self);
#line 71 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_free0 (self->name);
#line 72 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_free0 (self->id);
#line 1469 "FacebookPublishing.c"
}


GType publishing_facebook_album_get_type (void) {
	static volatile gsize publishing_facebook_album_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_facebook_album_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { publishing_facebook_value_album_init, publishing_facebook_value_album_free_value, publishing_facebook_value_album_copy_value, publishing_facebook_value_album_peek_pointer, "p", publishing_facebook_value_album_collect_value, "p", publishing_facebook_value_album_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (PublishingFacebookAlbumClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_facebook_album_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingFacebookAlbum), 0, (GInstanceInitFunc) publishing_facebook_album_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType publishing_facebook_album_type_id;
		publishing_facebook_album_type_id = g_type_register_fundamental (g_type_fundamental_next (), "PublishingFacebookAlbum", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&publishing_facebook_album_type_id__volatile, publishing_facebook_album_type_id);
	}
	return publishing_facebook_album_type_id__volatile;
}


gpointer publishing_facebook_album_ref (gpointer instance) {
	PublishingFacebookAlbum* self;
	self = instance;
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_atomic_int_inc (&self->ref_count);
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return instance;
#line 1494 "FacebookPublishing.c"
}


void publishing_facebook_album_unref (gpointer instance) {
	PublishingFacebookAlbum* self;
	self = instance;
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		PUBLISHING_FACEBOOK_ALBUM_GET_CLASS (self)->finalize (self);
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 1507 "FacebookPublishing.c"
	}
}


gchar* publishing_facebook_resolution_get_name (PublishingFacebookResolution self) {
	gchar* result = NULL;
#line 85 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	switch (self) {
#line 85 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		case PUBLISHING_FACEBOOK_RESOLUTION_STANDARD:
#line 1518 "FacebookPublishing.c"
		{
			const gchar* _tmp0_ = NULL;
			gchar* _tmp1_ = NULL;
#line 87 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			_tmp0_ = _ ("Standard (720 pixels)");
#line 87 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			_tmp1_ = g_strdup (_tmp0_);
#line 87 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			result = _tmp1_;
#line 87 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			return result;
#line 1530 "FacebookPublishing.c"
		}
#line 85 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		case PUBLISHING_FACEBOOK_RESOLUTION_HIGH:
#line 1534 "FacebookPublishing.c"
		{
			const gchar* _tmp2_ = NULL;
			gchar* _tmp3_ = NULL;
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			_tmp2_ = _ ("Large (2048 pixels)");
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			_tmp3_ = g_strdup (_tmp2_);
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			result = _tmp3_;
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			return result;
#line 1546 "FacebookPublishing.c"
		}
		default:
		{
			GEnumValue* _tmp4_;
#line 93 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			_tmp4_ = g_enum_get_value (g_type_class_ref (PUBLISHING_FACEBOOK_TYPE_RESOLUTION), self);
#line 93 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			g_error ("FacebookPublishing.vala:93: Unknown resolution %s", (_tmp4_ != NULL) ? _tmp4_->value_name : NULL);
#line 1555 "FacebookPublishing.c"
		}
	}
}


gint publishing_facebook_resolution_get_pixels (PublishingFacebookResolution self) {
	gint result = 0;
#line 98 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	switch (self) {
#line 98 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		case PUBLISHING_FACEBOOK_RESOLUTION_STANDARD:
#line 1567 "FacebookPublishing.c"
		{
#line 100 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			result = 720;
#line 100 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			return result;
#line 1573 "FacebookPublishing.c"
		}
#line 98 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		case PUBLISHING_FACEBOOK_RESOLUTION_HIGH:
#line 1577 "FacebookPublishing.c"
		{
#line 103 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			result = 2048;
#line 103 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			return result;
#line 1583 "FacebookPublishing.c"
		}
		default:
		{
			GEnumValue* _tmp0_;
#line 106 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			_tmp0_ = g_enum_get_value (g_type_class_ref (PUBLISHING_FACEBOOK_TYPE_RESOLUTION), self);
#line 106 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			g_error ("FacebookPublishing.vala:106: Unknown resolution %s", (_tmp0_ != NULL) ? _tmp0_->value_name : NULL);
#line 1592 "FacebookPublishing.c"
		}
	}
}


GType publishing_facebook_resolution_get_type (void) {
	static volatile gsize publishing_facebook_resolution_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_facebook_resolution_type_id__volatile)) {
		static const GEnumValue values[] = {{PUBLISHING_FACEBOOK_RESOLUTION_STANDARD, "PUBLISHING_FACEBOOK_RESOLUTION_STANDARD", "standard"}, {PUBLISHING_FACEBOOK_RESOLUTION_HIGH, "PUBLISHING_FACEBOOK_RESOLUTION_HIGH", "high"}, {0, NULL, NULL}};
		GType publishing_facebook_resolution_type_id;
		publishing_facebook_resolution_type_id = g_enum_register_static ("PublishingFacebookResolution", values);
		g_once_init_leave (&publishing_facebook_resolution_type_id__volatile, publishing_facebook_resolution_type_id);
	}
	return publishing_facebook_resolution_type_id__volatile;
}


PublishingFacebookPublishingParameters* publishing_facebook_publishing_parameters_construct (GType object_type) {
	PublishingFacebookPublishingParameters* self = NULL;
#line 125 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self = (PublishingFacebookPublishingParameters*) g_type_create_instance (object_type);
#line 126 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->albums = (_vala_array_free (self->albums, self->albums_length1, (GDestroyNotify) publishing_facebook_album_unref), NULL);
#line 126 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->albums = NULL;
#line 126 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->albums_length1 = 0;
#line 126 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->_albums_size_ = self->albums_length1;
#line 127 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_free0 (self->privacy_object);
#line 127 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->privacy_object = NULL;
#line 128 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->target_album = PUBLISHING_FACEBOOK_PUBLISHING_PARAMETERS_UNKNOWN_ALBUM;
#line 129 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_free0 (self->new_album_name);
#line 129 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->new_album_name = NULL;
#line 130 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->strip_metadata = FALSE;
#line 131 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->resolution = PUBLISHING_FACEBOOK_RESOLUTION_HIGH;
#line 125 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return self;
#line 1638 "FacebookPublishing.c"
}


PublishingFacebookPublishingParameters* publishing_facebook_publishing_parameters_new (void) {
#line 125 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return publishing_facebook_publishing_parameters_construct (PUBLISHING_FACEBOOK_TYPE_PUBLISHING_PARAMETERS);
#line 1645 "FacebookPublishing.c"
}


static gpointer _publishing_facebook_album_ref0 (gpointer self) {
#line 139 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return self ? publishing_facebook_album_ref (self) : NULL;
#line 1652 "FacebookPublishing.c"
}


static void _vala_array_add6 (PublishingFacebookAlbum*** array, int* length, int* size, PublishingFacebookAlbum* value) {
#line 139 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if ((*length) == (*size)) {
#line 139 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 139 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		*array = g_renew (PublishingFacebookAlbum*, *array, (*size) + 1);
#line 1663 "FacebookPublishing.c"
	}
#line 139 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	(*array)[(*length)++] = value;
#line 139 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	(*array)[*length] = NULL;
#line 1669 "FacebookPublishing.c"
}


void publishing_facebook_publishing_parameters_add_album (PublishingFacebookPublishingParameters* self, const gchar* name, const gchar* id) {
	PublishingFacebookAlbum** _tmp0_ = NULL;
	gint _tmp0__length1 = 0;
	PublishingFacebookAlbum* new_album = NULL;
	const gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	PublishingFacebookAlbum* _tmp4_ = NULL;
	PublishingFacebookAlbum** _tmp5_ = NULL;
	gint _tmp5__length1 = 0;
	PublishingFacebookAlbum* _tmp6_ = NULL;
#line 134 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_PUBLISHING_PARAMETERS (self));
#line 134 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (name != NULL);
#line 134 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (id != NULL);
#line 135 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = self->albums;
#line 135 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0__length1 = self->albums_length1;
#line 135 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (_tmp0_ == NULL) {
#line 1695 "FacebookPublishing.c"
		PublishingFacebookAlbum** _tmp1_ = NULL;
#line 136 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp1_ = g_new0 (PublishingFacebookAlbum*, 0 + 1);
#line 136 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		self->albums = (_vala_array_free (self->albums, self->albums_length1, (GDestroyNotify) publishing_facebook_album_unref), NULL);
#line 136 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		self->albums = _tmp1_;
#line 136 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		self->albums_length1 = 0;
#line 136 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		self->_albums_size_ = self->albums_length1;
#line 1707 "FacebookPublishing.c"
	}
#line 138 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp2_ = name;
#line 138 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp3_ = id;
#line 138 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp4_ = publishing_facebook_album_new (_tmp2_, _tmp3_);
#line 138 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	new_album = _tmp4_;
#line 139 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp5_ = self->albums;
#line 139 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp5__length1 = self->albums_length1;
#line 139 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp6_ = _publishing_facebook_album_ref0 (new_album);
#line 139 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_vala_array_add6 (&self->albums, &self->albums_length1, &self->_albums_size_, _tmp6_);
#line 134 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_publishing_facebook_album_unref0 (new_album);
#line 1727 "FacebookPublishing.c"
}


void publishing_facebook_publishing_parameters_set_target_album_by_name (PublishingFacebookPublishingParameters* self, const gchar* name) {
	const gchar* _tmp0_ = NULL;
#line 142 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_PUBLISHING_PARAMETERS (self));
#line 143 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = name;
#line 143 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (_tmp0_ == NULL) {
#line 144 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		self->target_album = PUBLISHING_FACEBOOK_PUBLISHING_PARAMETERS_UNKNOWN_ALBUM;
#line 145 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		return;
#line 1743 "FacebookPublishing.c"
	}
	{
		gint i = 0;
#line 148 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		i = 0;
#line 1749 "FacebookPublishing.c"
		{
			gboolean _tmp1_ = FALSE;
#line 148 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			_tmp1_ = TRUE;
#line 148 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			while (TRUE) {
#line 1756 "FacebookPublishing.c"
				gint _tmp3_ = 0;
				PublishingFacebookAlbum** _tmp4_ = NULL;
				gint _tmp4__length1 = 0;
				PublishingFacebookAlbum** _tmp5_ = NULL;
				gint _tmp5__length1 = 0;
				gint _tmp6_ = 0;
				PublishingFacebookAlbum* _tmp7_ = NULL;
				const gchar* _tmp8_ = NULL;
				const gchar* _tmp9_ = NULL;
#line 148 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				if (!_tmp1_) {
#line 1768 "FacebookPublishing.c"
					gint _tmp2_ = 0;
#line 148 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
					_tmp2_ = i;
#line 148 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
					i = _tmp2_ + 1;
#line 1774 "FacebookPublishing.c"
				}
#line 148 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				_tmp1_ = FALSE;
#line 148 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				_tmp3_ = i;
#line 148 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				_tmp4_ = self->albums;
#line 148 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				_tmp4__length1 = self->albums_length1;
#line 148 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				if (!(_tmp3_ < _tmp4__length1)) {
#line 148 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
					break;
#line 1788 "FacebookPublishing.c"
				}
#line 150 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				_tmp5_ = self->albums;
#line 150 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				_tmp5__length1 = self->albums_length1;
#line 150 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				_tmp6_ = i;
#line 150 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				_tmp7_ = _tmp5_[_tmp6_];
#line 150 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				_tmp8_ = _tmp7_->name;
#line 150 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				_tmp9_ = name;
#line 150 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				if (g_strcmp0 (_tmp8_, _tmp9_) == 0) {
#line 1804 "FacebookPublishing.c"
					gint _tmp10_ = 0;
#line 151 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
					_tmp10_ = i;
#line 151 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
					self->target_album = _tmp10_;
#line 152 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
					return;
#line 1812 "FacebookPublishing.c"
				}
			}
		}
	}
#line 156 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->target_album = PUBLISHING_FACEBOOK_PUBLISHING_PARAMETERS_UNKNOWN_ALBUM;
#line 1819 "FacebookPublishing.c"
}


gchar* publishing_facebook_publishing_parameters_get_target_album_name (PublishingFacebookPublishingParameters* self) {
	gchar* result = NULL;
	gboolean _tmp0_ = FALSE;
	PublishingFacebookAlbum** _tmp1_ = NULL;
	gint _tmp1__length1 = 0;
	PublishingFacebookAlbum** _tmp3_ = NULL;
	gint _tmp3__length1 = 0;
	gint _tmp4_ = 0;
	PublishingFacebookAlbum* _tmp5_ = NULL;
	const gchar* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
#line 159 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_val_if_fail (PUBLISHING_FACEBOOK_IS_PUBLISHING_PARAMETERS (self), NULL);
#line 160 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp1_ = self->albums;
#line 160 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp1__length1 = self->albums_length1;
#line 160 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (_tmp1_ == NULL) {
#line 160 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp0_ = TRUE;
#line 1844 "FacebookPublishing.c"
	} else {
		gint _tmp2_ = 0;
#line 160 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp2_ = self->target_album;
#line 160 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp0_ = _tmp2_ == PUBLISHING_FACEBOOK_PUBLISHING_PARAMETERS_UNKNOWN_ALBUM;
#line 1851 "FacebookPublishing.c"
	}
#line 160 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (_tmp0_) {
#line 161 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		result = NULL;
#line 161 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		return result;
#line 1859 "FacebookPublishing.c"
	}
#line 163 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp3_ = self->albums;
#line 163 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp3__length1 = self->albums_length1;
#line 163 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp4_ = self->target_album;
#line 163 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp5_ = _tmp3_[_tmp4_];
#line 163 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp6_ = _tmp5_->name;
#line 163 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp7_ = g_strdup (_tmp6_);
#line 163 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	result = _tmp7_;
#line 163 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return result;
#line 1877 "FacebookPublishing.c"
}


gchar* publishing_facebook_publishing_parameters_get_target_album_id (PublishingFacebookPublishingParameters* self) {
	gchar* result = NULL;
	gboolean _tmp0_ = FALSE;
	PublishingFacebookAlbum** _tmp1_ = NULL;
	gint _tmp1__length1 = 0;
	PublishingFacebookAlbum** _tmp3_ = NULL;
	gint _tmp3__length1 = 0;
	gint _tmp4_ = 0;
	PublishingFacebookAlbum* _tmp5_ = NULL;
	const gchar* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
#line 166 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_val_if_fail (PUBLISHING_FACEBOOK_IS_PUBLISHING_PARAMETERS (self), NULL);
#line 167 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp1_ = self->albums;
#line 167 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp1__length1 = self->albums_length1;
#line 167 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (_tmp1_ == NULL) {
#line 167 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp0_ = TRUE;
#line 1902 "FacebookPublishing.c"
	} else {
		gint _tmp2_ = 0;
#line 167 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp2_ = self->target_album;
#line 167 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp0_ = _tmp2_ == PUBLISHING_FACEBOOK_PUBLISHING_PARAMETERS_UNKNOWN_ALBUM;
#line 1909 "FacebookPublishing.c"
	}
#line 167 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (_tmp0_) {
#line 168 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		result = NULL;
#line 168 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		return result;
#line 1917 "FacebookPublishing.c"
	}
#line 170 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp3_ = self->albums;
#line 170 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp3__length1 = self->albums_length1;
#line 170 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp4_ = self->target_album;
#line 170 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp5_ = _tmp3_[_tmp4_];
#line 170 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp6_ = _tmp5_->id;
#line 170 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp7_ = g_strdup (_tmp6_);
#line 170 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	result = _tmp7_;
#line 170 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return result;
#line 1935 "FacebookPublishing.c"
}


static void publishing_facebook_value_publishing_parameters_init (GValue* value) {
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	value->data[0].v_pointer = NULL;
#line 1942 "FacebookPublishing.c"
}


static void publishing_facebook_value_publishing_parameters_free_value (GValue* value) {
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (value->data[0].v_pointer) {
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		publishing_facebook_publishing_parameters_unref (value->data[0].v_pointer);
#line 1951 "FacebookPublishing.c"
	}
}


static void publishing_facebook_value_publishing_parameters_copy_value (const GValue* src_value, GValue* dest_value) {
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (src_value->data[0].v_pointer) {
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		dest_value->data[0].v_pointer = publishing_facebook_publishing_parameters_ref (src_value->data[0].v_pointer);
#line 1961 "FacebookPublishing.c"
	} else {
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		dest_value->data[0].v_pointer = NULL;
#line 1965 "FacebookPublishing.c"
	}
}


static gpointer publishing_facebook_value_publishing_parameters_peek_pointer (const GValue* value) {
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return value->data[0].v_pointer;
#line 1973 "FacebookPublishing.c"
}


static gchar* publishing_facebook_value_publishing_parameters_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (collect_values[0].v_pointer) {
#line 1980 "FacebookPublishing.c"
		PublishingFacebookPublishingParameters* object;
		object = collect_values[0].v_pointer;
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		if (object->parent_instance.g_class == NULL) {
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 1987 "FacebookPublishing.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 1991 "FacebookPublishing.c"
		}
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		value->data[0].v_pointer = publishing_facebook_publishing_parameters_ref (object);
#line 1995 "FacebookPublishing.c"
	} else {
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 1999 "FacebookPublishing.c"
	}
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return NULL;
#line 2003 "FacebookPublishing.c"
}


static gchar* publishing_facebook_value_publishing_parameters_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	PublishingFacebookPublishingParameters** object_p;
	object_p = collect_values[0].v_pointer;
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (!object_p) {
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 2014 "FacebookPublishing.c"
	}
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (!value->data[0].v_pointer) {
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		*object_p = NULL;
#line 2020 "FacebookPublishing.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		*object_p = value->data[0].v_pointer;
#line 2024 "FacebookPublishing.c"
	} else {
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		*object_p = publishing_facebook_publishing_parameters_ref (value->data[0].v_pointer);
#line 2028 "FacebookPublishing.c"
	}
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return NULL;
#line 2032 "FacebookPublishing.c"
}


GParamSpec* publishing_facebook_param_spec_publishing_parameters (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
	PublishingFacebookParamSpecPublishingParameters* spec;
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_val_if_fail (g_type_is_a (object_type, PUBLISHING_FACEBOOK_TYPE_PUBLISHING_PARAMETERS), NULL);
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return G_PARAM_SPEC (spec);
#line 2046 "FacebookPublishing.c"
}


gpointer publishing_facebook_value_get_publishing_parameters (const GValue* value) {
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_FACEBOOK_TYPE_PUBLISHING_PARAMETERS), NULL);
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return value->data[0].v_pointer;
#line 2055 "FacebookPublishing.c"
}


void publishing_facebook_value_set_publishing_parameters (GValue* value, gpointer v_object) {
	PublishingFacebookPublishingParameters* old;
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_FACEBOOK_TYPE_PUBLISHING_PARAMETERS));
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	old = value->data[0].v_pointer;
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (v_object) {
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PUBLISHING_FACEBOOK_TYPE_PUBLISHING_PARAMETERS));
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		value->data[0].v_pointer = v_object;
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		publishing_facebook_publishing_parameters_ref (value->data[0].v_pointer);
#line 2075 "FacebookPublishing.c"
	} else {
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 2079 "FacebookPublishing.c"
	}
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (old) {
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		publishing_facebook_publishing_parameters_unref (old);
#line 2085 "FacebookPublishing.c"
	}
}


void publishing_facebook_value_take_publishing_parameters (GValue* value, gpointer v_object) {
	PublishingFacebookPublishingParameters* old;
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_FACEBOOK_TYPE_PUBLISHING_PARAMETERS));
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	old = value->data[0].v_pointer;
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (v_object) {
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PUBLISHING_FACEBOOK_TYPE_PUBLISHING_PARAMETERS));
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		value->data[0].v_pointer = v_object;
#line 2104 "FacebookPublishing.c"
	} else {
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 2108 "FacebookPublishing.c"
	}
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (old) {
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		publishing_facebook_publishing_parameters_unref (old);
#line 2114 "FacebookPublishing.c"
	}
}


static void publishing_facebook_publishing_parameters_class_init (PublishingFacebookPublishingParametersClass * klass) {
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_publishing_parameters_parent_class = g_type_class_peek_parent (klass);
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	((PublishingFacebookPublishingParametersClass *) klass)->finalize = publishing_facebook_publishing_parameters_finalize;
#line 2124 "FacebookPublishing.c"
}


static void publishing_facebook_publishing_parameters_instance_init (PublishingFacebookPublishingParameters * self) {
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->ref_count = 1;
#line 2131 "FacebookPublishing.c"
}


static void publishing_facebook_publishing_parameters_finalize (PublishingFacebookPublishingParameters* obj) {
	PublishingFacebookPublishingParameters * self;
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_FACEBOOK_TYPE_PUBLISHING_PARAMETERS, PublishingFacebookPublishingParameters);
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_handlers_destroy (self);
#line 115 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->albums = (_vala_array_free (self->albums, self->albums_length1, (GDestroyNotify) publishing_facebook_album_unref), NULL);
#line 117 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_free0 (self->new_album_name);
#line 121 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_free0 (self->privacy_object);
#line 2147 "FacebookPublishing.c"
}


GType publishing_facebook_publishing_parameters_get_type (void) {
	static volatile gsize publishing_facebook_publishing_parameters_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_facebook_publishing_parameters_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { publishing_facebook_value_publishing_parameters_init, publishing_facebook_value_publishing_parameters_free_value, publishing_facebook_value_publishing_parameters_copy_value, publishing_facebook_value_publishing_parameters_peek_pointer, "p", publishing_facebook_value_publishing_parameters_collect_value, "p", publishing_facebook_value_publishing_parameters_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (PublishingFacebookPublishingParametersClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_facebook_publishing_parameters_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingFacebookPublishingParameters), 0, (GInstanceInitFunc) publishing_facebook_publishing_parameters_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType publishing_facebook_publishing_parameters_type_id;
		publishing_facebook_publishing_parameters_type_id = g_type_register_fundamental (g_type_fundamental_next (), "PublishingFacebookPublishingParameters", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&publishing_facebook_publishing_parameters_type_id__volatile, publishing_facebook_publishing_parameters_type_id);
	}
	return publishing_facebook_publishing_parameters_type_id__volatile;
}


gpointer publishing_facebook_publishing_parameters_ref (gpointer instance) {
	PublishingFacebookPublishingParameters* self;
	self = instance;
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_atomic_int_inc (&self->ref_count);
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return instance;
#line 2172 "FacebookPublishing.c"
}


void publishing_facebook_publishing_parameters_unref (gpointer instance) {
	PublishingFacebookPublishingParameters* self;
	self = instance;
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		PUBLISHING_FACEBOOK_PUBLISHING_PARAMETERS_GET_CLASS (self)->finalize (self);
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 2185 "FacebookPublishing.c"
	}
}


static void _publishing_facebook_facebook_publisher_on_session_authenticated_publishing_facebook_graph_session_authenticated (PublishingFacebookGraphSession* _sender, gpointer self) {
#line 197 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_facebook_publisher_on_session_authenticated ((PublishingFacebookFacebookPublisher*) self);
#line 2193 "FacebookPublishing.c"
}


PublishingFacebookFacebookPublisher* publishing_facebook_facebook_publisher_construct (GType object_type, SpitPublishingService* service, SpitPublishingPluginHost* host) {
	PublishingFacebookFacebookPublisher * self = NULL;
	SpitPublishingService* _tmp0_ = NULL;
	SpitPublishingPluginHost* _tmp1_ = NULL;
	PublishingFacebookPublishingParameters* _tmp2_ = NULL;
	PublishingFacebookGraphSession* _tmp3_ = NULL;
	PublishingFacebookGraphSession* _tmp4_ = NULL;
#line 187 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_val_if_fail (SPIT_PUBLISHING_IS_SERVICE (service), NULL);
#line 187 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_val_if_fail (SPIT_PUBLISHING_IS_PLUGIN_HOST (host), NULL);
#line 187 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self = (PublishingFacebookFacebookPublisher*) g_object_new (object_type, NULL);
#line 189 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_debug ("FacebookPublishing.vala:189: FacebookPublisher instantiated.");
#line 191 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = service;
#line 191 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->service = _tmp0_;
#line 192 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp1_ = host;
#line 192 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->host = _tmp1_;
#line 194 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp2_ = publishing_facebook_publishing_parameters_new ();
#line 194 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_publishing_facebook_publishing_parameters_unref0 (self->priv->publishing_params);
#line 194 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->publishing_params = _tmp2_;
#line 196 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp3_ = publishing_facebook_graph_session_new ();
#line 196 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_publishing_facebook_graph_session_unref0 (self->priv->graph_session);
#line 196 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->graph_session = _tmp3_;
#line 197 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp4_ = self->priv->graph_session;
#line 197 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_connect_object (_tmp4_, "authenticated", (GCallback) _publishing_facebook_facebook_publisher_on_session_authenticated_publishing_facebook_graph_session_authenticated, self, 0);
#line 187 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return self;
#line 2238 "FacebookPublishing.c"
}


PublishingFacebookFacebookPublisher* publishing_facebook_facebook_publisher_new (SpitPublishingService* service, SpitPublishingPluginHost* host) {
#line 187 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return publishing_facebook_facebook_publisher_construct (PUBLISHING_FACEBOOK_TYPE_FACEBOOK_PUBLISHER, service, host);
#line 2245 "FacebookPublishing.c"
}


static gboolean publishing_facebook_facebook_publisher_is_persistent_session_valid (PublishingFacebookFacebookPublisher* self) {
	gboolean result = FALSE;
	gchar* token = NULL;
	gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	const gchar* _tmp3_ = NULL;
#line 200 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_val_if_fail (PUBLISHING_FACEBOOK_IS_FACEBOOK_PUBLISHER (self), FALSE);
#line 201 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = publishing_facebook_facebook_publisher_get_persistent_access_token (self);
#line 201 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	token = _tmp0_;
#line 203 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp1_ = token;
#line 203 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (_tmp1_ != NULL) {
#line 2265 "FacebookPublishing.c"
		const gchar* _tmp2_ = NULL;
#line 204 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp2_ = token;
#line 204 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		g_debug ("FacebookPublishing.vala:204: existing Facebook session found in config" \
"uration database (access_token = %s).", _tmp2_);
#line 2271 "FacebookPublishing.c"
	} else {
#line 207 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		g_debug ("FacebookPublishing.vala:207: no existing Facebook session available.");
#line 2275 "FacebookPublishing.c"
	}
#line 209 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp3_ = token;
#line 209 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	result = _tmp3_ != NULL;
#line 209 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_free0 (token);
#line 209 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return result;
#line 2285 "FacebookPublishing.c"
}


static gchar* publishing_facebook_facebook_publisher_get_persistent_access_token (PublishingFacebookFacebookPublisher* self) {
	gchar* result = NULL;
	SpitPublishingPluginHost* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 212 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_val_if_fail (PUBLISHING_FACEBOOK_IS_FACEBOOK_PUBLISHER (self), NULL);
#line 213 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = self->priv->host;
#line 213 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp1_ = spit_host_interface_get_config_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "access_token", NULL);
#line 213 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	result = _tmp1_;
#line 213 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return result;
#line 2303 "FacebookPublishing.c"
}


static gboolean publishing_facebook_facebook_publisher_get_persistent_strip_metadata (PublishingFacebookFacebookPublisher* self) {
	gboolean result = FALSE;
	SpitPublishingPluginHost* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
#line 216 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_val_if_fail (PUBLISHING_FACEBOOK_IS_FACEBOOK_PUBLISHER (self), FALSE);
#line 217 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = self->priv->host;
#line 217 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp1_ = spit_host_interface_get_config_bool (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "strip_metadata", FALSE);
#line 217 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	result = _tmp1_;
#line 217 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return result;
#line 2321 "FacebookPublishing.c"
}


static void publishing_facebook_facebook_publisher_set_persistent_access_token (PublishingFacebookFacebookPublisher* self, const gchar* access_token) {
	SpitPublishingPluginHost* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
#line 220 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_FACEBOOK_PUBLISHER (self));
#line 220 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (access_token != NULL);
#line 221 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = self->priv->host;
#line 221 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp1_ = access_token;
#line 221 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	spit_host_interface_set_config_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "access_token", _tmp1_);
#line 2338 "FacebookPublishing.c"
}


static void publishing_facebook_facebook_publisher_set_persistent_strip_metadata (PublishingFacebookFacebookPublisher* self, gboolean strip_metadata) {
	SpitPublishingPluginHost* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
#line 224 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_FACEBOOK_PUBLISHER (self));
#line 225 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = self->priv->host;
#line 225 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp1_ = strip_metadata;
#line 225 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	spit_host_interface_set_config_bool (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "strip_metadata", _tmp1_);
#line 2353 "FacebookPublishing.c"
}


gint publishing_facebook_facebook_publisher_get_persistent_default_size (PublishingFacebookFacebookPublisher* self) {
	gint result = 0;
	SpitPublishingPluginHost* _tmp0_ = NULL;
	gint _tmp1_ = 0;
#line 230 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_val_if_fail (PUBLISHING_FACEBOOK_IS_FACEBOOK_PUBLISHER (self), 0);
#line 231 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = self->priv->host;
#line 231 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp1_ = spit_host_interface_get_config_int (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "default_size", 0);
#line 231 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	result = _tmp1_;
#line 231 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return result;
#line 2371 "FacebookPublishing.c"
}


void publishing_facebook_facebook_publisher_set_persistent_default_size (PublishingFacebookFacebookPublisher* self, gint size) {
	SpitPublishingPluginHost* _tmp0_ = NULL;
	gint _tmp1_ = 0;
#line 234 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_FACEBOOK_PUBLISHER (self));
#line 235 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = self->priv->host;
#line 235 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp1_ = size;
#line 235 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	spit_host_interface_set_config_int (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "default_size", _tmp1_);
#line 2386 "FacebookPublishing.c"
}


static void publishing_facebook_facebook_publisher_invalidate_persistent_session (PublishingFacebookFacebookPublisher* self) {
#line 238 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_FACEBOOK_PUBLISHER (self));
#line 239 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_debug ("FacebookPublishing.vala:239: invalidating saved Facebook session.");
#line 241 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_facebook_publisher_set_persistent_access_token (self, "");
#line 2397 "FacebookPublishing.c"
}


static void _publishing_facebook_facebook_publisher_on_login_clicked_spit_publishing_login_callback (gpointer self) {
#line 247 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_facebook_publisher_on_login_clicked ((PublishingFacebookFacebookPublisher*) self);
#line 2404 "FacebookPublishing.c"
}


static void publishing_facebook_facebook_publisher_do_show_service_welcome_pane (PublishingFacebookFacebookPublisher* self) {
	SpitPublishingPluginHost* _tmp0_ = NULL;
	SpitPublishingPluginHost* _tmp1_ = NULL;
#line 244 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_FACEBOOK_PUBLISHER (self));
#line 245 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_debug ("FacebookPublishing.vala:245: ACTION: showing service welcome pane.");
#line 247 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = self->priv->host;
#line 247 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	spit_publishing_plugin_host_install_welcome_pane (_tmp0_, PUBLISHING_FACEBOOK_SERVICE_WELCOME_MESSAGE, _publishing_facebook_facebook_publisher_on_login_clicked_spit_publishing_login_callback, self);
#line 248 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp1_ = self->priv->host;
#line 248 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	spit_publishing_plugin_host_set_service_locked (_tmp1_, FALSE);
#line 2423 "FacebookPublishing.c"
}


static void _publishing_facebook_facebook_publisher_on_endpoint_test_completed_publishing_facebook_graph_message_completed (PublishingFacebookGraphMessage* _sender, gpointer self) {
#line 258 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_facebook_publisher_on_endpoint_test_completed ((PublishingFacebookFacebookPublisher*) self, _sender);
#line 2430 "FacebookPublishing.c"
}


static void _publishing_facebook_facebook_publisher_on_endpoint_test_error_publishing_facebook_graph_message_failed (PublishingFacebookGraphMessage* _sender, GError* err, gpointer self) {
#line 259 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_facebook_publisher_on_endpoint_test_error ((PublishingFacebookFacebookPublisher*) self, _sender, err);
#line 2437 "FacebookPublishing.c"
}


static void publishing_facebook_facebook_publisher_do_test_connection_to_endpoint (PublishingFacebookFacebookPublisher* self) {
	SpitPublishingPluginHost* _tmp0_ = NULL;
	SpitPublishingPluginHost* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	PublishingFacebookGraphMessage* endpoint_test_message = NULL;
	PublishingFacebookGraphSession* _tmp3_ = NULL;
	PublishingFacebookGraphMessage* _tmp4_ = NULL;
	PublishingFacebookGraphSession* _tmp5_ = NULL;
#line 251 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_FACEBOOK_PUBLISHER (self));
#line 252 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_debug ("FacebookPublishing.vala:252: ACTION: testing connection to Facebook en" \
"dpoint.");
#line 253 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = self->priv->host;
#line 253 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	spit_publishing_plugin_host_set_service_locked (_tmp0_, TRUE);
#line 255 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp1_ = self->priv->host;
#line 255 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp2_ = _ ("Testing connection to Facebook...");
#line 255 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	spit_publishing_plugin_host_install_static_message_pane (_tmp1_, _tmp2_, SPIT_PUBLISHING_PLUGIN_HOST_BUTTON_MODE_CANCEL);
#line 257 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp3_ = self->priv->graph_session;
#line 257 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp4_ = publishing_facebook_graph_session_new_endpoint_test (_tmp3_);
#line 257 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	endpoint_test_message = _tmp4_;
#line 258 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_connect_object (endpoint_test_message, "completed", (GCallback) _publishing_facebook_facebook_publisher_on_endpoint_test_completed_publishing_facebook_graph_message_completed, self, 0);
#line 259 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_connect_object (endpoint_test_message, "failed", (GCallback) _publishing_facebook_facebook_publisher_on_endpoint_test_error_publishing_facebook_graph_message_failed, self, 0);
#line 261 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp5_ = self->priv->graph_session;
#line 261 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_graph_session_send_message (_tmp5_, endpoint_test_message);
#line 251 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_publishing_facebook_graph_message_unref0 (endpoint_test_message);
#line 2479 "FacebookPublishing.c"
}


static void _publishing_facebook_facebook_publisher_on_fetch_user_info_completed_publishing_facebook_graph_message_completed (PublishingFacebookGraphMessage* _sender, gpointer self) {
#line 272 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_facebook_publisher_on_fetch_user_info_completed ((PublishingFacebookFacebookPublisher*) self, _sender);
#line 2486 "FacebookPublishing.c"
}


static void _publishing_facebook_facebook_publisher_on_fetch_user_info_error_publishing_facebook_graph_message_failed (PublishingFacebookGraphMessage* _sender, GError* err, gpointer self) {
#line 273 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_facebook_publisher_on_fetch_user_info_error ((PublishingFacebookFacebookPublisher*) self, _sender, err);
#line 2493 "FacebookPublishing.c"
}


static void publishing_facebook_facebook_publisher_do_fetch_user_info (PublishingFacebookFacebookPublisher* self) {
	SpitPublishingPluginHost* _tmp0_ = NULL;
	SpitPublishingPluginHost* _tmp1_ = NULL;
	PublishingFacebookGraphMessage* user_info_message = NULL;
	PublishingFacebookGraphSession* _tmp2_ = NULL;
	PublishingFacebookGraphMessage* _tmp3_ = NULL;
	PublishingFacebookGraphSession* _tmp4_ = NULL;
#line 264 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_FACEBOOK_PUBLISHER (self));
#line 265 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_debug ("FacebookPublishing.vala:265: ACTION: fetching user information.");
#line 267 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = self->priv->host;
#line 267 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	spit_publishing_plugin_host_set_service_locked (_tmp0_, TRUE);
#line 268 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp1_ = self->priv->host;
#line 268 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	spit_publishing_plugin_host_install_account_fetch_wait_pane (_tmp1_);
#line 270 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp2_ = self->priv->graph_session;
#line 270 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp3_ = publishing_facebook_graph_session_new_query (_tmp2_, "/me");
#line 270 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	user_info_message = _tmp3_;
#line 272 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_connect_object (user_info_message, "completed", (GCallback) _publishing_facebook_facebook_publisher_on_fetch_user_info_completed_publishing_facebook_graph_message_completed, self, 0);
#line 273 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_connect_object (user_info_message, "failed", (GCallback) _publishing_facebook_facebook_publisher_on_fetch_user_info_error_publishing_facebook_graph_message_failed, self, 0);
#line 275 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp4_ = self->priv->graph_session;
#line 275 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_graph_session_send_message (_tmp4_, user_info_message);
#line 264 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_publishing_facebook_graph_message_unref0 (user_info_message);
#line 2532 "FacebookPublishing.c"
}


static void _publishing_facebook_facebook_publisher_on_fetch_albums_completed_publishing_facebook_graph_message_completed (PublishingFacebookGraphMessage* _sender, gpointer self) {
#line 286 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_facebook_publisher_on_fetch_albums_completed ((PublishingFacebookFacebookPublisher*) self, _sender);
#line 2539 "FacebookPublishing.c"
}


static void _publishing_facebook_facebook_publisher_on_fetch_albums_error_publishing_facebook_graph_message_failed (PublishingFacebookGraphMessage* _sender, GError* err, gpointer self) {
#line 287 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_facebook_publisher_on_fetch_albums_error ((PublishingFacebookFacebookPublisher*) self, _sender, err);
#line 2546 "FacebookPublishing.c"
}


static void publishing_facebook_facebook_publisher_do_fetch_album_descriptions (PublishingFacebookFacebookPublisher* self) {
	SpitPublishingPluginHost* _tmp0_ = NULL;
	SpitPublishingPluginHost* _tmp1_ = NULL;
	PublishingFacebookGraphMessage* albums_message = NULL;
	PublishingFacebookGraphSession* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	PublishingFacebookGraphMessage* _tmp6_ = NULL;
	PublishingFacebookGraphMessage* _tmp7_ = NULL;
	PublishingFacebookGraphSession* _tmp8_ = NULL;
#line 278 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_FACEBOOK_PUBLISHER (self));
#line 279 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_debug ("FacebookPublishing.vala:279: ACTION: fetching album list.");
#line 281 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = self->priv->host;
#line 281 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	spit_publishing_plugin_host_set_service_locked (_tmp0_, TRUE);
#line 282 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp1_ = self->priv->host;
#line 282 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	spit_publishing_plugin_host_install_account_fetch_wait_pane (_tmp1_);
#line 284 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp2_ = self->priv->graph_session;
#line 284 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp3_ = self->priv->uid;
#line 284 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp4_ = g_strdup_printf ("/%s/albums", _tmp3_);
#line 284 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp5_ = _tmp4_;
#line 284 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp6_ = publishing_facebook_graph_session_new_query (_tmp2_, _tmp5_);
#line 284 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp7_ = _tmp6_;
#line 284 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_free0 (_tmp5_);
#line 284 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	albums_message = _tmp7_;
#line 286 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_connect_object (albums_message, "completed", (GCallback) _publishing_facebook_facebook_publisher_on_fetch_albums_completed_publishing_facebook_graph_message_completed, self, 0);
#line 287 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_connect_object (albums_message, "failed", (GCallback) _publishing_facebook_facebook_publisher_on_fetch_albums_error_publishing_facebook_graph_message_failed, self, 0);
#line 289 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp8_ = self->priv->graph_session;
#line 289 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_graph_session_send_message (_tmp8_, albums_message);
#line 278 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_publishing_facebook_graph_message_unref0 (albums_message);
#line 2599 "FacebookPublishing.c"
}


static JsonNode* _vala_JsonNode_copy (JsonNode* self) {
#line 299 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return g_boxed_copy (json_node_get_type (), self);
#line 2606 "FacebookPublishing.c"
}


static gpointer __vala_JsonNode_copy0 (gpointer self) {
#line 299 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return self ? _vala_JsonNode_copy (self) : NULL;
#line 2613 "FacebookPublishing.c"
}


static gpointer _json_object_ref0 (gpointer self) {
#line 300 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return self ? json_object_ref (self) : NULL;
#line 2620 "FacebookPublishing.c"
}


static void _vala_JsonNode_free (JsonNode* self) {
#line 295 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_boxed_free (json_node_get_type (), self);
#line 2627 "FacebookPublishing.c"
}


static void publishing_facebook_facebook_publisher_do_extract_user_info_from_json (PublishingFacebookFacebookPublisher* self, const gchar* json) {
	GError * _inner_error_ = NULL;
#line 292 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_FACEBOOK_PUBLISHER (self));
#line 292 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (json != NULL);
#line 293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_debug ("FacebookPublishing.vala:293: ACTION: extracting user info from JSON re" \
"sponse.");
#line 2639 "FacebookPublishing.c"
	{
		JsonParser* parser = NULL;
		JsonParser* _tmp0_ = NULL;
		JsonParser* _tmp1_ = NULL;
		const gchar* _tmp2_ = NULL;
		JsonNode* root = NULL;
		JsonParser* _tmp3_ = NULL;
		JsonNode* _tmp4_ = NULL;
		JsonNode* _tmp5_ = NULL;
		JsonObject* response_object = NULL;
		JsonNode* _tmp6_ = NULL;
		JsonObject* _tmp7_ = NULL;
		JsonObject* _tmp8_ = NULL;
		JsonObject* _tmp9_ = NULL;
		const gchar* _tmp10_ = NULL;
		gchar* _tmp11_ = NULL;
		JsonObject* _tmp12_ = NULL;
		const gchar* _tmp13_ = NULL;
		gchar* _tmp14_ = NULL;
#line 296 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp0_ = json_parser_new ();
#line 296 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		parser = _tmp0_;
#line 297 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp1_ = parser;
#line 297 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp2_ = json;
#line 297 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		json_parser_load_from_data (_tmp1_, _tmp2_, (gssize) -1, &_inner_error_);
#line 297 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 297 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			_g_object_unref0 (parser);
#line 2673 "FacebookPublishing.c"
			goto __catch0_g_error;
		}
#line 299 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp3_ = parser;
#line 299 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp4_ = json_parser_get_root (_tmp3_);
#line 299 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp5_ = __vala_JsonNode_copy0 (_tmp4_);
#line 299 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		root = _tmp5_;
#line 300 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp6_ = root;
#line 300 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp7_ = json_node_get_object (_tmp6_);
#line 300 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp8_ = _json_object_ref0 (_tmp7_);
#line 300 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		response_object = _tmp8_;
#line 301 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp9_ = response_object;
#line 301 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp10_ = json_object_get_string_member (_tmp9_, "id");
#line 301 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp11_ = g_strdup (_tmp10_);
#line 301 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_g_free0 (self->priv->uid);
#line 301 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		self->priv->uid = _tmp11_;
#line 302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp12_ = response_object;
#line 302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp13_ = json_object_get_string_member (_tmp12_, "name");
#line 302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp14_ = g_strdup (_tmp13_);
#line 302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_g_free0 (self->priv->username);
#line 302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		self->priv->username = _tmp14_;
#line 295 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_json_object_unref0 (response_object);
#line 295 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		__vala_JsonNode_free0 (root);
#line 295 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_g_object_unref0 (parser);
#line 2718 "FacebookPublishing.c"
	}
	goto __finally0;
	__catch0_g_error:
	{
		GError* _error_ = NULL;
		SpitPublishingPluginHost* _tmp15_ = NULL;
		GError* _tmp16_ = NULL;
		const gchar* _tmp17_ = NULL;
		GError* _tmp18_ = NULL;
		GError* _tmp19_ = NULL;
#line 295 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_error_ = _inner_error_;
#line 295 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_inner_error_ = NULL;
#line 304 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp15_ = self->priv->host;
#line 304 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp16_ = _error_;
#line 304 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp17_ = _tmp16_->message;
#line 304 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp18_ = g_error_new_literal (SPIT_PUBLISHING_PUBLISHING_ERROR, SPIT_PUBLISHING_PUBLISHING_ERROR_MALFORMED_RESPONSE, _tmp17_);
#line 304 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp19_ = _tmp18_;
#line 304 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		spit_publishing_plugin_host_post_error (_tmp15_, _tmp19_);
#line 304 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_g_error_free0 (_tmp19_);
#line 305 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_g_error_free0 (_error_);
#line 305 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		return;
#line 2751 "FacebookPublishing.c"
	}
	__finally0:
#line 295 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 295 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 295 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		g_clear_error (&_inner_error_);
#line 295 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		return;
#line 2762 "FacebookPublishing.c"
	}
#line 308 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_facebook_publisher_on_user_info_extracted (self);
#line 2766 "FacebookPublishing.c"
}


static gpointer _json_array_ref0 (gpointer self) {
#line 320 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return self ? json_array_ref (self) : NULL;
#line 2773 "FacebookPublishing.c"
}


static void publishing_facebook_facebook_publisher_do_extract_albums_from_json (PublishingFacebookFacebookPublisher* self, const gchar* json) {
	GError * _inner_error_ = NULL;
#line 311 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_FACEBOOK_PUBLISHER (self));
#line 311 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (json != NULL);
#line 312 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_debug ("FacebookPublishing.vala:312: ACTION: extracting album info from JSON r" \
"esponse.");
#line 2785 "FacebookPublishing.c"
	{
		JsonParser* parser = NULL;
		JsonParser* _tmp0_ = NULL;
		JsonParser* _tmp1_ = NULL;
		const gchar* _tmp2_ = NULL;
		JsonNode* root = NULL;
		JsonParser* _tmp3_ = NULL;
		JsonNode* _tmp4_ = NULL;
		JsonNode* _tmp5_ = NULL;
		JsonObject* response_object = NULL;
		JsonNode* _tmp6_ = NULL;
		JsonObject* _tmp7_ = NULL;
		JsonObject* _tmp8_ = NULL;
		JsonArray* album_list = NULL;
		JsonObject* _tmp9_ = NULL;
		JsonArray* _tmp10_ = NULL;
		JsonArray* _tmp11_ = NULL;
		PublishingFacebookPublishingParameters* _tmp12_ = NULL;
		PublishingFacebookAlbum** _tmp13_ = NULL;
#line 315 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp0_ = json_parser_new ();
#line 315 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		parser = _tmp0_;
#line 316 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp1_ = parser;
#line 316 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp2_ = json;
#line 316 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		json_parser_load_from_data (_tmp1_, _tmp2_, (gssize) -1, &_inner_error_);
#line 316 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 316 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			_g_object_unref0 (parser);
#line 2819 "FacebookPublishing.c"
			goto __catch1_g_error;
		}
#line 318 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp3_ = parser;
#line 318 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp4_ = json_parser_get_root (_tmp3_);
#line 318 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp5_ = __vala_JsonNode_copy0 (_tmp4_);
#line 318 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		root = _tmp5_;
#line 319 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp6_ = root;
#line 319 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp7_ = json_node_get_object (_tmp6_);
#line 319 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp8_ = _json_object_ref0 (_tmp7_);
#line 319 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		response_object = _tmp8_;
#line 320 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp9_ = response_object;
#line 320 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp10_ = json_object_get_array_member (_tmp9_, "data");
#line 320 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp11_ = _json_array_ref0 (_tmp10_);
#line 320 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		album_list = _tmp11_;
#line 322 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp12_ = self->priv->publishing_params;
#line 322 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp13_ = g_new0 (PublishingFacebookAlbum*, 0 + 1);
#line 322 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp12_->albums = (_vala_array_free (_tmp12_->albums, _tmp12_->albums_length1, (GDestroyNotify) publishing_facebook_album_unref), NULL);
#line 322 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp12_->albums = _tmp13_;
#line 322 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp12_->albums_length1 = 0;
#line 322 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp12_->_albums_size_ = _tmp12_->albums_length1;
#line 2858 "FacebookPublishing.c"
		{
			gint i = 0;
#line 324 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			i = 0;
#line 2863 "FacebookPublishing.c"
			{
				gboolean _tmp14_ = FALSE;
#line 324 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				_tmp14_ = TRUE;
#line 324 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				while (TRUE) {
#line 2870 "FacebookPublishing.c"
					gint _tmp16_ = 0;
					JsonArray* _tmp17_ = NULL;
					guint _tmp18_ = 0U;
					JsonObject* current_album = NULL;
					JsonArray* _tmp19_ = NULL;
					gint _tmp20_ = 0;
					JsonObject* _tmp21_ = NULL;
					JsonObject* _tmp22_ = NULL;
					gchar* album_id = NULL;
					JsonObject* _tmp23_ = NULL;
					const gchar* _tmp24_ = NULL;
					gchar* _tmp25_ = NULL;
					gchar* album_name = NULL;
					JsonObject* _tmp26_ = NULL;
					const gchar* _tmp27_ = NULL;
					gchar* _tmp28_ = NULL;
					PublishingFacebookPublishingParameters* _tmp29_ = NULL;
					const gchar* _tmp30_ = NULL;
					const gchar* _tmp31_ = NULL;
#line 324 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
					if (!_tmp14_) {
#line 2892 "FacebookPublishing.c"
						gint _tmp15_ = 0;
#line 324 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
						_tmp15_ = i;
#line 324 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
						i = _tmp15_ + 1;
#line 2898 "FacebookPublishing.c"
					}
#line 324 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
					_tmp14_ = FALSE;
#line 324 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
					_tmp16_ = i;
#line 324 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
					_tmp17_ = album_list;
#line 324 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
					_tmp18_ = json_array_get_length (_tmp17_);
#line 324 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
					if (!(((guint) _tmp16_) < _tmp18_)) {
#line 324 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
						break;
#line 2912 "FacebookPublishing.c"
					}
#line 325 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
					_tmp19_ = album_list;
#line 325 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
					_tmp20_ = i;
#line 325 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
					_tmp21_ = json_array_get_object_element (_tmp19_, (guint) _tmp20_);
#line 325 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
					_tmp22_ = _json_object_ref0 (_tmp21_);
#line 325 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
					current_album = _tmp22_;
#line 326 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
					_tmp23_ = current_album;
#line 326 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
					_tmp24_ = json_object_get_string_member (_tmp23_, "id");
#line 326 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
					_tmp25_ = g_strdup (_tmp24_);
#line 326 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
					album_id = _tmp25_;
#line 327 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
					_tmp26_ = current_album;
#line 327 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
					_tmp27_ = json_object_get_string_member (_tmp26_, "name");
#line 327 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
					_tmp28_ = g_strdup (_tmp27_);
#line 327 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
					album_name = _tmp28_;
#line 334 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
					_tmp29_ = self->priv->publishing_params;
#line 334 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
					_tmp30_ = album_name;
#line 334 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
					_tmp31_ = album_id;
#line 334 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
					publishing_facebook_publishing_parameters_add_album (_tmp29_, _tmp30_, _tmp31_);
#line 324 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
					_g_free0 (album_name);
#line 324 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
					_g_free0 (album_id);
#line 324 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
					_json_object_unref0 (current_album);
#line 2954 "FacebookPublishing.c"
				}
			}
		}
#line 314 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_json_array_unref0 (album_list);
#line 314 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_json_object_unref0 (response_object);
#line 314 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		__vala_JsonNode_free0 (root);
#line 314 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_g_object_unref0 (parser);
#line 2966 "FacebookPublishing.c"
	}
	goto __finally1;
	__catch1_g_error:
	{
		GError* _error_ = NULL;
		SpitPublishingPluginHost* _tmp32_ = NULL;
		GError* _tmp33_ = NULL;
		const gchar* _tmp34_ = NULL;
		GError* _tmp35_ = NULL;
		GError* _tmp36_ = NULL;
#line 314 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_error_ = _inner_error_;
#line 314 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_inner_error_ = NULL;
#line 337 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp32_ = self->priv->host;
#line 337 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp33_ = _error_;
#line 337 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp34_ = _tmp33_->message;
#line 337 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp35_ = g_error_new_literal (SPIT_PUBLISHING_PUBLISHING_ERROR, SPIT_PUBLISHING_PUBLISHING_ERROR_MALFORMED_RESPONSE, _tmp34_);
#line 337 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp36_ = _tmp35_;
#line 337 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		spit_publishing_plugin_host_post_error (_tmp32_, _tmp36_);
#line 337 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_g_error_free0 (_tmp36_);
#line 338 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_g_error_free0 (_error_);
#line 338 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		return;
#line 2999 "FacebookPublishing.c"
	}
	__finally1:
#line 314 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 314 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 314 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		g_clear_error (&_inner_error_);
#line 314 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		return;
#line 3010 "FacebookPublishing.c"
	}
#line 341 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_facebook_publisher_on_albums_extracted (self);
#line 3014 "FacebookPublishing.c"
}


static void _publishing_facebook_facebook_publisher_on_create_album_completed_publishing_facebook_graph_message_completed (PublishingFacebookGraphMessage* _sender, gpointer self) {
#line 353 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_facebook_publisher_on_create_album_completed ((PublishingFacebookFacebookPublisher*) self, _sender);
#line 3021 "FacebookPublishing.c"
}


static void _publishing_facebook_facebook_publisher_on_create_album_error_publishing_facebook_graph_message_failed (PublishingFacebookGraphMessage* _sender, GError* err, gpointer self) {
#line 354 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_facebook_publisher_on_create_album_error ((PublishingFacebookFacebookPublisher*) self, _sender, err);
#line 3028 "FacebookPublishing.c"
}


static void publishing_facebook_facebook_publisher_do_create_new_album (PublishingFacebookFacebookPublisher* self) {
	PublishingFacebookPublishingParameters* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	SpitPublishingPluginHost* _tmp2_ = NULL;
	SpitPublishingPluginHost* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	PublishingFacebookGraphMessage* create_album_message = NULL;
	PublishingFacebookGraphSession* _tmp5_ = NULL;
	PublishingFacebookPublishingParameters* _tmp6_ = NULL;
	const gchar* _tmp7_ = NULL;
	PublishingFacebookPublishingParameters* _tmp8_ = NULL;
	const gchar* _tmp9_ = NULL;
	PublishingFacebookGraphMessage* _tmp10_ = NULL;
	PublishingFacebookGraphSession* _tmp11_ = NULL;
#line 344 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_FACEBOOK_PUBLISHER (self));
#line 345 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = self->priv->publishing_params;
#line 345 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp1_ = _tmp0_->new_album_name;
#line 345 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_debug ("FacebookPublishing.vala:345: ACTION: creating a new album named \"%s\"" \
".\n", _tmp1_);
#line 347 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp2_ = self->priv->host;
#line 347 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	spit_publishing_plugin_host_set_service_locked (_tmp2_, TRUE);
#line 348 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp3_ = self->priv->host;
#line 348 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp4_ = _ ("Creating album...");
#line 348 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	spit_publishing_plugin_host_install_static_message_pane (_tmp3_, _tmp4_, SPIT_PUBLISHING_PLUGIN_HOST_BUTTON_MODE_CANCEL);
#line 350 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp5_ = self->priv->graph_session;
#line 350 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp6_ = self->priv->publishing_params;
#line 350 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp7_ = _tmp6_->new_album_name;
#line 350 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp8_ = self->priv->publishing_params;
#line 350 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp9_ = _tmp8_->privacy_object;
#line 350 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp10_ = publishing_facebook_graph_session_new_create_album (_tmp5_, _tmp7_, _tmp9_);
#line 350 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	create_album_message = _tmp10_;
#line 353 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_connect_object (create_album_message, "completed", (GCallback) _publishing_facebook_facebook_publisher_on_create_album_completed_publishing_facebook_graph_message_completed, self, 0);
#line 354 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_connect_object (create_album_message, "failed", (GCallback) _publishing_facebook_facebook_publisher_on_create_album_error_publishing_facebook_graph_message_failed, self, 0);
#line 356 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp11_ = self->priv->graph_session;
#line 356 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_graph_session_send_message (_tmp11_, create_album_message);
#line 344 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_publishing_facebook_graph_message_unref0 (create_album_message);
#line 3088 "FacebookPublishing.c"
}


static void _publishing_facebook_facebook_publisher_on_publishing_options_pane_logout_publishing_facebook_publishing_options_pane_logout (PublishingFacebookPublishingOptionsPane* _sender, gpointer self) {
#line 380 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_facebook_publisher_on_publishing_options_pane_logout ((PublishingFacebookFacebookPublisher*) self);
#line 3095 "FacebookPublishing.c"
}


static void _publishing_facebook_facebook_publisher_on_publishing_options_pane_publish_publishing_facebook_publishing_options_pane_publish (PublishingFacebookPublishingOptionsPane* _sender, const gchar* target_album, const gchar* privacy_setting, PublishingFacebookResolution target_resolution, gboolean strip_metadata, gpointer self) {
#line 381 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_facebook_publisher_on_publishing_options_pane_publish ((PublishingFacebookFacebookPublisher*) self, target_album, privacy_setting, target_resolution, strip_metadata);
#line 3102 "FacebookPublishing.c"
}


static void publishing_facebook_facebook_publisher_do_show_publishing_options_pane (PublishingFacebookFacebookPublisher* self) {
	SpitPublishingPluginHost* _tmp0_ = NULL;
	GtkBuilder* builder = NULL;
	GtkBuilder* _tmp1_ = NULL;
	const gchar* _tmp9_ = NULL;
	PublishingFacebookPublishingParameters* _tmp10_ = NULL;
	PublishingFacebookAlbum** _tmp11_ = NULL;
	gint _tmp11__length1 = 0;
	SpitPublishingPluginHost* _tmp12_ = NULL;
	SpitPublishingPublisherMediaType _tmp13_ = 0;
	GtkBuilder* _tmp14_ = NULL;
	gboolean _tmp15_ = FALSE;
	PublishingFacebookPublishingOptionsPane* _tmp16_ = NULL;
	PublishingFacebookPublishingOptionsPane* _tmp17_ = NULL;
	PublishingFacebookPublishingOptionsPane* _tmp18_ = NULL;
	SpitPublishingPluginHost* _tmp19_ = NULL;
	PublishingFacebookPublishingOptionsPane* _tmp20_ = NULL;
	GError * _inner_error_ = NULL;
#line 359 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_FACEBOOK_PUBLISHER (self));
#line 360 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_debug ("FacebookPublishing.vala:360: ACTION: showing publishing options pane.");
#line 362 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = self->priv->host;
#line 362 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	spit_publishing_plugin_host_set_service_locked (_tmp0_, FALSE);
#line 363 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp1_ = gtk_builder_new ();
#line 363 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	builder = _tmp1_;
#line 3136 "FacebookPublishing.c"
	{
		GtkBuilder* _tmp2_ = NULL;
#line 368 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp2_ = builder;
#line 368 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		gtk_builder_add_from_resource (_tmp2_, PLUGIN_RESOURCE_PATH "/" "facebook_publishing_options_pane.ui", &_inner_error_);
#line 368 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3145 "FacebookPublishing.c"
			goto __catch2_g_error;
		}
	}
	goto __finally2;
	__catch2_g_error:
	{
		GError* e = NULL;
		GError* _tmp3_ = NULL;
		const gchar* _tmp4_ = NULL;
		SpitPublishingPluginHost* _tmp5_ = NULL;
		const gchar* _tmp6_ = NULL;
		GError* _tmp7_ = NULL;
		GError* _tmp8_ = NULL;
#line 365 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		e = _inner_error_;
#line 365 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_inner_error_ = NULL;
#line 371 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp3_ = e;
#line 371 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp4_ = _tmp3_->message;
#line 371 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		g_warning ("FacebookPublishing.vala:371: Could not parse UI file! Error: %s.", _tmp4_);
#line 372 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp5_ = self->priv->host;
#line 372 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp6_ = _ ("A file required for publishing is unavailable. Publishing to Facebook " \
"can't continue.");
#line 372 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp7_ = g_error_new_literal (SPIT_PUBLISHING_PUBLISHING_ERROR, SPIT_PUBLISHING_PUBLISHING_ERROR_LOCAL_FILE_ERROR, _tmp6_);
#line 372 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp8_ = _tmp7_;
#line 372 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		spit_publishing_plugin_host_post_error (_tmp5_, _tmp8_);
#line 372 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_g_error_free0 (_tmp8_);
#line 375 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_g_error_free0 (e);
#line 375 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_g_object_unref0 (builder);
#line 375 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		return;
#line 3187 "FacebookPublishing.c"
	}
	__finally2:
#line 365 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 365 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_g_object_unref0 (builder);
#line 365 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 365 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		g_clear_error (&_inner_error_);
#line 365 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		return;
#line 3200 "FacebookPublishing.c"
	}
#line 378 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp9_ = self->priv->username;
#line 378 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp10_ = self->priv->publishing_params;
#line 378 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp11_ = _tmp10_->albums;
#line 378 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp11__length1 = _tmp10_->albums_length1;
#line 378 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp12_ = self->priv->host;
#line 378 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp13_ = spit_publishing_plugin_host_get_publishable_media_type (_tmp12_);
#line 378 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp14_ = builder;
#line 378 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp15_ = publishing_facebook_facebook_publisher_get_persistent_strip_metadata (self);
#line 378 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp16_ = publishing_facebook_publishing_options_pane_new (_tmp9_, _tmp11_, _tmp11__length1, _tmp13_, self, _tmp14_, _tmp15_);
#line 378 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_object_unref0 (self->priv->publishing_options_pane);
#line 378 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->publishing_options_pane = _tmp16_;
#line 380 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp17_ = self->priv->publishing_options_pane;
#line 380 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_connect_object (_tmp17_, "logout", (GCallback) _publishing_facebook_facebook_publisher_on_publishing_options_pane_logout_publishing_facebook_publishing_options_pane_logout, self, 0);
#line 381 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp18_ = self->priv->publishing_options_pane;
#line 381 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_connect_object (_tmp18_, "publish", (GCallback) _publishing_facebook_facebook_publisher_on_publishing_options_pane_publish_publishing_facebook_publishing_options_pane_publish, self, 0);
#line 382 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp19_ = self->priv->host;
#line 382 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp20_ = self->priv->publishing_options_pane;
#line 382 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	spit_publishing_plugin_host_install_dialog_pane (_tmp19_, G_TYPE_CHECK_INSTANCE_CAST (_tmp20_, SPIT_PUBLISHING_TYPE_DIALOG_PANE, SpitPublishingDialogPane), SPIT_PUBLISHING_PLUGIN_HOST_BUTTON_MODE_CANCEL);
#line 359 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_object_unref0 (builder);
#line 3240 "FacebookPublishing.c"
}


static void publishing_facebook_facebook_publisher_do_logout (PublishingFacebookFacebookPublisher* self) {
#line 386 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_FACEBOOK_PUBLISHER (self));
#line 387 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_debug ("FacebookPublishing.vala:387: ACTION: clearing persistent session infor" \
"mation and restaring interaction.");
#line 389 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_facebook_publisher_invalidate_persistent_session (self);
#line 391 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->running = FALSE;
#line 392 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	spit_publishing_publisher_start (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher));
#line 3255 "FacebookPublishing.c"
}


static void publishing_facebook_facebook_publisher_do_add_new_local_album_from_json (PublishingFacebookFacebookPublisher* self, const gchar* album_name, const gchar* json) {
	PublishingFacebookPublishingParameters* _tmp20_ = NULL;
	const gchar* _tmp21_ = NULL;
	GError * _inner_error_ = NULL;
#line 395 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_FACEBOOK_PUBLISHER (self));
#line 395 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (album_name != NULL);
#line 395 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (json != NULL);
#line 3269 "FacebookPublishing.c"
	{
		JsonParser* parser = NULL;
		JsonParser* _tmp0_ = NULL;
		JsonParser* _tmp1_ = NULL;
		const gchar* _tmp2_ = NULL;
		JsonNode* root = NULL;
		JsonParser* _tmp3_ = NULL;
		JsonNode* _tmp4_ = NULL;
		JsonNode* _tmp5_ = NULL;
		JsonObject* response_object = NULL;
		JsonNode* _tmp6_ = NULL;
		JsonObject* _tmp7_ = NULL;
		JsonObject* _tmp8_ = NULL;
		gchar* album_id = NULL;
		JsonObject* _tmp9_ = NULL;
		const gchar* _tmp10_ = NULL;
		gchar* _tmp11_ = NULL;
		PublishingFacebookPublishingParameters* _tmp12_ = NULL;
		const gchar* _tmp13_ = NULL;
		const gchar* _tmp14_ = NULL;
#line 397 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp0_ = json_parser_new ();
#line 397 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		parser = _tmp0_;
#line 398 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp1_ = parser;
#line 398 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp2_ = json;
#line 398 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		json_parser_load_from_data (_tmp1_, _tmp2_, (gssize) -1, &_inner_error_);
#line 398 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 398 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			_g_object_unref0 (parser);
#line 3304 "FacebookPublishing.c"
			goto __catch3_g_error;
		}
#line 400 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp3_ = parser;
#line 400 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp4_ = json_parser_get_root (_tmp3_);
#line 400 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp5_ = __vala_JsonNode_copy0 (_tmp4_);
#line 400 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		root = _tmp5_;
#line 401 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp6_ = root;
#line 401 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp7_ = json_node_get_object (_tmp6_);
#line 401 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp8_ = _json_object_ref0 (_tmp7_);
#line 401 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		response_object = _tmp8_;
#line 402 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp9_ = response_object;
#line 402 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp10_ = json_object_get_string_member (_tmp9_, "id");
#line 402 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp11_ = g_strdup (_tmp10_);
#line 402 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		album_id = _tmp11_;
#line 404 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp12_ = self->priv->publishing_params;
#line 404 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp13_ = album_name;
#line 404 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp14_ = album_id;
#line 404 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		publishing_facebook_publishing_parameters_add_album (_tmp12_, _tmp13_, _tmp14_);
#line 396 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_g_free0 (album_id);
#line 396 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_json_object_unref0 (response_object);
#line 396 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		__vala_JsonNode_free0 (root);
#line 396 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_g_object_unref0 (parser);
#line 3347 "FacebookPublishing.c"
	}
	goto __finally3;
	__catch3_g_error:
	{
		GError* _error_ = NULL;
		SpitPublishingPluginHost* _tmp15_ = NULL;
		GError* _tmp16_ = NULL;
		const gchar* _tmp17_ = NULL;
		GError* _tmp18_ = NULL;
		GError* _tmp19_ = NULL;
#line 396 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_error_ = _inner_error_;
#line 396 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_inner_error_ = NULL;
#line 406 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp15_ = self->priv->host;
#line 406 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp16_ = _error_;
#line 406 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp17_ = _tmp16_->message;
#line 406 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp18_ = g_error_new_literal (SPIT_PUBLISHING_PUBLISHING_ERROR, SPIT_PUBLISHING_PUBLISHING_ERROR_MALFORMED_RESPONSE, _tmp17_);
#line 406 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp19_ = _tmp18_;
#line 406 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		spit_publishing_plugin_host_post_error (_tmp15_, _tmp19_);
#line 406 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_g_error_free0 (_tmp19_);
#line 407 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_g_error_free0 (_error_);
#line 407 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		return;
#line 3380 "FacebookPublishing.c"
	}
	__finally3:
#line 396 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 396 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 396 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		g_clear_error (&_inner_error_);
#line 396 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		return;
#line 3391 "FacebookPublishing.c"
	}
#line 410 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp20_ = self->priv->publishing_params;
#line 410 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp21_ = album_name;
#line 410 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_publishing_parameters_set_target_album_by_name (_tmp20_, _tmp21_);
#line 411 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_facebook_publisher_do_upload (self);
#line 3401 "FacebookPublishing.c"
}


static void _publishing_facebook_facebook_publisher_on_web_auth_pane_login_succeeded_publishing_facebook_web_authentication_pane_login_succeeded (PublishingFacebookWebAuthenticationPane* _sender, const gchar* success_url, gpointer self) {
#line 420 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_facebook_publisher_on_web_auth_pane_login_succeeded ((PublishingFacebookFacebookPublisher*) self, success_url);
#line 3408 "FacebookPublishing.c"
}


static void _publishing_facebook_facebook_publisher_on_web_auth_pane_login_failed_publishing_facebook_web_authentication_pane_login_failed (PublishingFacebookWebAuthenticationPane* _sender, gpointer self) {
#line 421 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_facebook_publisher_on_web_auth_pane_login_failed ((PublishingFacebookFacebookPublisher*) self);
#line 3415 "FacebookPublishing.c"
}


static void publishing_facebook_facebook_publisher_do_hosted_web_authentication (PublishingFacebookFacebookPublisher* self) {
	SpitPublishingPluginHost* _tmp0_ = NULL;
	PublishingFacebookWebAuthenticationPane* _tmp1_ = NULL;
	PublishingFacebookWebAuthenticationPane* _tmp2_ = NULL;
	PublishingFacebookWebAuthenticationPane* _tmp3_ = NULL;
	SpitPublishingPluginHost* _tmp4_ = NULL;
	PublishingFacebookWebAuthenticationPane* _tmp5_ = NULL;
#line 414 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_FACEBOOK_PUBLISHER (self));
#line 415 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_debug ("FacebookPublishing.vala:415: ACTION: doing hosted web authentication.");
#line 417 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = self->priv->host;
#line 417 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	spit_publishing_plugin_host_set_service_locked (_tmp0_, FALSE);
#line 419 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp1_ = publishing_facebook_web_authentication_pane_new ();
#line 419 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_object_unref0 (self->priv->web_auth_pane);
#line 419 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->web_auth_pane = _tmp1_;
#line 420 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp2_ = self->priv->web_auth_pane;
#line 420 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_connect_object (_tmp2_, "login-succeeded", (GCallback) _publishing_facebook_facebook_publisher_on_web_auth_pane_login_succeeded_publishing_facebook_web_authentication_pane_login_succeeded, self, 0);
#line 421 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp3_ = self->priv->web_auth_pane;
#line 421 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_connect_object (_tmp3_, "login-failed", (GCallback) _publishing_facebook_facebook_publisher_on_web_auth_pane_login_failed_publishing_facebook_web_authentication_pane_login_failed, self, 0);
#line 423 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp4_ = self->priv->host;
#line 423 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp5_ = self->priv->web_auth_pane;
#line 423 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	spit_publishing_plugin_host_install_dialog_pane (_tmp4_, G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, SPIT_PUBLISHING_TYPE_DIALOG_PANE, SpitPublishingDialogPane), SPIT_PUBLISHING_PLUGIN_HOST_BUTTON_MODE_CANCEL);
#line 3454 "FacebookPublishing.c"
}


static gint string_index_of (const gchar* self, const gchar* needle, gint start_index) {
	gint result = 0;
	gchar* _result_ = NULL;
	gint _tmp0_ = 0;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
#line 987 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, 0);
#line 987 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	g_return_val_if_fail (needle != NULL, 0);
#line 988 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp0_ = start_index;
#line 988 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp1_ = needle;
#line 988 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp2_ = strstr (((gchar*) self) + _tmp0_, (gchar*) _tmp1_);
#line 988 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_result_ = _tmp2_;
#line 990 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp3_ = _result_;
#line 990 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	if (_tmp3_ != NULL) {
#line 3481 "FacebookPublishing.c"
		gchar* _tmp4_ = NULL;
#line 991 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp4_ = _result_;
#line 991 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		result = (gint) (_tmp4_ - ((gchar*) self));
#line 991 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		return result;
#line 3489 "FacebookPublishing.c"
	} else {
#line 993 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		result = -1;
#line 993 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		return result;
#line 3495 "FacebookPublishing.c"
	}
}


static gchar* string_slice (const gchar* self, glong start, glong end) {
	gchar* result = NULL;
	glong string_length = 0L;
	gint _tmp0_ = 0;
	gint _tmp1_ = 0;
	glong _tmp2_ = 0L;
	glong _tmp5_ = 0L;
	gboolean _tmp8_ = FALSE;
	glong _tmp9_ = 0L;
	gboolean _tmp12_ = FALSE;
	glong _tmp13_ = 0L;
	glong _tmp16_ = 0L;
	glong _tmp17_ = 0L;
	glong _tmp18_ = 0L;
	glong _tmp19_ = 0L;
	glong _tmp20_ = 0L;
	gchar* _tmp21_ = NULL;
#line 1328 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1329 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp0_ = strlen (self);
#line 1329 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp1_ = _tmp0_;
#line 1329 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	string_length = (glong) _tmp1_;
#line 1330 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp2_ = start;
#line 1330 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	if (_tmp2_ < ((glong) 0)) {
#line 3529 "FacebookPublishing.c"
		glong _tmp3_ = 0L;
		glong _tmp4_ = 0L;
#line 1331 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp3_ = string_length;
#line 1331 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp4_ = start;
#line 1331 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		start = _tmp3_ + _tmp4_;
#line 3538 "FacebookPublishing.c"
	}
#line 1333 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp5_ = end;
#line 1333 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	if (_tmp5_ < ((glong) 0)) {
#line 3544 "FacebookPublishing.c"
		glong _tmp6_ = 0L;
		glong _tmp7_ = 0L;
#line 1334 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp6_ = string_length;
#line 1334 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp7_ = end;
#line 1334 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		end = _tmp6_ + _tmp7_;
#line 3553 "FacebookPublishing.c"
	}
#line 1336 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp9_ = start;
#line 1336 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	if (_tmp9_ >= ((glong) 0)) {
#line 3559 "FacebookPublishing.c"
		glong _tmp10_ = 0L;
		glong _tmp11_ = 0L;
#line 1336 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp10_ = start;
#line 1336 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp11_ = string_length;
#line 1336 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp8_ = _tmp10_ <= _tmp11_;
#line 3568 "FacebookPublishing.c"
	} else {
#line 1336 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp8_ = FALSE;
#line 3572 "FacebookPublishing.c"
	}
#line 1336 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	g_return_val_if_fail (_tmp8_, NULL);
#line 1337 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp13_ = end;
#line 1337 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	if (_tmp13_ >= ((glong) 0)) {
#line 3580 "FacebookPublishing.c"
		glong _tmp14_ = 0L;
		glong _tmp15_ = 0L;
#line 1337 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp14_ = end;
#line 1337 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp15_ = string_length;
#line 1337 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp12_ = _tmp14_ <= _tmp15_;
#line 3589 "FacebookPublishing.c"
	} else {
#line 1337 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp12_ = FALSE;
#line 3593 "FacebookPublishing.c"
	}
#line 1337 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	g_return_val_if_fail (_tmp12_, NULL);
#line 1338 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp16_ = start;
#line 1338 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp17_ = end;
#line 1338 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	g_return_val_if_fail (_tmp16_ <= _tmp17_, NULL);
#line 1339 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp18_ = start;
#line 1339 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp19_ = end;
#line 1339 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp20_ = start;
#line 1339 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp21_ = g_strndup (((gchar*) self) + _tmp18_, (gsize) (_tmp19_ - _tmp20_));
#line 1339 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	result = _tmp21_;
#line 1339 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	return result;
#line 3615 "FacebookPublishing.c"
}


static gint string_index_of_char (const gchar* self, gunichar c, gint start_index) {
	gint result = 0;
	gchar* _result_ = NULL;
	gint _tmp0_ = 0;
	gunichar _tmp1_ = 0U;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
#line 1007 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, 0);
#line 1008 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp0_ = start_index;
#line 1008 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp1_ = c;
#line 1008 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp2_ = g_utf8_strchr (((gchar*) self) + _tmp0_, (gssize) -1, _tmp1_);
#line 1008 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_result_ = _tmp2_;
#line 1010 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp3_ = _result_;
#line 1010 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	if (_tmp3_ != NULL) {
#line 3640 "FacebookPublishing.c"
		gchar* _tmp4_ = NULL;
#line 1011 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp4_ = _result_;
#line 1011 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		result = (gint) (_tmp4_ - ((gchar*) self));
#line 1011 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		return result;
#line 3648 "FacebookPublishing.c"
	} else {
#line 1013 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		result = -1;
#line 1013 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		return result;
#line 3654 "FacebookPublishing.c"
	}
}


static gchar* string_replace (const gchar* self, const gchar* old, const gchar* replacement) {
	gchar* result = NULL;
	GError * _inner_error_ = NULL;
#line 1380 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1380 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	g_return_val_if_fail (old != NULL, NULL);
#line 1380 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	g_return_val_if_fail (replacement != NULL, NULL);
#line 3668 "FacebookPublishing.c"
	{
		GRegex* regex = NULL;
		const gchar* _tmp0_ = NULL;
		gchar* _tmp1_ = NULL;
		gchar* _tmp2_ = NULL;
		GRegex* _tmp3_ = NULL;
		GRegex* _tmp4_ = NULL;
		gchar* _tmp5_ = NULL;
		GRegex* _tmp6_ = NULL;
		const gchar* _tmp7_ = NULL;
		gchar* _tmp8_ = NULL;
		gchar* _tmp9_ = NULL;
#line 1382 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp0_ = old;
#line 1382 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp1_ = g_regex_escape_string (_tmp0_, -1);
#line 1382 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp2_ = _tmp1_;
#line 1382 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp3_ = g_regex_new (_tmp2_, 0, 0, &_inner_error_);
#line 1382 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp4_ = _tmp3_;
#line 1382 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_g_free0 (_tmp2_);
#line 1382 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		regex = _tmp4_;
#line 1382 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1382 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
			if (_inner_error_->domain == G_REGEX_ERROR) {
#line 3699 "FacebookPublishing.c"
				goto __catch4_g_regex_error;
			}
#line 1382 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1382 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
			g_clear_error (&_inner_error_);
#line 1382 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
			return NULL;
#line 3708 "FacebookPublishing.c"
		}
#line 1383 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp6_ = regex;
#line 1383 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp7_ = replacement;
#line 1383 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp8_ = g_regex_replace_literal (_tmp6_, self, (gssize) -1, 0, _tmp7_, 0, &_inner_error_);
#line 1383 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp5_ = _tmp8_;
#line 1383 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1383 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
			_g_regex_unref0 (regex);
#line 1383 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
			if (_inner_error_->domain == G_REGEX_ERROR) {
#line 3724 "FacebookPublishing.c"
				goto __catch4_g_regex_error;
			}
#line 1383 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
			_g_regex_unref0 (regex);
#line 1383 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1383 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
			g_clear_error (&_inner_error_);
#line 1383 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
			return NULL;
#line 3735 "FacebookPublishing.c"
		}
#line 1383 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp9_ = _tmp5_;
#line 1383 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp5_ = NULL;
#line 1383 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		result = _tmp9_;
#line 1383 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_g_free0 (_tmp5_);
#line 1383 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_g_regex_unref0 (regex);
#line 1383 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		return result;
#line 3749 "FacebookPublishing.c"
	}
	goto __finally4;
	__catch4_g_regex_error:
	{
		GError* e = NULL;
#line 1381 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		e = _inner_error_;
#line 1381 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_inner_error_ = NULL;
#line 1385 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		g_assert_not_reached ();
#line 1381 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_g_error_free0 (e);
#line 3763 "FacebookPublishing.c"
	}
	__finally4:
#line 1381 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1381 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1381 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		g_clear_error (&_inner_error_);
#line 1381 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		return NULL;
#line 3774 "FacebookPublishing.c"
	}
}


static void publishing_facebook_facebook_publisher_do_authenticate_session (PublishingFacebookFacebookPublisher* self, const gchar* good_login_uri) {
	const gchar* _tmp0_ = NULL;
	gchar* decoded_uri = NULL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* access_token = NULL;
	gint index = 0;
	const gchar* _tmp3_ = NULL;
	gint _tmp4_ = 0;
	gint _tmp5_ = 0;
	const gchar* _tmp12_ = NULL;
	gchar* trailing_params = NULL;
	const gchar* _tmp16_ = NULL;
	gint _tmp17_ = 0;
	gint _tmp18_ = 0;
	const gchar* _tmp25_ = NULL;
	const gchar* _tmp29_ = NULL;
	gchar* _tmp30_ = NULL;
	PublishingFacebookGraphSession* _tmp31_ = NULL;
	PublishingFacebookGraphSession* _tmp32_ = NULL;
	const gchar* _tmp33_ = NULL;
#line 428 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_FACEBOOK_PUBLISHER (self));
#line 428 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (good_login_uri != NULL);
#line 429 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = good_login_uri;
#line 429 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_debug ("FacebookPublishing.vala:429: ACTION: preparing to extract session info" \
"rmation encoded in uri = '%s'", _tmp0_);
#line 433 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp1_ = good_login_uri;
#line 433 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp2_ = soup_uri_decode (_tmp1_);
#line 433 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	decoded_uri = _tmp2_;
#line 436 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	access_token = NULL;
#line 437 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp3_ = decoded_uri;
#line 437 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp4_ = string_index_of (_tmp3_, "#access_token=", 0);
#line 437 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	index = _tmp4_;
#line 438 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp5_ = index;
#line 438 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (_tmp5_ >= 0) {
#line 3826 "FacebookPublishing.c"
		const gchar* _tmp6_ = NULL;
		gint _tmp7_ = 0;
		const gchar* _tmp8_ = NULL;
		gint _tmp9_ = 0;
		gint _tmp10_ = 0;
		gchar* _tmp11_ = NULL;
#line 439 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp6_ = decoded_uri;
#line 439 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp7_ = index;
#line 439 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp8_ = decoded_uri;
#line 439 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp9_ = strlen (_tmp8_);
#line 439 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp10_ = _tmp9_;
#line 439 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp11_ = string_slice (_tmp6_, (glong) _tmp7_, (glong) _tmp10_);
#line 439 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_g_free0 (access_token);
#line 439 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		access_token = _tmp11_;
#line 3849 "FacebookPublishing.c"
	}
#line 440 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp12_ = access_token;
#line 440 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (_tmp12_ == NULL) {
#line 3855 "FacebookPublishing.c"
		SpitPublishingPluginHost* _tmp13_ = NULL;
		GError* _tmp14_ = NULL;
		GError* _tmp15_ = NULL;
#line 441 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp13_ = self->priv->host;
#line 441 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp14_ = g_error_new_literal (SPIT_PUBLISHING_PUBLISHING_ERROR, SPIT_PUBLISHING_PUBLISHING_ERROR_MALFORMED_RESPONSE, "Server redirect URL contained no access token");
#line 441 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp15_ = _tmp14_;
#line 441 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		spit_publishing_plugin_host_post_error (_tmp13_, _tmp15_);
#line 441 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_g_error_free0 (_tmp15_);
#line 443 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_g_free0 (access_token);
#line 443 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_g_free0 (decoded_uri);
#line 443 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		return;
#line 3875 "FacebookPublishing.c"
	}
#line 447 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	trailing_params = NULL;
#line 448 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp16_ = access_token;
#line 448 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp17_ = string_index_of_char (_tmp16_, (gunichar) '&', 0);
#line 448 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	index = _tmp17_;
#line 449 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp18_ = index;
#line 449 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (_tmp18_ >= 0) {
#line 3889 "FacebookPublishing.c"
		const gchar* _tmp19_ = NULL;
		gint _tmp20_ = 0;
		const gchar* _tmp21_ = NULL;
		gint _tmp22_ = 0;
		gint _tmp23_ = 0;
		gchar* _tmp24_ = NULL;
#line 450 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp19_ = access_token;
#line 450 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp20_ = index;
#line 450 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp21_ = access_token;
#line 450 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp22_ = strlen (_tmp21_);
#line 450 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp23_ = _tmp22_;
#line 450 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp24_ = string_slice (_tmp19_, (glong) _tmp20_, (glong) _tmp23_);
#line 450 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_g_free0 (trailing_params);
#line 450 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		trailing_params = _tmp24_;
#line 3912 "FacebookPublishing.c"
	}
#line 451 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp25_ = trailing_params;
#line 451 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (_tmp25_ != NULL) {
#line 3918 "FacebookPublishing.c"
		const gchar* _tmp26_ = NULL;
		const gchar* _tmp27_ = NULL;
		gchar* _tmp28_ = NULL;
#line 452 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp26_ = access_token;
#line 452 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp27_ = trailing_params;
#line 452 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp28_ = string_replace (_tmp26_, _tmp27_, "");
#line 452 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_g_free0 (access_token);
#line 452 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		access_token = _tmp28_;
#line 3932 "FacebookPublishing.c"
	}
#line 455 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp29_ = access_token;
#line 455 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp30_ = string_replace (_tmp29_, "#access_token=", "");
#line 455 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_free0 (access_token);
#line 455 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	access_token = _tmp30_;
#line 458 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp31_ = self->priv->graph_session;
#line 458 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_connect_object (_tmp31_, "authenticated", (GCallback) _publishing_facebook_facebook_publisher_on_session_authenticated_publishing_facebook_graph_session_authenticated, self, 0);
#line 459 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp32_ = self->priv->graph_session;
#line 459 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp33_ = access_token;
#line 459 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_graph_session_authenticate (_tmp32_, _tmp33_);
#line 428 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_free0 (trailing_params);
#line 428 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_free0 (access_token);
#line 428 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_free0 (decoded_uri);
#line 3958 "FacebookPublishing.c"
}


static void publishing_facebook_facebook_publisher_do_save_session_information (PublishingFacebookFacebookPublisher* self) {
	PublishingFacebookGraphSession* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
#line 462 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_FACEBOOK_PUBLISHER (self));
#line 463 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_debug ("FacebookPublishing.vala:463: ACTION: saving session information to con" \
"figuration system.");
#line 465 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = self->priv->graph_session;
#line 465 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp1_ = publishing_facebook_graph_session_get_access_token (_tmp0_);
#line 465 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp2_ = _tmp1_;
#line 465 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_facebook_publisher_set_persistent_access_token (self, _tmp2_);
#line 465 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_free0 (_tmp2_);
#line 3980 "FacebookPublishing.c"
}


static void _publishing_facebook_facebook_publisher_on_upload_complete_publishing_facebook_uploader_upload_complete (PublishingFacebookUploader* _sender, gint num_photos_published, gpointer self) {
#line 488 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_facebook_publisher_on_upload_complete ((PublishingFacebookFacebookPublisher*) self, _sender, num_photos_published);
#line 3987 "FacebookPublishing.c"
}


static void _publishing_facebook_facebook_publisher_on_upload_error_publishing_facebook_uploader_upload_error (PublishingFacebookUploader* _sender, GError* err, gpointer self) {
#line 489 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_facebook_publisher_on_upload_error ((PublishingFacebookFacebookPublisher*) self, _sender, err);
#line 3994 "FacebookPublishing.c"
}


static void _publishing_facebook_facebook_publisher_on_upload_status_updated_spit_publishing_progress_callback (gint file_number, gdouble fraction_complete, gpointer self) {
#line 491 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_facebook_publisher_on_upload_status_updated ((PublishingFacebookFacebookPublisher*) self, file_number, fraction_complete);
#line 4001 "FacebookPublishing.c"
}


static void publishing_facebook_facebook_publisher_do_upload (PublishingFacebookFacebookPublisher* self) {
	gchar* _tmp0_ = NULL;
	PublishingFacebookPublishingParameters* _tmp1_ = NULL;
	gint _tmp2_ = 0;
	SpitPublishingPluginHost* _tmp6_ = NULL;
	SpitPublishingPluginHost* _tmp7_ = NULL;
	PublishingFacebookPublishingParameters* _tmp8_ = NULL;
	PublishingFacebookResolution _tmp9_ = 0;
	gint _tmp10_ = 0;
	PublishingFacebookPublishingParameters* _tmp11_ = NULL;
	gboolean _tmp12_ = FALSE;
	void* _tmp13_ = NULL;
	GDestroyNotify _tmp14_ = NULL;
	SpitPublishingProgressCallback _tmp15_ = NULL;
	gboolean _tmp16_ = FALSE;
	SpitPublishingPublishable** publishables = NULL;
	SpitPublishingPluginHost* _tmp17_ = NULL;
	gint _tmp18_ = 0;
	SpitPublishingPublishable** _tmp19_ = NULL;
	gint publishables_length1 = 0;
	gint _publishables_size_ = 0;
	PublishingFacebookGraphSession* _tmp20_ = NULL;
	PublishingFacebookPublishingParameters* _tmp21_ = NULL;
	SpitPublishingPublishable** _tmp22_ = NULL;
	gint _tmp22__length1 = 0;
	PublishingFacebookUploader* _tmp23_ = NULL;
	PublishingFacebookUploader* _tmp24_ = NULL;
	PublishingFacebookUploader* _tmp25_ = NULL;
	PublishingFacebookUploader* _tmp26_ = NULL;
#line 468 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_FACEBOOK_PUBLISHER (self));
#line 470 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp1_ = self->priv->publishing_params;
#line 470 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp2_ = _tmp1_->target_album;
#line 470 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (_tmp2_ == PUBLISHING_FACEBOOK_PUBLISHING_PARAMETERS_UNKNOWN_ALBUM) {
#line 4042 "FacebookPublishing.c"
		gchar* _tmp3_ = NULL;
#line 470 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp3_ = g_strdup ("(none)");
#line 470 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_g_free0 (_tmp0_);
#line 470 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp0_ = _tmp3_;
#line 4050 "FacebookPublishing.c"
	} else {
		PublishingFacebookPublishingParameters* _tmp4_ = NULL;
		gchar* _tmp5_ = NULL;
#line 471 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp4_ = self->priv->publishing_params;
#line 471 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp5_ = publishing_facebook_publishing_parameters_get_target_album_name (_tmp4_);
#line 471 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_g_free0 (_tmp0_);
#line 471 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp0_ = _tmp5_;
#line 4062 "FacebookPublishing.c"
	}
#line 469 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_debug ("FacebookPublishing.vala:469: ACTION: uploading photos to album '%s'", _tmp0_);
#line 473 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp6_ = self->priv->host;
#line 473 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	spit_publishing_plugin_host_set_service_locked (_tmp6_, TRUE);
#line 475 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp7_ = self->priv->host;
#line 475 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp8_ = self->priv->publishing_params;
#line 475 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp9_ = _tmp8_->resolution;
#line 475 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp10_ = publishing_facebook_resolution_get_pixels (_tmp9_);
#line 475 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp11_ = self->priv->publishing_params;
#line 475 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp12_ = _tmp11_->strip_metadata;
#line 475 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp15_ = spit_publishing_plugin_host_serialize_publishables (_tmp7_, _tmp10_, _tmp12_, &_tmp13_, &_tmp14_);
#line 475 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	(self->priv->progress_reporter_target_destroy_notify == NULL) ? NULL : (self->priv->progress_reporter_target_destroy_notify (self->priv->progress_reporter_target), NULL);
#line 475 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->progress_reporter = NULL;
#line 475 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->progress_reporter_target = NULL;
#line 475 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->progress_reporter_target_destroy_notify = NULL;
#line 475 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->progress_reporter = _tmp15_;
#line 475 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->progress_reporter_target = _tmp13_;
#line 475 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->progress_reporter_target_destroy_notify = _tmp14_;
#line 482 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp16_ = spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher));
#line 482 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (!_tmp16_) {
#line 483 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_g_free0 (_tmp0_);
#line 483 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		return;
#line 4106 "FacebookPublishing.c"
	}
#line 485 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp17_ = self->priv->host;
#line 485 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp19_ = spit_publishing_plugin_host_get_publishables (_tmp17_, &_tmp18_);
#line 485 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishables = _tmp19_;
#line 485 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishables_length1 = _tmp18_;
#line 485 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_publishables_size_ = publishables_length1;
#line 486 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp20_ = self->priv->graph_session;
#line 486 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp21_ = self->priv->publishing_params;
#line 486 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp22_ = publishables;
#line 486 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp22__length1 = publishables_length1;
#line 486 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp23_ = publishing_facebook_uploader_new (_tmp20_, _tmp21_, _tmp22_, _tmp22__length1);
#line 486 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_publishing_facebook_uploader_unref0 (self->priv->uploader);
#line 486 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->uploader = _tmp23_;
#line 488 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp24_ = self->priv->uploader;
#line 488 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_connect_object (_tmp24_, "upload-complete", (GCallback) _publishing_facebook_facebook_publisher_on_upload_complete_publishing_facebook_uploader_upload_complete, self, 0);
#line 489 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp25_ = self->priv->uploader;
#line 489 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_connect_object (_tmp25_, "upload-error", (GCallback) _publishing_facebook_facebook_publisher_on_upload_error_publishing_facebook_uploader_upload_error, self, 0);
#line 491 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp26_ = self->priv->uploader;
#line 491 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_uploader_upload (_tmp26_, _publishing_facebook_facebook_publisher_on_upload_status_updated_spit_publishing_progress_callback, self);
#line 468 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishables = (_vala_array_free (publishables, publishables_length1, (GDestroyNotify) g_object_unref), NULL);
#line 468 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_free0 (_tmp0_);
#line 4148 "FacebookPublishing.c"
}


static void publishing_facebook_facebook_publisher_do_show_success_pane (PublishingFacebookFacebookPublisher* self) {
	SpitPublishingPluginHost* _tmp0_ = NULL;
	SpitPublishingPluginHost* _tmp1_ = NULL;
#line 494 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_FACEBOOK_PUBLISHER (self));
#line 495 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_debug ("FacebookPublishing.vala:495: ACTION: showing success pane.");
#line 497 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = self->priv->host;
#line 497 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	spit_publishing_plugin_host_set_service_locked (_tmp0_, FALSE);
#line 498 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp1_ = self->priv->host;
#line 498 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	spit_publishing_plugin_host_install_success_pane (_tmp1_);
#line 4167 "FacebookPublishing.c"
}


static void publishing_facebook_facebook_publisher_on_generic_error (PublishingFacebookFacebookPublisher* self, GError* _error_) {
	GError* _tmp0_ = NULL;
#line 501 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_FACEBOOK_PUBLISHER (self));
#line 502 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = _error_;
#line 502 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (g_error_matches (_tmp0_, SPIT_PUBLISHING_PUBLISHING_ERROR, SPIT_PUBLISHING_PUBLISHING_ERROR_EXPIRED_SESSION)) {
#line 503 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		publishing_facebook_facebook_publisher_do_logout (self);
#line 4181 "FacebookPublishing.c"
	} else {
		SpitPublishingPluginHost* _tmp1_ = NULL;
		GError* _tmp2_ = NULL;
#line 505 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp1_ = self->priv->host;
#line 505 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp2_ = _error_;
#line 505 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		spit_publishing_plugin_host_post_error (_tmp1_, _tmp2_);
#line 4191 "FacebookPublishing.c"
	}
}


static void publishing_facebook_facebook_publisher_on_login_clicked (PublishingFacebookFacebookPublisher* self) {
	gboolean _tmp0_ = FALSE;
#line 508 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_FACEBOOK_PUBLISHER (self));
#line 509 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher));
#line 509 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (!_tmp0_) {
#line 510 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		return;
#line 4206 "FacebookPublishing.c"
	}
#line 512 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_debug ("FacebookPublishing.vala:512: EVENT: user clicked 'Login' on welcome pa" \
"ne.");
#line 514 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_facebook_publisher_do_test_connection_to_endpoint (self);
#line 4212 "FacebookPublishing.c"
}


static void publishing_facebook_facebook_publisher_on_endpoint_test_completed (PublishingFacebookFacebookPublisher* self, PublishingFacebookGraphMessage* message) {
	PublishingFacebookGraphMessage* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
	PublishingFacebookGraphMessage* _tmp2_ = NULL;
	guint _tmp3_ = 0U;
	gboolean _tmp4_ = FALSE;
#line 517 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_FACEBOOK_PUBLISHER (self));
#line 517 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_GRAPH_MESSAGE (message));
#line 518 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = message;
#line 518 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_parse_name ("completed", PUBLISHING_FACEBOOK_TYPE_GRAPH_MESSAGE, &_tmp1_, NULL, FALSE);
#line 518 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_facebook_facebook_publisher_on_endpoint_test_completed_publishing_facebook_graph_message_completed, self);
#line 519 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp2_ = message;
#line 519 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_parse_name ("failed", PUBLISHING_FACEBOOK_TYPE_GRAPH_MESSAGE, &_tmp3_, NULL, FALSE);
#line 519 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp2_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _publishing_facebook_facebook_publisher_on_endpoint_test_error_publishing_facebook_graph_message_failed, self);
#line 521 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp4_ = spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher));
#line 521 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (!_tmp4_) {
#line 522 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		return;
#line 4244 "FacebookPublishing.c"
	}
#line 524 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_debug ("FacebookPublishing.vala:524: EVENT: endpoint test transaction detected" \
" that the Facebook endpoint is alive.");
#line 526 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_facebook_publisher_do_hosted_web_authentication (self);
#line 4250 "FacebookPublishing.c"
}


static void publishing_facebook_facebook_publisher_on_endpoint_test_error (PublishingFacebookFacebookPublisher* self, PublishingFacebookGraphMessage* message, GError* _error_) {
	PublishingFacebookGraphMessage* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
	PublishingFacebookGraphMessage* _tmp2_ = NULL;
	guint _tmp3_ = 0U;
	gboolean _tmp4_ = FALSE;
	GError* _tmp5_ = NULL;
	const gchar* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
	gchar* _tmp8_ = NULL;
	GError* _tmp9_ = NULL;
#line 529 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_FACEBOOK_PUBLISHER (self));
#line 529 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_GRAPH_MESSAGE (message));
#line 531 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = message;
#line 531 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_parse_name ("completed", PUBLISHING_FACEBOOK_TYPE_GRAPH_MESSAGE, &_tmp1_, NULL, FALSE);
#line 531 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_facebook_facebook_publisher_on_endpoint_test_completed_publishing_facebook_graph_message_completed, self);
#line 532 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp2_ = message;
#line 532 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_parse_name ("failed", PUBLISHING_FACEBOOK_TYPE_GRAPH_MESSAGE, &_tmp3_, NULL, FALSE);
#line 532 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp2_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _publishing_facebook_facebook_publisher_on_endpoint_test_error_publishing_facebook_graph_message_failed, self);
#line 534 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp4_ = spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher));
#line 534 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (!_tmp4_) {
#line 535 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		return;
#line 4287 "FacebookPublishing.c"
	}
#line 537 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp5_ = _error_;
#line 537 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp6_ = _tmp5_->message;
#line 537 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp7_ = g_strconcat ("EVENT: endpoint test transaction failed to detect a connection to the " \
"Facebook " "endpoint", _tmp6_, NULL);
#line 537 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp8_ = _tmp7_;
#line 537 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_debug ("FacebookPublishing.vala:537: %s", _tmp8_);
#line 537 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_free0 (_tmp8_);
#line 540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp9_ = _error_;
#line 540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_facebook_publisher_on_generic_error (self, _tmp9_);
#line 4305 "FacebookPublishing.c"
}


static void publishing_facebook_facebook_publisher_on_web_auth_pane_login_succeeded (PublishingFacebookFacebookPublisher* self, const gchar* success_url) {
	gboolean _tmp0_ = FALSE;
	const gchar* _tmp1_ = NULL;
#line 543 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_FACEBOOK_PUBLISHER (self));
#line 543 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (success_url != NULL);
#line 544 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher));
#line 544 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (!_tmp0_) {
#line 545 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		return;
#line 4322 "FacebookPublishing.c"
	}
#line 547 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_debug ("FacebookPublishing.vala:547: EVENT: hosted web login succeeded.");
#line 549 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp1_ = success_url;
#line 549 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_facebook_publisher_do_authenticate_session (self, _tmp1_);
#line 4330 "FacebookPublishing.c"
}


static void publishing_facebook_facebook_publisher_on_web_auth_pane_login_failed (PublishingFacebookFacebookPublisher* self) {
	gboolean _tmp0_ = FALSE;
#line 554 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_FACEBOOK_PUBLISHER (self));
#line 555 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher));
#line 555 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (!_tmp0_) {
#line 556 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		return;
#line 4344 "FacebookPublishing.c"
	}
#line 558 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_debug ("FacebookPublishing.vala:558: EVENT: hosted web login failed.");
#line 566 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_facebook_publisher_do_show_service_welcome_pane (self);
#line 4350 "FacebookPublishing.c"
}


static void publishing_facebook_facebook_publisher_on_session_authenticated (PublishingFacebookFacebookPublisher* self) {
	PublishingFacebookGraphSession* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
	gboolean _tmp2_ = FALSE;
	PublishingFacebookGraphSession* _tmp3_ = NULL;
	gboolean _tmp4_ = FALSE;
#line 569 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_FACEBOOK_PUBLISHER (self));
#line 570 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = self->priv->graph_session;
#line 570 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_parse_name ("authenticated", PUBLISHING_FACEBOOK_TYPE_GRAPH_SESSION, &_tmp1_, NULL, FALSE);
#line 570 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_facebook_facebook_publisher_on_session_authenticated_publishing_facebook_graph_session_authenticated, self);
#line 572 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp2_ = spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher));
#line 572 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (!_tmp2_) {
#line 573 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		return;
#line 4374 "FacebookPublishing.c"
	}
#line 575 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp3_ = self->priv->graph_session;
#line 575 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp4_ = publishing_facebook_graph_session_is_authenticated (_tmp3_);
#line 575 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_vala_assert (_tmp4_, "graph_session.is_authenticated()");
#line 576 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_debug ("FacebookPublishing.vala:576: EVENT: an authenticated session has becom" \
"e available.");
#line 578 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_facebook_publisher_do_save_session_information (self);
#line 579 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_facebook_publisher_do_fetch_user_info (self);
#line 4388 "FacebookPublishing.c"
}


static void publishing_facebook_facebook_publisher_on_fetch_user_info_completed (PublishingFacebookFacebookPublisher* self, PublishingFacebookGraphMessage* message) {
	PublishingFacebookGraphMessage* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
	PublishingFacebookGraphMessage* _tmp2_ = NULL;
	guint _tmp3_ = 0U;
	gboolean _tmp4_ = FALSE;
	PublishingFacebookGraphMessage* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
	PublishingFacebookGraphMessage* _tmp8_ = NULL;
	gchar* _tmp9_ = NULL;
	gchar* _tmp10_ = NULL;
#line 582 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_FACEBOOK_PUBLISHER (self));
#line 582 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_GRAPH_MESSAGE (message));
#line 583 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = message;
#line 583 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_parse_name ("completed", PUBLISHING_FACEBOOK_TYPE_GRAPH_MESSAGE, &_tmp1_, NULL, FALSE);
#line 583 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_facebook_facebook_publisher_on_fetch_user_info_completed_publishing_facebook_graph_message_completed, self);
#line 584 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp2_ = message;
#line 584 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_parse_name ("failed", PUBLISHING_FACEBOOK_TYPE_GRAPH_MESSAGE, &_tmp3_, NULL, FALSE);
#line 584 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp2_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _publishing_facebook_facebook_publisher_on_fetch_user_info_error_publishing_facebook_graph_message_failed, self);
#line 586 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp4_ = spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher));
#line 586 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (!_tmp4_) {
#line 587 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		return;
#line 4426 "FacebookPublishing.c"
	}
#line 589 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp5_ = message;
#line 589 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp6_ = publishing_facebook_graph_message_get_response_body (_tmp5_);
#line 589 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp7_ = _tmp6_;
#line 589 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_debug ("FacebookPublishing.vala:589: EVENT: user info fetch completed; respons" \
"e = '%s'.", _tmp7_);
#line 589 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_free0 (_tmp7_);
#line 591 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp8_ = message;
#line 591 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp9_ = publishing_facebook_graph_message_get_response_body (_tmp8_);
#line 591 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp10_ = _tmp9_;
#line 591 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_facebook_publisher_do_extract_user_info_from_json (self, _tmp10_);
#line 591 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_free0 (_tmp10_);
#line 4448 "FacebookPublishing.c"
}


static void publishing_facebook_facebook_publisher_on_fetch_user_info_error (PublishingFacebookFacebookPublisher* self, PublishingFacebookGraphMessage* message, GError* _error_) {
	PublishingFacebookGraphMessage* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
	PublishingFacebookGraphMessage* _tmp2_ = NULL;
	guint _tmp3_ = 0U;
	gboolean _tmp4_ = FALSE;
	GError* _tmp5_ = NULL;
#line 594 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_FACEBOOK_PUBLISHER (self));
#line 594 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_GRAPH_MESSAGE (message));
#line 596 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = message;
#line 596 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_parse_name ("completed", PUBLISHING_FACEBOOK_TYPE_GRAPH_MESSAGE, &_tmp1_, NULL, FALSE);
#line 596 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_facebook_facebook_publisher_on_fetch_user_info_completed_publishing_facebook_graph_message_completed, self);
#line 597 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp2_ = message;
#line 597 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_parse_name ("failed", PUBLISHING_FACEBOOK_TYPE_GRAPH_MESSAGE, &_tmp3_, NULL, FALSE);
#line 597 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp2_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _publishing_facebook_facebook_publisher_on_fetch_user_info_error_publishing_facebook_graph_message_failed, self);
#line 599 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp4_ = spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher));
#line 599 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (!_tmp4_) {
#line 600 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		return;
#line 4481 "FacebookPublishing.c"
	}
#line 602 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_debug ("FacebookPublishing.vala:602: EVENT: fetching user info generated and e" \
"rror.");
#line 604 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp5_ = _error_;
#line 604 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_facebook_publisher_on_generic_error (self, _tmp5_);
#line 4489 "FacebookPublishing.c"
}


static void publishing_facebook_facebook_publisher_on_user_info_extracted (PublishingFacebookFacebookPublisher* self) {
	gboolean _tmp0_ = FALSE;
	const gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
#line 607 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_FACEBOOK_PUBLISHER (self));
#line 608 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher));
#line 608 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (!_tmp0_) {
#line 609 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		return;
#line 4505 "FacebookPublishing.c"
	}
#line 611 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp1_ = self->priv->uid;
#line 611 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp2_ = self->priv->username;
#line 611 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_debug ("FacebookPublishing.vala:611: EVENT: user info extracted from JSON resp" \
"onse: uid = %s; name = %s.", _tmp1_, _tmp2_);
#line 613 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_facebook_publisher_do_fetch_album_descriptions (self);
#line 4515 "FacebookPublishing.c"
}


static void publishing_facebook_facebook_publisher_on_fetch_albums_completed (PublishingFacebookFacebookPublisher* self, PublishingFacebookGraphMessage* message) {
	PublishingFacebookGraphMessage* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
	PublishingFacebookGraphMessage* _tmp2_ = NULL;
	guint _tmp3_ = 0U;
	gboolean _tmp4_ = FALSE;
	PublishingFacebookGraphMessage* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
	PublishingFacebookGraphMessage* _tmp8_ = NULL;
	gchar* _tmp9_ = NULL;
	gchar* _tmp10_ = NULL;
#line 616 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_FACEBOOK_PUBLISHER (self));
#line 616 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_GRAPH_MESSAGE (message));
#line 617 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = message;
#line 617 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_parse_name ("completed", PUBLISHING_FACEBOOK_TYPE_GRAPH_MESSAGE, &_tmp1_, NULL, FALSE);
#line 617 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_facebook_facebook_publisher_on_fetch_albums_completed_publishing_facebook_graph_message_completed, self);
#line 618 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp2_ = message;
#line 618 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_parse_name ("failed", PUBLISHING_FACEBOOK_TYPE_GRAPH_MESSAGE, &_tmp3_, NULL, FALSE);
#line 618 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp2_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _publishing_facebook_facebook_publisher_on_fetch_albums_error_publishing_facebook_graph_message_failed, self);
#line 620 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp4_ = spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher));
#line 620 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (!_tmp4_) {
#line 621 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		return;
#line 4553 "FacebookPublishing.c"
	}
#line 623 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp5_ = message;
#line 623 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp6_ = publishing_facebook_graph_message_get_response_body (_tmp5_);
#line 623 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp7_ = _tmp6_;
#line 623 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_debug ("FacebookPublishing.vala:623: EVENT: album descriptions fetch transacti" \
"on completed; response = '%s'.", _tmp7_);
#line 623 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_free0 (_tmp7_);
#line 626 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp8_ = message;
#line 626 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp9_ = publishing_facebook_graph_message_get_response_body (_tmp8_);
#line 626 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp10_ = _tmp9_;
#line 626 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_facebook_publisher_do_extract_albums_from_json (self, _tmp10_);
#line 626 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_free0 (_tmp10_);
#line 4575 "FacebookPublishing.c"
}


static void publishing_facebook_facebook_publisher_on_fetch_albums_error (PublishingFacebookFacebookPublisher* self, PublishingFacebookGraphMessage* message, GError* err) {
	PublishingFacebookGraphMessage* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
	PublishingFacebookGraphMessage* _tmp2_ = NULL;
	guint _tmp3_ = 0U;
	gboolean _tmp4_ = FALSE;
	GError* _tmp5_ = NULL;
#line 629 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_FACEBOOK_PUBLISHER (self));
#line 629 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_GRAPH_MESSAGE (message));
#line 631 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = message;
#line 631 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_parse_name ("completed", PUBLISHING_FACEBOOK_TYPE_GRAPH_MESSAGE, &_tmp1_, NULL, FALSE);
#line 631 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_facebook_facebook_publisher_on_fetch_albums_completed_publishing_facebook_graph_message_completed, self);
#line 632 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp2_ = message;
#line 632 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_parse_name ("failed", PUBLISHING_FACEBOOK_TYPE_GRAPH_MESSAGE, &_tmp3_, NULL, FALSE);
#line 632 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp2_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _publishing_facebook_facebook_publisher_on_fetch_albums_error_publishing_facebook_graph_message_failed, self);
#line 634 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp4_ = spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher));
#line 634 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (!_tmp4_) {
#line 635 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		return;
#line 4608 "FacebookPublishing.c"
	}
#line 637 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_debug ("FacebookPublishing.vala:637: EVENT: album description fetch attempt ge" \
"nerated an error.");
#line 639 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp5_ = err;
#line 639 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_facebook_publisher_on_generic_error (self, _tmp5_);
#line 4616 "FacebookPublishing.c"
}


static void publishing_facebook_facebook_publisher_on_albums_extracted (PublishingFacebookFacebookPublisher* self) {
	gboolean _tmp0_ = FALSE;
	PublishingFacebookPublishingParameters* _tmp1_ = NULL;
	PublishingFacebookAlbum** _tmp2_ = NULL;
	gint _tmp2__length1 = 0;
#line 642 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_FACEBOOK_PUBLISHER (self));
#line 643 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher));
#line 643 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (!_tmp0_) {
#line 644 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		return;
#line 4633 "FacebookPublishing.c"
	}
#line 646 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp1_ = self->priv->publishing_params;
#line 646 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp2_ = _tmp1_->albums;
#line 646 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp2__length1 = _tmp1_->albums_length1;
#line 646 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_debug ("FacebookPublishing.vala:646: EVENT: successfully extracted %d albums f" \
"rom JSON response", _tmp2__length1);
#line 649 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_facebook_publisher_do_show_publishing_options_pane (self);
#line 4645 "FacebookPublishing.c"
}


static void publishing_facebook_facebook_publisher_on_publishing_options_pane_logout (PublishingFacebookFacebookPublisher* self) {
	PublishingFacebookPublishingOptionsPane* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
	PublishingFacebookPublishingOptionsPane* _tmp2_ = NULL;
	guint _tmp3_ = 0U;
	gboolean _tmp4_ = FALSE;
#line 652 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_FACEBOOK_PUBLISHER (self));
#line 653 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = self->priv->publishing_options_pane;
#line 653 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_parse_name ("publish", PUBLISHING_FACEBOOK_TYPE_PUBLISHING_OPTIONS_PANE, &_tmp1_, NULL, FALSE);
#line 653 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_facebook_facebook_publisher_on_publishing_options_pane_publish_publishing_facebook_publishing_options_pane_publish, self);
#line 654 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp2_ = self->priv->publishing_options_pane;
#line 654 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_parse_name ("logout", PUBLISHING_FACEBOOK_TYPE_PUBLISHING_OPTIONS_PANE, &_tmp3_, NULL, FALSE);
#line 654 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp2_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _publishing_facebook_facebook_publisher_on_publishing_options_pane_logout_publishing_facebook_publishing_options_pane_logout, self);
#line 656 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp4_ = spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher));
#line 656 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (!_tmp4_) {
#line 657 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		return;
#line 4675 "FacebookPublishing.c"
	}
#line 659 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_debug ("FacebookPublishing.vala:659: EVENT: user clicked 'Logout' in publishin" \
"g options pane.");
#line 661 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_facebook_publisher_do_logout (self);
#line 4681 "FacebookPublishing.c"
}


static void publishing_facebook_facebook_publisher_on_publishing_options_pane_publish (PublishingFacebookFacebookPublisher* self, const gchar* target_album, const gchar* privacy_setting, PublishingFacebookResolution resolution, gboolean strip_metadata) {
	PublishingFacebookPublishingOptionsPane* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
	PublishingFacebookPublishingOptionsPane* _tmp2_ = NULL;
	guint _tmp3_ = 0U;
	gboolean _tmp4_ = FALSE;
	PublishingFacebookPublishingParameters* _tmp5_ = NULL;
	gboolean _tmp6_ = FALSE;
	gboolean _tmp7_ = FALSE;
	PublishingFacebookPublishingParameters* _tmp8_ = NULL;
	PublishingFacebookResolution _tmp9_ = 0;
	PublishingFacebookResolution _tmp10_ = 0;
	PublishingFacebookPublishingParameters* _tmp11_ = NULL;
	const gchar* _tmp12_ = NULL;
	gchar* _tmp13_ = NULL;
	const gchar* _tmp14_ = NULL;
#line 664 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_FACEBOOK_PUBLISHER (self));
#line 664 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (privacy_setting != NULL);
#line 666 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = self->priv->publishing_options_pane;
#line 666 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_parse_name ("publish", PUBLISHING_FACEBOOK_TYPE_PUBLISHING_OPTIONS_PANE, &_tmp1_, NULL, FALSE);
#line 666 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_facebook_facebook_publisher_on_publishing_options_pane_publish_publishing_facebook_publishing_options_pane_publish, self);
#line 667 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp2_ = self->priv->publishing_options_pane;
#line 667 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_parse_name ("logout", PUBLISHING_FACEBOOK_TYPE_PUBLISHING_OPTIONS_PANE, &_tmp3_, NULL, FALSE);
#line 667 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp2_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _publishing_facebook_facebook_publisher_on_publishing_options_pane_logout_publishing_facebook_publishing_options_pane_logout, self);
#line 669 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp4_ = spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher));
#line 669 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (!_tmp4_) {
#line 670 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		return;
#line 4723 "FacebookPublishing.c"
	}
#line 672 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_debug ("FacebookPublishing.vala:672: EVENT: user clicked 'Publish' in publishi" \
"ng options pane.");
#line 674 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp5_ = self->priv->publishing_params;
#line 674 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp6_ = strip_metadata;
#line 674 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp5_->strip_metadata = _tmp6_;
#line 675 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp7_ = strip_metadata;
#line 675 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_facebook_publisher_set_persistent_strip_metadata (self, _tmp7_);
#line 676 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp8_ = self->priv->publishing_params;
#line 676 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp9_ = resolution;
#line 676 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp8_->resolution = _tmp9_;
#line 677 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp10_ = resolution;
#line 677 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_facebook_publisher_set_persistent_default_size (self, (gint) _tmp10_);
#line 678 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp11_ = self->priv->publishing_params;
#line 678 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp12_ = privacy_setting;
#line 678 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp13_ = g_strdup (_tmp12_);
#line 678 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_free0 (_tmp11_->privacy_object);
#line 678 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp11_->privacy_object = _tmp13_;
#line 680 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp14_ = target_album;
#line 680 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (_tmp14_ != NULL) {
#line 4761 "FacebookPublishing.c"
		PublishingFacebookPublishingParameters* _tmp15_ = NULL;
		const gchar* _tmp16_ = NULL;
		PublishingFacebookPublishingParameters* _tmp17_ = NULL;
		gint _tmp18_ = 0;
#line 683 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp15_ = self->priv->publishing_params;
#line 683 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp16_ = target_album;
#line 683 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		publishing_facebook_publishing_parameters_set_target_album_by_name (_tmp15_, _tmp16_);
#line 684 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp17_ = self->priv->publishing_params;
#line 684 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp18_ = _tmp17_->target_album;
#line 684 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		if (_tmp18_ != PUBLISHING_FACEBOOK_PUBLISHING_PARAMETERS_UNKNOWN_ALBUM) {
#line 685 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			publishing_facebook_facebook_publisher_do_upload (self);
#line 4780 "FacebookPublishing.c"
		} else {
			PublishingFacebookPublishingParameters* _tmp19_ = NULL;
			const gchar* _tmp20_ = NULL;
			gchar* _tmp21_ = NULL;
#line 687 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			_tmp19_ = self->priv->publishing_params;
#line 687 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			_tmp20_ = target_album;
#line 687 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			_tmp21_ = g_strdup (_tmp20_);
#line 687 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			_g_free0 (_tmp19_->new_album_name);
#line 687 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			_tmp19_->new_album_name = _tmp21_;
#line 688 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			publishing_facebook_facebook_publisher_do_create_new_album (self);
#line 4797 "FacebookPublishing.c"
		}
	} else {
#line 692 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		publishing_facebook_facebook_publisher_do_upload (self);
#line 4802 "FacebookPublishing.c"
	}
}


static void publishing_facebook_facebook_publisher_on_create_album_completed (PublishingFacebookFacebookPublisher* self, PublishingFacebookGraphMessage* message) {
	PublishingFacebookGraphMessage* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
	PublishingFacebookGraphMessage* _tmp2_ = NULL;
	guint _tmp3_ = 0U;
	PublishingFacebookPublishingParameters* _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
	gboolean _tmp6_ = FALSE;
	PublishingFacebookGraphMessage* _tmp7_ = NULL;
	gchar* _tmp8_ = NULL;
	gchar* _tmp9_ = NULL;
	PublishingFacebookPublishingParameters* _tmp10_ = NULL;
	const gchar* _tmp11_ = NULL;
	PublishingFacebookGraphMessage* _tmp12_ = NULL;
	gchar* _tmp13_ = NULL;
	gchar* _tmp14_ = NULL;
#line 696 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_FACEBOOK_PUBLISHER (self));
#line 696 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_GRAPH_MESSAGE (message));
#line 697 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = message;
#line 697 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_parse_name ("completed", PUBLISHING_FACEBOOK_TYPE_GRAPH_MESSAGE, &_tmp1_, NULL, FALSE);
#line 697 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_facebook_facebook_publisher_on_create_album_completed_publishing_facebook_graph_message_completed, self);
#line 698 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp2_ = message;
#line 698 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_parse_name ("failed", PUBLISHING_FACEBOOK_TYPE_GRAPH_MESSAGE, &_tmp3_, NULL, FALSE);
#line 698 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp2_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _publishing_facebook_facebook_publisher_on_create_album_error_publishing_facebook_graph_message_failed, self);
#line 700 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp4_ = self->priv->publishing_params;
#line 700 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp5_ = _tmp4_->new_album_name;
#line 700 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_vala_assert (_tmp5_ != NULL, "publishing_params.new_album_name != null");
#line 702 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp6_ = spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher));
#line 702 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (!_tmp6_) {
#line 703 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		return;
#line 4851 "FacebookPublishing.c"
	}
#line 705 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp7_ = message;
#line 705 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp8_ = publishing_facebook_graph_message_get_response_body (_tmp7_);
#line 705 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp9_ = _tmp8_;
#line 705 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_debug ("FacebookPublishing.vala:705: EVENT: created new album resource on remo" \
"te host; response body = %s.\n", _tmp9_);
#line 705 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_free0 (_tmp9_);
#line 708 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp10_ = self->priv->publishing_params;
#line 708 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp11_ = _tmp10_->new_album_name;
#line 708 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp12_ = message;
#line 708 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp13_ = publishing_facebook_graph_message_get_response_body (_tmp12_);
#line 708 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp14_ = _tmp13_;
#line 708 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_facebook_publisher_do_add_new_local_album_from_json (self, _tmp11_, _tmp14_);
#line 708 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_free0 (_tmp14_);
#line 4877 "FacebookPublishing.c"
}


static void publishing_facebook_facebook_publisher_on_create_album_error (PublishingFacebookFacebookPublisher* self, PublishingFacebookGraphMessage* message, GError* err) {
	PublishingFacebookGraphMessage* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
	PublishingFacebookGraphMessage* _tmp2_ = NULL;
	guint _tmp3_ = 0U;
	gboolean _tmp4_ = FALSE;
	GError* _tmp5_ = NULL;
#line 712 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_FACEBOOK_PUBLISHER (self));
#line 712 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_GRAPH_MESSAGE (message));
#line 713 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = message;
#line 713 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_parse_name ("completed", PUBLISHING_FACEBOOK_TYPE_GRAPH_MESSAGE, &_tmp1_, NULL, FALSE);
#line 713 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_facebook_facebook_publisher_on_create_album_completed_publishing_facebook_graph_message_completed, self);
#line 714 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp2_ = message;
#line 714 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_parse_name ("failed", PUBLISHING_FACEBOOK_TYPE_GRAPH_MESSAGE, &_tmp3_, NULL, FALSE);
#line 714 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp2_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _publishing_facebook_facebook_publisher_on_create_album_error_publishing_facebook_graph_message_failed, self);
#line 716 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp4_ = spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher));
#line 716 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (!_tmp4_) {
#line 717 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		return;
#line 4910 "FacebookPublishing.c"
	}
#line 719 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_debug ("FacebookPublishing.vala:719: EVENT: attempt to create new album genera" \
"ted an error.");
#line 721 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp5_ = err;
#line 721 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_facebook_publisher_on_generic_error (self, _tmp5_);
#line 4918 "FacebookPublishing.c"
}


static void publishing_facebook_facebook_publisher_on_upload_status_updated (PublishingFacebookFacebookPublisher* self, gint file_number, gdouble completed_fraction) {
	gboolean _tmp0_ = FALSE;
	gdouble _tmp1_ = 0.0;
	SpitPublishingProgressCallback _tmp2_ = NULL;
	void* _tmp2__target = NULL;
	SpitPublishingProgressCallback _tmp3_ = NULL;
	void* _tmp3__target = NULL;
	gint _tmp4_ = 0;
	gdouble _tmp5_ = 0.0;
#line 724 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_FACEBOOK_PUBLISHER (self));
#line 725 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher));
#line 725 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (!_tmp0_) {
#line 726 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		return;
#line 4939 "FacebookPublishing.c"
	}
#line 728 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp1_ = completed_fraction;
#line 728 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_debug ("FacebookPublishing.vala:728: EVENT: uploader reports upload %.2f perce" \
"nt complete.", 100.0 * _tmp1_);
#line 730 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp2_ = self->priv->progress_reporter;
#line 730 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp2__target = self->priv->progress_reporter_target;
#line 730 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_vala_assert (_tmp2_ != NULL, "progress_reporter != null");
#line 732 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp3_ = self->priv->progress_reporter;
#line 732 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp3__target = self->priv->progress_reporter_target;
#line 732 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp4_ = file_number;
#line 732 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp5_ = completed_fraction;
#line 732 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp3_ (_tmp4_, _tmp5_, _tmp3__target);
#line 4961 "FacebookPublishing.c"
}


static void publishing_facebook_facebook_publisher_on_upload_complete (PublishingFacebookFacebookPublisher* self, PublishingFacebookUploader* uploader, gint num_published) {
	PublishingFacebookUploader* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
	PublishingFacebookUploader* _tmp2_ = NULL;
	guint _tmp3_ = 0U;
	gboolean _tmp4_ = FALSE;
	gint _tmp5_ = 0;
#line 735 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_FACEBOOK_PUBLISHER (self));
#line 735 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_UPLOADER (uploader));
#line 736 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = uploader;
#line 736 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_parse_name ("upload-complete", PUBLISHING_FACEBOOK_TYPE_UPLOADER, &_tmp1_, NULL, FALSE);
#line 736 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_facebook_facebook_publisher_on_upload_complete_publishing_facebook_uploader_upload_complete, self);
#line 737 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp2_ = uploader;
#line 737 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_parse_name ("upload-error", PUBLISHING_FACEBOOK_TYPE_UPLOADER, &_tmp3_, NULL, FALSE);
#line 737 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp2_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _publishing_facebook_facebook_publisher_on_upload_error_publishing_facebook_uploader_upload_error, self);
#line 739 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp4_ = spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher));
#line 739 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (!_tmp4_) {
#line 740 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		return;
#line 4994 "FacebookPublishing.c"
	}
#line 742 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp5_ = num_published;
#line 742 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_debug ("FacebookPublishing.vala:742: EVENT: uploader reports upload complete; " \
"%d items published.", _tmp5_);
#line 744 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_facebook_publisher_do_show_success_pane (self);
#line 5002 "FacebookPublishing.c"
}


static void publishing_facebook_facebook_publisher_on_upload_error (PublishingFacebookFacebookPublisher* self, PublishingFacebookUploader* uploader, GError* err) {
	PublishingFacebookUploader* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
	PublishingFacebookUploader* _tmp2_ = NULL;
	guint _tmp3_ = 0U;
	gboolean _tmp4_ = FALSE;
	GError* _tmp5_ = NULL;
	const gchar* _tmp6_ = NULL;
	SpitPublishingPluginHost* _tmp7_ = NULL;
	GError* _tmp8_ = NULL;
#line 747 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_FACEBOOK_PUBLISHER (self));
#line 747 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_UPLOADER (uploader));
#line 748 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = uploader;
#line 748 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_parse_name ("upload-complete", PUBLISHING_FACEBOOK_TYPE_UPLOADER, &_tmp1_, NULL, FALSE);
#line 748 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_facebook_facebook_publisher_on_upload_complete_publishing_facebook_uploader_upload_complete, self);
#line 749 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp2_ = uploader;
#line 749 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_parse_name ("upload-error", PUBLISHING_FACEBOOK_TYPE_UPLOADER, &_tmp3_, NULL, FALSE);
#line 749 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp2_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _publishing_facebook_facebook_publisher_on_upload_error_publishing_facebook_uploader_upload_error, self);
#line 751 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp4_ = spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher));
#line 751 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (!_tmp4_) {
#line 752 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		return;
#line 5038 "FacebookPublishing.c"
	}
#line 754 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp5_ = err;
#line 754 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp6_ = _tmp5_->message;
#line 754 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_debug ("FacebookPublishing.vala:754: EVENT: uploader reports upload error = '%" \
"s'.", _tmp6_);
#line 756 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp7_ = self->priv->host;
#line 756 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp8_ = err;
#line 756 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	spit_publishing_plugin_host_post_error (_tmp7_, _tmp8_);
#line 5052 "FacebookPublishing.c"
}


static SpitPublishingService* publishing_facebook_facebook_publisher_real_get_service (SpitPublishingPublisher* base) {
	PublishingFacebookFacebookPublisher * self;
	SpitPublishingService* result = NULL;
	SpitPublishingService* _tmp0_ = NULL;
	SpitPublishingService* _tmp1_ = NULL;
#line 759 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_FACEBOOK_TYPE_FACEBOOK_PUBLISHER, PublishingFacebookFacebookPublisher);
#line 760 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = self->priv->service;
#line 760 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 760 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	result = _tmp1_;
#line 760 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return result;
#line 5071 "FacebookPublishing.c"
}


gchar* publishing_facebook_facebook_publisher_get_service_name (PublishingFacebookFacebookPublisher* self) {
	gchar* result = NULL;
	gchar* _tmp0_ = NULL;
#line 763 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_val_if_fail (PUBLISHING_FACEBOOK_IS_FACEBOOK_PUBLISHER (self), NULL);
#line 764 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = g_strdup (PUBLISHING_FACEBOOK_SERVICE_NAME);
#line 764 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	result = _tmp0_;
#line 764 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return result;
#line 5086 "FacebookPublishing.c"
}


gchar* publishing_facebook_facebook_publisher_get_user_visible_name (PublishingFacebookFacebookPublisher* self) {
	gchar* result = NULL;
	gchar* _tmp0_ = NULL;
#line 767 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_val_if_fail (PUBLISHING_FACEBOOK_IS_FACEBOOK_PUBLISHER (self), NULL);
#line 768 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = g_strdup (PUBLISHING_FACEBOOK_USER_VISIBLE_NAME);
#line 768 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	result = _tmp0_;
#line 768 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return result;
#line 5101 "FacebookPublishing.c"
}


static void publishing_facebook_facebook_publisher_real_start (SpitPublishingPublisher* base) {
	PublishingFacebookFacebookPublisher * self;
	gboolean _tmp0_ = FALSE;
	PublishingFacebookPublishingParameters* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
#line 771 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_FACEBOOK_TYPE_FACEBOOK_PUBLISHER, PublishingFacebookFacebookPublisher);
#line 772 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher));
#line 772 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (_tmp0_) {
#line 773 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		return;
#line 5118 "FacebookPublishing.c"
	}
#line 775 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_debug ("FacebookPublishing.vala:775: FacebookPublisher: starting interaction.");
#line 777 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->running = TRUE;
#line 781 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp1_ = publishing_facebook_publishing_parameters_new ();
#line 781 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_publishing_facebook_publishing_parameters_unref0 (self->priv->publishing_params);
#line 781 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->publishing_params = _tmp1_;
#line 786 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp2_ = publishing_facebook_facebook_publisher_is_persistent_session_valid (self);
#line 786 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (_tmp2_) {
#line 5134 "FacebookPublishing.c"
		PublishingFacebookGraphSession* _tmp3_ = NULL;
		gchar* _tmp4_ = NULL;
		gchar* _tmp5_ = NULL;
#line 787 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp3_ = self->priv->graph_session;
#line 787 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp4_ = publishing_facebook_facebook_publisher_get_persistent_access_token (self);
#line 787 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp5_ = _tmp4_;
#line 787 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		publishing_facebook_graph_session_authenticate (_tmp3_, _tmp5_);
#line 787 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_g_free0 (_tmp5_);
#line 5148 "FacebookPublishing.c"
	} else {
		gboolean _tmp6_ = FALSE;
#line 789 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp6_ = publishing_facebook_web_authentication_pane_is_cache_dirty ();
#line 789 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		if (_tmp6_) {
#line 5155 "FacebookPublishing.c"
			SpitPublishingPluginHost* _tmp7_ = NULL;
			SpitPublishingPluginHost* _tmp8_ = NULL;
#line 790 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			_tmp7_ = self->priv->host;
#line 790 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			spit_publishing_plugin_host_set_service_locked (_tmp7_, FALSE);
#line 791 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			_tmp8_ = self->priv->host;
#line 791 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			spit_publishing_plugin_host_install_static_message_pane (_tmp8_, PUBLISHING_FACEBOOK_RESTART_ERROR_MESSAGE, SPIT_PUBLISHING_PLUGIN_HOST_BUTTON_MODE_CANCEL);
#line 5166 "FacebookPublishing.c"
		} else {
#line 794 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			publishing_facebook_facebook_publisher_do_show_service_welcome_pane (self);
#line 5170 "FacebookPublishing.c"
		}
	}
}


static void publishing_facebook_facebook_publisher_real_stop (SpitPublishingPublisher* base) {
	PublishingFacebookFacebookPublisher * self;
	PublishingFacebookGraphSession* _tmp0_ = NULL;
#line 799 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_FACEBOOK_TYPE_FACEBOOK_PUBLISHER, PublishingFacebookFacebookPublisher);
#line 800 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_debug ("FacebookPublishing.vala:800: FacebookPublisher: stop( ) invoked.");
#line 802 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = self->priv->graph_session;
#line 802 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (_tmp0_ != NULL) {
#line 5187 "FacebookPublishing.c"
		PublishingFacebookGraphSession* _tmp1_ = NULL;
#line 803 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp1_ = self->priv->graph_session;
#line 803 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		publishing_facebook_graph_session_stop_transactions (_tmp1_);
#line 5193 "FacebookPublishing.c"
	}
#line 805 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->host = NULL;
#line 806 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->running = FALSE;
#line 5199 "FacebookPublishing.c"
}


static gboolean publishing_facebook_facebook_publisher_real_is_running (SpitPublishingPublisher* base) {
	PublishingFacebookFacebookPublisher * self;
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
#line 809 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_FACEBOOK_TYPE_FACEBOOK_PUBLISHER, PublishingFacebookFacebookPublisher);
#line 810 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = self->priv->running;
#line 810 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	result = _tmp0_;
#line 810 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return result;
#line 5215 "FacebookPublishing.c"
}


static void publishing_facebook_facebook_publisher_class_init (PublishingFacebookFacebookPublisherClass * klass) {
#line 174 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_facebook_publisher_parent_class = g_type_class_peek_parent (klass);
#line 174 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_type_class_add_private (klass, sizeof (PublishingFacebookFacebookPublisherPrivate));
#line 174 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	G_OBJECT_CLASS (klass)->finalize = publishing_facebook_facebook_publisher_finalize;
#line 5226 "FacebookPublishing.c"
}


static void publishing_facebook_facebook_publisher_spit_publishing_publisher_interface_init (SpitPublishingPublisherIface * iface) {
#line 174 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_facebook_publisher_spit_publishing_publisher_parent_iface = g_type_interface_peek_parent (iface);
#line 174 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	iface->get_service = (SpitPublishingService* (*)(SpitPublishingPublisher*)) publishing_facebook_facebook_publisher_real_get_service;
#line 174 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	iface->start = (void (*)(SpitPublishingPublisher*)) publishing_facebook_facebook_publisher_real_start;
#line 174 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	iface->stop = (void (*)(SpitPublishingPublisher*)) publishing_facebook_facebook_publisher_real_stop;
#line 174 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	iface->is_running = (gboolean (*)(SpitPublishingPublisher*)) publishing_facebook_facebook_publisher_real_is_running;
#line 5241 "FacebookPublishing.c"
}


static void publishing_facebook_facebook_publisher_instance_init (PublishingFacebookFacebookPublisher * self) {
#line 174 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv = PUBLISHING_FACEBOOK_FACEBOOK_PUBLISHER_GET_PRIVATE (self);
#line 176 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->host = NULL;
#line 177 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->web_auth_pane = NULL;
#line 178 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->progress_reporter = NULL;
#line 179 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->service = NULL;
#line 180 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->running = FALSE;
#line 182 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->publishing_options_pane = NULL;
#line 183 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->uploader = NULL;
#line 184 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->uid = NULL;
#line 185 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->username = NULL;
#line 5266 "FacebookPublishing.c"
}


static void publishing_facebook_facebook_publisher_finalize (GObject* obj) {
	PublishingFacebookFacebookPublisher * self;
#line 174 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_FACEBOOK_TYPE_FACEBOOK_PUBLISHER, PublishingFacebookFacebookPublisher);
#line 175 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_publishing_facebook_publishing_parameters_unref0 (self->priv->publishing_params);
#line 177 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_object_unref0 (self->priv->web_auth_pane);
#line 178 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	(self->priv->progress_reporter_target_destroy_notify == NULL) ? NULL : (self->priv->progress_reporter_target_destroy_notify (self->priv->progress_reporter_target), NULL);
#line 178 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->progress_reporter = NULL;
#line 178 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->progress_reporter_target = NULL;
#line 178 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->progress_reporter_target_destroy_notify = NULL;
#line 181 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_publishing_facebook_graph_session_unref0 (self->priv->graph_session);
#line 182 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_object_unref0 (self->priv->publishing_options_pane);
#line 183 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_publishing_facebook_uploader_unref0 (self->priv->uploader);
#line 184 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_free0 (self->priv->uid);
#line 185 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_free0 (self->priv->username);
#line 174 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	G_OBJECT_CLASS (publishing_facebook_facebook_publisher_parent_class)->finalize (obj);
#line 5298 "FacebookPublishing.c"
}


GType publishing_facebook_facebook_publisher_get_type (void) {
	static volatile gsize publishing_facebook_facebook_publisher_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_facebook_facebook_publisher_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingFacebookFacebookPublisherClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_facebook_facebook_publisher_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingFacebookFacebookPublisher), 0, (GInstanceInitFunc) publishing_facebook_facebook_publisher_instance_init, NULL };
		static const GInterfaceInfo spit_publishing_publisher_info = { (GInterfaceInitFunc) publishing_facebook_facebook_publisher_spit_publishing_publisher_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType publishing_facebook_facebook_publisher_type_id;
		publishing_facebook_facebook_publisher_type_id = g_type_register_static (G_TYPE_OBJECT, "PublishingFacebookFacebookPublisher", &g_define_type_info, 0);
		g_type_add_interface_static (publishing_facebook_facebook_publisher_type_id, SPIT_PUBLISHING_TYPE_PUBLISHER, &spit_publishing_publisher_info);
		g_once_init_leave (&publishing_facebook_facebook_publisher_type_id__volatile, publishing_facebook_facebook_publisher_type_id);
	}
	return publishing_facebook_facebook_publisher_type_id__volatile;
}


static void _publishing_facebook_web_authentication_pane_on_page_load_changed_webkit_web_view_load_changed (WebKitWebView* _sender, WebKitLoadEvent load_event, gpointer self) {
#line 833 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_web_authentication_pane_on_page_load_changed ((PublishingFacebookWebAuthenticationPane*) self, load_event);
#line 5319 "FacebookPublishing.c"
}


static gboolean __lambda4_ (PublishingFacebookWebAuthenticationPane* self) {
	gboolean result = FALSE;
#line 834 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	result = TRUE;
#line 834 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return result;
#line 5329 "FacebookPublishing.c"
}


static gboolean ___lambda4__webkit_web_view_context_menu (WebKitWebView* _sender, WebKitContextMenu* context_menu, GdkEvent* event, WebKitHitTestResult* hit_test_result, gpointer self) {
	gboolean result;
	result = __lambda4_ ((PublishingFacebookWebAuthenticationPane*) self);
#line 834 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return result;
#line 5338 "FacebookPublishing.c"
}


PublishingFacebookWebAuthenticationPane* publishing_facebook_web_authentication_pane_construct (GType object_type) {
	PublishingFacebookWebAuthenticationPane * self = NULL;
	GtkBox* _tmp0_ = NULL;
	GtkScrolledWindow* _tmp1_ = NULL;
	GtkScrolledWindow* _tmp2_ = NULL;
	GtkScrolledWindow* _tmp3_ = NULL;
	WebKitWebView* _tmp4_ = NULL;
	WebKitWebView* _tmp5_ = NULL;
	WebKitSettings* _tmp6_ = NULL;
	WebKitWebView* _tmp7_ = NULL;
	WebKitWebView* _tmp8_ = NULL;
	GtkScrolledWindow* _tmp9_ = NULL;
	WebKitWebView* _tmp10_ = NULL;
	GtkBox* _tmp11_ = NULL;
	GtkScrolledWindow* _tmp12_ = NULL;
#line 823 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self = (PublishingFacebookWebAuthenticationPane*) g_object_new (object_type, NULL);
#line 824 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
#line 824 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_object_ref_sink (_tmp0_);
#line 824 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_object_unref0 (self->priv->pane_widget);
#line 824 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->pane_widget = _tmp0_;
#line 826 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp1_ = (GtkScrolledWindow*) gtk_scrolled_window_new (NULL, NULL);
#line 826 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_object_ref_sink (_tmp1_);
#line 826 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_object_unref0 (self->priv->webview_frame);
#line 826 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->webview_frame = _tmp1_;
#line 827 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp2_ = self->priv->webview_frame;
#line 827 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	gtk_scrolled_window_set_shadow_type (_tmp2_, GTK_SHADOW_ETCHED_IN);
#line 828 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp3_ = self->priv->webview_frame;
#line 828 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	gtk_scrolled_window_set_policy (_tmp3_, GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
#line 830 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp4_ = (WebKitWebView*) webkit_web_view_new ();
#line 830 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_object_ref_sink (_tmp4_);
#line 830 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_object_unref0 (self->priv->webview);
#line 830 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->webview = _tmp4_;
#line 831 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp5_ = self->priv->webview;
#line 831 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp6_ = webkit_web_view_get_settings (_tmp5_);
#line 831 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	webkit_settings_set_enable_plugins (_tmp6_, FALSE);
#line 833 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp7_ = self->priv->webview;
#line 833 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_connect_object (_tmp7_, "load-changed", (GCallback) _publishing_facebook_web_authentication_pane_on_page_load_changed_webkit_web_view_load_changed, self, 0);
#line 834 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp8_ = self->priv->webview;
#line 834 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_connect_object (_tmp8_, "context-menu", (GCallback) ___lambda4__webkit_web_view_context_menu, self, 0);
#line 836 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp9_ = self->priv->webview_frame;
#line 836 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp10_ = self->priv->webview;
#line 836 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	gtk_container_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, gtk_container_get_type (), GtkContainer), G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, gtk_widget_get_type (), GtkWidget));
#line 837 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp11_ = self->priv->pane_widget;
#line 837 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp12_ = self->priv->webview_frame;
#line 837 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	gtk_box_pack_start (_tmp11_, G_TYPE_CHECK_INSTANCE_CAST (_tmp12_, gtk_widget_get_type (), GtkWidget), TRUE, TRUE, (guint) 0);
#line 823 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return self;
#line 5419 "FacebookPublishing.c"
}


PublishingFacebookWebAuthenticationPane* publishing_facebook_web_authentication_pane_new (void) {
#line 823 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return publishing_facebook_web_authentication_pane_construct (PUBLISHING_FACEBOOK_TYPE_WEB_AUTHENTICATION_PANE);
#line 5426 "FacebookPublishing.c"
}


static gpointer _publishing_facebook_web_authentication_pane_locale_lookup_ref0 (gpointer self) {
#line 916 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return self ? publishing_facebook_web_authentication_pane_locale_lookup_ref (self) : NULL;
#line 5433 "FacebookPublishing.c"
}


static gboolean string_contains (const gchar* self, const gchar* needle) {
	gboolean result = FALSE;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 1376 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, FALSE);
#line 1376 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	g_return_val_if_fail (needle != NULL, FALSE);
#line 1377 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp0_ = needle;
#line 1377 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp1_ = strstr ((gchar*) self, (gchar*) _tmp0_);
#line 1377 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	result = _tmp1_ != NULL;
#line 1377 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	return result;
#line 5453 "FacebookPublishing.c"
}


static gchar* publishing_facebook_web_authentication_pane_get_system_locale_as_facebook_locale (PublishingFacebookWebAuthenticationPane* self) {
	gchar* result = NULL;
	const gchar* raw_system_locale = NULL;
	const gchar* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	const gchar* _tmp2_ = NULL;
	gchar* system_locale = NULL;
	const gchar* _tmp5_ = NULL;
	gchar** _tmp6_ = NULL;
	gchar** _tmp7_ = NULL;
	gchar** _tmp8_ = NULL;
	gint _tmp8__length1 = 0;
	const gchar* _tmp9_ = NULL;
	gchar* _tmp10_ = NULL;
	gchar* _tmp11_ = NULL;
	PublishingFacebookWebAuthenticationPaneLocaleLookup** _tmp12_ = NULL;
	gint _tmp12__length1 = 0;
	gchar* _tmp43_ = NULL;
#line 909 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_val_if_fail (PUBLISHING_FACEBOOK_IS_WEB_AUTHENTICATION_PANE (self), NULL);
#line 910 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = setlocale (LC_ALL, "");
#line 910 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	raw_system_locale = _tmp0_;
#line 911 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp2_ = raw_system_locale;
#line 911 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (_tmp2_ == NULL) {
#line 911 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp1_ = TRUE;
#line 5487 "FacebookPublishing.c"
	} else {
		const gchar* _tmp3_ = NULL;
#line 911 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp3_ = raw_system_locale;
#line 911 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp1_ = g_strcmp0 (_tmp3_, "") == 0;
#line 5494 "FacebookPublishing.c"
	}
#line 911 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (_tmp1_) {
#line 5498 "FacebookPublishing.c"
		gchar* _tmp4_ = NULL;
#line 912 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp4_ = g_strdup ("www");
#line 912 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		result = _tmp4_;
#line 912 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		return result;
#line 5506 "FacebookPublishing.c"
	}
#line 914 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp5_ = raw_system_locale;
#line 914 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp7_ = _tmp6_ = g_strsplit (_tmp5_, ".", 0);
#line 914 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp8_ = _tmp7_;
#line 914 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp8__length1 = _vala_array_length (_tmp6_);
#line 914 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp9_ = _tmp8_[0];
#line 914 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp10_ = g_strdup (_tmp9_);
#line 914 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp11_ = _tmp10_;
#line 914 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp8_ = (_vala_array_free (_tmp8_, _tmp8__length1, (GDestroyNotify) g_free), NULL);
#line 914 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	system_locale = _tmp11_;
#line 916 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp12_ = self->priv->locale_lookup_table;
#line 916 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp12__length1 = self->priv->locale_lookup_table_length1;
#line 5530 "FacebookPublishing.c"
	{
		PublishingFacebookWebAuthenticationPaneLocaleLookup** locale_lookup_collection = NULL;
		gint locale_lookup_collection_length1 = 0;
		gint _locale_lookup_collection_size_ = 0;
		gint locale_lookup_it = 0;
#line 916 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		locale_lookup_collection = _tmp12_;
#line 916 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		locale_lookup_collection_length1 = _tmp12__length1;
#line 916 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		for (locale_lookup_it = 0; locale_lookup_it < _tmp12__length1; locale_lookup_it = locale_lookup_it + 1) {
#line 5542 "FacebookPublishing.c"
			PublishingFacebookWebAuthenticationPaneLocaleLookup* _tmp13_ = NULL;
			PublishingFacebookWebAuthenticationPaneLocaleLookup* locale_lookup = NULL;
#line 916 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			_tmp13_ = _publishing_facebook_web_authentication_pane_locale_lookup_ref0 (locale_lookup_collection[locale_lookup_it]);
#line 916 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			locale_lookup = _tmp13_;
#line 5549 "FacebookPublishing.c"
			{
				const gchar* _tmp14_ = NULL;
				PublishingFacebookWebAuthenticationPaneLocaleLookup* _tmp15_ = NULL;
				const gchar* _tmp16_ = NULL;
				gboolean _tmp17_ = FALSE;
				PublishingFacebookWebAuthenticationPaneLocaleLookup* _tmp18_ = NULL;
				const gchar* _tmp19_ = NULL;
				PublishingFacebookWebAuthenticationPaneLocaleLookup* _tmp29_ = NULL;
				const gchar* _tmp30_ = NULL;
				PublishingFacebookWebAuthenticationPaneLocaleLookup* _tmp40_ = NULL;
				const gchar* _tmp41_ = NULL;
				gchar* _tmp42_ = NULL;
#line 917 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				_tmp14_ = system_locale;
#line 917 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				_tmp15_ = locale_lookup;
#line 917 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				_tmp16_ = _tmp15_->prefix;
#line 917 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				_tmp17_ = g_str_has_prefix (_tmp14_, _tmp16_);
#line 917 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				if (!_tmp17_) {
#line 918 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
					_publishing_facebook_web_authentication_pane_locale_lookup_unref0 (locale_lookup);
#line 918 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
					continue;
#line 5576 "FacebookPublishing.c"
				}
#line 920 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				_tmp18_ = locale_lookup;
#line 920 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				_tmp19_ = _tmp18_->exception_code;
#line 920 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				if (_tmp19_ != NULL) {
#line 5584 "FacebookPublishing.c"
					PublishingFacebookWebAuthenticationPaneLocaleLookup* _tmp20_ = NULL;
					const gchar* _tmp21_ = NULL;
					const gchar* _tmp22_ = NULL;
					PublishingFacebookWebAuthenticationPaneLocaleLookup* _tmp23_ = NULL;
					const gchar* _tmp24_ = NULL;
					gboolean _tmp25_ = FALSE;
#line 921 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
					_tmp20_ = locale_lookup;
#line 921 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
					_tmp21_ = _tmp20_->exception_translation;
#line 921 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
					_vala_assert (_tmp21_ != NULL, "locale_lookup.exception_translation != null");
#line 923 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
					_tmp22_ = system_locale;
#line 923 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
					_tmp23_ = locale_lookup;
#line 923 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
					_tmp24_ = _tmp23_->exception_code;
#line 923 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
					_tmp25_ = string_contains (_tmp22_, _tmp24_);
#line 923 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
					if (_tmp25_) {
#line 5607 "FacebookPublishing.c"
						PublishingFacebookWebAuthenticationPaneLocaleLookup* _tmp26_ = NULL;
						const gchar* _tmp27_ = NULL;
						gchar* _tmp28_ = NULL;
#line 924 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
						_tmp26_ = locale_lookup;
#line 924 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
						_tmp27_ = _tmp26_->exception_translation;
#line 924 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
						_tmp28_ = g_strdup (_tmp27_);
#line 924 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
						result = _tmp28_;
#line 924 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
						_publishing_facebook_web_authentication_pane_locale_lookup_unref0 (locale_lookup);
#line 924 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
						_g_free0 (system_locale);
#line 924 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
						return result;
#line 5625 "FacebookPublishing.c"
					}
				}
#line 927 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				_tmp29_ = locale_lookup;
#line 927 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				_tmp30_ = _tmp29_->exception_code_2;
#line 927 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				if (_tmp30_ != NULL) {
#line 5634 "FacebookPublishing.c"
					PublishingFacebookWebAuthenticationPaneLocaleLookup* _tmp31_ = NULL;
					const gchar* _tmp32_ = NULL;
					const gchar* _tmp33_ = NULL;
					PublishingFacebookWebAuthenticationPaneLocaleLookup* _tmp34_ = NULL;
					const gchar* _tmp35_ = NULL;
					gboolean _tmp36_ = FALSE;
#line 928 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
					_tmp31_ = locale_lookup;
#line 928 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
					_tmp32_ = _tmp31_->exception_translation_2;
#line 928 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
					_vala_assert (_tmp32_ != NULL, "locale_lookup.exception_translation_2 != null");
#line 930 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
					_tmp33_ = system_locale;
#line 930 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
					_tmp34_ = locale_lookup;
#line 930 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
					_tmp35_ = _tmp34_->exception_code_2;
#line 930 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
					_tmp36_ = string_contains (_tmp33_, _tmp35_);
#line 930 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
					if (_tmp36_) {
#line 5657 "FacebookPublishing.c"
						PublishingFacebookWebAuthenticationPaneLocaleLookup* _tmp37_ = NULL;
						const gchar* _tmp38_ = NULL;
						gchar* _tmp39_ = NULL;
#line 931 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
						_tmp37_ = locale_lookup;
#line 931 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
						_tmp38_ = _tmp37_->exception_translation_2;
#line 931 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
						_tmp39_ = g_strdup (_tmp38_);
#line 931 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
						result = _tmp39_;
#line 931 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
						_publishing_facebook_web_authentication_pane_locale_lookup_unref0 (locale_lookup);
#line 931 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
						_g_free0 (system_locale);
#line 931 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
						return result;
#line 5675 "FacebookPublishing.c"
					}
				}
#line 934 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				_tmp40_ = locale_lookup;
#line 934 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				_tmp41_ = _tmp40_->translation;
#line 934 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				_tmp42_ = g_strdup (_tmp41_);
#line 934 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				result = _tmp42_;
#line 934 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				_publishing_facebook_web_authentication_pane_locale_lookup_unref0 (locale_lookup);
#line 934 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				_g_free0 (system_locale);
#line 934 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				return result;
#line 5692 "FacebookPublishing.c"
			}
		}
	}
#line 938 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp43_ = g_strdup ("www");
#line 938 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	result = _tmp43_;
#line 938 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_free0 (system_locale);
#line 938 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return result;
#line 5704 "FacebookPublishing.c"
}


static gchar* publishing_facebook_web_authentication_pane_get_login_url (PublishingFacebookWebAuthenticationPane* self) {
	gchar* result = NULL;
	gchar* facebook_locale = NULL;
	gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 941 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_val_if_fail (PUBLISHING_FACEBOOK_IS_WEB_AUTHENTICATION_PANE (self), NULL);
#line 942 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = publishing_facebook_web_authentication_pane_get_system_locale_as_facebook_locale (self);
#line 942 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	facebook_locale = _tmp0_;
#line 943 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp1_ = g_strdup_printf ("https://%s.facebook.com/dialog/oauth?client_id=%s&redirect_uri=https:/" \
"/www.facebook.com/connect/login_success.html&display=popup&scope=publi" \
"sh_actions,user_photos,user_videos&response_type=token", facebook_locale, PUBLISHING_FACEBOOK_APPLICATION_ID);
#line 943 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	result = _tmp1_;
#line 943 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_free0 (facebook_locale);
#line 943 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return result;
#line 5727 "FacebookPublishing.c"
}


static void publishing_facebook_web_authentication_pane_on_page_load (PublishingFacebookWebAuthenticationPane* self) {
	GtkBox* _tmp0_ = NULL;
	GdkWindow* _tmp1_ = NULL;
	GdkCursor* _tmp2_ = NULL;
	GdkCursor* _tmp3_ = NULL;
	gchar* loaded_url = NULL;
	WebKitWebView* _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
	const gchar* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
	const gchar* _tmp8_ = NULL;
	gchar* _tmp9_ = NULL;
	gchar* _tmp10_ = NULL;
	const gchar* _tmp11_ = NULL;
	gboolean _tmp12_ = FALSE;
	const gchar* _tmp24_ = NULL;
	gboolean _tmp25_ = FALSE;
	const gchar* _tmp29_ = NULL;
	gboolean _tmp30_ = FALSE;
#line 946 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_WEB_AUTHENTICATION_PANE (self));
#line 947 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = self->priv->pane_widget;
#line 947 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp1_ = gtk_widget_get_window (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_widget_get_type (), GtkWidget));
#line 947 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp2_ = gdk_cursor_new (GDK_LEFT_PTR);
#line 947 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp3_ = _tmp2_;
#line 947 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	gdk_window_set_cursor (_tmp1_, _tmp3_);
#line 947 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_object_unref0 (_tmp3_);
#line 949 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp4_ = self->priv->webview;
#line 949 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp5_ = webkit_web_view_get_uri (_tmp4_);
#line 949 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp6_ = _tmp5_;
#line 949 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp7_ = g_strdup (_tmp6_);
#line 949 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	loaded_url = _tmp7_;
#line 950 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp8_ = loaded_url;
#line 950 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp9_ = g_strconcat ("loaded url: ", _tmp8_, NULL);
#line 950 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp10_ = _tmp9_;
#line 950 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_debug ("FacebookPublishing.vala:950: %s", _tmp10_);
#line 950 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_free0 (_tmp10_);
#line 953 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp11_ = loaded_url;
#line 953 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp12_ = string_contains (_tmp11_, "?");
#line 953 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (_tmp12_) {
#line 5790 "FacebookPublishing.c"
		gint index = 0;
		const gchar* _tmp13_ = NULL;
		gint _tmp14_ = 0;
		gchar* params = NULL;
		const gchar* _tmp15_ = NULL;
		gint _tmp16_ = 0;
		const gchar* _tmp17_ = NULL;
		gint _tmp18_ = 0;
		gint _tmp19_ = 0;
		gchar* _tmp20_ = NULL;
		const gchar* _tmp21_ = NULL;
		const gchar* _tmp22_ = NULL;
		gchar* _tmp23_ = NULL;
#line 954 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp13_ = loaded_url;
#line 954 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp14_ = string_index_of_char (_tmp13_, (gunichar) '?', 0);
#line 954 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		index = _tmp14_;
#line 955 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp15_ = loaded_url;
#line 955 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp16_ = index;
#line 955 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp17_ = loaded_url;
#line 955 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp18_ = strlen (_tmp17_);
#line 955 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp19_ = _tmp18_;
#line 955 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp20_ = string_slice (_tmp15_, (glong) _tmp16_, (glong) _tmp19_);
#line 955 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		params = _tmp20_;
#line 956 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp21_ = loaded_url;
#line 956 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp22_ = params;
#line 956 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp23_ = string_replace (_tmp21_, _tmp22_, "");
#line 956 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_g_free0 (loaded_url);
#line 956 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		loaded_url = _tmp23_;
#line 953 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_g_free0 (params);
#line 5836 "FacebookPublishing.c"
	}
#line 960 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp24_ = loaded_url;
#line 960 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp25_ = string_contains (_tmp24_, "login_success");
#line 960 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (_tmp25_) {
#line 5844 "FacebookPublishing.c"
		WebKitWebView* _tmp26_ = NULL;
		const gchar* _tmp27_ = NULL;
		const gchar* _tmp28_ = NULL;
#line 961 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		publishing_facebook_web_authentication_pane_cache_dirty = TRUE;
#line 962 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp26_ = self->priv->webview;
#line 962 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp27_ = webkit_web_view_get_uri (_tmp26_);
#line 962 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp28_ = _tmp27_;
#line 962 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		g_signal_emit_by_name (self, "login-succeeded", _tmp28_);
#line 963 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_g_free0 (loaded_url);
#line 963 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		return;
#line 5862 "FacebookPublishing.c"
	}
#line 967 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp29_ = loaded_url;
#line 967 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp30_ = string_contains (_tmp29_, "login_failure");
#line 967 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (_tmp30_) {
#line 968 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		g_signal_emit_by_name (self, "login-failed");
#line 969 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_g_free0 (loaded_url);
#line 969 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		return;
#line 5876 "FacebookPublishing.c"
	}
#line 946 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_free0 (loaded_url);
#line 5880 "FacebookPublishing.c"
}


static void publishing_facebook_web_authentication_pane_on_load_started (PublishingFacebookWebAuthenticationPane* self) {
	GtkBox* _tmp0_ = NULL;
	GdkWindow* _tmp1_ = NULL;
	GdkCursor* _tmp2_ = NULL;
	GdkCursor* _tmp3_ = NULL;
#line 973 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_WEB_AUTHENTICATION_PANE (self));
#line 974 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = self->priv->pane_widget;
#line 974 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp1_ = gtk_widget_get_window (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_widget_get_type (), GtkWidget));
#line 974 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp2_ = gdk_cursor_new (GDK_WATCH);
#line 974 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp3_ = _tmp2_;
#line 974 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	gdk_window_set_cursor (_tmp1_, _tmp3_);
#line 974 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_object_unref0 (_tmp3_);
#line 5903 "FacebookPublishing.c"
}


static void publishing_facebook_web_authentication_pane_on_page_load_changed (PublishingFacebookWebAuthenticationPane* self, WebKitLoadEvent load_event) {
	WebKitLoadEvent _tmp0_ = 0;
#line 977 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_WEB_AUTHENTICATION_PANE (self));
#line 978 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = load_event;
#line 978 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	switch (_tmp0_) {
#line 978 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		case WEBKIT_LOAD_STARTED:
#line 978 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		case WEBKIT_LOAD_REDIRECTED:
#line 5919 "FacebookPublishing.c"
		{
#line 981 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			publishing_facebook_web_authentication_pane_on_load_started (self);
#line 982 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			break;
#line 5925 "FacebookPublishing.c"
		}
#line 978 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		case WEBKIT_LOAD_FINISHED:
#line 5929 "FacebookPublishing.c"
		{
#line 984 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			publishing_facebook_web_authentication_pane_on_page_load (self);
#line 985 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			break;
#line 5935 "FacebookPublishing.c"
		}
		default:
#line 978 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		break;
#line 5940 "FacebookPublishing.c"
	}
#line 988 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return;
#line 5944 "FacebookPublishing.c"
}


gboolean publishing_facebook_web_authentication_pane_is_cache_dirty (void) {
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
#line 992 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = publishing_facebook_web_authentication_pane_cache_dirty;
#line 992 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	result = _tmp0_;
#line 992 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return result;
#line 5957 "FacebookPublishing.c"
}


static GtkWidget* publishing_facebook_web_authentication_pane_real_get_widget (SpitPublishingDialogPane* base) {
	PublishingFacebookWebAuthenticationPane * self;
	GtkWidget* result = NULL;
	GtkBox* _tmp0_ = NULL;
	GtkWidget* _tmp1_ = NULL;
#line 995 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_FACEBOOK_TYPE_WEB_AUTHENTICATION_PANE, PublishingFacebookWebAuthenticationPane);
#line 996 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = self->priv->pane_widget;
#line 996 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_widget_get_type (), GtkWidget));
#line 996 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	result = _tmp1_;
#line 996 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return result;
#line 5976 "FacebookPublishing.c"
}


static SpitPublishingDialogPaneGeometryOptions publishing_facebook_web_authentication_pane_real_get_preferred_geometry (SpitPublishingDialogPane* base) {
	PublishingFacebookWebAuthenticationPane * self;
	SpitPublishingDialogPaneGeometryOptions result = 0;
#line 999 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_FACEBOOK_TYPE_WEB_AUTHENTICATION_PANE, PublishingFacebookWebAuthenticationPane);
#line 1000 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	result = SPIT_PUBLISHING_DIALOG_PANE_GEOMETRY_OPTIONS_NONE;
#line 1000 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return result;
#line 5989 "FacebookPublishing.c"
}


static void publishing_facebook_web_authentication_pane_real_on_pane_installed (SpitPublishingDialogPane* base) {
	PublishingFacebookWebAuthenticationPane * self;
	WebKitWebView* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
#line 1003 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_FACEBOOK_TYPE_WEB_AUTHENTICATION_PANE, PublishingFacebookWebAuthenticationPane);
#line 1004 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = self->priv->webview;
#line 1004 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp1_ = publishing_facebook_web_authentication_pane_get_login_url (self);
#line 1004 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp2_ = _tmp1_;
#line 1004 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	webkit_web_view_load_uri (_tmp0_, _tmp2_);
#line 1004 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_free0 (_tmp2_);
#line 6010 "FacebookPublishing.c"
}


static void publishing_facebook_web_authentication_pane_real_on_pane_uninstalled (SpitPublishingDialogPane* base) {
	PublishingFacebookWebAuthenticationPane * self;
#line 1007 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_FACEBOOK_TYPE_WEB_AUTHENTICATION_PANE, PublishingFacebookWebAuthenticationPane);
#line 6018 "FacebookPublishing.c"
}


static PublishingFacebookWebAuthenticationPaneLocaleLookup* publishing_facebook_web_authentication_pane_locale_lookup_construct (GType object_type, const gchar* prefix, const gchar* translation, const gchar* exception_code, const gchar* exception_translation, const gchar* exception_code_2, const gchar* exception_translation_2) {
	PublishingFacebookWebAuthenticationPaneLocaleLookup* self = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	const gchar* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
	const gchar* _tmp8_ = NULL;
	gchar* _tmp9_ = NULL;
	const gchar* _tmp10_ = NULL;
	gchar* _tmp11_ = NULL;
#line 848 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_val_if_fail (prefix != NULL, NULL);
#line 848 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_val_if_fail (translation != NULL, NULL);
#line 848 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self = (PublishingFacebookWebAuthenticationPaneLocaleLookup*) g_type_create_instance (object_type);
#line 851 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = prefix;
#line 851 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 851 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_free0 (self->prefix);
#line 851 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->prefix = _tmp1_;
#line 852 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp2_ = translation;
#line 852 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp3_ = g_strdup (_tmp2_);
#line 852 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_free0 (self->translation);
#line 852 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->translation = _tmp3_;
#line 853 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp4_ = exception_code;
#line 853 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp5_ = g_strdup (_tmp4_);
#line 853 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_free0 (self->exception_code);
#line 853 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->exception_code = _tmp5_;
#line 854 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp6_ = exception_translation;
#line 854 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp7_ = g_strdup (_tmp6_);
#line 854 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_free0 (self->exception_translation);
#line 854 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->exception_translation = _tmp7_;
#line 855 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp8_ = exception_code_2;
#line 855 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp9_ = g_strdup (_tmp8_);
#line 855 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_free0 (self->exception_code_2);
#line 855 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->exception_code_2 = _tmp9_;
#line 856 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp10_ = exception_translation_2;
#line 856 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp11_ = g_strdup (_tmp10_);
#line 856 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_free0 (self->exception_translation_2);
#line 856 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->exception_translation_2 = _tmp11_;
#line 848 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return self;
#line 6092 "FacebookPublishing.c"
}


static PublishingFacebookWebAuthenticationPaneLocaleLookup* publishing_facebook_web_authentication_pane_locale_lookup_new (const gchar* prefix, const gchar* translation, const gchar* exception_code, const gchar* exception_translation, const gchar* exception_code_2, const gchar* exception_translation_2) {
#line 848 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return publishing_facebook_web_authentication_pane_locale_lookup_construct (PUBLISHING_FACEBOOK_WEB_AUTHENTICATION_PANE_TYPE_LOCALE_LOOKUP, prefix, translation, exception_code, exception_translation, exception_code_2, exception_translation_2);
#line 6099 "FacebookPublishing.c"
}


static void publishing_facebook_web_authentication_pane_value_locale_lookup_init (GValue* value) {
#line 840 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	value->data[0].v_pointer = NULL;
#line 6106 "FacebookPublishing.c"
}


static void publishing_facebook_web_authentication_pane_value_locale_lookup_free_value (GValue* value) {
#line 840 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (value->data[0].v_pointer) {
#line 840 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		publishing_facebook_web_authentication_pane_locale_lookup_unref (value->data[0].v_pointer);
#line 6115 "FacebookPublishing.c"
	}
}


static void publishing_facebook_web_authentication_pane_value_locale_lookup_copy_value (const GValue* src_value, GValue* dest_value) {
#line 840 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (src_value->data[0].v_pointer) {
#line 840 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		dest_value->data[0].v_pointer = publishing_facebook_web_authentication_pane_locale_lookup_ref (src_value->data[0].v_pointer);
#line 6125 "FacebookPublishing.c"
	} else {
#line 840 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		dest_value->data[0].v_pointer = NULL;
#line 6129 "FacebookPublishing.c"
	}
}


static gpointer publishing_facebook_web_authentication_pane_value_locale_lookup_peek_pointer (const GValue* value) {
#line 840 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return value->data[0].v_pointer;
#line 6137 "FacebookPublishing.c"
}


static gchar* publishing_facebook_web_authentication_pane_value_locale_lookup_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
#line 840 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (collect_values[0].v_pointer) {
#line 6144 "FacebookPublishing.c"
		PublishingFacebookWebAuthenticationPaneLocaleLookup* object;
		object = collect_values[0].v_pointer;
#line 840 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		if (object->parent_instance.g_class == NULL) {
#line 840 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 6151 "FacebookPublishing.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 840 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 6155 "FacebookPublishing.c"
		}
#line 840 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		value->data[0].v_pointer = publishing_facebook_web_authentication_pane_locale_lookup_ref (object);
#line 6159 "FacebookPublishing.c"
	} else {
#line 840 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 6163 "FacebookPublishing.c"
	}
#line 840 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return NULL;
#line 6167 "FacebookPublishing.c"
}


static gchar* publishing_facebook_web_authentication_pane_value_locale_lookup_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	PublishingFacebookWebAuthenticationPaneLocaleLookup** object_p;
	object_p = collect_values[0].v_pointer;
#line 840 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (!object_p) {
#line 840 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 6178 "FacebookPublishing.c"
	}
#line 840 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (!value->data[0].v_pointer) {
#line 840 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		*object_p = NULL;
#line 6184 "FacebookPublishing.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 840 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		*object_p = value->data[0].v_pointer;
#line 6188 "FacebookPublishing.c"
	} else {
#line 840 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		*object_p = publishing_facebook_web_authentication_pane_locale_lookup_ref (value->data[0].v_pointer);
#line 6192 "FacebookPublishing.c"
	}
#line 840 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return NULL;
#line 6196 "FacebookPublishing.c"
}


static GParamSpec* publishing_facebook_web_authentication_pane_param_spec_locale_lookup (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
	PublishingFacebookWebAuthenticationPaneParamSpecLocaleLookup* spec;
#line 840 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_val_if_fail (g_type_is_a (object_type, PUBLISHING_FACEBOOK_WEB_AUTHENTICATION_PANE_TYPE_LOCALE_LOOKUP), NULL);
#line 840 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 840 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 840 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return G_PARAM_SPEC (spec);
#line 6210 "FacebookPublishing.c"
}


static gpointer publishing_facebook_web_authentication_pane_value_get_locale_lookup (const GValue* value) {
#line 840 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_FACEBOOK_WEB_AUTHENTICATION_PANE_TYPE_LOCALE_LOOKUP), NULL);
#line 840 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return value->data[0].v_pointer;
#line 6219 "FacebookPublishing.c"
}


static void publishing_facebook_web_authentication_pane_value_set_locale_lookup (GValue* value, gpointer v_object) {
	PublishingFacebookWebAuthenticationPaneLocaleLookup* old;
#line 840 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_FACEBOOK_WEB_AUTHENTICATION_PANE_TYPE_LOCALE_LOOKUP));
#line 840 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	old = value->data[0].v_pointer;
#line 840 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (v_object) {
#line 840 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PUBLISHING_FACEBOOK_WEB_AUTHENTICATION_PANE_TYPE_LOCALE_LOOKUP));
#line 840 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 840 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		value->data[0].v_pointer = v_object;
#line 840 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		publishing_facebook_web_authentication_pane_locale_lookup_ref (value->data[0].v_pointer);
#line 6239 "FacebookPublishing.c"
	} else {
#line 840 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 6243 "FacebookPublishing.c"
	}
#line 840 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (old) {
#line 840 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		publishing_facebook_web_authentication_pane_locale_lookup_unref (old);
#line 6249 "FacebookPublishing.c"
	}
}


static void publishing_facebook_web_authentication_pane_value_take_locale_lookup (GValue* value, gpointer v_object) {
	PublishingFacebookWebAuthenticationPaneLocaleLookup* old;
#line 840 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_FACEBOOK_WEB_AUTHENTICATION_PANE_TYPE_LOCALE_LOOKUP));
#line 840 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	old = value->data[0].v_pointer;
#line 840 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (v_object) {
#line 840 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PUBLISHING_FACEBOOK_WEB_AUTHENTICATION_PANE_TYPE_LOCALE_LOOKUP));
#line 840 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 840 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		value->data[0].v_pointer = v_object;
#line 6268 "FacebookPublishing.c"
	} else {
#line 840 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 6272 "FacebookPublishing.c"
	}
#line 840 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (old) {
#line 840 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		publishing_facebook_web_authentication_pane_locale_lookup_unref (old);
#line 6278 "FacebookPublishing.c"
	}
}


static void publishing_facebook_web_authentication_pane_locale_lookup_class_init (PublishingFacebookWebAuthenticationPaneLocaleLookupClass * klass) {
#line 840 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_web_authentication_pane_locale_lookup_parent_class = g_type_class_peek_parent (klass);
#line 840 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	((PublishingFacebookWebAuthenticationPaneLocaleLookupClass *) klass)->finalize = publishing_facebook_web_authentication_pane_locale_lookup_finalize;
#line 6288 "FacebookPublishing.c"
}


static void publishing_facebook_web_authentication_pane_locale_lookup_instance_init (PublishingFacebookWebAuthenticationPaneLocaleLookup * self) {
#line 840 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->ref_count = 1;
#line 6295 "FacebookPublishing.c"
}


static void publishing_facebook_web_authentication_pane_locale_lookup_finalize (PublishingFacebookWebAuthenticationPaneLocaleLookup* obj) {
	PublishingFacebookWebAuthenticationPaneLocaleLookup * self;
#line 840 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_FACEBOOK_WEB_AUTHENTICATION_PANE_TYPE_LOCALE_LOOKUP, PublishingFacebookWebAuthenticationPaneLocaleLookup);
#line 840 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_handlers_destroy (self);
#line 841 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_free0 (self->prefix);
#line 842 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_free0 (self->translation);
#line 843 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_free0 (self->exception_code);
#line 844 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_free0 (self->exception_translation);
#line 845 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_free0 (self->exception_code_2);
#line 846 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_free0 (self->exception_translation_2);
#line 6317 "FacebookPublishing.c"
}


static GType publishing_facebook_web_authentication_pane_locale_lookup_get_type (void) {
	static volatile gsize publishing_facebook_web_authentication_pane_locale_lookup_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_facebook_web_authentication_pane_locale_lookup_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { publishing_facebook_web_authentication_pane_value_locale_lookup_init, publishing_facebook_web_authentication_pane_value_locale_lookup_free_value, publishing_facebook_web_authentication_pane_value_locale_lookup_copy_value, publishing_facebook_web_authentication_pane_value_locale_lookup_peek_pointer, "p", publishing_facebook_web_authentication_pane_value_locale_lookup_collect_value, "p", publishing_facebook_web_authentication_pane_value_locale_lookup_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (PublishingFacebookWebAuthenticationPaneLocaleLookupClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_facebook_web_authentication_pane_locale_lookup_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingFacebookWebAuthenticationPaneLocaleLookup), 0, (GInstanceInitFunc) publishing_facebook_web_authentication_pane_locale_lookup_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType publishing_facebook_web_authentication_pane_locale_lookup_type_id;
		publishing_facebook_web_authentication_pane_locale_lookup_type_id = g_type_register_fundamental (g_type_fundamental_next (), "PublishingFacebookWebAuthenticationPaneLocaleLookup", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&publishing_facebook_web_authentication_pane_locale_lookup_type_id__volatile, publishing_facebook_web_authentication_pane_locale_lookup_type_id);
	}
	return publishing_facebook_web_authentication_pane_locale_lookup_type_id__volatile;
}


static gpointer publishing_facebook_web_authentication_pane_locale_lookup_ref (gpointer instance) {
	PublishingFacebookWebAuthenticationPaneLocaleLookup* self;
	self = instance;
#line 840 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_atomic_int_inc (&self->ref_count);
#line 840 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return instance;
#line 6342 "FacebookPublishing.c"
}


static void publishing_facebook_web_authentication_pane_locale_lookup_unref (gpointer instance) {
	PublishingFacebookWebAuthenticationPaneLocaleLookup* self;
	self = instance;
#line 840 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 840 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		PUBLISHING_FACEBOOK_WEB_AUTHENTICATION_PANE_LOCALE_LOOKUP_GET_CLASS (self)->finalize (self);
#line 840 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 6355 "FacebookPublishing.c"
	}
}


static void publishing_facebook_web_authentication_pane_class_init (PublishingFacebookWebAuthenticationPaneClass * klass) {
#line 814 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_web_authentication_pane_parent_class = g_type_class_peek_parent (klass);
#line 814 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_type_class_add_private (klass, sizeof (PublishingFacebookWebAuthenticationPanePrivate));
#line 814 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	G_OBJECT_CLASS (klass)->finalize = publishing_facebook_web_authentication_pane_finalize;
#line 814 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_new ("login_succeeded", PUBLISHING_FACEBOOK_TYPE_WEB_AUTHENTICATION_PANE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__STRING, G_TYPE_NONE, 1, G_TYPE_STRING);
#line 814 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_new ("login_failed", PUBLISHING_FACEBOOK_TYPE_WEB_AUTHENTICATION_PANE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
#line 6371 "FacebookPublishing.c"
}


static void publishing_facebook_web_authentication_pane_spit_publishing_dialog_pane_interface_init (SpitPublishingDialogPaneIface * iface) {
#line 814 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_web_authentication_pane_spit_publishing_dialog_pane_parent_iface = g_type_interface_peek_parent (iface);
#line 814 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	iface->get_widget = (GtkWidget* (*)(SpitPublishingDialogPane*)) publishing_facebook_web_authentication_pane_real_get_widget;
#line 814 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	iface->get_preferred_geometry = (SpitPublishingDialogPaneGeometryOptions (*)(SpitPublishingDialogPane*)) publishing_facebook_web_authentication_pane_real_get_preferred_geometry;
#line 814 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	iface->on_pane_installed = (void (*)(SpitPublishingDialogPane*)) publishing_facebook_web_authentication_pane_real_on_pane_installed;
#line 814 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	iface->on_pane_uninstalled = (void (*)(SpitPublishingDialogPane*)) publishing_facebook_web_authentication_pane_real_on_pane_uninstalled;
#line 6386 "FacebookPublishing.c"
}


static void publishing_facebook_web_authentication_pane_instance_init (PublishingFacebookWebAuthenticationPane * self) {
	PublishingFacebookWebAuthenticationPaneLocaleLookup* _tmp0_ = NULL;
	PublishingFacebookWebAuthenticationPaneLocaleLookup* _tmp1_ = NULL;
	PublishingFacebookWebAuthenticationPaneLocaleLookup* _tmp2_ = NULL;
	PublishingFacebookWebAuthenticationPaneLocaleLookup* _tmp3_ = NULL;
	PublishingFacebookWebAuthenticationPaneLocaleLookup* _tmp4_ = NULL;
	PublishingFacebookWebAuthenticationPaneLocaleLookup* _tmp5_ = NULL;
	PublishingFacebookWebAuthenticationPaneLocaleLookup* _tmp6_ = NULL;
	PublishingFacebookWebAuthenticationPaneLocaleLookup* _tmp7_ = NULL;
	PublishingFacebookWebAuthenticationPaneLocaleLookup* _tmp8_ = NULL;
	PublishingFacebookWebAuthenticationPaneLocaleLookup* _tmp9_ = NULL;
	PublishingFacebookWebAuthenticationPaneLocaleLookup* _tmp10_ = NULL;
	PublishingFacebookWebAuthenticationPaneLocaleLookup* _tmp11_ = NULL;
	PublishingFacebookWebAuthenticationPaneLocaleLookup* _tmp12_ = NULL;
	PublishingFacebookWebAuthenticationPaneLocaleLookup* _tmp13_ = NULL;
	PublishingFacebookWebAuthenticationPaneLocaleLookup* _tmp14_ = NULL;
	PublishingFacebookWebAuthenticationPaneLocaleLookup* _tmp15_ = NULL;
	PublishingFacebookWebAuthenticationPaneLocaleLookup* _tmp16_ = NULL;
	PublishingFacebookWebAuthenticationPaneLocaleLookup* _tmp17_ = NULL;
	PublishingFacebookWebAuthenticationPaneLocaleLookup* _tmp18_ = NULL;
	PublishingFacebookWebAuthenticationPaneLocaleLookup* _tmp19_ = NULL;
	PublishingFacebookWebAuthenticationPaneLocaleLookup* _tmp20_ = NULL;
	PublishingFacebookWebAuthenticationPaneLocaleLookup* _tmp21_ = NULL;
	PublishingFacebookWebAuthenticationPaneLocaleLookup* _tmp22_ = NULL;
	PublishingFacebookWebAuthenticationPaneLocaleLookup* _tmp23_ = NULL;
	PublishingFacebookWebAuthenticationPaneLocaleLookup* _tmp24_ = NULL;
	PublishingFacebookWebAuthenticationPaneLocaleLookup* _tmp25_ = NULL;
	PublishingFacebookWebAuthenticationPaneLocaleLookup* _tmp26_ = NULL;
	PublishingFacebookWebAuthenticationPaneLocaleLookup* _tmp27_ = NULL;
	PublishingFacebookWebAuthenticationPaneLocaleLookup* _tmp28_ = NULL;
	PublishingFacebookWebAuthenticationPaneLocaleLookup* _tmp29_ = NULL;
	PublishingFacebookWebAuthenticationPaneLocaleLookup* _tmp30_ = NULL;
	PublishingFacebookWebAuthenticationPaneLocaleLookup* _tmp31_ = NULL;
	PublishingFacebookWebAuthenticationPaneLocaleLookup* _tmp32_ = NULL;
	PublishingFacebookWebAuthenticationPaneLocaleLookup* _tmp33_ = NULL;
	PublishingFacebookWebAuthenticationPaneLocaleLookup* _tmp34_ = NULL;
	PublishingFacebookWebAuthenticationPaneLocaleLookup* _tmp35_ = NULL;
	PublishingFacebookWebAuthenticationPaneLocaleLookup* _tmp36_ = NULL;
	PublishingFacebookWebAuthenticationPaneLocaleLookup* _tmp37_ = NULL;
	PublishingFacebookWebAuthenticationPaneLocaleLookup* _tmp38_ = NULL;
	PublishingFacebookWebAuthenticationPaneLocaleLookup* _tmp39_ = NULL;
	PublishingFacebookWebAuthenticationPaneLocaleLookup* _tmp40_ = NULL;
	PublishingFacebookWebAuthenticationPaneLocaleLookup* _tmp41_ = NULL;
	PublishingFacebookWebAuthenticationPaneLocaleLookup* _tmp42_ = NULL;
	PublishingFacebookWebAuthenticationPaneLocaleLookup* _tmp43_ = NULL;
	PublishingFacebookWebAuthenticationPaneLocaleLookup* _tmp44_ = NULL;
	PublishingFacebookWebAuthenticationPaneLocaleLookup** _tmp45_ = NULL;
#line 814 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv = PUBLISHING_FACEBOOK_WEB_AUTHENTICATION_PANE_GET_PRIVATE (self);
#line 815 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->webview = NULL;
#line 816 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->pane_widget = NULL;
#line 817 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->webview_frame = NULL;
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = publishing_facebook_web_authentication_pane_locale_lookup_new ("es", "es-la", "ES", "es-es", NULL, NULL);
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp1_ = publishing_facebook_web_authentication_pane_locale_lookup_new ("en", "en-gb", "US", "en-us", NULL, NULL);
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp2_ = publishing_facebook_web_authentication_pane_locale_lookup_new ("fr", "fr-fr", "CA", "fr-ca", NULL, NULL);
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp3_ = publishing_facebook_web_authentication_pane_locale_lookup_new ("pt", "pt-br", "PT", "pt-pt", NULL, NULL);
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp4_ = publishing_facebook_web_authentication_pane_locale_lookup_new ("zh", "zh-cn", "HK", "zh-hk", "TW", "zh-tw");
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp5_ = publishing_facebook_web_authentication_pane_locale_lookup_new ("af", "af-za", NULL, NULL, NULL, NULL);
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp6_ = publishing_facebook_web_authentication_pane_locale_lookup_new ("ar", "ar-ar", NULL, NULL, NULL, NULL);
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp7_ = publishing_facebook_web_authentication_pane_locale_lookup_new ("nb", "nb-no", NULL, NULL, NULL, NULL);
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp8_ = publishing_facebook_web_authentication_pane_locale_lookup_new ("no", "nb-no", NULL, NULL, NULL, NULL);
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp9_ = publishing_facebook_web_authentication_pane_locale_lookup_new ("id", "id-id", NULL, NULL, NULL, NULL);
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp10_ = publishing_facebook_web_authentication_pane_locale_lookup_new ("ms", "ms-my", NULL, NULL, NULL, NULL);
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp11_ = publishing_facebook_web_authentication_pane_locale_lookup_new ("ca", "ca-es", NULL, NULL, NULL, NULL);
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp12_ = publishing_facebook_web_authentication_pane_locale_lookup_new ("cs", "cs-cz", NULL, NULL, NULL, NULL);
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp13_ = publishing_facebook_web_authentication_pane_locale_lookup_new ("cy", "cy-gb", NULL, NULL, NULL, NULL);
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp14_ = publishing_facebook_web_authentication_pane_locale_lookup_new ("da", "da-dk", NULL, NULL, NULL, NULL);
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp15_ = publishing_facebook_web_authentication_pane_locale_lookup_new ("de", "de-de", NULL, NULL, NULL, NULL);
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp16_ = publishing_facebook_web_authentication_pane_locale_lookup_new ("tl", "tl-ph", NULL, NULL, NULL, NULL);
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp17_ = publishing_facebook_web_authentication_pane_locale_lookup_new ("ko", "ko-kr", NULL, NULL, NULL, NULL);
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp18_ = publishing_facebook_web_authentication_pane_locale_lookup_new ("hr", "hr-hr", NULL, NULL, NULL, NULL);
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp19_ = publishing_facebook_web_authentication_pane_locale_lookup_new ("it", "it-it", NULL, NULL, NULL, NULL);
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp20_ = publishing_facebook_web_authentication_pane_locale_lookup_new ("lt", "lt-lt", NULL, NULL, NULL, NULL);
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp21_ = publishing_facebook_web_authentication_pane_locale_lookup_new ("hu", "hu-hu", NULL, NULL, NULL, NULL);
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp22_ = publishing_facebook_web_authentication_pane_locale_lookup_new ("nl", "nl-nl", NULL, NULL, NULL, NULL);
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp23_ = publishing_facebook_web_authentication_pane_locale_lookup_new ("ja", "ja-jp", NULL, NULL, NULL, NULL);
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp24_ = publishing_facebook_web_authentication_pane_locale_lookup_new ("nb", "nb-no", NULL, NULL, NULL, NULL);
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp25_ = publishing_facebook_web_authentication_pane_locale_lookup_new ("no", "nb-no", NULL, NULL, NULL, NULL);
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp26_ = publishing_facebook_web_authentication_pane_locale_lookup_new ("pl", "pl-pl", NULL, NULL, NULL, NULL);
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp27_ = publishing_facebook_web_authentication_pane_locale_lookup_new ("ro", "ro-ro", NULL, NULL, NULL, NULL);
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp28_ = publishing_facebook_web_authentication_pane_locale_lookup_new ("ru", "ru-ru", NULL, NULL, NULL, NULL);
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp29_ = publishing_facebook_web_authentication_pane_locale_lookup_new ("sk", "sk-sk", NULL, NULL, NULL, NULL);
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp30_ = publishing_facebook_web_authentication_pane_locale_lookup_new ("sl", "sl-si", NULL, NULL, NULL, NULL);
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp31_ = publishing_facebook_web_authentication_pane_locale_lookup_new ("sv", "sv-se", NULL, NULL, NULL, NULL);
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp32_ = publishing_facebook_web_authentication_pane_locale_lookup_new ("th", "th-th", NULL, NULL, NULL, NULL);
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp33_ = publishing_facebook_web_authentication_pane_locale_lookup_new ("vi", "vi-vn", NULL, NULL, NULL, NULL);
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp34_ = publishing_facebook_web_authentication_pane_locale_lookup_new ("tr", "tr-tr", NULL, NULL, NULL, NULL);
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp35_ = publishing_facebook_web_authentication_pane_locale_lookup_new ("el", "el-gr", NULL, NULL, NULL, NULL);
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp36_ = publishing_facebook_web_authentication_pane_locale_lookup_new ("bg", "bg-bg", NULL, NULL, NULL, NULL);
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp37_ = publishing_facebook_web_authentication_pane_locale_lookup_new ("sr", "sr-rs", NULL, NULL, NULL, NULL);
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp38_ = publishing_facebook_web_authentication_pane_locale_lookup_new ("he", "he-il", NULL, NULL, NULL, NULL);
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp39_ = publishing_facebook_web_authentication_pane_locale_lookup_new ("hi", "hi-in", NULL, NULL, NULL, NULL);
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp40_ = publishing_facebook_web_authentication_pane_locale_lookup_new ("bn", "bn-in", NULL, NULL, NULL, NULL);
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp41_ = publishing_facebook_web_authentication_pane_locale_lookup_new ("pa", "pa-in", NULL, NULL, NULL, NULL);
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp42_ = publishing_facebook_web_authentication_pane_locale_lookup_new ("ta", "ta-in", NULL, NULL, NULL, NULL);
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp43_ = publishing_facebook_web_authentication_pane_locale_lookup_new ("te", "te-in", NULL, NULL, NULL, NULL);
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp44_ = publishing_facebook_web_authentication_pane_locale_lookup_new ("ml", "ml-in", NULL, NULL, NULL, NULL);
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp45_ = g_new0 (PublishingFacebookWebAuthenticationPaneLocaleLookup*, 45 + 1);
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp45_[0] = _tmp0_;
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp45_[1] = _tmp1_;
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp45_[2] = _tmp2_;
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp45_[3] = _tmp3_;
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp45_[4] = _tmp4_;
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp45_[5] = _tmp5_;
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp45_[6] = _tmp6_;
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp45_[7] = _tmp7_;
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp45_[8] = _tmp8_;
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp45_[9] = _tmp9_;
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp45_[10] = _tmp10_;
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp45_[11] = _tmp11_;
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp45_[12] = _tmp12_;
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp45_[13] = _tmp13_;
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp45_[14] = _tmp14_;
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp45_[15] = _tmp15_;
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp45_[16] = _tmp16_;
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp45_[17] = _tmp17_;
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp45_[18] = _tmp18_;
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp45_[19] = _tmp19_;
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp45_[20] = _tmp20_;
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp45_[21] = _tmp21_;
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp45_[22] = _tmp22_;
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp45_[23] = _tmp23_;
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp45_[24] = _tmp24_;
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp45_[25] = _tmp25_;
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp45_[26] = _tmp26_;
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp45_[27] = _tmp27_;
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp45_[28] = _tmp28_;
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp45_[29] = _tmp29_;
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp45_[30] = _tmp30_;
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp45_[31] = _tmp31_;
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp45_[32] = _tmp32_;
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp45_[33] = _tmp33_;
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp45_[34] = _tmp34_;
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp45_[35] = _tmp35_;
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp45_[36] = _tmp36_;
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp45_[37] = _tmp37_;
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp45_[38] = _tmp38_;
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp45_[39] = _tmp39_;
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp45_[40] = _tmp40_;
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp45_[41] = _tmp41_;
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp45_[42] = _tmp42_;
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp45_[43] = _tmp43_;
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp45_[44] = _tmp44_;
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->locale_lookup_table = _tmp45_;
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->locale_lookup_table_length1 = 45;
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->_locale_lookup_table_size_ = self->priv->locale_lookup_table_length1;
#line 6633 "FacebookPublishing.c"
}


static void publishing_facebook_web_authentication_pane_finalize (GObject* obj) {
	PublishingFacebookWebAuthenticationPane * self;
#line 814 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_FACEBOOK_TYPE_WEB_AUTHENTICATION_PANE, PublishingFacebookWebAuthenticationPane);
#line 815 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_object_unref0 (self->priv->webview);
#line 816 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_object_unref0 (self->priv->pane_widget);
#line 817 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_object_unref0 (self->priv->webview_frame);
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->locale_lookup_table = (_vala_array_free (self->priv->locale_lookup_table, self->priv->locale_lookup_table_length1, (GDestroyNotify) publishing_facebook_web_authentication_pane_locale_lookup_unref), NULL);
#line 814 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	G_OBJECT_CLASS (publishing_facebook_web_authentication_pane_parent_class)->finalize (obj);
#line 6651 "FacebookPublishing.c"
}


GType publishing_facebook_web_authentication_pane_get_type (void) {
	static volatile gsize publishing_facebook_web_authentication_pane_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_facebook_web_authentication_pane_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingFacebookWebAuthenticationPaneClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_facebook_web_authentication_pane_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingFacebookWebAuthenticationPane), 0, (GInstanceInitFunc) publishing_facebook_web_authentication_pane_instance_init, NULL };
		static const GInterfaceInfo spit_publishing_dialog_pane_info = { (GInterfaceInitFunc) publishing_facebook_web_authentication_pane_spit_publishing_dialog_pane_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType publishing_facebook_web_authentication_pane_type_id;
		publishing_facebook_web_authentication_pane_type_id = g_type_register_static (G_TYPE_OBJECT, "PublishingFacebookWebAuthenticationPane", &g_define_type_info, 0);
		g_type_add_interface_static (publishing_facebook_web_authentication_pane_type_id, SPIT_PUBLISHING_TYPE_DIALOG_PANE, &spit_publishing_dialog_pane_info);
		g_once_init_leave (&publishing_facebook_web_authentication_pane_type_id__volatile, publishing_facebook_web_authentication_pane_type_id);
	}
	return publishing_facebook_web_authentication_pane_type_id__volatile;
}


static PublishingFacebookAlbum** _vala_array_dup2 (PublishingFacebookAlbum** self, int length) {
	PublishingFacebookAlbum** result;
	int i;
#line 1060 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	result = g_new0 (PublishingFacebookAlbum*, length + 1);
#line 1060 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	for (i = 0; i < length; i++) {
#line 6676 "FacebookPublishing.c"
		PublishingFacebookAlbum* _tmp0_ = NULL;
#line 1060 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp0_ = _publishing_facebook_album_ref0 (self[i]);
#line 1060 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		result[i] = _tmp0_;
#line 6682 "FacebookPublishing.c"
	}
#line 1060 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return result;
#line 6686 "FacebookPublishing.c"
}


static void _publishing_facebook_publishing_options_pane_on_create_new_toggled_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 1083 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_publishing_options_pane_on_create_new_toggled ((PublishingFacebookPublishingOptionsPane*) self);
#line 6693 "FacebookPublishing.c"
}


static void _publishing_facebook_publishing_options_pane_on_use_existing_toggled_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 1084 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_publishing_options_pane_on_use_existing_toggled ((PublishingFacebookPublishingOptionsPane*) self);
#line 6700 "FacebookPublishing.c"
}


static void _publishing_facebook_publishing_options_pane_on_publish_button_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 1095 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_publishing_options_pane_on_publish_button_clicked ((PublishingFacebookPublishingOptionsPane*) self);
#line 6707 "FacebookPublishing.c"
}


static void _publishing_facebook_publishing_options_pane_on_logout_button_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 1096 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_publishing_options_pane_on_logout_button_clicked ((PublishingFacebookPublishingOptionsPane*) self);
#line 6714 "FacebookPublishing.c"
}


static void _publishing_facebook_publishing_options_pane_on_size_changed_gtk_combo_box_changed (GtkComboBox* _sender, gpointer self) {
#line 1100 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_publishing_options_pane_on_size_changed ((PublishingFacebookPublishingOptionsPane*) self);
#line 6721 "FacebookPublishing.c"
}


PublishingFacebookPublishingOptionsPane* publishing_facebook_publishing_options_pane_construct (GType object_type, const gchar* username, PublishingFacebookAlbum** albums, int albums_length1, SpitPublishingPublisherMediaType media_type, PublishingFacebookFacebookPublisher* publisher, GtkBuilder* builder, gboolean strip_metadata) {
	PublishingFacebookPublishingOptionsPane * self = NULL;
	GtkBuilder* _tmp0_ = NULL;
	GtkBuilder* _tmp1_ = NULL;
	GtkBuilder* _tmp2_ = NULL;
	GtkBuilder* _tmp3_ = NULL;
	GSList* _tmp4_ = NULL;
	GSList* _tmp5_ = NULL;
	guint _tmp6_ = 0U;
	PublishingFacebookAlbum** _tmp7_ = NULL;
	gint _tmp7__length1 = 0;
	PublishingFacebookAlbum** _tmp8_ = NULL;
	gint _tmp8__length1 = 0;
	gint _tmp9_ = 0;
	PublishingFacebookPublishingOptionsPanePrivacyDescription** _tmp10_ = NULL;
	gint _tmp11_ = 0;
	PublishingFacebookResolution* _tmp12_ = NULL;
	PublishingFacebookFacebookPublisher* _tmp13_ = NULL;
	PublishingFacebookFacebookPublisher* _tmp14_ = NULL;
	SpitPublishingPublisherMediaType _tmp15_ = 0;
	GtkBuilder* _tmp16_ = NULL;
	GObject* _tmp17_ = NULL;
	GtkBox* _tmp18_ = NULL;
	GtkBox* _tmp19_ = NULL;
	GtkBuilder* _tmp20_ = NULL;
	GObject* _tmp21_ = NULL;
	GtkRadioButton* _tmp22_ = NULL;
	GtkBuilder* _tmp23_ = NULL;
	GObject* _tmp24_ = NULL;
	GtkRadioButton* _tmp25_ = NULL;
	GtkBuilder* _tmp26_ = NULL;
	GObject* _tmp27_ = NULL;
	GtkComboBoxText* _tmp28_ = NULL;
	GtkBuilder* _tmp29_ = NULL;
	GObject* _tmp30_ = NULL;
	GtkComboBoxText* _tmp31_ = NULL;
	GtkBuilder* _tmp32_ = NULL;
	GObject* _tmp33_ = NULL;
	GtkButton* _tmp34_ = NULL;
	GtkBuilder* _tmp35_ = NULL;
	GObject* _tmp36_ = NULL;
	GtkButton* _tmp37_ = NULL;
	GtkBuilder* _tmp38_ = NULL;
	GObject* _tmp39_ = NULL;
	GtkEntry* _tmp40_ = NULL;
	GtkBuilder* _tmp41_ = NULL;
	GObject* _tmp42_ = NULL;
	GtkComboBoxText* _tmp43_ = NULL;
	GtkBuilder* _tmp44_ = NULL;
	GObject* _tmp45_ = NULL;
	GtkLabel* _tmp46_ = NULL;
	GtkBuilder* _tmp47_ = NULL;
	GObject* _tmp48_ = NULL;
	GtkCheckButton* _tmp49_ = NULL;
	GtkRadioButton* _tmp50_ = NULL;
	GtkRadioButton* _tmp51_ = NULL;
	gchar* label_text = NULL;
	const gchar* _tmp52_ = NULL;
	gchar* _tmp53_ = NULL;
	SpitPublishingPublisherMediaType _tmp54_ = 0;
	GtkLabel* _tmp57_ = NULL;
	const gchar* _tmp58_ = NULL;
	GtkCheckButton* _tmp59_ = NULL;
	gboolean _tmp60_ = FALSE;
	GtkComboBoxText* _tmp61_ = NULL;
	GtkButton* _tmp62_ = NULL;
	GtkButton* _tmp63_ = NULL;
	GtkComboBoxText* _tmp64_ = NULL;
	PublishingFacebookFacebookPublisher* _tmp65_ = NULL;
	gint _tmp66_ = 0;
	GtkComboBoxText* _tmp67_ = NULL;
	gboolean _tmp68_ = FALSE;
	gboolean _tmp69_ = FALSE;
	GtkRadioButton* _tmp70_ = NULL;
	GtkComboBoxText* _tmp75_ = NULL;
	SpitPublishingPublisherMediaType _tmp76_ = 0;
#line 1052 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_val_if_fail (username != NULL, NULL);
#line 1052 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_val_if_fail (PUBLISHING_FACEBOOK_IS_FACEBOOK_PUBLISHER (publisher), NULL);
#line 1052 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_val_if_fail (GTK_IS_BUILDER (builder), NULL);
#line 1052 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self = (PublishingFacebookPublishingOptionsPane*) g_object_new (object_type, NULL);
#line 1056 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = builder;
#line 1056 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 1056 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_object_unref0 (self->priv->builder);
#line 1056 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->builder = _tmp1_;
#line 1057 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp2_ = builder;
#line 1057 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_vala_assert (_tmp2_ != NULL, "builder != null");
#line 1058 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp3_ = builder;
#line 1058 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp4_ = gtk_builder_get_objects (_tmp3_);
#line 1058 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp5_ = _tmp4_;
#line 1058 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp6_ = g_slist_length (_tmp5_);
#line 1058 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_vala_assert (_tmp6_ > ((guint) 0), "builder.get_objects().length() > 0");
#line 1058 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_slist_free0 (_tmp5_);
#line 1060 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp7_ = albums;
#line 1060 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp7__length1 = albums_length1;
#line 1060 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp8_ = (_tmp7_ != NULL) ? _vala_array_dup2 (_tmp7_, _tmp7__length1) : ((gpointer) _tmp7_);
#line 1060 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp8__length1 = _tmp7__length1;
#line 1060 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->albums = (_vala_array_free (self->priv->albums, self->priv->albums_length1, (GDestroyNotify) publishing_facebook_album_unref), NULL);
#line 1060 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->albums = _tmp8_;
#line 1060 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->albums_length1 = _tmp8__length1;
#line 1060 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->_albums_size_ = self->priv->albums_length1;
#line 1061 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp10_ = publishing_facebook_publishing_options_pane_create_privacy_descriptions (self, &_tmp9_);
#line 1061 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->privacy_descriptions = (_vala_array_free (self->priv->privacy_descriptions, self->priv->privacy_descriptions_length1, (GDestroyNotify) publishing_facebook_publishing_options_pane_privacy_description_unref), NULL);
#line 1061 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->privacy_descriptions = _tmp10_;
#line 1061 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->privacy_descriptions_length1 = _tmp9_;
#line 1061 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->_privacy_descriptions_size_ = self->priv->privacy_descriptions_length1;
#line 1063 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp12_ = publishing_facebook_publishing_options_pane_create_resolution_list (self, &_tmp11_);
#line 1063 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->possible_resolutions = (g_free (self->priv->possible_resolutions), NULL);
#line 1063 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->possible_resolutions = _tmp12_;
#line 1063 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->possible_resolutions_length1 = _tmp11_;
#line 1063 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->_possible_resolutions_size_ = self->priv->possible_resolutions_length1;
#line 1064 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp13_ = publisher;
#line 1064 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp14_ = _g_object_ref0 (_tmp13_);
#line 1064 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_object_unref0 (self->priv->publisher);
#line 1064 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->publisher = _tmp14_;
#line 1067 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp15_ = media_type;
#line 1067 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->media_type = _tmp15_;
#line 1069 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp16_ = builder;
#line 1069 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp17_ = gtk_builder_get_object (_tmp16_, "facebook_pane_box");
#line 1069 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp18_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp17_, gtk_box_get_type (), GtkBox));
#line 1069 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_object_unref0 (self->priv->pane_widget);
#line 1069 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->pane_widget = _tmp18_;
#line 1070 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp19_ = self->priv->pane_widget;
#line 1070 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	gtk_container_set_border_width (G_TYPE_CHECK_INSTANCE_CAST (_tmp19_, gtk_container_get_type (), GtkContainer), (guint) 16);
#line 1072 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp20_ = self->priv->builder;
#line 1072 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp21_ = gtk_builder_get_object (_tmp20_, "use_existing_radio");
#line 1072 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp22_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp21_, gtk_radio_button_get_type (), GtkRadioButton));
#line 1072 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_object_unref0 (self->priv->use_existing_radio);
#line 1072 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->use_existing_radio = _tmp22_;
#line 1073 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp23_ = self->priv->builder;
#line 1073 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp24_ = gtk_builder_get_object (_tmp23_, "create_new_radio");
#line 1073 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp25_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp24_, gtk_radio_button_get_type (), GtkRadioButton));
#line 1073 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_object_unref0 (self->priv->create_new_radio);
#line 1073 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->create_new_radio = _tmp25_;
#line 1074 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp26_ = self->priv->builder;
#line 1074 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp27_ = gtk_builder_get_object (_tmp26_, "existing_albums_combo");
#line 1074 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp28_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp27_, gtk_combo_box_text_get_type (), GtkComboBoxText));
#line 1074 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_object_unref0 (self->priv->existing_albums_combo);
#line 1074 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->existing_albums_combo = _tmp28_;
#line 1075 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp29_ = self->priv->builder;
#line 1075 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp30_ = gtk_builder_get_object (_tmp29_, "visibility_combo");
#line 1075 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp31_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp30_, gtk_combo_box_text_get_type (), GtkComboBoxText));
#line 1075 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_object_unref0 (self->priv->visibility_combo);
#line 1075 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->visibility_combo = _tmp31_;
#line 1076 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp32_ = self->priv->builder;
#line 1076 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp33_ = gtk_builder_get_object (_tmp32_, "publish_button");
#line 1076 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp34_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp33_, gtk_button_get_type (), GtkButton));
#line 1076 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_object_unref0 (self->priv->publish_button);
#line 1076 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->publish_button = _tmp34_;
#line 1077 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp35_ = self->priv->builder;
#line 1077 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp36_ = gtk_builder_get_object (_tmp35_, "logout_button");
#line 1077 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp37_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp36_, gtk_button_get_type (), GtkButton));
#line 1077 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_object_unref0 (self->priv->logout_button);
#line 1077 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->logout_button = _tmp37_;
#line 1078 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp38_ = self->priv->builder;
#line 1078 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp39_ = gtk_builder_get_object (_tmp38_, "new_album_entry");
#line 1078 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp40_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp39_, gtk_entry_get_type (), GtkEntry));
#line 1078 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_object_unref0 (self->priv->new_album_entry);
#line 1078 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->new_album_entry = _tmp40_;
#line 1079 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp41_ = self->priv->builder;
#line 1079 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp42_ = gtk_builder_get_object (_tmp41_, "resolution_combo");
#line 1079 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp43_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp42_, gtk_combo_box_text_get_type (), GtkComboBoxText));
#line 1079 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_object_unref0 (self->priv->resolution_combo);
#line 1079 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->resolution_combo = _tmp43_;
#line 1080 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp44_ = self->priv->builder;
#line 1080 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp45_ = gtk_builder_get_object (_tmp44_, "how_to_label");
#line 1080 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp46_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp45_, gtk_label_get_type (), GtkLabel));
#line 1080 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_object_unref0 (self->priv->how_to_label);
#line 1080 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->how_to_label = _tmp46_;
#line 1081 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp47_ = self->priv->builder;
#line 1081 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp48_ = gtk_builder_get_object (_tmp47_, "strip_metadata_check");
#line 1081 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp49_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp48_, gtk_check_button_get_type (), GtkCheckButton));
#line 1081 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_object_unref0 (self->priv->strip_metadata_check);
#line 1081 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->strip_metadata_check = _tmp49_;
#line 1083 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp50_ = self->priv->create_new_radio;
#line 1083 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp50_, gtk_button_get_type (), GtkButton), "clicked", (GCallback) _publishing_facebook_publishing_options_pane_on_create_new_toggled_gtk_button_clicked, self, 0);
#line 1084 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp51_ = self->priv->use_existing_radio;
#line 1084 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp51_, gtk_button_get_type (), GtkButton), "clicked", (GCallback) _publishing_facebook_publishing_options_pane_on_use_existing_toggled_gtk_button_clicked, self, 0);
#line 1086 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp52_ = username;
#line 1086 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp53_ = g_strdup_printf (PUBLISHING_FACEBOOK_PUBLISHING_OPTIONS_PANE_HEADER_LABEL_TEXT, _tmp52_);
#line 1086 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	label_text = _tmp53_;
#line 1087 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp54_ = media_type;
#line 1087 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if ((_tmp54_ & SPIT_PUBLISHING_PUBLISHER_MEDIA_TYPE_PHOTO) != 0) {
#line 7013 "FacebookPublishing.c"
		const gchar* _tmp55_ = NULL;
		gchar* _tmp56_ = NULL;
#line 1088 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp55_ = label_text;
#line 1088 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp56_ = g_strconcat (_tmp55_, PUBLISHING_FACEBOOK_PUBLISHING_OPTIONS_PANE_PHOTOS_LABEL_TEXT, NULL);
#line 1088 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_g_free0 (label_text);
#line 1088 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		label_text = _tmp56_;
#line 7024 "FacebookPublishing.c"
	}
#line 1089 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp57_ = self->priv->how_to_label;
#line 1089 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp58_ = label_text;
#line 1089 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	gtk_label_set_label (_tmp57_, _tmp58_);
#line 1090 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp59_ = self->priv->strip_metadata_check;
#line 1090 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp60_ = strip_metadata;
#line 1090 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	gtk_toggle_button_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp59_, gtk_toggle_button_get_type (), GtkToggleButton), _tmp60_);
#line 1092 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_publishing_options_pane_setup_visibility_combo (self);
#line 1093 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp61_ = self->priv->visibility_combo;
#line 1093 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	gtk_combo_box_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp61_, gtk_combo_box_get_type (), GtkComboBox), 0);
#line 1095 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp62_ = self->priv->publish_button;
#line 1095 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_connect_object (_tmp62_, "clicked", (GCallback) _publishing_facebook_publishing_options_pane_on_publish_button_clicked_gtk_button_clicked, self, 0);
#line 1096 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp63_ = self->priv->logout_button;
#line 1096 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_connect_object (_tmp63_, "clicked", (GCallback) _publishing_facebook_publishing_options_pane_on_logout_button_clicked_gtk_button_clicked, self, 0);
#line 1098 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_publishing_options_pane_setup_resolution_combo (self);
#line 1099 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp64_ = self->priv->resolution_combo;
#line 1099 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp65_ = publisher;
#line 1099 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp66_ = publishing_facebook_facebook_publisher_get_persistent_default_size (_tmp65_);
#line 1099 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	gtk_combo_box_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp64_, gtk_combo_box_get_type (), GtkComboBox), _tmp66_);
#line 1100 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp67_ = self->priv->resolution_combo;
#line 1100 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp67_, gtk_combo_box_get_type (), GtkComboBox), "changed", (GCallback) _publishing_facebook_publishing_options_pane_on_size_changed_gtk_combo_box_changed, self, 0);
#line 1106 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp70_ = self->priv->create_new_radio;
#line 1106 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (_tmp70_ != NULL) {
#line 7070 "FacebookPublishing.c"
		GtkRadioButton* _tmp71_ = NULL;
		gboolean _tmp72_ = FALSE;
		gboolean _tmp73_ = FALSE;
#line 1106 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp71_ = self->priv->create_new_radio;
#line 1106 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp72_ = gtk_toggle_button_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp71_, gtk_toggle_button_get_type (), GtkToggleButton));
#line 1106 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp73_ = _tmp72_;
#line 1106 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp69_ = _tmp73_;
#line 7082 "FacebookPublishing.c"
	} else {
#line 1106 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp69_ = FALSE;
#line 7086 "FacebookPublishing.c"
	}
#line 1106 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (_tmp69_) {
#line 1106 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp68_ = TRUE;
#line 7092 "FacebookPublishing.c"
	} else {
		SpitPublishingPublisherMediaType _tmp74_ = 0;
#line 1107 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp74_ = media_type;
#line 1107 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp68_ = (_tmp74_ & SPIT_PUBLISHING_PUBLISHER_MEDIA_TYPE_VIDEO) != 0;
#line 7099 "FacebookPublishing.c"
	}
#line 1105 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp75_ = self->priv->visibility_combo;
#line 1105 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp75_, gtk_widget_get_type (), GtkWidget), _tmp68_);
#line 1110 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp76_ = media_type;
#line 1110 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (_tmp76_ == SPIT_PUBLISHING_PUBLISHER_MEDIA_TYPE_VIDEO) {
#line 7109 "FacebookPublishing.c"
		GtkCheckButton* _tmp77_ = NULL;
		GtkCheckButton* _tmp78_ = NULL;
		GtkComboBoxText* _tmp79_ = NULL;
		GtkRadioButton* _tmp80_ = NULL;
		GtkRadioButton* _tmp81_ = NULL;
		GtkComboBoxText* _tmp82_ = NULL;
		GtkEntry* _tmp83_ = NULL;
#line 1111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp77_ = self->priv->strip_metadata_check;
#line 1111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		gtk_toggle_button_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp77_, gtk_toggle_button_get_type (), GtkToggleButton), FALSE);
#line 1112 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp78_ = self->priv->strip_metadata_check;
#line 1112 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp78_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 1113 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp79_ = self->priv->resolution_combo;
#line 1113 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp79_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 1114 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp80_ = self->priv->use_existing_radio;
#line 1114 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp80_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 1115 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp81_ = self->priv->create_new_radio;
#line 1115 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp81_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 1116 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp82_ = self->priv->existing_albums_combo;
#line 1116 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp82_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 1117 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp83_ = self->priv->new_album_entry;
#line 1117 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp83_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 7145 "FacebookPublishing.c"
	}
#line 1052 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_free0 (label_text);
#line 1052 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return self;
#line 7151 "FacebookPublishing.c"
}


PublishingFacebookPublishingOptionsPane* publishing_facebook_publishing_options_pane_new (const gchar* username, PublishingFacebookAlbum** albums, int albums_length1, SpitPublishingPublisherMediaType media_type, PublishingFacebookFacebookPublisher* publisher, GtkBuilder* builder, gboolean strip_metadata) {
#line 1052 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return publishing_facebook_publishing_options_pane_construct (PUBLISHING_FACEBOOK_TYPE_PUBLISHING_OPTIONS_PANE, username, albums, albums_length1, media_type, publisher, builder, strip_metadata);
#line 7158 "FacebookPublishing.c"
}


static gboolean publishing_facebook_publishing_options_pane_publishing_photos (PublishingFacebookPublishingOptionsPane* self) {
	gboolean result = FALSE;
	SpitPublishingPublisherMediaType _tmp0_ = 0;
#line 1121 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_val_if_fail (PUBLISHING_FACEBOOK_IS_PUBLISHING_OPTIONS_PANE (self), FALSE);
#line 1122 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = self->priv->media_type;
#line 1122 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	result = (_tmp0_ & SPIT_PUBLISHING_PUBLISHER_MEDIA_TYPE_PHOTO) != 0;
#line 1122 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return result;
#line 7173 "FacebookPublishing.c"
}


static gpointer _publishing_facebook_publishing_options_pane_privacy_description_ref0 (gpointer self) {
#line 1126 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return self ? publishing_facebook_publishing_options_pane_privacy_description_ref (self) : NULL;
#line 7180 "FacebookPublishing.c"
}


static void publishing_facebook_publishing_options_pane_setup_visibility_combo (PublishingFacebookPublishingOptionsPane* self) {
	PublishingFacebookPublishingOptionsPanePrivacyDescription** _tmp0_ = NULL;
	gint _tmp0__length1 = 0;
#line 1125 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_PUBLISHING_OPTIONS_PANE (self));
#line 1126 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = self->priv->privacy_descriptions;
#line 1126 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0__length1 = self->priv->privacy_descriptions_length1;
#line 7193 "FacebookPublishing.c"
	{
		PublishingFacebookPublishingOptionsPanePrivacyDescription** p_collection = NULL;
		gint p_collection_length1 = 0;
		gint _p_collection_size_ = 0;
		gint p_it = 0;
#line 1126 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		p_collection = _tmp0_;
#line 1126 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		p_collection_length1 = _tmp0__length1;
#line 1126 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		for (p_it = 0; p_it < _tmp0__length1; p_it = p_it + 1) {
#line 7205 "FacebookPublishing.c"
			PublishingFacebookPublishingOptionsPanePrivacyDescription* _tmp1_ = NULL;
			PublishingFacebookPublishingOptionsPanePrivacyDescription* p = NULL;
#line 1126 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			_tmp1_ = _publishing_facebook_publishing_options_pane_privacy_description_ref0 (p_collection[p_it]);
#line 1126 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			p = _tmp1_;
#line 7212 "FacebookPublishing.c"
			{
				GtkComboBoxText* _tmp2_ = NULL;
				PublishingFacebookPublishingOptionsPanePrivacyDescription* _tmp3_ = NULL;
				const gchar* _tmp4_ = NULL;
#line 1127 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				_tmp2_ = self->priv->visibility_combo;
#line 1127 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				_tmp3_ = p;
#line 1127 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				_tmp4_ = _tmp3_->description;
#line 1127 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				gtk_combo_box_text_append_text (_tmp2_, _tmp4_);
#line 1126 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				_publishing_facebook_publishing_options_pane_privacy_description_unref0 (p);
#line 7227 "FacebookPublishing.c"
			}
		}
	}
}


static void publishing_facebook_publishing_options_pane_setup_resolution_combo (PublishingFacebookPublishingOptionsPane* self) {
	PublishingFacebookResolution* _tmp0_ = NULL;
	gint _tmp0__length1 = 0;
#line 1130 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_PUBLISHING_OPTIONS_PANE (self));
#line 1131 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = self->priv->possible_resolutions;
#line 1131 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0__length1 = self->priv->possible_resolutions_length1;
#line 7243 "FacebookPublishing.c"
	{
		PublishingFacebookResolution* res_collection = NULL;
		gint res_collection_length1 = 0;
		gint _res_collection_size_ = 0;
		gint res_it = 0;
#line 1131 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		res_collection = _tmp0_;
#line 1131 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		res_collection_length1 = _tmp0__length1;
#line 1131 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		for (res_it = 0; res_it < _tmp0__length1; res_it = res_it + 1) {
#line 7255 "FacebookPublishing.c"
			PublishingFacebookResolution res = 0;
#line 1131 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			res = res_collection[res_it];
#line 7259 "FacebookPublishing.c"
			{
				GtkComboBoxText* _tmp1_ = NULL;
				PublishingFacebookResolution _tmp2_ = 0;
				gchar* _tmp3_ = NULL;
				gchar* _tmp4_ = NULL;
#line 1132 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				_tmp1_ = self->priv->resolution_combo;
#line 1132 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				_tmp2_ = res;
#line 1132 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				_tmp3_ = publishing_facebook_resolution_get_name (_tmp2_);
#line 1132 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				_tmp4_ = _tmp3_;
#line 1132 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				gtk_combo_box_text_append_text (_tmp1_, _tmp4_);
#line 1132 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				_g_free0 (_tmp4_);
#line 7277 "FacebookPublishing.c"
			}
		}
	}
}


static void publishing_facebook_publishing_options_pane_on_use_existing_toggled (PublishingFacebookPublishingOptionsPane* self) {
	GtkRadioButton* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_ = FALSE;
#line 1135 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_PUBLISHING_OPTIONS_PANE (self));
#line 1136 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = self->priv->use_existing_radio;
#line 1136 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp1_ = gtk_toggle_button_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_toggle_button_get_type (), GtkToggleButton));
#line 1136 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp2_ = _tmp1_;
#line 1136 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (_tmp2_) {
#line 7298 "FacebookPublishing.c"
		GtkComboBoxText* _tmp3_ = NULL;
		GtkEntry* _tmp4_ = NULL;
		GtkComboBoxText* _tmp5_ = NULL;
		SpitPublishingPublisherMediaType _tmp6_ = 0;
		GtkComboBoxText* _tmp7_ = NULL;
#line 1137 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp3_ = self->priv->existing_albums_combo;
#line 1137 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, gtk_widget_get_type (), GtkWidget), TRUE);
#line 1138 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp4_ = self->priv->new_album_entry;
#line 1138 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 1143 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp5_ = self->priv->visibility_combo;
#line 1143 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp6_ = self->priv->media_type;
#line 1143 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, gtk_widget_get_type (), GtkWidget), (_tmp6_ & SPIT_PUBLISHING_PUBLISHER_MEDIA_TYPE_VIDEO) != 0);
#line 1145 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp7_ = self->priv->existing_albums_combo;
#line 1145 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		gtk_widget_grab_focus (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, gtk_widget_get_type (), GtkWidget));
#line 7322 "FacebookPublishing.c"
	}
}


static void publishing_facebook_publishing_options_pane_on_create_new_toggled (PublishingFacebookPublishingOptionsPane* self) {
	GtkRadioButton* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_ = FALSE;
#line 1149 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_PUBLISHING_OPTIONS_PANE (self));
#line 1150 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = self->priv->create_new_radio;
#line 1150 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp1_ = gtk_toggle_button_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_toggle_button_get_type (), GtkToggleButton));
#line 1150 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp2_ = _tmp1_;
#line 1150 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (_tmp2_) {
#line 7341 "FacebookPublishing.c"
		GtkComboBoxText* _tmp3_ = NULL;
		GtkEntry* _tmp4_ = NULL;
		GtkEntry* _tmp5_ = NULL;
		GtkComboBoxText* _tmp6_ = NULL;
#line 1151 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp3_ = self->priv->existing_albums_combo;
#line 1151 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 1152 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp4_ = self->priv->new_album_entry;
#line 1152 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, gtk_widget_get_type (), GtkWidget), TRUE);
#line 1153 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp5_ = self->priv->new_album_entry;
#line 1153 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		gtk_widget_grab_focus (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, gtk_widget_get_type (), GtkWidget));
#line 1157 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp6_ = self->priv->visibility_combo;
#line 1157 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, gtk_widget_get_type (), GtkWidget), TRUE);
#line 7362 "FacebookPublishing.c"
	}
}


static void publishing_facebook_publishing_options_pane_on_size_changed (PublishingFacebookPublishingOptionsPane* self) {
	PublishingFacebookFacebookPublisher* _tmp0_ = NULL;
	GtkComboBoxText* _tmp1_ = NULL;
	gint _tmp2_ = 0;
#line 1161 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_PUBLISHING_OPTIONS_PANE (self));
#line 1162 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = self->priv->publisher;
#line 1162 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp1_ = self->priv->resolution_combo;
#line 1162 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp2_ = gtk_combo_box_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, gtk_combo_box_get_type (), GtkComboBox));
#line 1162 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_facebook_publisher_set_persistent_default_size (_tmp0_, _tmp2_);
#line 7381 "FacebookPublishing.c"
}


static void publishing_facebook_publishing_options_pane_on_logout_button_clicked (PublishingFacebookPublishingOptionsPane* self) {
#line 1165 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_PUBLISHING_OPTIONS_PANE (self));
#line 1166 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_emit_by_name (self, "logout");
#line 7390 "FacebookPublishing.c"
}


static void publishing_facebook_publishing_options_pane_on_publish_button_clicked (PublishingFacebookPublishingOptionsPane* self) {
	gchar* album_name = NULL;
	gchar* privacy_setting = NULL;
	PublishingFacebookPublishingOptionsPanePrivacyDescription** _tmp0_ = NULL;
	gint _tmp0__length1 = 0;
	GtkComboBoxText* _tmp1_ = NULL;
	gint _tmp2_ = 0;
	PublishingFacebookPublishingOptionsPanePrivacyDescription* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	PublishingFacebookResolution resolution_setting = 0;
	gboolean _tmp6_ = FALSE;
	const gchar* _tmp19_ = NULL;
	const gchar* _tmp20_ = NULL;
	PublishingFacebookResolution _tmp21_ = 0;
	GtkCheckButton* _tmp22_ = NULL;
	gboolean _tmp23_ = FALSE;
#line 1169 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_PUBLISHING_OPTIONS_PANE (self));
#line 1171 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = self->priv->privacy_descriptions;
#line 1171 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0__length1 = self->priv->privacy_descriptions_length1;
#line 1171 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp1_ = self->priv->visibility_combo;
#line 1171 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp2_ = gtk_combo_box_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, gtk_combo_box_get_type (), GtkComboBox));
#line 1171 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp3_ = _tmp0_[_tmp2_];
#line 1171 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp4_ = _tmp3_->privacy_setting;
#line 1171 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp5_ = g_strdup (_tmp4_);
#line 1171 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	privacy_setting = _tmp5_;
#line 1175 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp6_ = publishing_facebook_publishing_options_pane_publishing_photos (self);
#line 1175 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (_tmp6_) {
#line 7433 "FacebookPublishing.c"
		PublishingFacebookResolution* _tmp7_ = NULL;
		gint _tmp7__length1 = 0;
		GtkComboBoxText* _tmp8_ = NULL;
		gint _tmp9_ = 0;
		PublishingFacebookResolution _tmp10_ = 0;
		GtkRadioButton* _tmp11_ = NULL;
		gboolean _tmp12_ = FALSE;
		gboolean _tmp13_ = FALSE;
#line 1176 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp7_ = self->priv->possible_resolutions;
#line 1176 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp7__length1 = self->priv->possible_resolutions_length1;
#line 1176 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp8_ = self->priv->resolution_combo;
#line 1176 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp9_ = gtk_combo_box_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, gtk_combo_box_get_type (), GtkComboBox));
#line 1176 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp10_ = _tmp7_[_tmp9_];
#line 1176 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		resolution_setting = _tmp10_;
#line 1177 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp11_ = self->priv->use_existing_radio;
#line 1177 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp12_ = gtk_toggle_button_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp11_, gtk_toggle_button_get_type (), GtkToggleButton));
#line 1177 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp13_ = _tmp12_;
#line 1177 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		if (_tmp13_) {
#line 7462 "FacebookPublishing.c"
			GtkComboBoxText* _tmp14_ = NULL;
			gchar* _tmp15_ = NULL;
#line 1178 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			_tmp14_ = self->priv->existing_albums_combo;
#line 1178 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			_tmp15_ = gtk_combo_box_text_get_active_text (_tmp14_);
#line 1178 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			_g_free0 (album_name);
#line 1178 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			album_name = _tmp15_;
#line 7473 "FacebookPublishing.c"
		} else {
			GtkEntry* _tmp16_ = NULL;
			const gchar* _tmp17_ = NULL;
			gchar* _tmp18_ = NULL;
#line 1180 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			_tmp16_ = self->priv->new_album_entry;
#line 1180 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			_tmp17_ = gtk_entry_get_text (_tmp16_);
#line 1180 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			_tmp18_ = g_strdup (_tmp17_);
#line 1180 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			_g_free0 (album_name);
#line 1180 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			album_name = _tmp18_;
#line 7488 "FacebookPublishing.c"
		}
	} else {
#line 1183 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		resolution_setting = PUBLISHING_FACEBOOK_RESOLUTION_STANDARD;
#line 1184 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_g_free0 (album_name);
#line 1184 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		album_name = NULL;
#line 7497 "FacebookPublishing.c"
	}
#line 1187 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp19_ = album_name;
#line 1187 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp20_ = privacy_setting;
#line 1187 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp21_ = resolution_setting;
#line 1187 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp22_ = self->priv->strip_metadata_check;
#line 1187 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp23_ = gtk_toggle_button_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp22_, gtk_toggle_button_get_type (), GtkToggleButton));
#line 1187 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_emit_by_name (self, "publish", _tmp19_, _tmp20_, _tmp21_, _tmp23_);
#line 1169 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_free0 (privacy_setting);
#line 1169 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_free0 (album_name);
#line 7515 "FacebookPublishing.c"
}


static void _vala_array_add7 (PublishingFacebookPublishingOptionsPanePrivacyDescription*** array, int* length, int* size, PublishingFacebookPublishingOptionsPanePrivacyDescription* value) {
#line 1193 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if ((*length) == (*size)) {
#line 1193 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 1193 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		*array = g_renew (PublishingFacebookPublishingOptionsPanePrivacyDescription*, *array, (*size) + 1);
#line 7526 "FacebookPublishing.c"
	}
#line 1193 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	(*array)[(*length)++] = value;
#line 1193 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	(*array)[*length] = NULL;
#line 7532 "FacebookPublishing.c"
}


static void _vala_array_add8 (PublishingFacebookPublishingOptionsPanePrivacyDescription*** array, int* length, int* size, PublishingFacebookPublishingOptionsPanePrivacyDescription* value) {
#line 1194 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if ((*length) == (*size)) {
#line 1194 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 1194 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		*array = g_renew (PublishingFacebookPublishingOptionsPanePrivacyDescription*, *array, (*size) + 1);
#line 7543 "FacebookPublishing.c"
	}
#line 1194 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	(*array)[(*length)++] = value;
#line 1194 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	(*array)[*length] = NULL;
#line 7549 "FacebookPublishing.c"
}


static void _vala_array_add9 (PublishingFacebookPublishingOptionsPanePrivacyDescription*** array, int* length, int* size, PublishingFacebookPublishingOptionsPanePrivacyDescription* value) {
#line 1195 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if ((*length) == (*size)) {
#line 1195 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 1195 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		*array = g_renew (PublishingFacebookPublishingOptionsPanePrivacyDescription*, *array, (*size) + 1);
#line 7560 "FacebookPublishing.c"
	}
#line 1195 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	(*array)[(*length)++] = value;
#line 1195 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	(*array)[*length] = NULL;
#line 7566 "FacebookPublishing.c"
}


static PublishingFacebookPublishingOptionsPanePrivacyDescription** publishing_facebook_publishing_options_pane_create_privacy_descriptions (PublishingFacebookPublishingOptionsPane* self, int* result_length1) {
	PublishingFacebookPublishingOptionsPanePrivacyDescription** result = NULL;
	PublishingFacebookPublishingOptionsPanePrivacyDescription** _result_ = NULL;
	PublishingFacebookPublishingOptionsPanePrivacyDescription** _tmp0_ = NULL;
	gint _result__length1 = 0;
	gint __result__size_ = 0;
	PublishingFacebookPublishingOptionsPanePrivacyDescription** _tmp1_ = NULL;
	gint _tmp1__length1 = 0;
	const gchar* _tmp2_ = NULL;
	PublishingFacebookPublishingOptionsPanePrivacyDescription* _tmp3_ = NULL;
	PublishingFacebookPublishingOptionsPanePrivacyDescription** _tmp4_ = NULL;
	gint _tmp4__length1 = 0;
	const gchar* _tmp5_ = NULL;
	PublishingFacebookPublishingOptionsPanePrivacyDescription* _tmp6_ = NULL;
	PublishingFacebookPublishingOptionsPanePrivacyDescription** _tmp7_ = NULL;
	gint _tmp7__length1 = 0;
	const gchar* _tmp8_ = NULL;
	PublishingFacebookPublishingOptionsPanePrivacyDescription* _tmp9_ = NULL;
	PublishingFacebookPublishingOptionsPanePrivacyDescription** _tmp10_ = NULL;
	gint _tmp10__length1 = 0;
#line 1190 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_val_if_fail (PUBLISHING_FACEBOOK_IS_PUBLISHING_OPTIONS_PANE (self), NULL);
#line 1191 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = g_new0 (PublishingFacebookPublishingOptionsPanePrivacyDescription*, 0 + 1);
#line 1191 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_result_ = _tmp0_;
#line 1191 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_result__length1 = 0;
#line 1191 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	__result__size_ = _result__length1;
#line 1193 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp1_ = _result_;
#line 1193 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp1__length1 = _result__length1;
#line 1193 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp2_ = _ ("Just me");
#line 1193 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp3_ = publishing_facebook_publishing_options_pane_privacy_description_new (_tmp2_, "{ 'value' : 'SELF' }");
#line 1193 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_vala_array_add7 (&_result_, &_result__length1, &__result__size_, _tmp3_);
#line 1194 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp4_ = _result_;
#line 1194 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp4__length1 = _result__length1;
#line 1194 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp5_ = _ ("Friends");
#line 1194 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp6_ = publishing_facebook_publishing_options_pane_privacy_description_new (_tmp5_, "{ 'value' : 'ALL_FRIENDS' }");
#line 1194 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_vala_array_add8 (&_result_, &_result__length1, &__result__size_, _tmp6_);
#line 1195 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp7_ = _result_;
#line 1195 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp7__length1 = _result__length1;
#line 1195 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp8_ = _ ("Everyone");
#line 1195 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp9_ = publishing_facebook_publishing_options_pane_privacy_description_new (_tmp8_, "{ 'value' : 'EVERYONE' }");
#line 1195 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_vala_array_add9 (&_result_, &_result__length1, &__result__size_, _tmp9_);
#line 1197 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp10_ = _result_;
#line 1197 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp10__length1 = _result__length1;
#line 1197 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (result_length1) {
#line 1197 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		*result_length1 = _tmp10__length1;
#line 7638 "FacebookPublishing.c"
	}
#line 1197 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	result = _tmp10_;
#line 1197 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return result;
#line 7644 "FacebookPublishing.c"
}


static void _vala_array_add10 (PublishingFacebookResolution** array, int* length, int* size, PublishingFacebookResolution value) {
#line 1203 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if ((*length) == (*size)) {
#line 1203 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 1203 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		*array = g_renew (PublishingFacebookResolution, *array, *size);
#line 7655 "FacebookPublishing.c"
	}
#line 1203 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	(*array)[(*length)++] = value;
#line 7659 "FacebookPublishing.c"
}


static void _vala_array_add11 (PublishingFacebookResolution** array, int* length, int* size, PublishingFacebookResolution value) {
#line 1204 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if ((*length) == (*size)) {
#line 1204 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 1204 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		*array = g_renew (PublishingFacebookResolution, *array, *size);
#line 7670 "FacebookPublishing.c"
	}
#line 1204 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	(*array)[(*length)++] = value;
#line 7674 "FacebookPublishing.c"
}


static PublishingFacebookResolution* publishing_facebook_publishing_options_pane_create_resolution_list (PublishingFacebookPublishingOptionsPane* self, int* result_length1) {
	PublishingFacebookResolution* result = NULL;
	PublishingFacebookResolution* _result_ = NULL;
	PublishingFacebookResolution* _tmp0_ = NULL;
	gint _result__length1 = 0;
	gint __result__size_ = 0;
	PublishingFacebookResolution* _tmp1_ = NULL;
	gint _tmp1__length1 = 0;
	PublishingFacebookResolution* _tmp2_ = NULL;
	gint _tmp2__length1 = 0;
	PublishingFacebookResolution* _tmp3_ = NULL;
	gint _tmp3__length1 = 0;
#line 1200 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_val_if_fail (PUBLISHING_FACEBOOK_IS_PUBLISHING_OPTIONS_PANE (self), NULL);
#line 1201 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = g_new0 (PublishingFacebookResolution, 0);
#line 1201 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_result_ = _tmp0_;
#line 1201 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_result__length1 = 0;
#line 1201 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	__result__size_ = _result__length1;
#line 1203 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp1_ = _result_;
#line 1203 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp1__length1 = _result__length1;
#line 1203 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_vala_array_add10 (&_result_, &_result__length1, &__result__size_, PUBLISHING_FACEBOOK_RESOLUTION_STANDARD);
#line 1204 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp2_ = _result_;
#line 1204 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp2__length1 = _result__length1;
#line 1204 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_vala_array_add11 (&_result_, &_result__length1, &__result__size_, PUBLISHING_FACEBOOK_RESOLUTION_HIGH);
#line 1206 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp3_ = _result_;
#line 1206 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp3__length1 = _result__length1;
#line 1206 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (result_length1) {
#line 1206 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		*result_length1 = _tmp3__length1;
#line 7720 "FacebookPublishing.c"
	}
#line 1206 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	result = _tmp3_;
#line 1206 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return result;
#line 7726 "FacebookPublishing.c"
}


void publishing_facebook_publishing_options_pane_installed (PublishingFacebookPublishingOptionsPane* self) {
	gboolean _tmp0_ = FALSE;
	GtkButton* _tmp24_ = NULL;
#line 1209 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_PUBLISHING_OPTIONS_PANE (self));
#line 1210 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = publishing_facebook_publishing_options_pane_publishing_photos (self);
#line 1210 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (_tmp0_) {
#line 7739 "FacebookPublishing.c"
		PublishingFacebookAlbum** _tmp1_ = NULL;
		gint _tmp1__length1 = 0;
#line 1211 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp1_ = self->priv->albums;
#line 1211 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp1__length1 = self->priv->albums_length1;
#line 1211 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		if (_tmp1__length1 == 0) {
#line 7748 "FacebookPublishing.c"
			GtkRadioButton* _tmp2_ = NULL;
			GtkEntry* _tmp3_ = NULL;
			GtkComboBoxText* _tmp4_ = NULL;
			GtkRadioButton* _tmp5_ = NULL;
#line 1212 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			_tmp2_ = self->priv->create_new_radio;
#line 1212 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			gtk_toggle_button_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, gtk_toggle_button_get_type (), GtkToggleButton), TRUE);
#line 1213 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			_tmp3_ = self->priv->new_album_entry;
#line 1213 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			gtk_entry_set_text (_tmp3_, PUBLISHING_FACEBOOK_DEFAULT_ALBUM_NAME);
#line 1214 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			_tmp4_ = self->priv->existing_albums_combo;
#line 1214 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 1215 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			_tmp5_ = self->priv->use_existing_radio;
#line 1215 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 7769 "FacebookPublishing.c"
		} else {
			gint default_album_seq_num = 0;
			gint ticker = 0;
			PublishingFacebookAlbum** _tmp6_ = NULL;
			gint _tmp6__length1 = 0;
			gint _tmp15_ = 0;
#line 1217 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			default_album_seq_num = -1;
#line 1218 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			ticker = 0;
#line 1219 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			_tmp6_ = self->priv->albums;
#line 1219 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			_tmp6__length1 = self->priv->albums_length1;
#line 7784 "FacebookPublishing.c"
			{
				PublishingFacebookAlbum** album_collection = NULL;
				gint album_collection_length1 = 0;
				gint _album_collection_size_ = 0;
				gint album_it = 0;
#line 1219 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				album_collection = _tmp6_;
#line 1219 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				album_collection_length1 = _tmp6__length1;
#line 1219 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				for (album_it = 0; album_it < _tmp6__length1; album_it = album_it + 1) {
#line 7796 "FacebookPublishing.c"
					PublishingFacebookAlbum* _tmp7_ = NULL;
					PublishingFacebookAlbum* album = NULL;
#line 1219 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
					_tmp7_ = _publishing_facebook_album_ref0 (album_collection[album_it]);
#line 1219 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
					album = _tmp7_;
#line 7803 "FacebookPublishing.c"
					{
						GtkComboBoxText* _tmp8_ = NULL;
						PublishingFacebookAlbum* _tmp9_ = NULL;
						const gchar* _tmp10_ = NULL;
						PublishingFacebookAlbum* _tmp11_ = NULL;
						const gchar* _tmp12_ = NULL;
						gint _tmp14_ = 0;
#line 1220 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
						_tmp8_ = self->priv->existing_albums_combo;
#line 1220 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
						_tmp9_ = album;
#line 1220 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
						_tmp10_ = _tmp9_->name;
#line 1220 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
						gtk_combo_box_text_append_text (_tmp8_, _tmp10_);
#line 1221 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
						_tmp11_ = album;
#line 1221 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
						_tmp12_ = _tmp11_->name;
#line 1221 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
						if (g_strcmp0 (_tmp12_, PUBLISHING_FACEBOOK_DEFAULT_ALBUM_NAME) == 0) {
#line 7825 "FacebookPublishing.c"
							gint _tmp13_ = 0;
#line 1222 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
							_tmp13_ = ticker;
#line 1222 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
							default_album_seq_num = _tmp13_;
#line 7831 "FacebookPublishing.c"
						}
#line 1223 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
						_tmp14_ = ticker;
#line 1223 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
						ticker = _tmp14_ + 1;
#line 1219 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
						_publishing_facebook_album_unref0 (album);
#line 7839 "FacebookPublishing.c"
					}
				}
			}
#line 1225 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			_tmp15_ = default_album_seq_num;
#line 1225 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			if (_tmp15_ != -1) {
#line 7847 "FacebookPublishing.c"
				GtkComboBoxText* _tmp16_ = NULL;
				gint _tmp17_ = 0;
				GtkRadioButton* _tmp18_ = NULL;
				GtkEntry* _tmp19_ = NULL;
#line 1226 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				_tmp16_ = self->priv->existing_albums_combo;
#line 1226 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				_tmp17_ = default_album_seq_num;
#line 1226 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				gtk_combo_box_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp16_, gtk_combo_box_get_type (), GtkComboBox), _tmp17_);
#line 1227 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				_tmp18_ = self->priv->use_existing_radio;
#line 1227 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				gtk_toggle_button_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp18_, gtk_toggle_button_get_type (), GtkToggleButton), TRUE);
#line 1228 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				_tmp19_ = self->priv->new_album_entry;
#line 1228 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp19_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 7866 "FacebookPublishing.c"
			} else {
				GtkRadioButton* _tmp20_ = NULL;
				GtkComboBoxText* _tmp21_ = NULL;
				GtkComboBoxText* _tmp22_ = NULL;
				GtkEntry* _tmp23_ = NULL;
#line 1231 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				_tmp20_ = self->priv->create_new_radio;
#line 1231 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				gtk_toggle_button_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp20_, gtk_toggle_button_get_type (), GtkToggleButton), TRUE);
#line 1232 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				_tmp21_ = self->priv->existing_albums_combo;
#line 1232 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				gtk_combo_box_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp21_, gtk_combo_box_get_type (), GtkComboBox), 0);
#line 1233 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				_tmp22_ = self->priv->existing_albums_combo;
#line 1233 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp22_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 1234 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				_tmp23_ = self->priv->new_album_entry;
#line 1234 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				gtk_entry_set_text (_tmp23_, PUBLISHING_FACEBOOK_DEFAULT_ALBUM_NAME);
#line 7888 "FacebookPublishing.c"
			}
		}
	}
#line 1239 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp24_ = self->priv->publish_button;
#line 1239 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	gtk_widget_grab_focus (G_TYPE_CHECK_INSTANCE_CAST (_tmp24_, gtk_widget_get_type (), GtkWidget));
#line 7896 "FacebookPublishing.c"
}


static void publishing_facebook_publishing_options_pane_notify_logout (PublishingFacebookPublishingOptionsPane* self) {
#line 1242 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_PUBLISHING_OPTIONS_PANE (self));
#line 1243 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_emit_by_name (self, "logout");
#line 7905 "FacebookPublishing.c"
}


static void publishing_facebook_publishing_options_pane_notify_publish (PublishingFacebookPublishingOptionsPane* self, const gchar* target_album, const gchar* privacy_setting, PublishingFacebookResolution target_resolution) {
	const gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	PublishingFacebookResolution _tmp2_ = 0;
	GtkCheckButton* _tmp3_ = NULL;
	gboolean _tmp4_ = FALSE;
#line 1246 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_PUBLISHING_OPTIONS_PANE (self));
#line 1246 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (privacy_setting != NULL);
#line 1247 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = target_album;
#line 1247 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp1_ = privacy_setting;
#line 1247 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp2_ = target_resolution;
#line 1247 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp3_ = self->priv->strip_metadata_check;
#line 1247 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp4_ = gtk_toggle_button_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, gtk_toggle_button_get_type (), GtkToggleButton));
#line 1247 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_emit_by_name (self, "publish", _tmp0_, _tmp1_, _tmp2_, _tmp4_);
#line 7931 "FacebookPublishing.c"
}


static GtkWidget* publishing_facebook_publishing_options_pane_real_get_widget (SpitPublishingDialogPane* base) {
	PublishingFacebookPublishingOptionsPane * self;
	GtkWidget* result = NULL;
	GtkBox* _tmp0_ = NULL;
	GtkWidget* _tmp1_ = NULL;
#line 1250 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_FACEBOOK_TYPE_PUBLISHING_OPTIONS_PANE, PublishingFacebookPublishingOptionsPane);
#line 1251 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = self->priv->pane_widget;
#line 1251 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_widget_get_type (), GtkWidget));
#line 1251 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	result = _tmp1_;
#line 1251 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return result;
#line 7950 "FacebookPublishing.c"
}


static SpitPublishingDialogPaneGeometryOptions publishing_facebook_publishing_options_pane_real_get_preferred_geometry (SpitPublishingDialogPane* base) {
	PublishingFacebookPublishingOptionsPane * self;
	SpitPublishingDialogPaneGeometryOptions result = 0;
#line 1254 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_FACEBOOK_TYPE_PUBLISHING_OPTIONS_PANE, PublishingFacebookPublishingOptionsPane);
#line 1255 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	result = SPIT_PUBLISHING_DIALOG_PANE_GEOMETRY_OPTIONS_NONE;
#line 1255 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return result;
#line 7963 "FacebookPublishing.c"
}


static void _publishing_facebook_publishing_options_pane_notify_logout_publishing_facebook_publishing_options_pane_logout (PublishingFacebookPublishingOptionsPane* _sender, gpointer self) {
#line 1259 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_publishing_options_pane_notify_logout ((PublishingFacebookPublishingOptionsPane*) self);
#line 7970 "FacebookPublishing.c"
}


static void _publishing_facebook_publishing_options_pane_notify_publish_publishing_facebook_publishing_options_pane_publish (PublishingFacebookPublishingOptionsPane* _sender, const gchar* target_album, const gchar* privacy_setting, PublishingFacebookResolution target_resolution, gboolean strip_metadata, gpointer self) {
#line 1260 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_publishing_options_pane_notify_publish ((PublishingFacebookPublishingOptionsPane*) self, target_album, privacy_setting, target_resolution);
#line 7977 "FacebookPublishing.c"
}


static void publishing_facebook_publishing_options_pane_real_on_pane_installed (SpitPublishingDialogPane* base) {
	PublishingFacebookPublishingOptionsPane * self;
#line 1258 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_FACEBOOK_TYPE_PUBLISHING_OPTIONS_PANE, PublishingFacebookPublishingOptionsPane);
#line 1259 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_connect_object (self, "logout", (GCallback) _publishing_facebook_publishing_options_pane_notify_logout_publishing_facebook_publishing_options_pane_logout, self, 0);
#line 1260 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_connect_object (self, "publish", (GCallback) _publishing_facebook_publishing_options_pane_notify_publish_publishing_facebook_publishing_options_pane_publish, self, 0);
#line 1262 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_publishing_options_pane_installed (self);
#line 7991 "FacebookPublishing.c"
}


static void publishing_facebook_publishing_options_pane_real_on_pane_uninstalled (SpitPublishingDialogPane* base) {
	PublishingFacebookPublishingOptionsPane * self;
	guint _tmp0_ = 0U;
	guint _tmp1_ = 0U;
#line 1265 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_FACEBOOK_TYPE_PUBLISHING_OPTIONS_PANE, PublishingFacebookPublishingOptionsPane);
#line 1266 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_parse_name ("logout", PUBLISHING_FACEBOOK_TYPE_PUBLISHING_OPTIONS_PANE, &_tmp0_, NULL, FALSE);
#line 1266 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_handlers_disconnect_matched (self, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp0_, 0, NULL, (GCallback) _publishing_facebook_publishing_options_pane_notify_logout_publishing_facebook_publishing_options_pane_logout, self);
#line 1267 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_parse_name ("publish", PUBLISHING_FACEBOOK_TYPE_PUBLISHING_OPTIONS_PANE, &_tmp1_, NULL, FALSE);
#line 1267 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_handlers_disconnect_matched (self, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_facebook_publishing_options_pane_notify_publish_publishing_facebook_publishing_options_pane_publish, self);
#line 8009 "FacebookPublishing.c"
}


static void g_cclosure_user_marshal_VOID__STRING_STRING_ENUM_BOOLEAN (GClosure * closure, GValue * return_value, guint n_param_values, const GValue * param_values, gpointer invocation_hint, gpointer marshal_data) {
	typedef void (*GMarshalFunc_VOID__STRING_STRING_ENUM_BOOLEAN) (gpointer data1, const char* arg_1, const char* arg_2, gint arg_3, gboolean arg_4, gpointer data2);
	register GMarshalFunc_VOID__STRING_STRING_ENUM_BOOLEAN callback;
	register GCClosure * cc;
	register gpointer data1;
	register gpointer data2;
	cc = (GCClosure *) closure;
#line 1011 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (n_param_values == 5);
#line 1011 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (G_CCLOSURE_SWAP_DATA (closure)) {
#line 1011 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		data1 = closure->data;
#line 1011 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		data2 = param_values->data[0].v_pointer;
#line 8028 "FacebookPublishing.c"
	} else {
#line 1011 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		data1 = param_values->data[0].v_pointer;
#line 1011 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		data2 = closure->data;
#line 8034 "FacebookPublishing.c"
	}
#line 1011 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	callback = (GMarshalFunc_VOID__STRING_STRING_ENUM_BOOLEAN) (marshal_data ? marshal_data : cc->callback);
#line 1011 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	callback (data1, g_value_get_string (param_values + 1), g_value_get_string (param_values + 2), g_value_get_enum (param_values + 3), g_value_get_boolean (param_values + 4), data2);
#line 8040 "FacebookPublishing.c"
}


static PublishingFacebookPublishingOptionsPanePrivacyDescription* publishing_facebook_publishing_options_pane_privacy_description_construct (GType object_type, const gchar* description, const gchar* privacy_setting) {
	PublishingFacebookPublishingOptionsPanePrivacyDescription* self = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
#line 1046 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_val_if_fail (description != NULL, NULL);
#line 1046 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_val_if_fail (privacy_setting != NULL, NULL);
#line 1046 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self = (PublishingFacebookPublishingOptionsPanePrivacyDescription*) g_type_create_instance (object_type);
#line 1047 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = description;
#line 1047 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 1047 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_free0 (self->description);
#line 1047 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->description = _tmp1_;
#line 1048 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp2_ = privacy_setting;
#line 1048 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp3_ = g_strdup (_tmp2_);
#line 1048 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_free0 (self->privacy_setting);
#line 1048 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->privacy_setting = _tmp3_;
#line 1046 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return self;
#line 8074 "FacebookPublishing.c"
}


static PublishingFacebookPublishingOptionsPanePrivacyDescription* publishing_facebook_publishing_options_pane_privacy_description_new (const gchar* description, const gchar* privacy_setting) {
#line 1046 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return publishing_facebook_publishing_options_pane_privacy_description_construct (PUBLISHING_FACEBOOK_PUBLISHING_OPTIONS_PANE_TYPE_PRIVACY_DESCRIPTION, description, privacy_setting);
#line 8081 "FacebookPublishing.c"
}


static void publishing_facebook_publishing_options_pane_value_privacy_description_init (GValue* value) {
#line 1042 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	value->data[0].v_pointer = NULL;
#line 8088 "FacebookPublishing.c"
}


static void publishing_facebook_publishing_options_pane_value_privacy_description_free_value (GValue* value) {
#line 1042 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (value->data[0].v_pointer) {
#line 1042 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		publishing_facebook_publishing_options_pane_privacy_description_unref (value->data[0].v_pointer);
#line 8097 "FacebookPublishing.c"
	}
}


static void publishing_facebook_publishing_options_pane_value_privacy_description_copy_value (const GValue* src_value, GValue* dest_value) {
#line 1042 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (src_value->data[0].v_pointer) {
#line 1042 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		dest_value->data[0].v_pointer = publishing_facebook_publishing_options_pane_privacy_description_ref (src_value->data[0].v_pointer);
#line 8107 "FacebookPublishing.c"
	} else {
#line 1042 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		dest_value->data[0].v_pointer = NULL;
#line 8111 "FacebookPublishing.c"
	}
}


static gpointer publishing_facebook_publishing_options_pane_value_privacy_description_peek_pointer (const GValue* value) {
#line 1042 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return value->data[0].v_pointer;
#line 8119 "FacebookPublishing.c"
}


static gchar* publishing_facebook_publishing_options_pane_value_privacy_description_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
#line 1042 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (collect_values[0].v_pointer) {
#line 8126 "FacebookPublishing.c"
		PublishingFacebookPublishingOptionsPanePrivacyDescription* object;
		object = collect_values[0].v_pointer;
#line 1042 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		if (object->parent_instance.g_class == NULL) {
#line 1042 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 8133 "FacebookPublishing.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 1042 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 8137 "FacebookPublishing.c"
		}
#line 1042 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		value->data[0].v_pointer = publishing_facebook_publishing_options_pane_privacy_description_ref (object);
#line 8141 "FacebookPublishing.c"
	} else {
#line 1042 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 8145 "FacebookPublishing.c"
	}
#line 1042 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return NULL;
#line 8149 "FacebookPublishing.c"
}


static gchar* publishing_facebook_publishing_options_pane_value_privacy_description_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	PublishingFacebookPublishingOptionsPanePrivacyDescription** object_p;
	object_p = collect_values[0].v_pointer;
#line 1042 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (!object_p) {
#line 1042 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 8160 "FacebookPublishing.c"
	}
#line 1042 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (!value->data[0].v_pointer) {
#line 1042 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		*object_p = NULL;
#line 8166 "FacebookPublishing.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 1042 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		*object_p = value->data[0].v_pointer;
#line 8170 "FacebookPublishing.c"
	} else {
#line 1042 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		*object_p = publishing_facebook_publishing_options_pane_privacy_description_ref (value->data[0].v_pointer);
#line 8174 "FacebookPublishing.c"
	}
#line 1042 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return NULL;
#line 8178 "FacebookPublishing.c"
}


static GParamSpec* publishing_facebook_publishing_options_pane_param_spec_privacy_description (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
	PublishingFacebookPublishingOptionsPaneParamSpecPrivacyDescription* spec;
#line 1042 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_val_if_fail (g_type_is_a (object_type, PUBLISHING_FACEBOOK_PUBLISHING_OPTIONS_PANE_TYPE_PRIVACY_DESCRIPTION), NULL);
#line 1042 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 1042 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 1042 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return G_PARAM_SPEC (spec);
#line 8192 "FacebookPublishing.c"
}


static gpointer publishing_facebook_publishing_options_pane_value_get_privacy_description (const GValue* value) {
#line 1042 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_FACEBOOK_PUBLISHING_OPTIONS_PANE_TYPE_PRIVACY_DESCRIPTION), NULL);
#line 1042 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return value->data[0].v_pointer;
#line 8201 "FacebookPublishing.c"
}


static void publishing_facebook_publishing_options_pane_value_set_privacy_description (GValue* value, gpointer v_object) {
	PublishingFacebookPublishingOptionsPanePrivacyDescription* old;
#line 1042 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_FACEBOOK_PUBLISHING_OPTIONS_PANE_TYPE_PRIVACY_DESCRIPTION));
#line 1042 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	old = value->data[0].v_pointer;
#line 1042 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (v_object) {
#line 1042 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PUBLISHING_FACEBOOK_PUBLISHING_OPTIONS_PANE_TYPE_PRIVACY_DESCRIPTION));
#line 1042 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 1042 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		value->data[0].v_pointer = v_object;
#line 1042 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		publishing_facebook_publishing_options_pane_privacy_description_ref (value->data[0].v_pointer);
#line 8221 "FacebookPublishing.c"
	} else {
#line 1042 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 8225 "FacebookPublishing.c"
	}
#line 1042 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (old) {
#line 1042 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		publishing_facebook_publishing_options_pane_privacy_description_unref (old);
#line 8231 "FacebookPublishing.c"
	}
}


static void publishing_facebook_publishing_options_pane_value_take_privacy_description (GValue* value, gpointer v_object) {
	PublishingFacebookPublishingOptionsPanePrivacyDescription* old;
#line 1042 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_FACEBOOK_PUBLISHING_OPTIONS_PANE_TYPE_PRIVACY_DESCRIPTION));
#line 1042 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	old = value->data[0].v_pointer;
#line 1042 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (v_object) {
#line 1042 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PUBLISHING_FACEBOOK_PUBLISHING_OPTIONS_PANE_TYPE_PRIVACY_DESCRIPTION));
#line 1042 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 1042 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		value->data[0].v_pointer = v_object;
#line 8250 "FacebookPublishing.c"
	} else {
#line 1042 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 8254 "FacebookPublishing.c"
	}
#line 1042 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (old) {
#line 1042 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		publishing_facebook_publishing_options_pane_privacy_description_unref (old);
#line 8260 "FacebookPublishing.c"
	}
}


static void publishing_facebook_publishing_options_pane_privacy_description_class_init (PublishingFacebookPublishingOptionsPanePrivacyDescriptionClass * klass) {
#line 1042 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_publishing_options_pane_privacy_description_parent_class = g_type_class_peek_parent (klass);
#line 1042 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	((PublishingFacebookPublishingOptionsPanePrivacyDescriptionClass *) klass)->finalize = publishing_facebook_publishing_options_pane_privacy_description_finalize;
#line 8270 "FacebookPublishing.c"
}


static void publishing_facebook_publishing_options_pane_privacy_description_instance_init (PublishingFacebookPublishingOptionsPanePrivacyDescription * self) {
#line 1042 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->ref_count = 1;
#line 8277 "FacebookPublishing.c"
}


static void publishing_facebook_publishing_options_pane_privacy_description_finalize (PublishingFacebookPublishingOptionsPanePrivacyDescription* obj) {
	PublishingFacebookPublishingOptionsPanePrivacyDescription * self;
#line 1042 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_FACEBOOK_PUBLISHING_OPTIONS_PANE_TYPE_PRIVACY_DESCRIPTION, PublishingFacebookPublishingOptionsPanePrivacyDescription);
#line 1042 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_handlers_destroy (self);
#line 1043 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_free0 (self->description);
#line 1044 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_free0 (self->privacy_setting);
#line 8291 "FacebookPublishing.c"
}


static GType publishing_facebook_publishing_options_pane_privacy_description_get_type (void) {
	static volatile gsize publishing_facebook_publishing_options_pane_privacy_description_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_facebook_publishing_options_pane_privacy_description_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { publishing_facebook_publishing_options_pane_value_privacy_description_init, publishing_facebook_publishing_options_pane_value_privacy_description_free_value, publishing_facebook_publishing_options_pane_value_privacy_description_copy_value, publishing_facebook_publishing_options_pane_value_privacy_description_peek_pointer, "p", publishing_facebook_publishing_options_pane_value_privacy_description_collect_value, "p", publishing_facebook_publishing_options_pane_value_privacy_description_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (PublishingFacebookPublishingOptionsPanePrivacyDescriptionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_facebook_publishing_options_pane_privacy_description_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingFacebookPublishingOptionsPanePrivacyDescription), 0, (GInstanceInitFunc) publishing_facebook_publishing_options_pane_privacy_description_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType publishing_facebook_publishing_options_pane_privacy_description_type_id;
		publishing_facebook_publishing_options_pane_privacy_description_type_id = g_type_register_fundamental (g_type_fundamental_next (), "PublishingFacebookPublishingOptionsPanePrivacyDescription", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&publishing_facebook_publishing_options_pane_privacy_description_type_id__volatile, publishing_facebook_publishing_options_pane_privacy_description_type_id);
	}
	return publishing_facebook_publishing_options_pane_privacy_description_type_id__volatile;
}


static gpointer publishing_facebook_publishing_options_pane_privacy_description_ref (gpointer instance) {
	PublishingFacebookPublishingOptionsPanePrivacyDescription* self;
	self = instance;
#line 1042 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_atomic_int_inc (&self->ref_count);
#line 1042 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return instance;
#line 8316 "FacebookPublishing.c"
}


static void publishing_facebook_publishing_options_pane_privacy_description_unref (gpointer instance) {
	PublishingFacebookPublishingOptionsPanePrivacyDescription* self;
	self = instance;
#line 1042 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 1042 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		PUBLISHING_FACEBOOK_PUBLISHING_OPTIONS_PANE_PRIVACY_DESCRIPTION_GET_CLASS (self)->finalize (self);
#line 1042 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 8329 "FacebookPublishing.c"
	}
}


static void publishing_facebook_publishing_options_pane_class_init (PublishingFacebookPublishingOptionsPaneClass * klass) {
#line 1011 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_publishing_options_pane_parent_class = g_type_class_peek_parent (klass);
#line 1011 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_type_class_add_private (klass, sizeof (PublishingFacebookPublishingOptionsPanePrivate));
#line 1011 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	G_OBJECT_CLASS (klass)->finalize = publishing_facebook_publishing_options_pane_finalize;
#line 1011 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_new ("logout", PUBLISHING_FACEBOOK_TYPE_PUBLISHING_OPTIONS_PANE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
#line 1011 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_new ("publish", PUBLISHING_FACEBOOK_TYPE_PUBLISHING_OPTIONS_PANE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_user_marshal_VOID__STRING_STRING_ENUM_BOOLEAN, G_TYPE_NONE, 4, G_TYPE_STRING, G_TYPE_STRING, PUBLISHING_FACEBOOK_TYPE_RESOLUTION, G_TYPE_BOOLEAN);
#line 8345 "FacebookPublishing.c"
}


static void publishing_facebook_publishing_options_pane_spit_publishing_dialog_pane_interface_init (SpitPublishingDialogPaneIface * iface) {
#line 1011 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_publishing_options_pane_spit_publishing_dialog_pane_parent_iface = g_type_interface_peek_parent (iface);
#line 1011 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	iface->get_widget = (GtkWidget* (*)(SpitPublishingDialogPane*)) publishing_facebook_publishing_options_pane_real_get_widget;
#line 1011 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	iface->get_preferred_geometry = (SpitPublishingDialogPaneGeometryOptions (*)(SpitPublishingDialogPane*)) publishing_facebook_publishing_options_pane_real_get_preferred_geometry;
#line 1011 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	iface->on_pane_installed = (void (*)(SpitPublishingDialogPane*)) publishing_facebook_publishing_options_pane_real_on_pane_installed;
#line 1011 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	iface->on_pane_uninstalled = (void (*)(SpitPublishingDialogPane*)) publishing_facebook_publishing_options_pane_real_on_pane_uninstalled;
#line 8360 "FacebookPublishing.c"
}


static void publishing_facebook_publishing_options_pane_instance_init (PublishingFacebookPublishingOptionsPane * self) {
#line 1011 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv = PUBLISHING_FACEBOOK_PUBLISHING_OPTIONS_PANE_GET_PRIVATE (self);
#line 1013 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->pane_widget = NULL;
#line 1014 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->use_existing_radio = NULL;
#line 1015 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->create_new_radio = NULL;
#line 1016 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->existing_albums_combo = NULL;
#line 1017 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->visibility_combo = NULL;
#line 1018 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->new_album_entry = NULL;
#line 1019 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->strip_metadata_check = NULL;
#line 1020 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->publish_button = NULL;
#line 1021 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->logout_button = NULL;
#line 1022 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->how_to_label = NULL;
#line 1023 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->albums = NULL;
#line 1023 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->albums_length1 = 0;
#line 1023 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->_albums_size_ = self->priv->albums_length1;
#line 1024 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->publisher = NULL;
#line 1028 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->resolution_combo = NULL;
#line 8397 "FacebookPublishing.c"
}


static void publishing_facebook_publishing_options_pane_finalize (GObject* obj) {
	PublishingFacebookPublishingOptionsPane * self;
#line 1011 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_FACEBOOK_TYPE_PUBLISHING_OPTIONS_PANE, PublishingFacebookPublishingOptionsPane);
#line 1012 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_object_unref0 (self->priv->builder);
#line 1013 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_object_unref0 (self->priv->pane_widget);
#line 1014 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_object_unref0 (self->priv->use_existing_radio);
#line 1015 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_object_unref0 (self->priv->create_new_radio);
#line 1016 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_object_unref0 (self->priv->existing_albums_combo);
#line 1017 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_object_unref0 (self->priv->visibility_combo);
#line 1018 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_object_unref0 (self->priv->new_album_entry);
#line 1019 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_object_unref0 (self->priv->strip_metadata_check);
#line 1020 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_object_unref0 (self->priv->publish_button);
#line 1021 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_object_unref0 (self->priv->logout_button);
#line 1022 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_object_unref0 (self->priv->how_to_label);
#line 1023 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->albums = (_vala_array_free (self->priv->albums, self->priv->albums_length1, (GDestroyNotify) publishing_facebook_album_unref), NULL);
#line 1024 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_object_unref0 (self->priv->publisher);
#line 1025 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->privacy_descriptions = (_vala_array_free (self->priv->privacy_descriptions, self->priv->privacy_descriptions_length1, (GDestroyNotify) publishing_facebook_publishing_options_pane_privacy_description_unref), NULL);
#line 1027 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->possible_resolutions = (g_free (self->priv->possible_resolutions), NULL);
#line 1028 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_object_unref0 (self->priv->resolution_combo);
#line 1011 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	G_OBJECT_CLASS (publishing_facebook_publishing_options_pane_parent_class)->finalize (obj);
#line 8439 "FacebookPublishing.c"
}


GType publishing_facebook_publishing_options_pane_get_type (void) {
	static volatile gsize publishing_facebook_publishing_options_pane_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_facebook_publishing_options_pane_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingFacebookPublishingOptionsPaneClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_facebook_publishing_options_pane_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingFacebookPublishingOptionsPane), 0, (GInstanceInitFunc) publishing_facebook_publishing_options_pane_instance_init, NULL };
		static const GInterfaceInfo spit_publishing_dialog_pane_info = { (GInterfaceInitFunc) publishing_facebook_publishing_options_pane_spit_publishing_dialog_pane_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType publishing_facebook_publishing_options_pane_type_id;
		publishing_facebook_publishing_options_pane_type_id = g_type_register_static (G_TYPE_OBJECT, "PublishingFacebookPublishingOptionsPane", &g_define_type_info, 0);
		g_type_add_interface_static (publishing_facebook_publishing_options_pane_type_id, SPIT_PUBLISHING_TYPE_DIALOG_PANE, &spit_publishing_dialog_pane_info);
		g_once_init_leave (&publishing_facebook_publishing_options_pane_type_id__volatile, publishing_facebook_publishing_options_pane_type_id);
	}
	return publishing_facebook_publishing_options_pane_type_id__volatile;
}


gchar* publishing_facebook_endpoint_to_uri (PublishingFacebookEndpoint self) {
	gchar* result = NULL;
#line 1277 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	switch (self) {
#line 1277 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		case PUBLISHING_FACEBOOK_ENDPOINT_DEFAULT:
#line 8463 "FacebookPublishing.c"
		{
			gchar* _tmp0_ = NULL;
#line 1279 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			_tmp0_ = g_strdup ("https://graph.facebook.com/");
#line 1279 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			result = _tmp0_;
#line 1279 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			return result;
#line 8472 "FacebookPublishing.c"
		}
#line 1277 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		case PUBLISHING_FACEBOOK_ENDPOINT_VIDEO:
#line 8476 "FacebookPublishing.c"
		{
			gchar* _tmp1_ = NULL;
#line 1282 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			_tmp1_ = g_strdup ("https://graph-video.facebook.com/");
#line 1282 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			result = _tmp1_;
#line 1282 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			return result;
#line 8485 "FacebookPublishing.c"
		}
#line 1277 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		case PUBLISHING_FACEBOOK_ENDPOINT_TEST_CONNECTION:
#line 8489 "FacebookPublishing.c"
		{
			gchar* _tmp2_ = NULL;
#line 1285 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			_tmp2_ = g_strdup ("https://www.facebook.com/");
#line 1285 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			result = _tmp2_;
#line 1285 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			return result;
#line 8498 "FacebookPublishing.c"
		}
		default:
		{
#line 1288 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			g_assert_not_reached ();
#line 8504 "FacebookPublishing.c"
		}
	}
}


GType publishing_facebook_endpoint_get_type (void) {
	static volatile gsize publishing_facebook_endpoint_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_facebook_endpoint_type_id__volatile)) {
		static const GEnumValue values[] = {{PUBLISHING_FACEBOOK_ENDPOINT_DEFAULT, "PUBLISHING_FACEBOOK_ENDPOINT_DEFAULT", "default"}, {PUBLISHING_FACEBOOK_ENDPOINT_VIDEO, "PUBLISHING_FACEBOOK_ENDPOINT_VIDEO", "video"}, {PUBLISHING_FACEBOOK_ENDPOINT_TEST_CONNECTION, "PUBLISHING_FACEBOOK_ENDPOINT_TEST_CONNECTION", "test-connection"}, {0, NULL, NULL}};
		GType publishing_facebook_endpoint_type_id;
		publishing_facebook_endpoint_type_id = g_enum_register_static ("PublishingFacebookEndpoint", values);
		g_once_init_leave (&publishing_facebook_endpoint_type_id__volatile, publishing_facebook_endpoint_type_id);
	}
	return publishing_facebook_endpoint_type_id__volatile;
}


static gchar* publishing_facebook_graph_message_real_get_uri (PublishingFacebookGraphMessage* self) {
#line 1298 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_critical ("Type `%s' does not implement abstract method `publishing_facebook_graph_message_get_uri'", g_type_name (G_TYPE_FROM_INSTANCE (self)));
#line 1298 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return NULL;
#line 8527 "FacebookPublishing.c"
}


gchar* publishing_facebook_graph_message_get_uri (PublishingFacebookGraphMessage* self) {
#line 1298 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_val_if_fail (PUBLISHING_FACEBOOK_IS_GRAPH_MESSAGE (self), NULL);
#line 1298 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return PUBLISHING_FACEBOOK_GRAPH_MESSAGE_GET_CLASS (self)->get_uri (self);
#line 8536 "FacebookPublishing.c"
}


static gchar* publishing_facebook_graph_message_real_get_response_body (PublishingFacebookGraphMessage* self) {
#line 1299 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_critical ("Type `%s' does not implement abstract method `publishing_facebook_graph_message_get_response_body'", g_type_name (G_TYPE_FROM_INSTANCE (self)));
#line 1299 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return NULL;
#line 8545 "FacebookPublishing.c"
}


gchar* publishing_facebook_graph_message_get_response_body (PublishingFacebookGraphMessage* self) {
#line 1299 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_val_if_fail (PUBLISHING_FACEBOOK_IS_GRAPH_MESSAGE (self), NULL);
#line 1299 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return PUBLISHING_FACEBOOK_GRAPH_MESSAGE_GET_CLASS (self)->get_response_body (self);
#line 8554 "FacebookPublishing.c"
}


PublishingFacebookGraphMessage* publishing_facebook_graph_message_construct (GType object_type) {
	PublishingFacebookGraphMessage* self = NULL;
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self = (PublishingFacebookGraphMessage*) g_type_create_instance (object_type);
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return self;
#line 8564 "FacebookPublishing.c"
}


static void g_cclosure_user_marshal_VOID__INT_INT (GClosure * closure, GValue * return_value, guint n_param_values, const GValue * param_values, gpointer invocation_hint, gpointer marshal_data) {
	typedef void (*GMarshalFunc_VOID__INT_INT) (gpointer data1, gint arg_1, gint arg_2, gpointer data2);
	register GMarshalFunc_VOID__INT_INT callback;
	register GCClosure * cc;
	register gpointer data1;
	register gpointer data2;
	cc = (GCClosure *) closure;
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (n_param_values == 3);
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (G_CCLOSURE_SWAP_DATA (closure)) {
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		data1 = closure->data;
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		data2 = param_values->data[0].v_pointer;
#line 8583 "FacebookPublishing.c"
	} else {
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		data1 = param_values->data[0].v_pointer;
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		data2 = closure->data;
#line 8589 "FacebookPublishing.c"
	}
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	callback = (GMarshalFunc_VOID__INT_INT) (marshal_data ? marshal_data : cc->callback);
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	callback (data1, g_value_get_int (param_values + 1), g_value_get_int (param_values + 2), data2);
#line 8595 "FacebookPublishing.c"
}


static void publishing_facebook_value_graph_message_init (GValue* value) {
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	value->data[0].v_pointer = NULL;
#line 8602 "FacebookPublishing.c"
}


static void publishing_facebook_value_graph_message_free_value (GValue* value) {
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (value->data[0].v_pointer) {
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		publishing_facebook_graph_message_unref (value->data[0].v_pointer);
#line 8611 "FacebookPublishing.c"
	}
}


static void publishing_facebook_value_graph_message_copy_value (const GValue* src_value, GValue* dest_value) {
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (src_value->data[0].v_pointer) {
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		dest_value->data[0].v_pointer = publishing_facebook_graph_message_ref (src_value->data[0].v_pointer);
#line 8621 "FacebookPublishing.c"
	} else {
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		dest_value->data[0].v_pointer = NULL;
#line 8625 "FacebookPublishing.c"
	}
}


static gpointer publishing_facebook_value_graph_message_peek_pointer (const GValue* value) {
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return value->data[0].v_pointer;
#line 8633 "FacebookPublishing.c"
}


static gchar* publishing_facebook_value_graph_message_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (collect_values[0].v_pointer) {
#line 8640 "FacebookPublishing.c"
		PublishingFacebookGraphMessage* object;
		object = collect_values[0].v_pointer;
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		if (object->parent_instance.g_class == NULL) {
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 8647 "FacebookPublishing.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 8651 "FacebookPublishing.c"
		}
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		value->data[0].v_pointer = publishing_facebook_graph_message_ref (object);
#line 8655 "FacebookPublishing.c"
	} else {
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 8659 "FacebookPublishing.c"
	}
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return NULL;
#line 8663 "FacebookPublishing.c"
}


static gchar* publishing_facebook_value_graph_message_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	PublishingFacebookGraphMessage** object_p;
	object_p = collect_values[0].v_pointer;
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (!object_p) {
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 8674 "FacebookPublishing.c"
	}
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (!value->data[0].v_pointer) {
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		*object_p = NULL;
#line 8680 "FacebookPublishing.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		*object_p = value->data[0].v_pointer;
#line 8684 "FacebookPublishing.c"
	} else {
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		*object_p = publishing_facebook_graph_message_ref (value->data[0].v_pointer);
#line 8688 "FacebookPublishing.c"
	}
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return NULL;
#line 8692 "FacebookPublishing.c"
}


GParamSpec* publishing_facebook_param_spec_graph_message (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
	PublishingFacebookParamSpecGraphMessage* spec;
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_val_if_fail (g_type_is_a (object_type, PUBLISHING_FACEBOOK_TYPE_GRAPH_MESSAGE), NULL);
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return G_PARAM_SPEC (spec);
#line 8706 "FacebookPublishing.c"
}


gpointer publishing_facebook_value_get_graph_message (const GValue* value) {
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_FACEBOOK_TYPE_GRAPH_MESSAGE), NULL);
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return value->data[0].v_pointer;
#line 8715 "FacebookPublishing.c"
}


void publishing_facebook_value_set_graph_message (GValue* value, gpointer v_object) {
	PublishingFacebookGraphMessage* old;
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_FACEBOOK_TYPE_GRAPH_MESSAGE));
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	old = value->data[0].v_pointer;
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (v_object) {
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PUBLISHING_FACEBOOK_TYPE_GRAPH_MESSAGE));
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		value->data[0].v_pointer = v_object;
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		publishing_facebook_graph_message_ref (value->data[0].v_pointer);
#line 8735 "FacebookPublishing.c"
	} else {
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 8739 "FacebookPublishing.c"
	}
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (old) {
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		publishing_facebook_graph_message_unref (old);
#line 8745 "FacebookPublishing.c"
	}
}


void publishing_facebook_value_take_graph_message (GValue* value, gpointer v_object) {
	PublishingFacebookGraphMessage* old;
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_FACEBOOK_TYPE_GRAPH_MESSAGE));
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	old = value->data[0].v_pointer;
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (v_object) {
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PUBLISHING_FACEBOOK_TYPE_GRAPH_MESSAGE));
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		value->data[0].v_pointer = v_object;
#line 8764 "FacebookPublishing.c"
	} else {
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 8768 "FacebookPublishing.c"
	}
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (old) {
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		publishing_facebook_graph_message_unref (old);
#line 8774 "FacebookPublishing.c"
	}
}


static void publishing_facebook_graph_message_class_init (PublishingFacebookGraphMessageClass * klass) {
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_graph_message_parent_class = g_type_class_peek_parent (klass);
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	((PublishingFacebookGraphMessageClass *) klass)->finalize = publishing_facebook_graph_message_finalize;
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	((PublishingFacebookGraphMessageClass *) klass)->get_uri = publishing_facebook_graph_message_real_get_uri;
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	((PublishingFacebookGraphMessageClass *) klass)->get_response_body = publishing_facebook_graph_message_real_get_response_body;
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_new ("completed", PUBLISHING_FACEBOOK_TYPE_GRAPH_MESSAGE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_new ("failed", PUBLISHING_FACEBOOK_TYPE_GRAPH_MESSAGE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__POINTER, G_TYPE_NONE, 1, G_TYPE_POINTER);
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_new ("data_transmitted", PUBLISHING_FACEBOOK_TYPE_GRAPH_MESSAGE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_user_marshal_VOID__INT_INT, G_TYPE_NONE, 2, G_TYPE_INT, G_TYPE_INT);
#line 8794 "FacebookPublishing.c"
}


static void publishing_facebook_graph_message_instance_init (PublishingFacebookGraphMessage * self) {
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->ref_count = 1;
#line 8801 "FacebookPublishing.c"
}


static void publishing_facebook_graph_message_finalize (PublishingFacebookGraphMessage* obj) {
	PublishingFacebookGraphMessage * self;
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_FACEBOOK_TYPE_GRAPH_MESSAGE, PublishingFacebookGraphMessage);
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_handlers_destroy (self);
#line 8811 "FacebookPublishing.c"
}


GType publishing_facebook_graph_message_get_type (void) {
	static volatile gsize publishing_facebook_graph_message_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_facebook_graph_message_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { publishing_facebook_value_graph_message_init, publishing_facebook_value_graph_message_free_value, publishing_facebook_value_graph_message_copy_value, publishing_facebook_value_graph_message_peek_pointer, "p", publishing_facebook_value_graph_message_collect_value, "p", publishing_facebook_value_graph_message_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (PublishingFacebookGraphMessageClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_facebook_graph_message_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingFacebookGraphMessage), 0, (GInstanceInitFunc) publishing_facebook_graph_message_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType publishing_facebook_graph_message_type_id;
		publishing_facebook_graph_message_type_id = g_type_register_fundamental (g_type_fundamental_next (), "PublishingFacebookGraphMessage", &g_define_type_info, &g_define_type_fundamental_info, G_TYPE_FLAG_ABSTRACT);
		g_once_init_leave (&publishing_facebook_graph_message_type_id__volatile, publishing_facebook_graph_message_type_id);
	}
	return publishing_facebook_graph_message_type_id__volatile;
}


gpointer publishing_facebook_graph_message_ref (gpointer instance) {
	PublishingFacebookGraphMessage* self;
	self = instance;
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_atomic_int_inc (&self->ref_count);
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return instance;
#line 8836 "FacebookPublishing.c"
}


void publishing_facebook_graph_message_unref (gpointer instance) {
	PublishingFacebookGraphMessage* self;
	self = instance;
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		PUBLISHING_FACEBOOK_GRAPH_MESSAGE_GET_CLASS (self)->finalize (self);
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 8849 "FacebookPublishing.c"
	}
}


static void _publishing_facebook_graph_session_on_request_unqueued_soup_session_request_unqueued (SoupSession* _sender, SoupMessage* msg, gpointer self) {
#line 1478 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_graph_session_on_request_unqueued ((PublishingFacebookGraphSession*) self, msg);
#line 8857 "FacebookPublishing.c"
}


PublishingFacebookGraphSession* publishing_facebook_graph_session_construct (GType object_type) {
	PublishingFacebookGraphSession* self = NULL;
	SoupSessionAsync* _tmp0_ = NULL;
	SoupSession* _tmp1_ = NULL;
	SoupSession* _tmp2_ = NULL;
	SoupSession* _tmp3_ = NULL;
#line 1468 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self = (PublishingFacebookGraphSession*) g_type_create_instance (object_type);
#line 1469 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = (SoupSessionAsync*) soup_session_async_new ();
#line 1469 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_object_unref0 (self->priv->soup_session);
#line 1469 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->soup_session = G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, soup_session_get_type (), SoupSession);
#line 1470 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp1_ = self->priv->soup_session;
#line 1470 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_connect (_tmp1_, "request-unqueued", (GCallback) _publishing_facebook_graph_session_on_request_unqueued_soup_session_request_unqueued, self);
#line 1471 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp2_ = self->priv->soup_session;
#line 1471 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_object_set (_tmp2_, "timeout", (guint) 15, NULL);
#line 1472 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_free0 (self->priv->access_token);
#line 1472 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->access_token = NULL;
#line 1473 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_publishing_facebook_graph_message_unref0 (self->priv->current_message);
#line 1473 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->current_message = NULL;
#line 1474 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp3_ = self->priv->soup_session;
#line 1474 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_object_set (_tmp3_, "ssl-use-system-ca-file", TRUE, NULL);
#line 1468 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return self;
#line 8897 "FacebookPublishing.c"
}


PublishingFacebookGraphSession* publishing_facebook_graph_session_new (void) {
#line 1468 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return publishing_facebook_graph_session_construct (PUBLISHING_FACEBOOK_TYPE_GRAPH_SESSION);
#line 8904 "FacebookPublishing.c"
}


static gpointer _publishing_facebook_graph_message_ref0 (gpointer self) {
#line 1484 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return self ? publishing_facebook_graph_message_ref (self) : NULL;
#line 8911 "FacebookPublishing.c"
}


static void publishing_facebook_graph_session_manage_message (PublishingFacebookGraphSession* self, PublishingFacebookGraphMessage* msg) {
	PublishingFacebookGraphMessage* _tmp0_ = NULL;
	PublishingFacebookGraphMessage* _tmp1_ = NULL;
	PublishingFacebookGraphMessage* _tmp2_ = NULL;
#line 1481 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_GRAPH_SESSION (self));
#line 1481 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_GRAPH_MESSAGE (msg));
#line 1482 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = self->priv->current_message;
#line 1482 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_vala_assert (_tmp0_ == NULL, "current_message == null");
#line 1484 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp1_ = msg;
#line 1484 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp2_ = _publishing_facebook_graph_message_ref0 (_tmp1_);
#line 1484 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_publishing_facebook_graph_message_unref0 (self->priv->current_message);
#line 1484 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->current_message = _tmp2_;
#line 8935 "FacebookPublishing.c"
}


static void publishing_facebook_graph_session_unmanage_message (PublishingFacebookGraphSession* self, PublishingFacebookGraphMessage* msg) {
	PublishingFacebookGraphMessage* _tmp0_ = NULL;
#line 1487 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_GRAPH_SESSION (self));
#line 1487 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_GRAPH_MESSAGE (msg));
#line 1488 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = self->priv->current_message;
#line 1488 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_vala_assert (_tmp0_ != NULL, "current_message != null");
#line 1490 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_publishing_facebook_graph_message_unref0 (self->priv->current_message);
#line 1490 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->current_message = NULL;
#line 8953 "FacebookPublishing.c"
}


static void _publishing_facebook_graph_session_graph_message_impl_on_wrote_body_data_soup_message_wrote_body_data (SoupMessage* _sender, SoupBuffer* chunk, gpointer self) {
#line 1509 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_graph_session_graph_message_impl_on_wrote_body_data ((PublishingFacebookGraphSessionGraphMessageImpl*) self, chunk);
#line 8960 "FacebookPublishing.c"
}


static void publishing_facebook_graph_session_on_request_unqueued (PublishingFacebookGraphSession* self, SoupMessage* msg) {
	PublishingFacebookGraphMessage* _tmp0_ = NULL;
	PublishingFacebookGraphSessionGraphMessageImpl* real_message = NULL;
	PublishingFacebookGraphMessage* _tmp1_ = NULL;
	PublishingFacebookGraphSessionGraphMessageImpl* _tmp2_ = NULL;
	PublishingFacebookGraphSessionGraphMessageImpl* _tmp3_ = NULL;
	SoupMessage* _tmp4_ = NULL;
	SoupMessage* _tmp5_ = NULL;
	gboolean _tmp6_ = FALSE;
	gboolean _tmp7_ = FALSE;
	SoupMessage* _tmp8_ = NULL;
	guint _tmp9_ = 0U;
	guint _tmp10_ = 0U;
	PublishingFacebookGraphSessionGraphMessageImpl* _tmp21_ = NULL;
	SoupMessage* _tmp22_ = NULL;
	PublishingFacebookGraphSessionGraphMessageImpl* _tmp23_ = NULL;
	guint _tmp24_ = 0U;
	GError* _error_ = NULL;
	SoupMessage* _tmp25_ = NULL;
	guint _tmp26_ = 0U;
	guint _tmp27_ = 0U;
	GError* _tmp68_ = NULL;
	GError* _tmp80_ = NULL;
#line 1493 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_GRAPH_SESSION (self));
#line 1493 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (SOUP_IS_MESSAGE (msg));
#line 1494 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = self->priv->current_message;
#line 1494 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_vala_assert (_tmp0_ != NULL, "current_message != null");
#line 1495 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp1_ = self->priv->current_message;
#line 1495 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp2_ = _publishing_facebook_graph_message_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, PUBLISHING_FACEBOOK_GRAPH_SESSION_TYPE_GRAPH_MESSAGE_IMPL, PublishingFacebookGraphSessionGraphMessageImpl));
#line 1495 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	real_message = _tmp2_;
#line 1496 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp3_ = real_message;
#line 1496 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp4_ = _tmp3_->soup_message;
#line 1496 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp5_ = msg;
#line 1496 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_vala_assert (_tmp4_ == _tmp5_, "real_message.soup_message == msg");
#line 1500 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp8_ = msg;
#line 1500 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_object_get (_tmp8_, "status-code", &_tmp9_, NULL);
#line 1500 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp10_ = _tmp9_;
#line 1500 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (_tmp10_ == ((guint) SOUP_STATUS_IO_ERROR)) {
#line 1500 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp7_ = TRUE;
#line 9019 "FacebookPublishing.c"
	} else {
		SoupMessage* _tmp11_ = NULL;
		guint _tmp12_ = 0U;
		guint _tmp13_ = 0U;
#line 1501 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp11_ = msg;
#line 1501 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		g_object_get (_tmp11_, "status-code", &_tmp12_, NULL);
#line 1501 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp13_ = _tmp12_;
#line 1501 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp7_ = _tmp13_ == ((guint) SOUP_STATUS_MALFORMED);
#line 9032 "FacebookPublishing.c"
	}
#line 1500 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (_tmp7_) {
#line 1500 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp6_ = TRUE;
#line 9038 "FacebookPublishing.c"
	} else {
		SoupMessage* _tmp14_ = NULL;
		guint _tmp15_ = 0U;
		guint _tmp16_ = 0U;
#line 1502 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp14_ = msg;
#line 1502 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		g_object_get (_tmp14_, "status-code", &_tmp15_, NULL);
#line 1502 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp16_ = _tmp15_;
#line 1502 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp6_ = _tmp16_ == ((guint) SOUP_STATUS_TRY_AGAIN);
#line 9051 "FacebookPublishing.c"
	}
#line 1500 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (_tmp6_) {
#line 9055 "FacebookPublishing.c"
		PublishingFacebookGraphSessionGraphMessageImpl* _tmp17_ = NULL;
		SoupSession* _tmp18_ = NULL;
		SoupMessage* _tmp19_ = NULL;
		SoupMessage* _tmp20_ = NULL;
#line 1503 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp17_ = real_message;
#line 1503 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp17_->bytes_so_far = 0;
#line 1504 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp18_ = self->priv->soup_session;
#line 1504 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp19_ = msg;
#line 1504 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp20_ = _g_object_ref0 (_tmp19_);
#line 1504 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		soup_session_queue_message (_tmp18_, _tmp20_, NULL, NULL);
#line 1505 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_publishing_facebook_graph_message_unref0 (real_message);
#line 1505 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		return;
#line 9076 "FacebookPublishing.c"
	}
#line 1508 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp21_ = real_message;
#line 1508 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_graph_session_unmanage_message (self, G_TYPE_CHECK_INSTANCE_CAST (_tmp21_, PUBLISHING_FACEBOOK_TYPE_GRAPH_MESSAGE, PublishingFacebookGraphMessage));
#line 1509 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp22_ = msg;
#line 1509 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp23_ = real_message;
#line 1509 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_parse_name ("wrote-body-data", soup_message_get_type (), &_tmp24_, NULL, FALSE);
#line 1509 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp22_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp24_, 0, NULL, (GCallback) _publishing_facebook_graph_session_graph_message_impl_on_wrote_body_data_soup_message_wrote_body_data, _tmp23_);
#line 1511 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_error_ = NULL;
#line 1512 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp25_ = msg;
#line 1512 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_object_get (_tmp25_, "status-code", &_tmp26_, NULL);
#line 1512 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp27_ = _tmp26_;
#line 1512 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	switch (_tmp27_) {
#line 1512 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		case SOUP_STATUS_OK:
#line 1512 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		case SOUP_STATUS_CREATED:
#line 9104 "FacebookPublishing.c"
		{
#line 1517 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			break;
#line 9108 "FacebookPublishing.c"
		}
#line 1512 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		case PUBLISHING_FACEBOOK_EXPIRED_SESSION_STATUS_CODE:
#line 9112 "FacebookPublishing.c"
		{
			GError* _tmp28_ = NULL;
#line 1520 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			_tmp28_ = g_error_new_literal (SPIT_PUBLISHING_PUBLISHING_ERROR, SPIT_PUBLISHING_PUBLISHING_ERROR_EXPIRED_SESSION, "OAuth Access Token has Expired. Logout user.");
#line 1520 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			_g_error_free0 (_error_);
#line 1520 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			_error_ = _tmp28_;
#line 1522 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			break;
#line 9123 "FacebookPublishing.c"
		}
#line 1512 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		case SOUP_STATUS_CANT_RESOLVE:
#line 1512 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		case SOUP_STATUS_CANT_RESOLVE_PROXY:
#line 9129 "FacebookPublishing.c"
		{
			PublishingFacebookGraphSessionGraphMessageImpl* _tmp29_ = NULL;
			gchar* _tmp30_ = NULL;
			gchar* _tmp31_ = NULL;
			SoupMessage* _tmp32_ = NULL;
			guint _tmp33_ = 0U;
			guint _tmp34_ = 0U;
			GError* _tmp35_ = NULL;
#line 1526 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			_tmp29_ = real_message;
#line 1526 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			_tmp30_ = publishing_facebook_graph_message_get_uri (G_TYPE_CHECK_INSTANCE_CAST (_tmp29_, PUBLISHING_FACEBOOK_TYPE_GRAPH_MESSAGE, PublishingFacebookGraphMessage));
#line 1526 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			_tmp31_ = _tmp30_;
#line 1526 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			_tmp32_ = msg;
#line 1526 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			g_object_get (_tmp32_, "status-code", &_tmp33_, NULL);
#line 1526 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			_tmp34_ = _tmp33_;
#line 1526 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			_tmp35_ = g_error_new (SPIT_PUBLISHING_PUBLISHING_ERROR, SPIT_PUBLISHING_PUBLISHING_ERROR_NO_ANSWER, "Unable to resolve %s (error code %u)", _tmp31_, _tmp34_);
#line 1526 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			_g_error_free0 (_error_);
#line 1526 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			_error_ = _tmp35_;
#line 1526 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			_g_free0 (_tmp31_);
#line 1528 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			break;
#line 9160 "FacebookPublishing.c"
		}
#line 1512 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		case SOUP_STATUS_CANT_CONNECT:
#line 1512 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		case SOUP_STATUS_CANT_CONNECT_PROXY:
#line 9166 "FacebookPublishing.c"
		{
			PublishingFacebookGraphSessionGraphMessageImpl* _tmp36_ = NULL;
			gchar* _tmp37_ = NULL;
			gchar* _tmp38_ = NULL;
			SoupMessage* _tmp39_ = NULL;
			guint _tmp40_ = 0U;
			guint _tmp41_ = 0U;
			GError* _tmp42_ = NULL;
#line 1532 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			_tmp36_ = real_message;
#line 1532 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			_tmp37_ = publishing_facebook_graph_message_get_uri (G_TYPE_CHECK_INSTANCE_CAST (_tmp36_, PUBLISHING_FACEBOOK_TYPE_GRAPH_MESSAGE, PublishingFacebookGraphMessage));
#line 1532 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			_tmp38_ = _tmp37_;
#line 1532 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			_tmp39_ = msg;
#line 1532 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			g_object_get (_tmp39_, "status-code", &_tmp40_, NULL);
#line 1532 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			_tmp41_ = _tmp40_;
#line 1532 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			_tmp42_ = g_error_new (SPIT_PUBLISHING_PUBLISHING_ERROR, SPIT_PUBLISHING_PUBLISHING_ERROR_NO_ANSWER, "Unable to connect to %s (error code %u)", _tmp38_, _tmp41_);
#line 1532 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			_g_error_free0 (_error_);
#line 1532 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			_error_ = _tmp42_;
#line 1532 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			_g_free0 (_tmp38_);
#line 1534 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			break;
#line 9197 "FacebookPublishing.c"
		}
		default:
		{
			SoupMessage* _tmp43_ = NULL;
			guint _tmp44_ = 0U;
			guint _tmp45_ = 0U;
#line 1539 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			_tmp43_ = msg;
#line 1539 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			g_object_get (_tmp43_, "status-code", &_tmp44_, NULL);
#line 1539 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			_tmp45_ = _tmp44_;
#line 1539 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			if (_tmp45_ >= ((guint) 100)) {
#line 9212 "FacebookPublishing.c"
				PublishingFacebookGraphSessionGraphMessageImpl* _tmp46_ = NULL;
				gchar* _tmp47_ = NULL;
				gchar* _tmp48_ = NULL;
				SoupMessage* _tmp49_ = NULL;
				guint _tmp50_ = 0U;
				guint _tmp51_ = 0U;
				SoupMessage* _tmp52_ = NULL;
				gchar* _tmp53_ = NULL;
				gchar* _tmp54_ = NULL;
				gchar* _tmp55_ = NULL;
				GError* _tmp56_ = NULL;
#line 1540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				_tmp46_ = real_message;
#line 1540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				_tmp47_ = publishing_facebook_graph_message_get_uri (G_TYPE_CHECK_INSTANCE_CAST (_tmp46_, PUBLISHING_FACEBOOK_TYPE_GRAPH_MESSAGE, PublishingFacebookGraphMessage));
#line 1540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				_tmp48_ = _tmp47_;
#line 1540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				_tmp49_ = msg;
#line 1540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				g_object_get (_tmp49_, "status-code", &_tmp50_, NULL);
#line 1540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				_tmp51_ = _tmp50_;
#line 1540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				_tmp52_ = msg;
#line 1540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				g_object_get (_tmp52_, "reason-phrase", &_tmp53_, NULL);
#line 1540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				_tmp54_ = _tmp53_;
#line 1540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				_tmp55_ = _tmp54_;
#line 1540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				_tmp56_ = g_error_new (SPIT_PUBLISHING_PUBLISHING_ERROR, SPIT_PUBLISHING_PUBLISHING_ERROR_NO_ANSWER, "Service %s returned HTTP status code %u %s", _tmp48_, _tmp51_, _tmp55_);
#line 1540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				_g_error_free0 (_error_);
#line 1540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				_error_ = _tmp56_;
#line 1540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				_g_free0 (_tmp55_);
#line 1540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				_g_free0 (_tmp48_);
#line 9254 "FacebookPublishing.c"
			} else {
				SoupMessage* _tmp57_ = NULL;
				gchar* _tmp58_ = NULL;
				gchar* _tmp59_ = NULL;
				gchar* _tmp60_ = NULL;
				PublishingFacebookGraphSessionGraphMessageImpl* _tmp61_ = NULL;
				gchar* _tmp62_ = NULL;
				gchar* _tmp63_ = NULL;
				SoupMessage* _tmp64_ = NULL;
				guint _tmp65_ = 0U;
				guint _tmp66_ = 0U;
				GError* _tmp67_ = NULL;
#line 1544 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				_tmp57_ = msg;
#line 1544 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				g_object_get (_tmp57_, "reason-phrase", &_tmp58_, NULL);
#line 1544 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				_tmp59_ = _tmp58_;
#line 1544 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				_tmp60_ = _tmp59_;
#line 1544 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				g_debug ("FacebookPublishing.vala:1544: %s", _tmp60_);
#line 1544 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				_g_free0 (_tmp60_);
#line 1545 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				_tmp61_ = real_message;
#line 1545 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				_tmp62_ = publishing_facebook_graph_message_get_uri (G_TYPE_CHECK_INSTANCE_CAST (_tmp61_, PUBLISHING_FACEBOOK_TYPE_GRAPH_MESSAGE, PublishingFacebookGraphMessage));
#line 1545 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				_tmp63_ = _tmp62_;
#line 1545 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				_tmp64_ = msg;
#line 1545 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				g_object_get (_tmp64_, "status-code", &_tmp65_, NULL);
#line 1545 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				_tmp66_ = _tmp65_;
#line 1545 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				_tmp67_ = g_error_new (SPIT_PUBLISHING_PUBLISHING_ERROR, SPIT_PUBLISHING_PUBLISHING_ERROR_NO_ANSWER, "Failure communicating with %s (error code %u)", _tmp63_, _tmp66_);
#line 1545 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				_g_error_free0 (_error_);
#line 1545 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				_error_ = _tmp67_;
#line 1545 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
				_g_free0 (_tmp63_);
#line 9299 "FacebookPublishing.c"
			}
#line 1549 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			break;
#line 9303 "FacebookPublishing.c"
		}
	}
#line 1553 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp68_ = _error_;
#line 1553 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (_tmp68_ == NULL) {
#line 9310 "FacebookPublishing.c"
		gboolean _tmp69_ = FALSE;
		SoupMessage* _tmp70_ = NULL;
		SoupMessageBody* _tmp71_ = NULL;
		guint8* _tmp72_ = NULL;
		gint _tmp72__length1 = 0;
#line 1554 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp70_ = msg;
#line 1554 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp71_ = _tmp70_->response_body;
#line 1554 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp72_ = _tmp71_->data;
#line 1554 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp72__length1 = (gint) _tmp71_->length;
#line 1554 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		if (_tmp72_ == NULL) {
#line 1554 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			_tmp69_ = TRUE;
#line 9328 "FacebookPublishing.c"
		} else {
			SoupMessage* _tmp73_ = NULL;
			SoupMessageBody* _tmp74_ = NULL;
			guint8* _tmp75_ = NULL;
			gint _tmp75__length1 = 0;
#line 1554 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			_tmp73_ = msg;
#line 1554 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			_tmp74_ = _tmp73_->response_body;
#line 1554 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			_tmp75_ = _tmp74_->data;
#line 1554 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			_tmp75__length1 = (gint) _tmp74_->length;
#line 1554 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			_tmp69_ = _tmp75__length1 == 0;
#line 9344 "FacebookPublishing.c"
		}
#line 1554 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		if (_tmp69_) {
#line 9348 "FacebookPublishing.c"
			PublishingFacebookGraphSessionGraphMessageImpl* _tmp76_ = NULL;
			gchar* _tmp77_ = NULL;
			gchar* _tmp78_ = NULL;
			GError* _tmp79_ = NULL;
#line 1555 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			_tmp76_ = real_message;
#line 1555 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			_tmp77_ = publishing_facebook_graph_message_get_uri (G_TYPE_CHECK_INSTANCE_CAST (_tmp76_, PUBLISHING_FACEBOOK_TYPE_GRAPH_MESSAGE, PublishingFacebookGraphMessage));
#line 1555 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			_tmp78_ = _tmp77_;
#line 1555 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			_tmp79_ = g_error_new (SPIT_PUBLISHING_PUBLISHING_ERROR, SPIT_PUBLISHING_PUBLISHING_ERROR_MALFORMED_RESPONSE, "No response data from %s", _tmp78_);
#line 1555 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			_g_error_free0 (_error_);
#line 1555 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			_error_ = _tmp79_;
#line 1555 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			_g_free0 (_tmp78_);
#line 9367 "FacebookPublishing.c"
		}
	}
#line 1558 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp80_ = _error_;
#line 1558 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (_tmp80_ == NULL) {
#line 9374 "FacebookPublishing.c"
		PublishingFacebookGraphSessionGraphMessageImpl* _tmp81_ = NULL;
#line 1559 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp81_ = real_message;
#line 1559 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		g_signal_emit_by_name (G_TYPE_CHECK_INSTANCE_CAST (_tmp81_, PUBLISHING_FACEBOOK_TYPE_GRAPH_MESSAGE, PublishingFacebookGraphMessage), "completed");
#line 9380 "FacebookPublishing.c"
	} else {
		PublishingFacebookGraphSessionGraphMessageImpl* _tmp82_ = NULL;
		GError* _tmp83_ = NULL;
#line 1561 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp82_ = real_message;
#line 1561 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp83_ = _error_;
#line 1561 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		g_signal_emit_by_name (G_TYPE_CHECK_INSTANCE_CAST (_tmp82_, PUBLISHING_FACEBOOK_TYPE_GRAPH_MESSAGE, PublishingFacebookGraphMessage), "failed", _tmp83_);
#line 9390 "FacebookPublishing.c"
	}
#line 1493 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_error_free0 (_error_);
#line 1493 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_publishing_facebook_graph_message_unref0 (real_message);
#line 9396 "FacebookPublishing.c"
}


void publishing_facebook_graph_session_authenticate (PublishingFacebookGraphSession* self, const gchar* access_token) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 1564 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_GRAPH_SESSION (self));
#line 1564 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (access_token != NULL);
#line 1565 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = access_token;
#line 1565 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 1565 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_free0 (self->priv->access_token);
#line 1565 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->access_token = _tmp1_;
#line 1566 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_emit_by_name (self, "authenticated");
#line 9417 "FacebookPublishing.c"
}


gboolean publishing_facebook_graph_session_is_authenticated (PublishingFacebookGraphSession* self) {
	gboolean result = FALSE;
	const gchar* _tmp0_ = NULL;
#line 1569 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_val_if_fail (PUBLISHING_FACEBOOK_IS_GRAPH_SESSION (self), FALSE);
#line 1570 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = self->priv->access_token;
#line 1570 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	result = _tmp0_ != NULL;
#line 1570 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return result;
#line 9432 "FacebookPublishing.c"
}


gchar* publishing_facebook_graph_session_get_access_token (PublishingFacebookGraphSession* self) {
	gchar* result = NULL;
	gboolean _tmp0_ = FALSE;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
#line 1573 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_val_if_fail (PUBLISHING_FACEBOOK_IS_GRAPH_SESSION (self), NULL);
#line 1574 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = publishing_facebook_graph_session_is_authenticated (self);
#line 1574 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_vala_assert (_tmp0_, "is_authenticated()");
#line 1575 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp1_ = self->priv->access_token;
#line 1575 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp2_ = g_strdup (_tmp1_);
#line 1575 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	result = _tmp2_;
#line 1575 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return result;
#line 9455 "FacebookPublishing.c"
}


PublishingFacebookGraphMessage* publishing_facebook_graph_session_new_endpoint_test (PublishingFacebookGraphSession* self) {
	PublishingFacebookGraphMessage* result = NULL;
	PublishingFacebookGraphSessionGraphEndpointProbeMessage* _tmp0_ = NULL;
#line 1578 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_val_if_fail (PUBLISHING_FACEBOOK_IS_GRAPH_SESSION (self), NULL);
#line 1579 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = publishing_facebook_graph_session_graph_endpoint_probe_message_new (self);
#line 1579 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	result = G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, PUBLISHING_FACEBOOK_TYPE_GRAPH_MESSAGE, PublishingFacebookGraphMessage);
#line 1579 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return result;
#line 9470 "FacebookPublishing.c"
}


PublishingFacebookGraphMessage* publishing_facebook_graph_session_new_query (PublishingFacebookGraphSession* self, const gchar* resource_path) {
	PublishingFacebookGraphMessage* result = NULL;
	const gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	PublishingFacebookGraphSessionGraphQueryMessage* _tmp2_ = NULL;
#line 1582 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_val_if_fail (PUBLISHING_FACEBOOK_IS_GRAPH_SESSION (self), NULL);
#line 1582 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_val_if_fail (resource_path != NULL, NULL);
#line 1583 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = resource_path;
#line 1583 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp1_ = self->priv->access_token;
#line 1583 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp2_ = publishing_facebook_graph_session_graph_query_message_new (self, _tmp0_, _tmp1_);
#line 1583 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	result = G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, PUBLISHING_FACEBOOK_TYPE_GRAPH_MESSAGE, PublishingFacebookGraphMessage);
#line 1583 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return result;
#line 9493 "FacebookPublishing.c"
}


PublishingFacebookGraphMessage* publishing_facebook_graph_session_new_upload (PublishingFacebookGraphSession* self, const gchar* resource_path, SpitPublishingPublishable* publishable, gboolean suppress_titling, const gchar* resource_privacy) {
	PublishingFacebookGraphMessage* result = NULL;
	const gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	SpitPublishingPublishable* _tmp2_ = NULL;
	gboolean _tmp3_ = FALSE;
	const gchar* _tmp4_ = NULL;
	PublishingFacebookGraphSessionGraphUploadMessage* _tmp5_ = NULL;
#line 1586 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_val_if_fail (PUBLISHING_FACEBOOK_IS_GRAPH_SESSION (self), NULL);
#line 1586 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_val_if_fail (resource_path != NULL, NULL);
#line 1586 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_val_if_fail (SPIT_PUBLISHING_IS_PUBLISHABLE (publishable), NULL);
#line 1588 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = self->priv->access_token;
#line 1588 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp1_ = resource_path;
#line 1588 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp2_ = publishable;
#line 1588 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp3_ = suppress_titling;
#line 1588 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp4_ = resource_privacy;
#line 1588 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp5_ = publishing_facebook_graph_session_graph_upload_message_new (self, _tmp0_, _tmp1_, _tmp2_, _tmp3_, _tmp4_);
#line 1588 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	result = G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, PUBLISHING_FACEBOOK_TYPE_GRAPH_MESSAGE, PublishingFacebookGraphMessage);
#line 1588 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return result;
#line 9527 "FacebookPublishing.c"
}


PublishingFacebookGraphMessage* publishing_facebook_graph_session_new_create_album (PublishingFacebookGraphSession* self, const gchar* album_name, const gchar* privacy) {
	PublishingFacebookGraphMessage* result = NULL;
	const gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	PublishingFacebookGraphSessionGraphCreateAlbumMessage* _tmp3_ = NULL;
#line 1592 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_val_if_fail (PUBLISHING_FACEBOOK_IS_GRAPH_SESSION (self), NULL);
#line 1592 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_val_if_fail (album_name != NULL, NULL);
#line 1592 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_val_if_fail (privacy != NULL, NULL);
#line 1593 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = self->priv->access_token;
#line 1593 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp1_ = album_name;
#line 1593 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp2_ = privacy;
#line 1593 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp3_ = publishing_facebook_graph_session_graph_create_album_message_new (self, _tmp0_, _tmp1_, _tmp2_);
#line 1593 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	result = G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, PUBLISHING_FACEBOOK_TYPE_GRAPH_MESSAGE, PublishingFacebookGraphMessage);
#line 1593 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return result;
#line 9555 "FacebookPublishing.c"
}


void publishing_facebook_graph_session_send_message (PublishingFacebookGraphSession* self, PublishingFacebookGraphMessage* message) {
	PublishingFacebookGraphSessionGraphMessageImpl* real_message = NULL;
	PublishingFacebookGraphMessage* _tmp0_ = NULL;
	PublishingFacebookGraphSessionGraphMessageImpl* _tmp1_ = NULL;
	PublishingFacebookGraphSessionGraphMessageImpl* _tmp2_ = NULL;
	SoupMessage* _tmp3_ = NULL;
	SoupURI* _tmp4_ = NULL;
	SoupURI* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
	gchar* _tmp8_ = NULL;
	gchar* _tmp9_ = NULL;
	PublishingFacebookGraphSessionGraphMessageImpl* _tmp10_ = NULL;
	gboolean _tmp11_ = FALSE;
#line 1596 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_GRAPH_SESSION (self));
#line 1596 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_GRAPH_MESSAGE (message));
#line 1597 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = message;
#line 1597 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp1_ = _publishing_facebook_graph_message_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, PUBLISHING_FACEBOOK_GRAPH_SESSION_TYPE_GRAPH_MESSAGE_IMPL, PublishingFacebookGraphSessionGraphMessageImpl));
#line 1597 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	real_message = _tmp1_;
#line 1599 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp2_ = real_message;
#line 1599 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp3_ = _tmp2_->soup_message;
#line 1599 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp4_ = soup_message_get_uri (_tmp3_);
#line 1599 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp5_ = _tmp4_;
#line 1599 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp6_ = soup_uri_to_string (_tmp5_, FALSE);
#line 1599 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp7_ = _tmp6_;
#line 1599 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp8_ = g_strconcat ("making HTTP request to URI: ", _tmp7_, NULL);
#line 1599 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp9_ = _tmp8_;
#line 1599 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_debug ("FacebookPublishing.vala:1599: %s", _tmp9_);
#line 1599 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_free0 (_tmp9_);
#line 1599 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_free0 (_tmp7_);
#line 1601 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp10_ = real_message;
#line 1601 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp11_ = publishing_facebook_graph_session_graph_message_impl_prepare_for_transmission (_tmp10_);
#line 1601 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (_tmp11_) {
#line 9611 "FacebookPublishing.c"
		PublishingFacebookGraphMessage* _tmp12_ = NULL;
		SoupSession* _tmp13_ = NULL;
		PublishingFacebookGraphSessionGraphMessageImpl* _tmp14_ = NULL;
		SoupMessage* _tmp15_ = NULL;
		SoupMessage* _tmp16_ = NULL;
#line 1602 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp12_ = message;
#line 1602 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		publishing_facebook_graph_session_manage_message (self, _tmp12_);
#line 1603 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp13_ = self->priv->soup_session;
#line 1603 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp14_ = real_message;
#line 1603 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp15_ = _tmp14_->soup_message;
#line 1603 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp16_ = _g_object_ref0 (_tmp15_);
#line 1603 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		soup_session_queue_message (_tmp13_, _tmp16_, NULL, NULL);
#line 9631 "FacebookPublishing.c"
	}
#line 1596 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_publishing_facebook_graph_message_unref0 (real_message);
#line 9635 "FacebookPublishing.c"
}


void publishing_facebook_graph_session_stop_transactions (PublishingFacebookGraphSession* self) {
	SoupSession* _tmp0_ = NULL;
#line 1607 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_GRAPH_SESSION (self));
#line 1608 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = self->priv->soup_session;
#line 1608 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	soup_session_abort (_tmp0_);
#line 9647 "FacebookPublishing.c"
}


static PublishingFacebookGraphSessionGraphMessageImpl* publishing_facebook_graph_session_graph_message_impl_construct (GType object_type, PublishingFacebookGraphSession* host_session, PublishingRESTSupportHttpMethod method, const gchar* relative_uri, const gchar* access_token, PublishingFacebookEndpoint endpoint) {
	PublishingFacebookGraphSessionGraphMessageImpl* self = NULL;
	PublishingRESTSupportHttpMethod _tmp0_ = 0;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	PublishingFacebookGraphSession* _tmp3_ = NULL;
	gchar* endpoint_uri = NULL;
	PublishingFacebookEndpoint _tmp4_ = 0;
	gchar* _tmp5_ = NULL;
	GError * _inner_error_ = NULL;
#line 1311 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_val_if_fail (PUBLISHING_FACEBOOK_IS_GRAPH_SESSION (host_session), NULL);
#line 1311 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_val_if_fail (relative_uri != NULL, NULL);
#line 1311 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_val_if_fail (access_token != NULL, NULL);
#line 1311 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self = (PublishingFacebookGraphSessionGraphMessageImpl*) publishing_facebook_graph_message_construct (object_type);
#line 1313 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = method;
#line 1313 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->method = _tmp0_;
#line 1314 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp1_ = access_token;
#line 1314 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp2_ = g_strdup (_tmp1_);
#line 1314 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_free0 (self->access_token);
#line 1314 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->access_token = _tmp2_;
#line 1315 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp3_ = host_session;
#line 1315 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->host_session = _tmp3_;
#line 1316 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->bytes_so_far = 0;
#line 1318 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp4_ = endpoint;
#line 1318 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp5_ = publishing_facebook_endpoint_to_uri (_tmp4_);
#line 1318 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	endpoint_uri = _tmp5_;
#line 9693 "FacebookPublishing.c"
	{
		GRegex* starting_slashes = NULL;
		GRegex* _tmp6_ = NULL;
		gchar* _tmp7_ = NULL;
		GRegex* _tmp8_ = NULL;
		const gchar* _tmp9_ = NULL;
		gchar* _tmp10_ = NULL;
		const gchar* _tmp11_ = NULL;
		gchar* _tmp12_ = NULL;
		gchar* _tmp13_ = NULL;
		gchar* _tmp14_ = NULL;
#line 1320 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp6_ = g_regex_new ("^/+", 0, 0, &_inner_error_);
#line 1320 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		starting_slashes = _tmp6_;
#line 1320 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1320 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			if (_inner_error_->domain == G_REGEX_ERROR) {
#line 9713 "FacebookPublishing.c"
				goto __catch5_g_regex_error;
			}
#line 1320 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			_g_free0 (endpoint_uri);
#line 1320 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1320 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			g_clear_error (&_inner_error_);
#line 1320 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			return NULL;
#line 9724 "FacebookPublishing.c"
		}
#line 1321 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp8_ = starting_slashes;
#line 1321 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp9_ = relative_uri;
#line 1321 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp10_ = g_regex_replace (_tmp8_, _tmp9_, (gssize) -1, 0, "", 0, &_inner_error_);
#line 1321 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp7_ = _tmp10_;
#line 1321 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1321 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			_g_regex_unref0 (starting_slashes);
#line 1321 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			if (_inner_error_->domain == G_REGEX_ERROR) {
#line 9740 "FacebookPublishing.c"
				goto __catch5_g_regex_error;
			}
#line 1321 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			_g_regex_unref0 (starting_slashes);
#line 1321 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			_g_free0 (endpoint_uri);
#line 1321 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1321 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			g_clear_error (&_inner_error_);
#line 1321 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			return NULL;
#line 9753 "FacebookPublishing.c"
		}
#line 1321 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp11_ = endpoint_uri;
#line 1321 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp12_ = _tmp7_;
#line 1321 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp7_ = NULL;
#line 1321 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp13_ = _tmp12_;
#line 1321 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp14_ = g_strconcat (_tmp11_, _tmp13_, NULL);
#line 1321 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_g_free0 (self->uri);
#line 1321 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		self->uri = _tmp14_;
#line 1321 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_g_free0 (_tmp13_);
#line 1319 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_g_free0 (_tmp7_);
#line 1319 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_g_regex_unref0 (starting_slashes);
#line 9775 "FacebookPublishing.c"
	}
	goto __finally5;
	__catch5_g_regex_error:
	{
		GError* err = NULL;
#line 1319 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		err = _inner_error_;
#line 1319 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_inner_error_ = NULL;
#line 1323 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		g_assert_not_reached ();
#line 1319 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_g_error_free0 (err);
#line 9789 "FacebookPublishing.c"
	}
	__finally5:
#line 1319 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1319 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_g_free0 (endpoint_uri);
#line 1319 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1319 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		g_clear_error (&_inner_error_);
#line 1319 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		return NULL;
#line 9802 "FacebookPublishing.c"
	}
#line 1311 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_free0 (endpoint_uri);
#line 1311 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return self;
#line 9808 "FacebookPublishing.c"
}


static gboolean publishing_facebook_graph_session_graph_message_impl_real_prepare_for_transmission (PublishingFacebookGraphSessionGraphMessageImpl* self) {
	gboolean result = FALSE;
#line 1328 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	result = TRUE;
#line 1328 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return result;
#line 9818 "FacebookPublishing.c"
}


gboolean publishing_facebook_graph_session_graph_message_impl_prepare_for_transmission (PublishingFacebookGraphSessionGraphMessageImpl* self) {
#line 1327 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_val_if_fail (PUBLISHING_FACEBOOK_GRAPH_SESSION_IS_GRAPH_MESSAGE_IMPL (self), FALSE);
#line 1327 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return PUBLISHING_FACEBOOK_GRAPH_SESSION_GRAPH_MESSAGE_IMPL_GET_CLASS (self)->prepare_for_transmission (self);
#line 9827 "FacebookPublishing.c"
}


static gchar* publishing_facebook_graph_session_graph_message_impl_real_get_uri (PublishingFacebookGraphMessage* base) {
	PublishingFacebookGraphSessionGraphMessageImpl * self;
	gchar* result = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 1331 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_FACEBOOK_GRAPH_SESSION_TYPE_GRAPH_MESSAGE_IMPL, PublishingFacebookGraphSessionGraphMessageImpl);
#line 1332 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = self->uri;
#line 1332 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 1332 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	result = _tmp1_;
#line 1332 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return result;
#line 9846 "FacebookPublishing.c"
}


static gchar* publishing_facebook_graph_session_graph_message_impl_real_get_response_body (PublishingFacebookGraphMessage* base) {
	PublishingFacebookGraphSessionGraphMessageImpl * self;
	gchar* result = NULL;
	SoupMessage* _tmp0_ = NULL;
	SoupMessageBody* _tmp1_ = NULL;
	guint8* _tmp2_ = NULL;
	gint _tmp2__length1 = 0;
	gchar* _tmp3_ = NULL;
#line 1335 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_FACEBOOK_GRAPH_SESSION_TYPE_GRAPH_MESSAGE_IMPL, PublishingFacebookGraphSessionGraphMessageImpl);
#line 1336 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = self->soup_message;
#line 1336 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp1_ = _tmp0_->response_body;
#line 1336 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp2_ = _tmp1_->data;
#line 1336 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp2__length1 = (gint) _tmp1_->length;
#line 1336 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp3_ = g_strdup ((const gchar*) _tmp2_);
#line 1336 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	result = _tmp3_;
#line 1336 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return result;
#line 9874 "FacebookPublishing.c"
}


static void publishing_facebook_graph_session_graph_message_impl_on_wrote_body_data (PublishingFacebookGraphSessionGraphMessageImpl* self, SoupBuffer* chunk) {
	gint _tmp0_ = 0;
	SoupBuffer* _tmp1_ = NULL;
	gsize _tmp2_ = 0UL;
	gint _tmp3_ = 0;
	SoupMessage* _tmp4_ = NULL;
	SoupMessageBody* _tmp5_ = NULL;
	gint64 _tmp6_ = 0LL;
#line 1339 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_GRAPH_SESSION_IS_GRAPH_MESSAGE_IMPL (self));
#line 1339 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (chunk != NULL);
#line 1340 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = self->bytes_so_far;
#line 1340 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp1_ = chunk;
#line 1340 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp2_ = _tmp1_->length;
#line 1340 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->bytes_so_far = _tmp0_ + ((gint) _tmp2_);
#line 1342 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp3_ = self->bytes_so_far;
#line 1342 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp4_ = self->soup_message;
#line 1342 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp5_ = _tmp4_->request_body;
#line 1342 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp6_ = _tmp5_->length;
#line 1342 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_emit_by_name (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_FACEBOOK_TYPE_GRAPH_MESSAGE, PublishingFacebookGraphMessage), "data-transmitted", _tmp3_, (gint) _tmp6_);
#line 9908 "FacebookPublishing.c"
}


static void publishing_facebook_graph_session_graph_message_impl_class_init (PublishingFacebookGraphSessionGraphMessageImplClass * klass) {
#line 1303 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_graph_session_graph_message_impl_parent_class = g_type_class_peek_parent (klass);
#line 1303 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	((PublishingFacebookGraphMessageClass *) klass)->finalize = publishing_facebook_graph_session_graph_message_impl_finalize;
#line 1303 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	((PublishingFacebookGraphSessionGraphMessageImplClass *) klass)->prepare_for_transmission = publishing_facebook_graph_session_graph_message_impl_real_prepare_for_transmission;
#line 1303 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	((PublishingFacebookGraphMessageClass *) klass)->get_uri = publishing_facebook_graph_session_graph_message_impl_real_get_uri;
#line 1303 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	((PublishingFacebookGraphMessageClass *) klass)->get_response_body = publishing_facebook_graph_session_graph_message_impl_real_get_response_body;
#line 9923 "FacebookPublishing.c"
}


static void publishing_facebook_graph_session_graph_message_impl_instance_init (PublishingFacebookGraphSessionGraphMessageImpl * self) {
}


static void publishing_facebook_graph_session_graph_message_impl_finalize (PublishingFacebookGraphMessage* obj) {
	PublishingFacebookGraphSessionGraphMessageImpl * self;
#line 1303 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_FACEBOOK_GRAPH_SESSION_TYPE_GRAPH_MESSAGE_IMPL, PublishingFacebookGraphSessionGraphMessageImpl);
#line 1305 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_free0 (self->uri);
#line 1306 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_free0 (self->access_token);
#line 1307 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_object_unref0 (self->soup_message);
#line 1303 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	PUBLISHING_FACEBOOK_GRAPH_MESSAGE_CLASS (publishing_facebook_graph_session_graph_message_impl_parent_class)->finalize (obj);
#line 9943 "FacebookPublishing.c"
}


static GType publishing_facebook_graph_session_graph_message_impl_get_type (void) {
	static volatile gsize publishing_facebook_graph_session_graph_message_impl_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_facebook_graph_session_graph_message_impl_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingFacebookGraphSessionGraphMessageImplClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_facebook_graph_session_graph_message_impl_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingFacebookGraphSessionGraphMessageImpl), 0, (GInstanceInitFunc) publishing_facebook_graph_session_graph_message_impl_instance_init, NULL };
		GType publishing_facebook_graph_session_graph_message_impl_type_id;
		publishing_facebook_graph_session_graph_message_impl_type_id = g_type_register_static (PUBLISHING_FACEBOOK_TYPE_GRAPH_MESSAGE, "PublishingFacebookGraphSessionGraphMessageImpl", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
		g_once_init_leave (&publishing_facebook_graph_session_graph_message_impl_type_id__volatile, publishing_facebook_graph_session_graph_message_impl_type_id);
	}
	return publishing_facebook_graph_session_graph_message_impl_type_id__volatile;
}


static void _vala_SoupURI_free (SoupURI* self) {
#line 1347 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_boxed_free (soup_uri_get_type (), self);
#line 9962 "FacebookPublishing.c"
}


static PublishingFacebookGraphSessionGraphQueryMessage* publishing_facebook_graph_session_graph_query_message_construct (GType object_type, PublishingFacebookGraphSession* host_session, const gchar* relative_uri, const gchar* access_token) {
	PublishingFacebookGraphSessionGraphQueryMessage* self = NULL;
	PublishingFacebookGraphSession* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	SoupURI* destination_uri = NULL;
	const gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	const gchar* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
	gchar* _tmp8_ = NULL;
	SoupURI* _tmp9_ = NULL;
	SoupURI* _tmp10_ = NULL;
	PublishingRESTSupportHttpMethod _tmp11_ = 0;
	gchar* _tmp12_ = NULL;
	gchar* _tmp13_ = NULL;
	SoupMessage* _tmp14_ = NULL;
	SoupMessage* _tmp15_ = NULL;
#line 1347 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_val_if_fail (PUBLISHING_FACEBOOK_IS_GRAPH_SESSION (host_session), NULL);
#line 1347 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_val_if_fail (relative_uri != NULL, NULL);
#line 1347 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_val_if_fail (access_token != NULL, NULL);
#line 1349 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = host_session;
#line 1349 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp1_ = relative_uri;
#line 1349 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp2_ = access_token;
#line 1349 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self = (PublishingFacebookGraphSessionGraphQueryMessage*) publishing_facebook_graph_session_graph_message_impl_construct (object_type, _tmp0_, PUBLISHING_REST_SUPPORT_HTTP_METHOD_GET, _tmp1_, _tmp2_, PUBLISHING_FACEBOOK_ENDPOINT_DEFAULT);
#line 1351 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp3_ = G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_FACEBOOK_GRAPH_SESSION_TYPE_GRAPH_MESSAGE_IMPL, PublishingFacebookGraphSessionGraphMessageImpl)->uri;
#line 1351 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp4_ = g_strconcat (_tmp3_, "?access_token=", NULL);
#line 1351 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp5_ = _tmp4_;
#line 1351 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp6_ = access_token;
#line 1351 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp7_ = g_strconcat (_tmp5_, _tmp6_, NULL);
#line 1351 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp8_ = _tmp7_;
#line 1351 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp9_ = soup_uri_new (_tmp8_);
#line 1351 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp10_ = _tmp9_;
#line 1351 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_free0 (_tmp8_);
#line 1351 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_free0 (_tmp5_);
#line 1351 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	destination_uri = _tmp10_;
#line 1352 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp11_ = G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_FACEBOOK_GRAPH_SESSION_TYPE_GRAPH_MESSAGE_IMPL, PublishingFacebookGraphSessionGraphMessageImpl)->method;
#line 1352 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp12_ = publishing_rest_support_http_method_to_string (_tmp11_);
#line 1352 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp13_ = _tmp12_;
#line 1352 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp14_ = soup_message_new_from_uri (_tmp13_, destination_uri);
#line 1352 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_object_unref0 (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_FACEBOOK_GRAPH_SESSION_TYPE_GRAPH_MESSAGE_IMPL, PublishingFacebookGraphSessionGraphMessageImpl)->soup_message);
#line 1352 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_FACEBOOK_GRAPH_SESSION_TYPE_GRAPH_MESSAGE_IMPL, PublishingFacebookGraphSessionGraphMessageImpl)->soup_message = _tmp14_;
#line 1352 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_free0 (_tmp13_);
#line 1353 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp15_ = G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_FACEBOOK_GRAPH_SESSION_TYPE_GRAPH_MESSAGE_IMPL, PublishingFacebookGraphSessionGraphMessageImpl)->soup_message;
#line 1353 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_connect (_tmp15_, "wrote-body-data", (GCallback) _publishing_facebook_graph_session_graph_message_impl_on_wrote_body_data_soup_message_wrote_body_data, G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_FACEBOOK_GRAPH_SESSION_TYPE_GRAPH_MESSAGE_IMPL, PublishingFacebookGraphSessionGraphMessageImpl));
#line 1347 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	__vala_SoupURI_free0 (destination_uri);
#line 1347 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return self;
#line 10043 "FacebookPublishing.c"
}


static PublishingFacebookGraphSessionGraphQueryMessage* publishing_facebook_graph_session_graph_query_message_new (PublishingFacebookGraphSession* host_session, const gchar* relative_uri, const gchar* access_token) {
#line 1347 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return publishing_facebook_graph_session_graph_query_message_construct (PUBLISHING_FACEBOOK_GRAPH_SESSION_TYPE_GRAPH_QUERY_MESSAGE, host_session, relative_uri, access_token);
#line 10050 "FacebookPublishing.c"
}


static void publishing_facebook_graph_session_graph_query_message_class_init (PublishingFacebookGraphSessionGraphQueryMessageClass * klass) {
#line 1346 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_graph_session_graph_query_message_parent_class = g_type_class_peek_parent (klass);
#line 10057 "FacebookPublishing.c"
}


static void publishing_facebook_graph_session_graph_query_message_instance_init (PublishingFacebookGraphSessionGraphQueryMessage * self) {
}


static GType publishing_facebook_graph_session_graph_query_message_get_type (void) {
	static volatile gsize publishing_facebook_graph_session_graph_query_message_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_facebook_graph_session_graph_query_message_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingFacebookGraphSessionGraphQueryMessageClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_facebook_graph_session_graph_query_message_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingFacebookGraphSessionGraphQueryMessage), 0, (GInstanceInitFunc) publishing_facebook_graph_session_graph_query_message_instance_init, NULL };
		GType publishing_facebook_graph_session_graph_query_message_type_id;
		publishing_facebook_graph_session_graph_query_message_type_id = g_type_register_static (PUBLISHING_FACEBOOK_GRAPH_SESSION_TYPE_GRAPH_MESSAGE_IMPL, "PublishingFacebookGraphSessionGraphQueryMessage", &g_define_type_info, 0);
		g_once_init_leave (&publishing_facebook_graph_session_graph_query_message_type_id__volatile, publishing_facebook_graph_session_graph_query_message_type_id);
	}
	return publishing_facebook_graph_session_graph_query_message_type_id__volatile;
}


static PublishingFacebookGraphSessionGraphEndpointProbeMessage* publishing_facebook_graph_session_graph_endpoint_probe_message_construct (GType object_type, PublishingFacebookGraphSession* host_session) {
	PublishingFacebookGraphSessionGraphEndpointProbeMessage* self = NULL;
	PublishingFacebookGraphSession* _tmp0_ = NULL;
	PublishingRESTSupportHttpMethod _tmp1_ = 0;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	SoupURI* _tmp5_ = NULL;
	SoupURI* _tmp6_ = NULL;
	SoupMessage* _tmp7_ = NULL;
	SoupMessage* _tmp8_ = NULL;
#line 1358 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_val_if_fail (PUBLISHING_FACEBOOK_IS_GRAPH_SESSION (host_session), NULL);
#line 1359 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = host_session;
#line 1359 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self = (PublishingFacebookGraphSessionGraphEndpointProbeMessage*) publishing_facebook_graph_session_graph_message_impl_construct (object_type, _tmp0_, PUBLISHING_REST_SUPPORT_HTTP_METHOD_GET, "/", "", PUBLISHING_FACEBOOK_ENDPOINT_TEST_CONNECTION);
#line 1362 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp1_ = G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_FACEBOOK_GRAPH_SESSION_TYPE_GRAPH_MESSAGE_IMPL, PublishingFacebookGraphSessionGraphMessageImpl)->method;
#line 1362 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp2_ = publishing_rest_support_http_method_to_string (_tmp1_);
#line 1362 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp3_ = _tmp2_;
#line 1362 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp4_ = G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_FACEBOOK_GRAPH_SESSION_TYPE_GRAPH_MESSAGE_IMPL, PublishingFacebookGraphSessionGraphMessageImpl)->uri;
#line 1362 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp5_ = soup_uri_new (_tmp4_);
#line 1362 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp6_ = _tmp5_;
#line 1362 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp7_ = soup_message_new_from_uri (_tmp3_, _tmp6_);
#line 1362 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_object_unref0 (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_FACEBOOK_GRAPH_SESSION_TYPE_GRAPH_MESSAGE_IMPL, PublishingFacebookGraphSessionGraphMessageImpl)->soup_message);
#line 1362 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_FACEBOOK_GRAPH_SESSION_TYPE_GRAPH_MESSAGE_IMPL, PublishingFacebookGraphSessionGraphMessageImpl)->soup_message = _tmp7_;
#line 1362 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	__vala_SoupURI_free0 (_tmp6_);
#line 1362 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_free0 (_tmp3_);
#line 1363 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp8_ = G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_FACEBOOK_GRAPH_SESSION_TYPE_GRAPH_MESSAGE_IMPL, PublishingFacebookGraphSessionGraphMessageImpl)->soup_message;
#line 1363 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_connect (_tmp8_, "wrote-body-data", (GCallback) _publishing_facebook_graph_session_graph_message_impl_on_wrote_body_data_soup_message_wrote_body_data, G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_FACEBOOK_GRAPH_SESSION_TYPE_GRAPH_MESSAGE_IMPL, PublishingFacebookGraphSessionGraphMessageImpl));
#line 1358 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return self;
#line 10122 "FacebookPublishing.c"
}


static PublishingFacebookGraphSessionGraphEndpointProbeMessage* publishing_facebook_graph_session_graph_endpoint_probe_message_new (PublishingFacebookGraphSession* host_session) {
#line 1358 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return publishing_facebook_graph_session_graph_endpoint_probe_message_construct (PUBLISHING_FACEBOOK_GRAPH_SESSION_TYPE_GRAPH_ENDPOINT_PROBE_MESSAGE, host_session);
#line 10129 "FacebookPublishing.c"
}


static void publishing_facebook_graph_session_graph_endpoint_probe_message_class_init (PublishingFacebookGraphSessionGraphEndpointProbeMessageClass * klass) {
#line 1357 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_graph_session_graph_endpoint_probe_message_parent_class = g_type_class_peek_parent (klass);
#line 10136 "FacebookPublishing.c"
}


static void publishing_facebook_graph_session_graph_endpoint_probe_message_instance_init (PublishingFacebookGraphSessionGraphEndpointProbeMessage * self) {
}


static GType publishing_facebook_graph_session_graph_endpoint_probe_message_get_type (void) {
	static volatile gsize publishing_facebook_graph_session_graph_endpoint_probe_message_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_facebook_graph_session_graph_endpoint_probe_message_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingFacebookGraphSessionGraphEndpointProbeMessageClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_facebook_graph_session_graph_endpoint_probe_message_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingFacebookGraphSessionGraphEndpointProbeMessage), 0, (GInstanceInitFunc) publishing_facebook_graph_session_graph_endpoint_probe_message_instance_init, NULL };
		GType publishing_facebook_graph_session_graph_endpoint_probe_message_type_id;
		publishing_facebook_graph_session_graph_endpoint_probe_message_type_id = g_type_register_static (PUBLISHING_FACEBOOK_GRAPH_SESSION_TYPE_GRAPH_MESSAGE_IMPL, "PublishingFacebookGraphSessionGraphEndpointProbeMessage", &g_define_type_info, 0);
		g_once_init_leave (&publishing_facebook_graph_session_graph_endpoint_probe_message_type_id__volatile, publishing_facebook_graph_session_graph_endpoint_probe_message_type_id);
	}
	return publishing_facebook_graph_session_graph_endpoint_probe_message_type_id__volatile;
}


static gchar* g_date_time_to_string (GDateTime* self) {
	gchar* result = NULL;
	gchar* _tmp0_ = NULL;
#line 2785 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 2786 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp0_ = g_date_time_format (self, "%FT%H:%M:%S%z");
#line 2786 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	result = _tmp0_;
#line 2786 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	return result;
#line 10167 "FacebookPublishing.c"
}


static void _vala_SoupMultipart_free (SoupMultipart* self) {
#line 1371 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_boxed_free (soup_multipart_get_type (), self);
#line 10174 "FacebookPublishing.c"
}


static void _vala_SoupBuffer_free (SoupBuffer* self) {
#line 1371 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_boxed_free (soup_buffer_get_type (), self);
#line 10181 "FacebookPublishing.c"
}


static PublishingFacebookGraphSessionGraphUploadMessage* publishing_facebook_graph_session_graph_upload_message_construct (GType object_type, PublishingFacebookGraphSession* host_session, const gchar* access_token, const gchar* relative_uri, SpitPublishingPublishable* publishable, gboolean suppress_titling, const gchar* resource_privacy) {
	PublishingFacebookGraphSessionGraphUploadMessage* self = NULL;
	PublishingFacebookEndpoint _tmp0_ = 0;
	SpitPublishingPublishable* _tmp1_ = NULL;
	SpitPublishingPublisherMediaType _tmp2_ = 0;
	PublishingFacebookGraphSession* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
	gboolean _tmp6_ = FALSE;
	SpitPublishingPublishable* _tmp7_ = NULL;
	SpitPublishingPublisherMediaType _tmp8_ = 0;
	SpitPublishingPublishable* _tmp10_ = NULL;
	SpitPublishingPublishable* _tmp11_ = NULL;
	PublishingRESTSupportHttpMethod _tmp21_ = 0;
	gchar* _tmp22_ = NULL;
	gchar* _tmp23_ = NULL;
	const gchar* _tmp24_ = NULL;
	SoupURI* _tmp25_ = NULL;
	SoupURI* _tmp26_ = NULL;
	SoupMessage* _tmp27_ = NULL;
	SoupMessage* _tmp28_ = NULL;
	guint8* payload = NULL;
	GMappedFile* _tmp29_ = NULL;
	gchar* _tmp30_ = NULL;
	gint payload_length1 = 0;
	gint _payload_size_ = 0;
	GMappedFile* _tmp31_ = NULL;
	gsize _tmp32_ = 0UL;
	gint _tmp33_ = 0;
	SoupBuffer* image_data = NULL;
	guint8* _tmp34_ = NULL;
	gint _tmp34__length1 = 0;
	SoupBuffer* _tmp35_ = NULL;
	SoupMultipart* mp_envelope = NULL;
	SoupMultipart* _tmp36_ = NULL;
	SoupMultipart* _tmp37_ = NULL;
	const gchar* _tmp38_ = NULL;
	SpitPublishingPublishable* _tmp39_ = NULL;
	SpitPublishingPublisherMediaType _tmp40_ = 0;
	gchar* publishable_title = NULL;
	SpitPublishingPublishable* _tmp43_ = NULL;
	gchar* _tmp44_ = NULL;
	gboolean _tmp45_ = FALSE;
	gboolean _tmp46_ = FALSE;
	gchar* publishable_comment = NULL;
	SpitPublishingPublishable* _tmp50_ = NULL;
	gchar* _tmp51_ = NULL;
	gboolean _tmp52_ = FALSE;
	gboolean _tmp53_ = FALSE;
	gboolean _tmp57_ = FALSE;
	const gchar* _tmp64_ = NULL;
	SpitPublishingPublishable* _tmp65_ = NULL;
	SpitPublishingPublisherMediaType _tmp66_ = 0;
	gchar* source_file_mime_type = NULL;
	gchar* _tmp67_ = NULL;
	SoupMultipart* _tmp68_ = NULL;
	SpitPublishingPublishable* _tmp69_ = NULL;
	GFile* _tmp70_ = NULL;
	GFile* _tmp71_ = NULL;
	gchar* _tmp72_ = NULL;
	gchar* _tmp73_ = NULL;
	const gchar* _tmp74_ = NULL;
	SoupBuffer* _tmp75_ = NULL;
	SoupMultipart* _tmp76_ = NULL;
	SoupMessage* _tmp77_ = NULL;
	SoupMessageHeaders* _tmp78_ = NULL;
	SoupMessage* _tmp79_ = NULL;
	SoupMessageBody* _tmp80_ = NULL;
	GError * _inner_error_ = NULL;
#line 1371 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_val_if_fail (PUBLISHING_FACEBOOK_IS_GRAPH_SESSION (host_session), NULL);
#line 1371 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_val_if_fail (access_token != NULL, NULL);
#line 1371 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_val_if_fail (relative_uri != NULL, NULL);
#line 1371 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_val_if_fail (SPIT_PUBLISHING_IS_PUBLISHABLE (publishable), NULL);
#line 1375 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp1_ = publishable;
#line 1375 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp2_ = spit_publishing_publishable_get_media_type (_tmp1_);
#line 1375 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (_tmp2_ == SPIT_PUBLISHING_PUBLISHER_MEDIA_TYPE_VIDEO) {
#line 1376 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp0_ = PUBLISHING_FACEBOOK_ENDPOINT_VIDEO;
#line 10270 "FacebookPublishing.c"
	} else {
#line 1376 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp0_ = PUBLISHING_FACEBOOK_ENDPOINT_DEFAULT;
#line 10274 "FacebookPublishing.c"
	}
#line 1374 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp3_ = host_session;
#line 1374 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp4_ = relative_uri;
#line 1374 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp5_ = access_token;
#line 1374 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self = (PublishingFacebookGraphSessionGraphUploadMessage*) publishing_facebook_graph_session_graph_message_impl_construct (object_type, _tmp3_, PUBLISHING_REST_SUPPORT_HTTP_METHOD_POST, _tmp4_, _tmp5_, _tmp0_);
#line 1381 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp7_ = publishable;
#line 1381 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp8_ = spit_publishing_publishable_get_media_type (_tmp7_);
#line 1381 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (_tmp8_ != SPIT_PUBLISHING_PUBLISHER_MEDIA_TYPE_VIDEO) {
#line 1381 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp6_ = TRUE;
#line 10292 "FacebookPublishing.c"
	} else {
		const gchar* _tmp9_ = NULL;
#line 1382 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp9_ = resource_privacy;
#line 1382 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp6_ = _tmp9_ != NULL;
#line 10299 "FacebookPublishing.c"
	}
#line 1381 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_vala_assert (_tmp6_, "publishable.get_media_type() != Spit.Publishing.Publisher.MediaType.VIDEO ||                 resource_privacy != null");
#line 1384 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp10_ = publishable;
#line 1384 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp11_ = _g_object_ref0 (_tmp10_);
#line 1384 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_object_unref0 (self->priv->publishable);
#line 1384 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->publishable = _tmp11_;
#line 10311 "FacebookPublishing.c"
	{
		GMappedFile* _tmp12_ = NULL;
		SpitPublishingPublishable* _tmp13_ = NULL;
		GFile* _tmp14_ = NULL;
		GFile* _tmp15_ = NULL;
		gchar* _tmp16_ = NULL;
		gchar* _tmp17_ = NULL;
		GMappedFile* _tmp18_ = NULL;
		GMappedFile* _tmp19_ = NULL;
		GMappedFile* _tmp20_ = NULL;
#line 1388 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp13_ = publishable;
#line 1388 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp14_ = spit_publishing_publishable_get_serialized_file (_tmp13_);
#line 1388 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp15_ = _tmp14_;
#line 1388 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp16_ = g_file_get_path (_tmp15_);
#line 1388 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp17_ = _tmp16_;
#line 1388 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp18_ = g_mapped_file_new (_tmp17_, FALSE, &_inner_error_);
#line 1388 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp19_ = _tmp18_;
#line 1388 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_g_free0 (_tmp17_);
#line 1388 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_g_object_unref0 (_tmp15_);
#line 1388 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp12_ = _tmp19_;
#line 1388 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1388 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			if (_inner_error_->domain == G_FILE_ERROR) {
#line 10346 "FacebookPublishing.c"
				goto __catch6_g_file_error;
			}
#line 1388 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1388 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			g_clear_error (&_inner_error_);
#line 1388 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			return NULL;
#line 10355 "FacebookPublishing.c"
		}
#line 1388 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp20_ = _tmp12_;
#line 1388 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp12_ = NULL;
#line 1388 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_g_mapped_file_unref0 (self->priv->mapped_file);
#line 1388 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		self->priv->mapped_file = _tmp20_;
#line 1387 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_g_mapped_file_unref0 (_tmp12_);
#line 10367 "FacebookPublishing.c"
	}
	goto __finally6;
	__catch6_g_file_error:
	{
		GError* e = NULL;
#line 1387 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		e = _inner_error_;
#line 1387 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_inner_error_ = NULL;
#line 1391 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_g_error_free0 (e);
#line 1391 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		return self;
#line 10381 "FacebookPublishing.c"
	}
	__finally6:
#line 1387 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1387 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1387 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		g_clear_error (&_inner_error_);
#line 1387 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		return NULL;
#line 10392 "FacebookPublishing.c"
	}
#line 1394 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp21_ = G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_FACEBOOK_GRAPH_SESSION_TYPE_GRAPH_MESSAGE_IMPL, PublishingFacebookGraphSessionGraphMessageImpl)->method;
#line 1394 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp22_ = publishing_rest_support_http_method_to_string (_tmp21_);
#line 1394 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp23_ = _tmp22_;
#line 1394 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp24_ = G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_FACEBOOK_GRAPH_SESSION_TYPE_GRAPH_MESSAGE_IMPL, PublishingFacebookGraphSessionGraphMessageImpl)->uri;
#line 1394 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp25_ = soup_uri_new (_tmp24_);
#line 1394 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp26_ = _tmp25_;
#line 1394 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp27_ = soup_message_new_from_uri (_tmp23_, _tmp26_);
#line 1394 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_object_unref0 (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_FACEBOOK_GRAPH_SESSION_TYPE_GRAPH_MESSAGE_IMPL, PublishingFacebookGraphSessionGraphMessageImpl)->soup_message);
#line 1394 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_FACEBOOK_GRAPH_SESSION_TYPE_GRAPH_MESSAGE_IMPL, PublishingFacebookGraphSessionGraphMessageImpl)->soup_message = _tmp27_;
#line 1394 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	__vala_SoupURI_free0 (_tmp26_);
#line 1394 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_free0 (_tmp23_);
#line 1395 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp28_ = G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_FACEBOOK_GRAPH_SESSION_TYPE_GRAPH_MESSAGE_IMPL, PublishingFacebookGraphSessionGraphMessageImpl)->soup_message;
#line 1395 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_connect (_tmp28_, "wrote-body-data", (GCallback) _publishing_facebook_graph_session_graph_message_impl_on_wrote_body_data_soup_message_wrote_body_data, G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_FACEBOOK_GRAPH_SESSION_TYPE_GRAPH_MESSAGE_IMPL, PublishingFacebookGraphSessionGraphMessageImpl));
#line 1397 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp29_ = self->priv->mapped_file;
#line 1397 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp30_ = g_mapped_file_get_contents (_tmp29_);
#line 1397 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	payload = (guint8*) _tmp30_;
#line 1397 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	payload_length1 = -1;
#line 1397 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_payload_size_ = payload_length1;
#line 1398 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp31_ = self->priv->mapped_file;
#line 1398 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp32_ = g_mapped_file_get_length (_tmp31_);
#line 1398 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	payload_length1 = (gint) _tmp32_;
#line 1398 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp33_ = payload_length1;
#line 1400 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp34_ = payload;
#line 1400 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp34__length1 = payload_length1;
#line 1400 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp35_ = soup_buffer_new (SOUP_MEMORY_TEMPORARY, _tmp34_, _tmp34__length1);
#line 1400 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	image_data = _tmp35_;
#line 1402 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp36_ = soup_multipart_new ("multipart/form-data");
#line 1402 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	mp_envelope = _tmp36_;
#line 1404 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp37_ = mp_envelope;
#line 1404 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp38_ = access_token;
#line 1404 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	soup_multipart_append_form_string (_tmp37_, "access_token", _tmp38_);
#line 1406 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp39_ = publishable;
#line 1406 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp40_ = spit_publishing_publishable_get_media_type (_tmp39_);
#line 1406 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (_tmp40_ == SPIT_PUBLISHING_PUBLISHER_MEDIA_TYPE_VIDEO) {
#line 10462 "FacebookPublishing.c"
		SoupMultipart* _tmp41_ = NULL;
		const gchar* _tmp42_ = NULL;
#line 1407 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp41_ = mp_envelope;
#line 1407 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp42_ = resource_privacy;
#line 1407 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		soup_multipart_append_form_string (_tmp41_, "privacy", _tmp42_);
#line 10471 "FacebookPublishing.c"
	}
#line 1410 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp43_ = publishable;
#line 1410 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp44_ = spit_publishing_publishable_get_param_string (_tmp43_, "title");
#line 1410 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishable_title = _tmp44_;
#line 1411 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp46_ = suppress_titling;
#line 1411 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (!_tmp46_) {
#line 10483 "FacebookPublishing.c"
		const gchar* _tmp47_ = NULL;
#line 1411 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp47_ = publishable_title;
#line 1411 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp45_ = _tmp47_ != NULL;
#line 10489 "FacebookPublishing.c"
	} else {
#line 1411 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp45_ = FALSE;
#line 10493 "FacebookPublishing.c"
	}
#line 1411 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (_tmp45_) {
#line 10497 "FacebookPublishing.c"
		SoupMultipart* _tmp48_ = NULL;
		const gchar* _tmp49_ = NULL;
#line 1412 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp48_ = mp_envelope;
#line 1412 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp49_ = publishable_title;
#line 1412 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		soup_multipart_append_form_string (_tmp48_, "name", _tmp49_);
#line 10506 "FacebookPublishing.c"
	}
#line 1415 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp50_ = publishable;
#line 1415 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp51_ = spit_publishing_publishable_get_param_string (_tmp50_, "comment");
#line 1415 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishable_comment = _tmp51_;
#line 1416 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp53_ = suppress_titling;
#line 1416 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (!_tmp53_) {
#line 10518 "FacebookPublishing.c"
		const gchar* _tmp54_ = NULL;
#line 1416 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp54_ = publishable_comment;
#line 1416 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp52_ = _tmp54_ != NULL;
#line 10524 "FacebookPublishing.c"
	} else {
#line 1416 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp52_ = FALSE;
#line 10528 "FacebookPublishing.c"
	}
#line 1416 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (_tmp52_) {
#line 10532 "FacebookPublishing.c"
		SoupMultipart* _tmp55_ = NULL;
		const gchar* _tmp56_ = NULL;
#line 1417 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp55_ = mp_envelope;
#line 1417 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp56_ = publishable_comment;
#line 1417 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		soup_multipart_append_form_string (_tmp55_, "message", _tmp56_);
#line 10541 "FacebookPublishing.c"
	}
#line 1420 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp57_ = suppress_titling;
#line 1420 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (!_tmp57_) {
#line 10547 "FacebookPublishing.c"
		SoupMultipart* _tmp58_ = NULL;
		SpitPublishingPublishable* _tmp59_ = NULL;
		GDateTime* _tmp60_ = NULL;
		GDateTime* _tmp61_ = NULL;
		gchar* _tmp62_ = NULL;
		gchar* _tmp63_ = NULL;
#line 1421 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp58_ = mp_envelope;
#line 1421 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp59_ = publishable;
#line 1421 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp60_ = spit_publishing_publishable_get_exposure_date_time (_tmp59_);
#line 1421 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp61_ = _tmp60_;
#line 1421 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp62_ = g_date_time_to_string (_tmp61_);
#line 1421 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp63_ = _tmp62_;
#line 1421 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		soup_multipart_append_form_string (_tmp58_, "backdated_time", _tmp63_);
#line 1421 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_g_free0 (_tmp63_);
#line 1421 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_g_date_time_unref0 (_tmp61_);
#line 10572 "FacebookPublishing.c"
	}
#line 1424 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp65_ = publishable;
#line 1424 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp66_ = spit_publishing_publishable_get_media_type (_tmp65_);
#line 1424 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (_tmp66_ == SPIT_PUBLISHING_PUBLISHER_MEDIA_TYPE_VIDEO) {
#line 1425 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp64_ = "video";
#line 10582 "FacebookPublishing.c"
	} else {
#line 1425 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp64_ = "image/jpeg";
#line 10586 "FacebookPublishing.c"
	}
#line 1423 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp67_ = g_strdup (_tmp64_);
#line 1423 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	source_file_mime_type = _tmp67_;
#line 1426 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp68_ = mp_envelope;
#line 1426 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp69_ = publishable;
#line 1426 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp70_ = spit_publishing_publishable_get_serialized_file (_tmp69_);
#line 1426 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp71_ = _tmp70_;
#line 1426 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp72_ = g_file_get_basename (_tmp71_);
#line 1426 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp73_ = _tmp72_;
#line 1426 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp74_ = source_file_mime_type;
#line 1426 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp75_ = image_data;
#line 1426 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	soup_multipart_append_form_file (_tmp68_, "source", _tmp73_, _tmp74_, _tmp75_);
#line 1426 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_free0 (_tmp73_);
#line 1426 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_object_unref0 (_tmp71_);
#line 1429 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp76_ = mp_envelope;
#line 1429 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp77_ = G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_FACEBOOK_GRAPH_SESSION_TYPE_GRAPH_MESSAGE_IMPL, PublishingFacebookGraphSessionGraphMessageImpl)->soup_message;
#line 1429 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp78_ = _tmp77_->request_headers;
#line 1429 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp79_ = G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_FACEBOOK_GRAPH_SESSION_TYPE_GRAPH_MESSAGE_IMPL, PublishingFacebookGraphSessionGraphMessageImpl)->soup_message;
#line 1429 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp80_ = _tmp79_->request_body;
#line 1429 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	soup_multipart_to_message (_tmp76_, _tmp78_, _tmp80_);
#line 1371 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_free0 (source_file_mime_type);
#line 1371 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_free0 (publishable_comment);
#line 1371 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_free0 (publishable_title);
#line 1371 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	__vala_SoupMultipart_free0 (mp_envelope);
#line 1371 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	__vala_SoupBuffer_free0 (image_data);
#line 1371 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return self;
#line 10638 "FacebookPublishing.c"
}


static PublishingFacebookGraphSessionGraphUploadMessage* publishing_facebook_graph_session_graph_upload_message_new (PublishingFacebookGraphSession* host_session, const gchar* access_token, const gchar* relative_uri, SpitPublishingPublishable* publishable, gboolean suppress_titling, const gchar* resource_privacy) {
#line 1371 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return publishing_facebook_graph_session_graph_upload_message_construct (PUBLISHING_FACEBOOK_GRAPH_SESSION_TYPE_GRAPH_UPLOAD_MESSAGE, host_session, access_token, relative_uri, publishable, suppress_titling, resource_privacy);
#line 10645 "FacebookPublishing.c"
}


static gboolean publishing_facebook_graph_session_graph_upload_message_real_prepare_for_transmission (PublishingFacebookGraphSessionGraphMessageImpl* base) {
	PublishingFacebookGraphSessionGraphUploadMessage * self;
	gboolean result = FALSE;
	GMappedFile* _tmp0_ = NULL;
#line 1432 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_FACEBOOK_GRAPH_SESSION_TYPE_GRAPH_UPLOAD_MESSAGE, PublishingFacebookGraphSessionGraphUploadMessage);
#line 1433 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = self->priv->mapped_file;
#line 1433 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (_tmp0_ == NULL) {
#line 10659 "FacebookPublishing.c"
		SpitPublishingPublishable* _tmp1_ = NULL;
		GFile* _tmp2_ = NULL;
		GFile* _tmp3_ = NULL;
		gchar* _tmp4_ = NULL;
		gchar* _tmp5_ = NULL;
		gchar* _tmp6_ = NULL;
		gchar* _tmp7_ = NULL;
		GError* _tmp8_ = NULL;
		GError* _tmp9_ = NULL;
#line 1434 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp1_ = self->priv->publishable;
#line 1434 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp2_ = spit_publishing_publishable_get_serialized_file (_tmp1_);
#line 1434 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp3_ = _tmp2_;
#line 1434 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp4_ = g_file_get_path (_tmp3_);
#line 1434 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp5_ = _tmp4_;
#line 1434 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp6_ = g_strdup_printf ("File %s is unavailable.", _tmp5_);
#line 1434 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp7_ = _tmp6_;
#line 1434 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp8_ = g_error_new_literal (SPIT_PUBLISHING_PUBLISHING_ERROR, SPIT_PUBLISHING_PUBLISHING_ERROR_LOCAL_FILE_ERROR, _tmp7_);
#line 1434 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp9_ = _tmp8_;
#line 1434 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		g_signal_emit_by_name (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_FACEBOOK_TYPE_GRAPH_MESSAGE, PublishingFacebookGraphMessage), "failed", _tmp9_);
#line 1434 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_g_error_free0 (_tmp9_);
#line 1434 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_g_free0 (_tmp7_);
#line 1434 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_g_free0 (_tmp5_);
#line 1434 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_g_object_unref0 (_tmp3_);
#line 1436 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		result = FALSE;
#line 1436 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		return result;
#line 10701 "FacebookPublishing.c"
	} else {
#line 1438 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		result = TRUE;
#line 1438 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		return result;
#line 10707 "FacebookPublishing.c"
	}
}


static void publishing_facebook_graph_session_graph_upload_message_class_init (PublishingFacebookGraphSessionGraphUploadMessageClass * klass) {
#line 1367 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_graph_session_graph_upload_message_parent_class = g_type_class_peek_parent (klass);
#line 1367 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	((PublishingFacebookGraphMessageClass *) klass)->finalize = publishing_facebook_graph_session_graph_upload_message_finalize;
#line 1367 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_type_class_add_private (klass, sizeof (PublishingFacebookGraphSessionGraphUploadMessagePrivate));
#line 1367 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	((PublishingFacebookGraphSessionGraphMessageImplClass *) klass)->prepare_for_transmission = publishing_facebook_graph_session_graph_upload_message_real_prepare_for_transmission;
#line 10721 "FacebookPublishing.c"
}


static void publishing_facebook_graph_session_graph_upload_message_instance_init (PublishingFacebookGraphSessionGraphUploadMessage * self) {
#line 1367 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv = PUBLISHING_FACEBOOK_GRAPH_SESSION_GRAPH_UPLOAD_MESSAGE_GET_PRIVATE (self);
#line 1368 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->mapped_file = NULL;
#line 10730 "FacebookPublishing.c"
}


static void publishing_facebook_graph_session_graph_upload_message_finalize (PublishingFacebookGraphMessage* obj) {
	PublishingFacebookGraphSessionGraphUploadMessage * self;
#line 1367 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_FACEBOOK_GRAPH_SESSION_TYPE_GRAPH_UPLOAD_MESSAGE, PublishingFacebookGraphSessionGraphUploadMessage);
#line 1368 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_mapped_file_unref0 (self->priv->mapped_file);
#line 1369 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_object_unref0 (self->priv->publishable);
#line 1367 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	PUBLISHING_FACEBOOK_GRAPH_MESSAGE_CLASS (publishing_facebook_graph_session_graph_upload_message_parent_class)->finalize (obj);
#line 10744 "FacebookPublishing.c"
}


static GType publishing_facebook_graph_session_graph_upload_message_get_type (void) {
	static volatile gsize publishing_facebook_graph_session_graph_upload_message_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_facebook_graph_session_graph_upload_message_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingFacebookGraphSessionGraphUploadMessageClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_facebook_graph_session_graph_upload_message_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingFacebookGraphSessionGraphUploadMessage), 0, (GInstanceInitFunc) publishing_facebook_graph_session_graph_upload_message_instance_init, NULL };
		GType publishing_facebook_graph_session_graph_upload_message_type_id;
		publishing_facebook_graph_session_graph_upload_message_type_id = g_type_register_static (PUBLISHING_FACEBOOK_GRAPH_SESSION_TYPE_GRAPH_MESSAGE_IMPL, "PublishingFacebookGraphSessionGraphUploadMessage", &g_define_type_info, 0);
		g_once_init_leave (&publishing_facebook_graph_session_graph_upload_message_type_id__volatile, publishing_facebook_graph_session_graph_upload_message_type_id);
	}
	return publishing_facebook_graph_session_graph_upload_message_type_id__volatile;
}


static PublishingFacebookGraphSessionGraphCreateAlbumMessage* publishing_facebook_graph_session_graph_create_album_message_construct (GType object_type, PublishingFacebookGraphSession* host_session, const gchar* access_token, const gchar* album_name, const gchar* album_privacy) {
	PublishingFacebookGraphSessionGraphCreateAlbumMessage* self = NULL;
	PublishingFacebookGraphSession* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	const gchar* _tmp3_ = NULL;
	PublishingRESTSupportHttpMethod _tmp5_ = 0;
	gchar* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
	const gchar* _tmp8_ = NULL;
	SoupURI* _tmp9_ = NULL;
	SoupURI* _tmp10_ = NULL;
	SoupMessage* _tmp11_ = NULL;
	SoupMultipart* mp_envelope = NULL;
	SoupMultipart* _tmp12_ = NULL;
	const gchar* _tmp13_ = NULL;
	const gchar* _tmp14_ = NULL;
	const gchar* _tmp15_ = NULL;
	SoupMessage* _tmp16_ = NULL;
	SoupMessageHeaders* _tmp17_ = NULL;
	SoupMessage* _tmp18_ = NULL;
	SoupMessageBody* _tmp19_ = NULL;
#line 1444 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_val_if_fail (PUBLISHING_FACEBOOK_IS_GRAPH_SESSION (host_session), NULL);
#line 1444 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_val_if_fail (access_token != NULL, NULL);
#line 1444 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_val_if_fail (album_name != NULL, NULL);
#line 1444 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_val_if_fail (album_privacy != NULL, NULL);
#line 1446 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = host_session;
#line 1446 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp1_ = access_token;
#line 1446 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self = (PublishingFacebookGraphSessionGraphCreateAlbumMessage*) publishing_facebook_graph_session_graph_message_impl_construct (object_type, _tmp0_, PUBLISHING_REST_SUPPORT_HTTP_METHOD_POST, "/me/albums", _tmp1_, PUBLISHING_FACEBOOK_ENDPOINT_DEFAULT);
#line 1448 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp3_ = album_privacy;
#line 1448 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (_tmp3_ != NULL) {
#line 10800 "FacebookPublishing.c"
		const gchar* _tmp4_ = NULL;
#line 1448 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp4_ = album_privacy;
#line 1448 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp2_ = g_strcmp0 (_tmp4_, "") != 0;
#line 10806 "FacebookPublishing.c"
	} else {
#line 1448 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp2_ = FALSE;
#line 10810 "FacebookPublishing.c"
	}
#line 1448 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_vala_assert (_tmp2_, "album_privacy != null && album_privacy != \"\"");
#line 1450 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp5_ = G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_FACEBOOK_GRAPH_SESSION_TYPE_GRAPH_MESSAGE_IMPL, PublishingFacebookGraphSessionGraphMessageImpl)->method;
#line 1450 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp6_ = publishing_rest_support_http_method_to_string (_tmp5_);
#line 1450 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp7_ = _tmp6_;
#line 1450 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp8_ = G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_FACEBOOK_GRAPH_SESSION_TYPE_GRAPH_MESSAGE_IMPL, PublishingFacebookGraphSessionGraphMessageImpl)->uri;
#line 1450 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp9_ = soup_uri_new (_tmp8_);
#line 1450 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp10_ = _tmp9_;
#line 1450 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp11_ = soup_message_new_from_uri (_tmp7_, _tmp10_);
#line 1450 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_object_unref0 (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_FACEBOOK_GRAPH_SESSION_TYPE_GRAPH_MESSAGE_IMPL, PublishingFacebookGraphSessionGraphMessageImpl)->soup_message);
#line 1450 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_FACEBOOK_GRAPH_SESSION_TYPE_GRAPH_MESSAGE_IMPL, PublishingFacebookGraphSessionGraphMessageImpl)->soup_message = _tmp11_;
#line 1450 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	__vala_SoupURI_free0 (_tmp10_);
#line 1450 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_free0 (_tmp7_);
#line 1452 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp12_ = soup_multipart_new ("multipart/form-data");
#line 1452 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	mp_envelope = _tmp12_;
#line 1454 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp13_ = access_token;
#line 1454 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	soup_multipart_append_form_string (mp_envelope, "access_token", _tmp13_);
#line 1455 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp14_ = album_name;
#line 1455 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	soup_multipart_append_form_string (mp_envelope, "name", _tmp14_);
#line 1456 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp15_ = album_privacy;
#line 1456 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	soup_multipart_append_form_string (mp_envelope, "privacy", _tmp15_);
#line 1458 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp16_ = G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_FACEBOOK_GRAPH_SESSION_TYPE_GRAPH_MESSAGE_IMPL, PublishingFacebookGraphSessionGraphMessageImpl)->soup_message;
#line 1458 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp17_ = _tmp16_->request_headers;
#line 1458 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp18_ = G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_FACEBOOK_GRAPH_SESSION_TYPE_GRAPH_MESSAGE_IMPL, PublishingFacebookGraphSessionGraphMessageImpl)->soup_message;
#line 1458 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp19_ = _tmp18_->request_body;
#line 1458 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	soup_multipart_to_message (mp_envelope, _tmp17_, _tmp19_);
#line 1444 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	__vala_SoupMultipart_free0 (mp_envelope);
#line 1444 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return self;
#line 10866 "FacebookPublishing.c"
}


static PublishingFacebookGraphSessionGraphCreateAlbumMessage* publishing_facebook_graph_session_graph_create_album_message_new (PublishingFacebookGraphSession* host_session, const gchar* access_token, const gchar* album_name, const gchar* album_privacy) {
#line 1444 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return publishing_facebook_graph_session_graph_create_album_message_construct (PUBLISHING_FACEBOOK_GRAPH_SESSION_TYPE_GRAPH_CREATE_ALBUM_MESSAGE, host_session, access_token, album_name, album_privacy);
#line 10873 "FacebookPublishing.c"
}


static void publishing_facebook_graph_session_graph_create_album_message_class_init (PublishingFacebookGraphSessionGraphCreateAlbumMessageClass * klass) {
#line 1443 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_graph_session_graph_create_album_message_parent_class = g_type_class_peek_parent (klass);
#line 10880 "FacebookPublishing.c"
}


static void publishing_facebook_graph_session_graph_create_album_message_instance_init (PublishingFacebookGraphSessionGraphCreateAlbumMessage * self) {
}


static GType publishing_facebook_graph_session_graph_create_album_message_get_type (void) {
	static volatile gsize publishing_facebook_graph_session_graph_create_album_message_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_facebook_graph_session_graph_create_album_message_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingFacebookGraphSessionGraphCreateAlbumMessageClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_facebook_graph_session_graph_create_album_message_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingFacebookGraphSessionGraphCreateAlbumMessage), 0, (GInstanceInitFunc) publishing_facebook_graph_session_graph_create_album_message_instance_init, NULL };
		GType publishing_facebook_graph_session_graph_create_album_message_type_id;
		publishing_facebook_graph_session_graph_create_album_message_type_id = g_type_register_static (PUBLISHING_FACEBOOK_GRAPH_SESSION_TYPE_GRAPH_MESSAGE_IMPL, "PublishingFacebookGraphSessionGraphCreateAlbumMessage", &g_define_type_info, 0);
		g_once_init_leave (&publishing_facebook_graph_session_graph_create_album_message_type_id__volatile, publishing_facebook_graph_session_graph_create_album_message_type_id);
	}
	return publishing_facebook_graph_session_graph_create_album_message_type_id__volatile;
}


static void publishing_facebook_value_graph_session_init (GValue* value) {
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	value->data[0].v_pointer = NULL;
#line 10903 "FacebookPublishing.c"
}


static void publishing_facebook_value_graph_session_free_value (GValue* value) {
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (value->data[0].v_pointer) {
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		publishing_facebook_graph_session_unref (value->data[0].v_pointer);
#line 10912 "FacebookPublishing.c"
	}
}


static void publishing_facebook_value_graph_session_copy_value (const GValue* src_value, GValue* dest_value) {
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (src_value->data[0].v_pointer) {
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		dest_value->data[0].v_pointer = publishing_facebook_graph_session_ref (src_value->data[0].v_pointer);
#line 10922 "FacebookPublishing.c"
	} else {
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		dest_value->data[0].v_pointer = NULL;
#line 10926 "FacebookPublishing.c"
	}
}


static gpointer publishing_facebook_value_graph_session_peek_pointer (const GValue* value) {
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return value->data[0].v_pointer;
#line 10934 "FacebookPublishing.c"
}


static gchar* publishing_facebook_value_graph_session_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (collect_values[0].v_pointer) {
#line 10941 "FacebookPublishing.c"
		PublishingFacebookGraphSession* object;
		object = collect_values[0].v_pointer;
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		if (object->parent_instance.g_class == NULL) {
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 10948 "FacebookPublishing.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 10952 "FacebookPublishing.c"
		}
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		value->data[0].v_pointer = publishing_facebook_graph_session_ref (object);
#line 10956 "FacebookPublishing.c"
	} else {
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 10960 "FacebookPublishing.c"
	}
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return NULL;
#line 10964 "FacebookPublishing.c"
}


static gchar* publishing_facebook_value_graph_session_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	PublishingFacebookGraphSession** object_p;
	object_p = collect_values[0].v_pointer;
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (!object_p) {
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 10975 "FacebookPublishing.c"
	}
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (!value->data[0].v_pointer) {
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		*object_p = NULL;
#line 10981 "FacebookPublishing.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		*object_p = value->data[0].v_pointer;
#line 10985 "FacebookPublishing.c"
	} else {
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		*object_p = publishing_facebook_graph_session_ref (value->data[0].v_pointer);
#line 10989 "FacebookPublishing.c"
	}
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return NULL;
#line 10993 "FacebookPublishing.c"
}


GParamSpec* publishing_facebook_param_spec_graph_session (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
	PublishingFacebookParamSpecGraphSession* spec;
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_val_if_fail (g_type_is_a (object_type, PUBLISHING_FACEBOOK_TYPE_GRAPH_SESSION), NULL);
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return G_PARAM_SPEC (spec);
#line 11007 "FacebookPublishing.c"
}


gpointer publishing_facebook_value_get_graph_session (const GValue* value) {
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_FACEBOOK_TYPE_GRAPH_SESSION), NULL);
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return value->data[0].v_pointer;
#line 11016 "FacebookPublishing.c"
}


void publishing_facebook_value_set_graph_session (GValue* value, gpointer v_object) {
	PublishingFacebookGraphSession* old;
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_FACEBOOK_TYPE_GRAPH_SESSION));
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	old = value->data[0].v_pointer;
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (v_object) {
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PUBLISHING_FACEBOOK_TYPE_GRAPH_SESSION));
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		value->data[0].v_pointer = v_object;
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		publishing_facebook_graph_session_ref (value->data[0].v_pointer);
#line 11036 "FacebookPublishing.c"
	} else {
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 11040 "FacebookPublishing.c"
	}
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (old) {
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		publishing_facebook_graph_session_unref (old);
#line 11046 "FacebookPublishing.c"
	}
}


void publishing_facebook_value_take_graph_session (GValue* value, gpointer v_object) {
	PublishingFacebookGraphSession* old;
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_FACEBOOK_TYPE_GRAPH_SESSION));
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	old = value->data[0].v_pointer;
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (v_object) {
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PUBLISHING_FACEBOOK_TYPE_GRAPH_SESSION));
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		value->data[0].v_pointer = v_object;
#line 11065 "FacebookPublishing.c"
	} else {
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 11069 "FacebookPublishing.c"
	}
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (old) {
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		publishing_facebook_graph_session_unref (old);
#line 11075 "FacebookPublishing.c"
	}
}


static void publishing_facebook_graph_session_class_init (PublishingFacebookGraphSessionClass * klass) {
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_graph_session_parent_class = g_type_class_peek_parent (klass);
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	((PublishingFacebookGraphSessionClass *) klass)->finalize = publishing_facebook_graph_session_finalize;
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_type_class_add_private (klass, sizeof (PublishingFacebookGraphSessionPrivate));
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_new ("authenticated", PUBLISHING_FACEBOOK_TYPE_GRAPH_SESSION, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
#line 11089 "FacebookPublishing.c"
}


static void publishing_facebook_graph_session_instance_init (PublishingFacebookGraphSession * self) {
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv = PUBLISHING_FACEBOOK_GRAPH_SESSION_GET_PRIVATE (self);
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->ref_count = 1;
#line 11098 "FacebookPublishing.c"
}


static void publishing_facebook_graph_session_finalize (PublishingFacebookGraphSession* obj) {
	PublishingFacebookGraphSession * self;
	SoupSession* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_FACEBOOK_TYPE_GRAPH_SESSION, PublishingFacebookGraphSession);
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_handlers_destroy (self);
#line 1478 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = self->priv->soup_session;
#line 1478 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_parse_name ("request-unqueued", soup_session_get_type (), &_tmp1_, NULL, FALSE);
#line 1478 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_facebook_graph_session_on_request_unqueued_soup_session_request_unqueued, self);
#line 1464 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_object_unref0 (self->priv->soup_session);
#line 1465 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_free0 (self->priv->access_token);
#line 1466 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_publishing_facebook_graph_message_unref0 (self->priv->current_message);
#line 11122 "FacebookPublishing.c"
}


GType publishing_facebook_graph_session_get_type (void) {
	static volatile gsize publishing_facebook_graph_session_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_facebook_graph_session_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { publishing_facebook_value_graph_session_init, publishing_facebook_value_graph_session_free_value, publishing_facebook_value_graph_session_copy_value, publishing_facebook_value_graph_session_peek_pointer, "p", publishing_facebook_value_graph_session_collect_value, "p", publishing_facebook_value_graph_session_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (PublishingFacebookGraphSessionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_facebook_graph_session_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingFacebookGraphSession), 0, (GInstanceInitFunc) publishing_facebook_graph_session_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType publishing_facebook_graph_session_type_id;
		publishing_facebook_graph_session_type_id = g_type_register_fundamental (g_type_fundamental_next (), "PublishingFacebookGraphSession", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&publishing_facebook_graph_session_type_id__volatile, publishing_facebook_graph_session_type_id);
	}
	return publishing_facebook_graph_session_type_id__volatile;
}


gpointer publishing_facebook_graph_session_ref (gpointer instance) {
	PublishingFacebookGraphSession* self;
	self = instance;
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_atomic_int_inc (&self->ref_count);
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return instance;
#line 11147 "FacebookPublishing.c"
}


void publishing_facebook_graph_session_unref (gpointer instance) {
	PublishingFacebookGraphSession* self;
	self = instance;
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		PUBLISHING_FACEBOOK_GRAPH_SESSION_GET_CLASS (self)->finalize (self);
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 11160 "FacebookPublishing.c"
	}
}


static SpitPublishingPublishable** _vala_array_dup3 (SpitPublishingPublishable** self, int length) {
	SpitPublishingPublishable** result;
	int i;
#line 1625 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	result = g_new0 (SpitPublishingPublishable*, length + 1);
#line 1625 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	for (i = 0; i < length; i++) {
#line 11172 "FacebookPublishing.c"
		SpitPublishingPublishable* _tmp0_ = NULL;
#line 1625 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp0_ = _g_object_ref0 (self[i]);
#line 1625 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		result[i] = _tmp0_;
#line 11178 "FacebookPublishing.c"
	}
#line 1625 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return result;
#line 11182 "FacebookPublishing.c"
}


static gpointer _publishing_facebook_graph_session_ref0 (gpointer self) {
#line 1626 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return self ? publishing_facebook_graph_session_ref (self) : NULL;
#line 11189 "FacebookPublishing.c"
}


static gpointer _publishing_facebook_publishing_parameters_ref0 (gpointer self) {
#line 1627 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return self ? publishing_facebook_publishing_parameters_ref (self) : NULL;
#line 11196 "FacebookPublishing.c"
}


PublishingFacebookUploader* publishing_facebook_uploader_construct (GType object_type, PublishingFacebookGraphSession* session, PublishingFacebookPublishingParameters* publishing_params, SpitPublishingPublishable** publishables, int publishables_length1) {
	PublishingFacebookUploader* self = NULL;
	SpitPublishingPublishable** _tmp0_ = NULL;
	gint _tmp0__length1 = 0;
	SpitPublishingPublishable** _tmp1_ = NULL;
	gint _tmp1__length1 = 0;
	PublishingFacebookGraphSession* _tmp2_ = NULL;
	PublishingFacebookGraphSession* _tmp3_ = NULL;
	PublishingFacebookPublishingParameters* _tmp4_ = NULL;
	PublishingFacebookPublishingParameters* _tmp5_ = NULL;
#line 1622 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_val_if_fail (PUBLISHING_FACEBOOK_IS_GRAPH_SESSION (session), NULL);
#line 1622 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_val_if_fail (PUBLISHING_FACEBOOK_IS_PUBLISHING_PARAMETERS (publishing_params), NULL);
#line 1622 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self = (PublishingFacebookUploader*) g_type_create_instance (object_type);
#line 1624 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->current_file = 0;
#line 1625 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = publishables;
#line 1625 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0__length1 = publishables_length1;
#line 1625 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp1_ = (_tmp0_ != NULL) ? _vala_array_dup3 (_tmp0_, _tmp0__length1) : ((gpointer) _tmp0_);
#line 1625 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp1__length1 = _tmp0__length1;
#line 1625 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->publishables = (_vala_array_free (self->priv->publishables, self->priv->publishables_length1, (GDestroyNotify) g_object_unref), NULL);
#line 1625 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->publishables = _tmp1_;
#line 1625 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->publishables_length1 = _tmp1__length1;
#line 1625 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->_publishables_size_ = self->priv->publishables_length1;
#line 1626 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp2_ = session;
#line 1626 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp3_ = _publishing_facebook_graph_session_ref0 (_tmp2_);
#line 1626 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_publishing_facebook_graph_session_unref0 (self->priv->session);
#line 1626 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->session = _tmp3_;
#line 1627 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp4_ = publishing_params;
#line 1627 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp5_ = _publishing_facebook_publishing_parameters_ref0 (_tmp4_);
#line 1627 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_publishing_facebook_publishing_parameters_unref0 (self->priv->publishing_params);
#line 1627 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->publishing_params = _tmp5_;
#line 1622 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return self;
#line 11252 "FacebookPublishing.c"
}


PublishingFacebookUploader* publishing_facebook_uploader_new (PublishingFacebookGraphSession* session, PublishingFacebookPublishingParameters* publishing_params, SpitPublishingPublishable** publishables, int publishables_length1) {
#line 1622 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return publishing_facebook_uploader_construct (PUBLISHING_FACEBOOK_TYPE_UPLOADER, session, publishing_params, publishables, publishables_length1);
#line 11259 "FacebookPublishing.c"
}


static void _publishing_facebook_uploader_on_chunk_transmitted_publishing_facebook_graph_message_data_transmitted (PublishingFacebookGraphMessage* _sender, gint bytes_sent_so_far, gint total_bytes, gpointer self) {
#line 1649 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_uploader_on_chunk_transmitted ((PublishingFacebookUploader*) self, bytes_sent_so_far, total_bytes);
#line 11266 "FacebookPublishing.c"
}


static void _publishing_facebook_uploader_on_message_completed_publishing_facebook_graph_message_completed (PublishingFacebookGraphMessage* _sender, gpointer self) {
#line 1650 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_uploader_on_message_completed ((PublishingFacebookUploader*) self, _sender);
#line 11273 "FacebookPublishing.c"
}


static void _publishing_facebook_uploader_on_message_failed_publishing_facebook_graph_message_failed (PublishingFacebookGraphMessage* _sender, GError* err, gpointer self) {
#line 1651 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_uploader_on_message_failed ((PublishingFacebookUploader*) self, _sender, err);
#line 11280 "FacebookPublishing.c"
}


static void publishing_facebook_uploader_send_current_file (PublishingFacebookUploader* self) {
	SpitPublishingPublishable* publishable = NULL;
	SpitPublishingPublishable** _tmp0_ = NULL;
	gint _tmp0__length1 = 0;
	gint _tmp1_ = 0;
	SpitPublishingPublishable* _tmp2_ = NULL;
	SpitPublishingPublishable* _tmp3_ = NULL;
	GFile* file = NULL;
	SpitPublishingPublishable* _tmp4_ = NULL;
	GFile* _tmp5_ = NULL;
	GFile* _tmp6_ = NULL;
	gchar* _tmp8_ = NULL;
	SpitPublishingPublishable* _tmp9_ = NULL;
	SpitPublishingPublisherMediaType _tmp10_ = 0;
	gchar* resource_uri = NULL;
	gchar* _tmp16_ = NULL;
	const gchar* _tmp17_ = NULL;
	SpitPublishingPublishable* _tmp18_ = NULL;
	SpitPublishingPublisherMediaType _tmp19_ = 0;
	gchar* resource_privacy = NULL;
	gchar* _tmp22_ = NULL;
	PublishingFacebookGraphMessage* upload_message = NULL;
	PublishingFacebookGraphSession* _tmp23_ = NULL;
	const gchar* _tmp24_ = NULL;
	SpitPublishingPublishable* _tmp25_ = NULL;
	PublishingFacebookPublishingParameters* _tmp26_ = NULL;
	gboolean _tmp27_ = FALSE;
	const gchar* _tmp28_ = NULL;
	PublishingFacebookGraphMessage* _tmp29_ = NULL;
	PublishingFacebookGraphMessage* _tmp30_ = NULL;
	PublishingFacebookGraphMessage* _tmp31_ = NULL;
	PublishingFacebookGraphMessage* _tmp32_ = NULL;
	PublishingFacebookGraphSession* _tmp33_ = NULL;
	PublishingFacebookGraphMessage* _tmp34_ = NULL;
#line 1630 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_UPLOADER (self));
#line 1631 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = self->priv->publishables;
#line 1631 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0__length1 = self->priv->publishables_length1;
#line 1631 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp1_ = self->priv->current_file;
#line 1631 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp2_ = _tmp0_[_tmp1_];
#line 1631 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 1631 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishable = _tmp3_;
#line 1632 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp4_ = publishable;
#line 1632 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp5_ = spit_publishing_publishable_get_serialized_file (_tmp4_);
#line 1632 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	file = _tmp5_;
#line 1635 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp6_ = file;
#line 1635 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (_tmp6_ == NULL) {
#line 11342 "FacebookPublishing.c"
		gint _tmp7_ = 0;
#line 1636 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp7_ = self->priv->current_file;
#line 1636 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		self->priv->current_file = _tmp7_ + 1;
#line 1637 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_g_object_unref0 (file);
#line 1637 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_g_object_unref0 (publishable);
#line 1637 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		return;
#line 11354 "FacebookPublishing.c"
	}
#line 1641 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp9_ = publishable;
#line 1641 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp10_ = spit_publishing_publishable_get_media_type (_tmp9_);
#line 1641 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (_tmp10_ == SPIT_PUBLISHING_PUBLISHER_MEDIA_TYPE_PHOTO) {
#line 11362 "FacebookPublishing.c"
		PublishingFacebookPublishingParameters* _tmp11_ = NULL;
		gchar* _tmp12_ = NULL;
		gchar* _tmp13_ = NULL;
		gchar* _tmp14_ = NULL;
#line 1642 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp11_ = self->priv->publishing_params;
#line 1642 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp12_ = publishing_facebook_publishing_parameters_get_target_album_id (_tmp11_);
#line 1642 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp13_ = _tmp12_;
#line 1642 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp14_ = g_strdup_printf ("/%s/photos", _tmp13_);
#line 1642 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_g_free0 (_tmp8_);
#line 1642 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp8_ = _tmp14_;
#line 1642 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_g_free0 (_tmp13_);
#line 11381 "FacebookPublishing.c"
	} else {
		gchar* _tmp15_ = NULL;
#line 1642 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp15_ = g_strdup ("/me/videos");
#line 1642 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_g_free0 (_tmp8_);
#line 1642 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp8_ = _tmp15_;
#line 11390 "FacebookPublishing.c"
	}
#line 1640 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp16_ = g_strdup (_tmp8_);
#line 1640 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	resource_uri = _tmp16_;
#line 1644 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp18_ = publishable;
#line 1644 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp19_ = spit_publishing_publishable_get_media_type (_tmp18_);
#line 1644 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (_tmp19_ == SPIT_PUBLISHING_PUBLISHER_MEDIA_TYPE_VIDEO) {
#line 11402 "FacebookPublishing.c"
		PublishingFacebookPublishingParameters* _tmp20_ = NULL;
		const gchar* _tmp21_ = NULL;
#line 1645 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp20_ = self->priv->publishing_params;
#line 1645 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp21_ = _tmp20_->privacy_object;
#line 1645 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp17_ = _tmp21_;
#line 11411 "FacebookPublishing.c"
	} else {
#line 1645 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp17_ = NULL;
#line 11415 "FacebookPublishing.c"
	}
#line 1643 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp22_ = g_strdup (_tmp17_);
#line 1643 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	resource_privacy = _tmp22_;
#line 1646 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp23_ = self->priv->session;
#line 1646 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp24_ = resource_uri;
#line 1646 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp25_ = publishable;
#line 1646 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp26_ = self->priv->publishing_params;
#line 1646 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp27_ = _tmp26_->strip_metadata;
#line 1646 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp28_ = resource_privacy;
#line 1646 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp29_ = publishing_facebook_graph_session_new_upload (_tmp23_, _tmp24_, _tmp25_, _tmp27_, _tmp28_);
#line 1646 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	upload_message = _tmp29_;
#line 1649 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp30_ = upload_message;
#line 1649 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_connect (_tmp30_, "data-transmitted", (GCallback) _publishing_facebook_uploader_on_chunk_transmitted_publishing_facebook_graph_message_data_transmitted, self);
#line 1650 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp31_ = upload_message;
#line 1650 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_connect (_tmp31_, "completed", (GCallback) _publishing_facebook_uploader_on_message_completed_publishing_facebook_graph_message_completed, self);
#line 1651 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp32_ = upload_message;
#line 1651 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_connect (_tmp32_, "failed", (GCallback) _publishing_facebook_uploader_on_message_failed_publishing_facebook_graph_message_failed, self);
#line 1653 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp33_ = self->priv->session;
#line 1653 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp34_ = upload_message;
#line 1653 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_graph_session_send_message (_tmp33_, _tmp34_);
#line 1630 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_publishing_facebook_graph_message_unref0 (upload_message);
#line 1630 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_free0 (resource_privacy);
#line 1630 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_free0 (resource_uri);
#line 1630 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_free0 (_tmp8_);
#line 1630 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_object_unref0 (file);
#line 1630 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_g_object_unref0 (publishable);
#line 11467 "FacebookPublishing.c"
}


static void publishing_facebook_uploader_send_files (PublishingFacebookUploader* self) {
#line 1656 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_UPLOADER (self));
#line 1657 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->current_file = 0;
#line 1658 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_uploader_send_current_file (self);
#line 11478 "FacebookPublishing.c"
}


static void publishing_facebook_uploader_on_chunk_transmitted (PublishingFacebookUploader* self, gint bytes_written_so_far, gint total_bytes) {
	gdouble file_span = 0.0;
	SpitPublishingPublishable** _tmp0_ = NULL;
	gint _tmp0__length1 = 0;
	gdouble this_file_fraction_complete = 0.0;
	gint _tmp1_ = 0;
	gint _tmp2_ = 0;
	gdouble fraction_complete = 0.0;
	gint _tmp3_ = 0;
	gdouble _tmp4_ = 0.0;
	gdouble _tmp5_ = 0.0;
	gdouble _tmp6_ = 0.0;
	SpitPublishingProgressCallback _tmp7_ = NULL;
	void* _tmp7__target = NULL;
#line 1661 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_UPLOADER (self));
#line 1662 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = self->priv->publishables;
#line 1662 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0__length1 = self->priv->publishables_length1;
#line 1662 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	file_span = 1.0 / _tmp0__length1;
#line 1663 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp1_ = bytes_written_so_far;
#line 1663 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp2_ = total_bytes;
#line 1663 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	this_file_fraction_complete = ((gdouble) _tmp1_) / _tmp2_;
#line 1664 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp3_ = self->priv->current_file;
#line 1664 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp4_ = file_span;
#line 1664 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp5_ = this_file_fraction_complete;
#line 1664 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp6_ = file_span;
#line 1664 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	fraction_complete = (_tmp3_ * _tmp4_) + (_tmp5_ * _tmp6_);
#line 1667 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp7_ = self->priv->status_updated;
#line 1667 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp7__target = self->priv->status_updated_target;
#line 1667 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (_tmp7_ != NULL) {
#line 11526 "FacebookPublishing.c"
		SpitPublishingProgressCallback _tmp8_ = NULL;
		void* _tmp8__target = NULL;
		gint _tmp9_ = 0;
		gdouble _tmp10_ = 0.0;
#line 1668 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp8_ = self->priv->status_updated;
#line 1668 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp8__target = self->priv->status_updated_target;
#line 1668 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp9_ = self->priv->current_file;
#line 1668 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp10_ = fraction_complete;
#line 1668 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp8_ (_tmp9_ + 1, _tmp10_, _tmp8__target);
#line 11541 "FacebookPublishing.c"
	}
}


static void publishing_facebook_uploader_on_message_completed (PublishingFacebookUploader* self, PublishingFacebookGraphMessage* message) {
	PublishingFacebookGraphMessage* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
	PublishingFacebookGraphMessage* _tmp2_ = NULL;
	guint _tmp3_ = 0U;
	PublishingFacebookGraphMessage* _tmp4_ = NULL;
	guint _tmp5_ = 0U;
	gint _tmp6_ = 0;
	gint _tmp7_ = 0;
	SpitPublishingPublishable** _tmp8_ = NULL;
	gint _tmp8__length1 = 0;
#line 1671 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_UPLOADER (self));
#line 1671 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_GRAPH_MESSAGE (message));
#line 1672 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = message;
#line 1672 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_parse_name ("data-transmitted", PUBLISHING_FACEBOOK_TYPE_GRAPH_MESSAGE, &_tmp1_, NULL, FALSE);
#line 1672 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_facebook_uploader_on_chunk_transmitted_publishing_facebook_graph_message_data_transmitted, self);
#line 1673 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp2_ = message;
#line 1673 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_parse_name ("completed", PUBLISHING_FACEBOOK_TYPE_GRAPH_MESSAGE, &_tmp3_, NULL, FALSE);
#line 1673 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp2_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _publishing_facebook_uploader_on_message_completed_publishing_facebook_graph_message_completed, self);
#line 1674 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp4_ = message;
#line 1674 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_parse_name ("failed", PUBLISHING_FACEBOOK_TYPE_GRAPH_MESSAGE, &_tmp5_, NULL, FALSE);
#line 1674 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp4_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp5_, 0, NULL, (GCallback) _publishing_facebook_uploader_on_message_failed_publishing_facebook_graph_message_failed, self);
#line 1676 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp6_ = self->priv->current_file;
#line 1676 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->current_file = _tmp6_ + 1;
#line 1677 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp7_ = self->priv->current_file;
#line 1677 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp8_ = self->priv->publishables;
#line 1677 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp8__length1 = self->priv->publishables_length1;
#line 1677 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (_tmp7_ < _tmp8__length1) {
#line 1678 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		publishing_facebook_uploader_send_current_file (self);
#line 11593 "FacebookPublishing.c"
	} else {
		gint _tmp9_ = 0;
#line 1680 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		_tmp9_ = self->priv->current_file;
#line 1680 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		g_signal_emit_by_name (self, "upload-complete", _tmp9_);
#line 11600 "FacebookPublishing.c"
	}
}


static void publishing_facebook_uploader_on_message_failed (PublishingFacebookUploader* self, PublishingFacebookGraphMessage* message, GError* _error_) {
	PublishingFacebookGraphMessage* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
	PublishingFacebookGraphMessage* _tmp2_ = NULL;
	guint _tmp3_ = 0U;
	PublishingFacebookGraphMessage* _tmp4_ = NULL;
	guint _tmp5_ = 0U;
	GError* _tmp6_ = NULL;
#line 1684 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_UPLOADER (self));
#line 1684 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_GRAPH_MESSAGE (message));
#line 1685 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = message;
#line 1685 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_parse_name ("data-transmitted", PUBLISHING_FACEBOOK_TYPE_GRAPH_MESSAGE, &_tmp1_, NULL, FALSE);
#line 1685 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_facebook_uploader_on_chunk_transmitted_publishing_facebook_graph_message_data_transmitted, self);
#line 1686 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp2_ = message;
#line 1686 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_parse_name ("completed", PUBLISHING_FACEBOOK_TYPE_GRAPH_MESSAGE, &_tmp3_, NULL, FALSE);
#line 1686 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp2_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _publishing_facebook_uploader_on_message_completed_publishing_facebook_graph_message_completed, self);
#line 1687 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp4_ = message;
#line 1687 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_parse_name ("failed", PUBLISHING_FACEBOOK_TYPE_GRAPH_MESSAGE, &_tmp5_, NULL, FALSE);
#line 1687 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp4_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp5_, 0, NULL, (GCallback) _publishing_facebook_uploader_on_message_failed_publishing_facebook_graph_message_failed, self);
#line 1689 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp6_ = _error_;
#line 1689 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_emit_by_name (self, "upload-error", _tmp6_);
#line 11639 "FacebookPublishing.c"
}


void publishing_facebook_uploader_upload (PublishingFacebookUploader* self, SpitPublishingProgressCallback status_updated, void* status_updated_target) {
	SpitPublishingProgressCallback _tmp0_ = NULL;
	void* _tmp0__target = NULL;
	SpitPublishingPublishable** _tmp1_ = NULL;
	gint _tmp1__length1 = 0;
#line 1692 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (PUBLISHING_FACEBOOK_IS_UPLOADER (self));
#line 1693 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0_ = status_updated;
#line 1693 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp0__target = status_updated_target;
#line 1693 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->status_updated = _tmp0_;
#line 1693 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->status_updated_target = _tmp0__target;
#line 1695 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp1_ = self->priv->publishables;
#line 1695 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_tmp1__length1 = self->priv->publishables_length1;
#line 1695 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (_tmp1__length1 > 0) {
#line 1696 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		publishing_facebook_uploader_send_files (self);
#line 11666 "FacebookPublishing.c"
	}
}


static void publishing_facebook_value_uploader_init (GValue* value) {
#line 1612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	value->data[0].v_pointer = NULL;
#line 11674 "FacebookPublishing.c"
}


static void publishing_facebook_value_uploader_free_value (GValue* value) {
#line 1612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (value->data[0].v_pointer) {
#line 1612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		publishing_facebook_uploader_unref (value->data[0].v_pointer);
#line 11683 "FacebookPublishing.c"
	}
}


static void publishing_facebook_value_uploader_copy_value (const GValue* src_value, GValue* dest_value) {
#line 1612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (src_value->data[0].v_pointer) {
#line 1612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		dest_value->data[0].v_pointer = publishing_facebook_uploader_ref (src_value->data[0].v_pointer);
#line 11693 "FacebookPublishing.c"
	} else {
#line 1612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		dest_value->data[0].v_pointer = NULL;
#line 11697 "FacebookPublishing.c"
	}
}


static gpointer publishing_facebook_value_uploader_peek_pointer (const GValue* value) {
#line 1612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return value->data[0].v_pointer;
#line 11705 "FacebookPublishing.c"
}


static gchar* publishing_facebook_value_uploader_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
#line 1612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (collect_values[0].v_pointer) {
#line 11712 "FacebookPublishing.c"
		PublishingFacebookUploader* object;
		object = collect_values[0].v_pointer;
#line 1612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		if (object->parent_instance.g_class == NULL) {
#line 1612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 11719 "FacebookPublishing.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 1612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 11723 "FacebookPublishing.c"
		}
#line 1612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		value->data[0].v_pointer = publishing_facebook_uploader_ref (object);
#line 11727 "FacebookPublishing.c"
	} else {
#line 1612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 11731 "FacebookPublishing.c"
	}
#line 1612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return NULL;
#line 11735 "FacebookPublishing.c"
}


static gchar* publishing_facebook_value_uploader_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	PublishingFacebookUploader** object_p;
	object_p = collect_values[0].v_pointer;
#line 1612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (!object_p) {
#line 1612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 11746 "FacebookPublishing.c"
	}
#line 1612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (!value->data[0].v_pointer) {
#line 1612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		*object_p = NULL;
#line 11752 "FacebookPublishing.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 1612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		*object_p = value->data[0].v_pointer;
#line 11756 "FacebookPublishing.c"
	} else {
#line 1612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		*object_p = publishing_facebook_uploader_ref (value->data[0].v_pointer);
#line 11760 "FacebookPublishing.c"
	}
#line 1612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return NULL;
#line 11764 "FacebookPublishing.c"
}


GParamSpec* publishing_facebook_param_spec_uploader (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
	PublishingFacebookParamSpecUploader* spec;
#line 1612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_val_if_fail (g_type_is_a (object_type, PUBLISHING_FACEBOOK_TYPE_UPLOADER), NULL);
#line 1612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 1612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 1612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return G_PARAM_SPEC (spec);
#line 11778 "FacebookPublishing.c"
}


gpointer publishing_facebook_value_get_uploader (const GValue* value) {
#line 1612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_FACEBOOK_TYPE_UPLOADER), NULL);
#line 1612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return value->data[0].v_pointer;
#line 11787 "FacebookPublishing.c"
}


void publishing_facebook_value_set_uploader (GValue* value, gpointer v_object) {
	PublishingFacebookUploader* old;
#line 1612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_FACEBOOK_TYPE_UPLOADER));
#line 1612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	old = value->data[0].v_pointer;
#line 1612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (v_object) {
#line 1612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PUBLISHING_FACEBOOK_TYPE_UPLOADER));
#line 1612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 1612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		value->data[0].v_pointer = v_object;
#line 1612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		publishing_facebook_uploader_ref (value->data[0].v_pointer);
#line 11807 "FacebookPublishing.c"
	} else {
#line 1612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 11811 "FacebookPublishing.c"
	}
#line 1612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (old) {
#line 1612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		publishing_facebook_uploader_unref (old);
#line 11817 "FacebookPublishing.c"
	}
}


void publishing_facebook_value_take_uploader (GValue* value, gpointer v_object) {
	PublishingFacebookUploader* old;
#line 1612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_FACEBOOK_TYPE_UPLOADER));
#line 1612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	old = value->data[0].v_pointer;
#line 1612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (v_object) {
#line 1612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PUBLISHING_FACEBOOK_TYPE_UPLOADER));
#line 1612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 1612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		value->data[0].v_pointer = v_object;
#line 11836 "FacebookPublishing.c"
	} else {
#line 1612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 11840 "FacebookPublishing.c"
	}
#line 1612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (old) {
#line 1612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		publishing_facebook_uploader_unref (old);
#line 11846 "FacebookPublishing.c"
	}
}


static void publishing_facebook_uploader_class_init (PublishingFacebookUploaderClass * klass) {
#line 1612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	publishing_facebook_uploader_parent_class = g_type_class_peek_parent (klass);
#line 1612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	((PublishingFacebookUploaderClass *) klass)->finalize = publishing_facebook_uploader_finalize;
#line 1612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_type_class_add_private (klass, sizeof (PublishingFacebookUploaderPrivate));
#line 1612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_new ("upload_complete", PUBLISHING_FACEBOOK_TYPE_UPLOADER, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__INT, G_TYPE_NONE, 1, G_TYPE_INT);
#line 1612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_new ("upload_error", PUBLISHING_FACEBOOK_TYPE_UPLOADER, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__POINTER, G_TYPE_NONE, 1, G_TYPE_POINTER);
#line 11862 "FacebookPublishing.c"
}


static void publishing_facebook_uploader_instance_init (PublishingFacebookUploader * self) {
#line 1612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv = PUBLISHING_FACEBOOK_UPLOADER_GET_PRIVATE (self);
#line 1617 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->status_updated = NULL;
#line 1612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->ref_count = 1;
#line 11873 "FacebookPublishing.c"
}


static void publishing_facebook_uploader_finalize (PublishingFacebookUploader* obj) {
	PublishingFacebookUploader * self;
#line 1612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_FACEBOOK_TYPE_UPLOADER, PublishingFacebookUploader);
#line 1612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_signal_handlers_destroy (self);
#line 1614 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	self->priv->publishables = (_vala_array_free (self->priv->publishables, self->priv->publishables_length1, (GDestroyNotify) g_object_unref), NULL);
#line 1615 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_publishing_facebook_graph_session_unref0 (self->priv->session);
#line 1616 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	_publishing_facebook_publishing_parameters_unref0 (self->priv->publishing_params);
#line 11889 "FacebookPublishing.c"
}


GType publishing_facebook_uploader_get_type (void) {
	static volatile gsize publishing_facebook_uploader_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_facebook_uploader_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { publishing_facebook_value_uploader_init, publishing_facebook_value_uploader_free_value, publishing_facebook_value_uploader_copy_value, publishing_facebook_value_uploader_peek_pointer, "p", publishing_facebook_value_uploader_collect_value, "p", publishing_facebook_value_uploader_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (PublishingFacebookUploaderClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_facebook_uploader_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingFacebookUploader), 0, (GInstanceInitFunc) publishing_facebook_uploader_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType publishing_facebook_uploader_type_id;
		publishing_facebook_uploader_type_id = g_type_register_fundamental (g_type_fundamental_next (), "PublishingFacebookUploader", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&publishing_facebook_uploader_type_id__volatile, publishing_facebook_uploader_type_id);
	}
	return publishing_facebook_uploader_type_id__volatile;
}


gpointer publishing_facebook_uploader_ref (gpointer instance) {
	PublishingFacebookUploader* self;
	self = instance;
#line 1612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	g_atomic_int_inc (&self->ref_count);
#line 1612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	return instance;
#line 11914 "FacebookPublishing.c"
}


void publishing_facebook_uploader_unref (gpointer instance) {
	PublishingFacebookUploader* self;
	self = instance;
#line 1612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 1612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		PUBLISHING_FACEBOOK_UPLOADER_GET_CLASS (self)->finalize (self);
#line 1612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FacebookPublishing.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 11927 "FacebookPublishing.c"
	}
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}


static gint _vala_array_length (gpointer array) {
	int length;
	length = 0;
	if (array) {
		while (((gpointer*) array)[length]) {
			length++;
		}
	}
	return length;
}



