/* Dialogs.c generated by valac 0.32.1, the Vala compiler
 * generated from Dialogs.vala, do not modify */

/* Copyright 2016 Software Freedom Conservancy Inc.
 *
 * This software is licensed under the GNU LGPL (version 2.1 or later).
 * See the COPYING file in this distribution.
 */
/* namespace for future migration of AppWindow alert and other question dialogs into single*/
/* place: http://trac.yorba.org/ticket/3452*/

#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <glib/gi18n-lib.h>
#include <gtk/gtk.h>
#include <gio/gio.h>
#include <gee.h>
#include <float.h>
#include <math.h>
#include <gdk/gdk.h>
#include <time.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <gobject/gvaluecollector.h>


#define TYPE_DATA_OBJECT (data_object_get_type ())
#define DATA_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATA_OBJECT, DataObject))
#define DATA_OBJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATA_OBJECT, DataObjectClass))
#define IS_DATA_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATA_OBJECT))
#define IS_DATA_OBJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATA_OBJECT))
#define DATA_OBJECT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATA_OBJECT, DataObjectClass))

typedef struct _DataObject DataObject;
typedef struct _DataObjectClass DataObjectClass;

#define TYPE_DATA_SOURCE (data_source_get_type ())
#define DATA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATA_SOURCE, DataSource))
#define DATA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATA_SOURCE, DataSourceClass))
#define IS_DATA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATA_SOURCE))
#define IS_DATA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATA_SOURCE))
#define DATA_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATA_SOURCE, DataSourceClass))

typedef struct _DataSource DataSource;
typedef struct _DataSourceClass DataSourceClass;

#define TYPE_TAG (tag_get_type ())
#define TAG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_TAG, Tag))
#define TAG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_TAG, TagClass))
#define IS_TAG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_TAG))
#define IS_TAG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_TAG))
#define TAG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_TAG, TagClass))

typedef struct _Tag Tag;
typedef struct _TagClass TagClass;
#define _g_free0(var) (var = (g_free (var), NULL))

#define TYPE_SAVED_SEARCH (saved_search_get_type ())
#define SAVED_SEARCH(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SAVED_SEARCH, SavedSearch))
#define SAVED_SEARCH_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SAVED_SEARCH, SavedSearchClass))
#define IS_SAVED_SEARCH(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SAVED_SEARCH))
#define IS_SAVED_SEARCH_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SAVED_SEARCH))
#define SAVED_SEARCH_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SAVED_SEARCH, SavedSearchClass))

typedef struct _SavedSearch SavedSearch;
typedef struct _SavedSearchClass SavedSearchClass;

#define TYPE_PAGE_WINDOW (page_window_get_type ())
#define PAGE_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PAGE_WINDOW, PageWindow))
#define PAGE_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PAGE_WINDOW, PageWindowClass))
#define IS_PAGE_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PAGE_WINDOW))
#define IS_PAGE_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PAGE_WINDOW))
#define PAGE_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PAGE_WINDOW, PageWindowClass))

typedef struct _PageWindow PageWindow;
typedef struct _PageWindowClass PageWindowClass;

#define TYPE_APP_WINDOW (app_window_get_type ())
#define APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_APP_WINDOW, AppWindow))
#define APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_APP_WINDOW, AppWindowClass))
#define IS_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_APP_WINDOW))
#define IS_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_APP_WINDOW))
#define APP_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_APP_WINDOW, AppWindowClass))

typedef struct _AppWindow AppWindow;
typedef struct _AppWindowClass AppWindowClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define TYPE_THUMBNAIL_SOURCE (thumbnail_source_get_type ())
#define THUMBNAIL_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_THUMBNAIL_SOURCE, ThumbnailSource))
#define THUMBNAIL_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_THUMBNAIL_SOURCE, ThumbnailSourceClass))
#define IS_THUMBNAIL_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_THUMBNAIL_SOURCE))
#define IS_THUMBNAIL_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_THUMBNAIL_SOURCE))
#define THUMBNAIL_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_THUMBNAIL_SOURCE, ThumbnailSourceClass))

typedef struct _ThumbnailSource ThumbnailSource;
typedef struct _ThumbnailSourceClass ThumbnailSourceClass;

#define TYPE_MEDIA_SOURCE (media_source_get_type ())
#define MEDIA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MEDIA_SOURCE, MediaSource))
#define MEDIA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MEDIA_SOURCE, MediaSourceClass))
#define IS_MEDIA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MEDIA_SOURCE))
#define IS_MEDIA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MEDIA_SOURCE))
#define MEDIA_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MEDIA_SOURCE, MediaSourceClass))

typedef struct _MediaSource MediaSource;
typedef struct _MediaSourceClass MediaSourceClass;

#define TYPE_PHOTO_SOURCE (photo_source_get_type ())
#define PHOTO_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PHOTO_SOURCE, PhotoSource))
#define PHOTO_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PHOTO_SOURCE, PhotoSourceClass))
#define IS_PHOTO_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PHOTO_SOURCE))
#define IS_PHOTO_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PHOTO_SOURCE))
#define PHOTO_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PHOTO_SOURCE, PhotoSourceClass))

typedef struct _PhotoSource PhotoSource;
typedef struct _PhotoSourceClass PhotoSourceClass;

#define TYPE_PHOTO (photo_get_type ())
#define PHOTO(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PHOTO, Photo))
#define PHOTO_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PHOTO, PhotoClass))
#define IS_PHOTO(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PHOTO))
#define IS_PHOTO_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PHOTO))
#define PHOTO_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PHOTO, PhotoClass))

typedef struct _Photo Photo;
typedef struct _PhotoClass PhotoClass;

#define TYPE_EXPORT_DIALOG (export_dialog_get_type ())
#define EXPORT_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_EXPORT_DIALOG, ExportDialog))
#define EXPORT_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_EXPORT_DIALOG, ExportDialogClass))
#define IS_EXPORT_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_EXPORT_DIALOG))
#define IS_EXPORT_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_EXPORT_DIALOG))
#define EXPORT_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_EXPORT_DIALOG, ExportDialogClass))

typedef struct _ExportDialog ExportDialog;
typedef struct _ExportDialogClass ExportDialogClass;
typedef struct _ExportDialogPrivate ExportDialogPrivate;

#define TYPE_SCALE_CONSTRAINT (scale_constraint_get_type ())

#define TYPE_EXPORT_FORMAT_PARAMETERS (export_format_parameters_get_type ())

#define TYPE_EXPORT_FORMAT_MODE (export_format_mode_get_type ())

#define TYPE_PHOTO_FILE_FORMAT (photo_file_format_get_type ())

#define JPEG_TYPE_QUALITY (jpeg_quality_get_type ())
typedef struct _ExportFormatParameters ExportFormatParameters;

#define TYPE_PHOTO_FILE_FORMAT_PROPERTIES (photo_file_format_properties_get_type ())
#define PHOTO_FILE_FORMAT_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PHOTO_FILE_FORMAT_PROPERTIES, PhotoFileFormatProperties))
#define PHOTO_FILE_FORMAT_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PHOTO_FILE_FORMAT_PROPERTIES, PhotoFileFormatPropertiesClass))
#define IS_PHOTO_FILE_FORMAT_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PHOTO_FILE_FORMAT_PROPERTIES))
#define IS_PHOTO_FILE_FORMAT_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PHOTO_FILE_FORMAT_PROPERTIES))
#define PHOTO_FILE_FORMAT_PROPERTIES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PHOTO_FILE_FORMAT_PROPERTIES, PhotoFileFormatPropertiesClass))

typedef struct _PhotoFileFormatProperties PhotoFileFormatProperties;
typedef struct _PhotoFileFormatPropertiesClass PhotoFileFormatPropertiesClass;
#define _photo_file_format_properties_unref0(var) ((var == NULL) ? NULL : (var = (photo_file_format_properties_unref (var), NULL)))

#define TYPE_BATCH_IMPORT_RESULT (batch_import_result_get_type ())
#define BATCH_IMPORT_RESULT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_BATCH_IMPORT_RESULT, BatchImportResult))
#define BATCH_IMPORT_RESULT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_BATCH_IMPORT_RESULT, BatchImportResultClass))
#define IS_BATCH_IMPORT_RESULT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_BATCH_IMPORT_RESULT))
#define IS_BATCH_IMPORT_RESULT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_BATCH_IMPORT_RESULT))
#define BATCH_IMPORT_RESULT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_BATCH_IMPORT_RESULT, BatchImportResultClass))

typedef struct _BatchImportResult BatchImportResult;
typedef struct _BatchImportResultClass BatchImportResultClass;
typedef struct _BatchImportResultPrivate BatchImportResultPrivate;

#define TYPE_BATCH_IMPORT_JOB (batch_import_job_get_type ())
#define BATCH_IMPORT_JOB(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_BATCH_IMPORT_JOB, BatchImportJob))
#define BATCH_IMPORT_JOB_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_BATCH_IMPORT_JOB, BatchImportJobClass))
#define IS_BATCH_IMPORT_JOB(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_BATCH_IMPORT_JOB))
#define IS_BATCH_IMPORT_JOB_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_BATCH_IMPORT_JOB))
#define BATCH_IMPORT_JOB_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_BATCH_IMPORT_JOB, BatchImportJobClass))

typedef struct _BatchImportJob BatchImportJob;
typedef struct _BatchImportJobClass BatchImportJobClass;

#define TYPE_IMPORT_RESULT (import_result_get_type ())

#define TYPE_DUPLICATED_FILE (duplicated_file_get_type ())
#define DUPLICATED_FILE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DUPLICATED_FILE, DuplicatedFile))
#define DUPLICATED_FILE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DUPLICATED_FILE, DuplicatedFileClass))
#define IS_DUPLICATED_FILE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DUPLICATED_FILE))
#define IS_DUPLICATED_FILE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DUPLICATED_FILE))
#define DUPLICATED_FILE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DUPLICATED_FILE, DuplicatedFileClass))

typedef struct _DuplicatedFile DuplicatedFile;
typedef struct _DuplicatedFileClass DuplicatedFileClass;
#define _batch_import_result_unref0(var) ((var == NULL) ? NULL : (var = (batch_import_result_unref (var), NULL)))

#define IMPORT_UI_TYPE_QUESTION_PARAMS (import_ui_question_params_get_type ())
#define IMPORT_UI_QUESTION_PARAMS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), IMPORT_UI_TYPE_QUESTION_PARAMS, ImportUIQuestionParams))
#define IMPORT_UI_QUESTION_PARAMS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), IMPORT_UI_TYPE_QUESTION_PARAMS, ImportUIQuestionParamsClass))
#define IMPORT_UI_IS_QUESTION_PARAMS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), IMPORT_UI_TYPE_QUESTION_PARAMS))
#define IMPORT_UI_IS_QUESTION_PARAMS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), IMPORT_UI_TYPE_QUESTION_PARAMS))
#define IMPORT_UI_QUESTION_PARAMS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), IMPORT_UI_TYPE_QUESTION_PARAMS, ImportUIQuestionParamsClass))

typedef struct _ImportUIQuestionParams ImportUIQuestionParams;
typedef struct _ImportUIQuestionParamsClass ImportUIQuestionParamsClass;
typedef struct _ImportUIQuestionParamsPrivate ImportUIQuestionParamsPrivate;
typedef struct _ImportUIParamSpecQuestionParams ImportUIParamSpecQuestionParams;

#define TYPE_IMPORT_MANIFEST (import_manifest_get_type ())
#define IMPORT_MANIFEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_IMPORT_MANIFEST, ImportManifest))
#define IMPORT_MANIFEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_IMPORT_MANIFEST, ImportManifestClass))
#define IS_IMPORT_MANIFEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_IMPORT_MANIFEST))
#define IS_IMPORT_MANIFEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_IMPORT_MANIFEST))
#define IMPORT_MANIFEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_IMPORT_MANIFEST, ImportManifestClass))

typedef struct _ImportManifest ImportManifest;
typedef struct _ImportManifestClass ImportManifestClass;
typedef struct _ImportManifestPrivate ImportManifestPrivate;
#define _g_string_free0(var) ((var == NULL) ? NULL : (var = (g_string_free (var, TRUE), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))

#define TYPE_TEXT_ENTRY_DIALOG_MEDIATOR (text_entry_dialog_mediator_get_type ())
#define TEXT_ENTRY_DIALOG_MEDIATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_TEXT_ENTRY_DIALOG_MEDIATOR, TextEntryDialogMediator))
#define TEXT_ENTRY_DIALOG_MEDIATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_TEXT_ENTRY_DIALOG_MEDIATOR, TextEntryDialogMediatorClass))
#define IS_TEXT_ENTRY_DIALOG_MEDIATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_TEXT_ENTRY_DIALOG_MEDIATOR))
#define IS_TEXT_ENTRY_DIALOG_MEDIATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_TEXT_ENTRY_DIALOG_MEDIATOR))
#define TEXT_ENTRY_DIALOG_MEDIATOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_TEXT_ENTRY_DIALOG_MEDIATOR, TextEntryDialogMediatorClass))

typedef struct _TextEntryDialogMediator TextEntryDialogMediator;
typedef struct _TextEntryDialogMediatorClass TextEntryDialogMediatorClass;
typedef struct _TextEntryDialogMediatorPrivate TextEntryDialogMediatorPrivate;

#define TYPE_TEXT_ENTRY_DIALOG (text_entry_dialog_get_type ())
#define TEXT_ENTRY_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_TEXT_ENTRY_DIALOG, TextEntryDialog))
#define TEXT_ENTRY_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_TEXT_ENTRY_DIALOG, TextEntryDialogClass))
#define IS_TEXT_ENTRY_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_TEXT_ENTRY_DIALOG))
#define IS_TEXT_ENTRY_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_TEXT_ENTRY_DIALOG))
#define TEXT_ENTRY_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_TEXT_ENTRY_DIALOG, TextEntryDialogClass))

typedef struct _TextEntryDialog TextEntryDialog;
typedef struct _TextEntryDialogClass TextEntryDialogClass;
typedef struct _ParamSpecTextEntryDialogMediator ParamSpecTextEntryDialogMediator;

#define TYPE_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR (multi_text_entry_dialog_mediator_get_type ())
#define MULTI_TEXT_ENTRY_DIALOG_MEDIATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR, MultiTextEntryDialogMediator))
#define MULTI_TEXT_ENTRY_DIALOG_MEDIATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR, MultiTextEntryDialogMediatorClass))
#define IS_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR))
#define IS_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR))
#define MULTI_TEXT_ENTRY_DIALOG_MEDIATOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR, MultiTextEntryDialogMediatorClass))

typedef struct _MultiTextEntryDialogMediator MultiTextEntryDialogMediator;
typedef struct _MultiTextEntryDialogMediatorClass MultiTextEntryDialogMediatorClass;
typedef struct _MultiTextEntryDialogMediatorPrivate MultiTextEntryDialogMediatorPrivate;

#define TYPE_MULTI_TEXT_ENTRY_DIALOG (multi_text_entry_dialog_get_type ())
#define MULTI_TEXT_ENTRY_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MULTI_TEXT_ENTRY_DIALOG, MultiTextEntryDialog))
#define MULTI_TEXT_ENTRY_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MULTI_TEXT_ENTRY_DIALOG, MultiTextEntryDialogClass))
#define IS_MULTI_TEXT_ENTRY_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MULTI_TEXT_ENTRY_DIALOG))
#define IS_MULTI_TEXT_ENTRY_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MULTI_TEXT_ENTRY_DIALOG))
#define MULTI_TEXT_ENTRY_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MULTI_TEXT_ENTRY_DIALOG, MultiTextEntryDialogClass))

typedef struct _MultiTextEntryDialog MultiTextEntryDialog;
typedef struct _MultiTextEntryDialogClass MultiTextEntryDialogClass;
typedef struct _ParamSpecMultiTextEntryDialogMediator ParamSpecMultiTextEntryDialogMediator;

#define TYPE_ENTRY_MULTI_COMPLETION (entry_multi_completion_get_type ())
#define ENTRY_MULTI_COMPLETION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_ENTRY_MULTI_COMPLETION, EntryMultiCompletion))
#define ENTRY_MULTI_COMPLETION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_ENTRY_MULTI_COMPLETION, EntryMultiCompletionClass))
#define IS_ENTRY_MULTI_COMPLETION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_ENTRY_MULTI_COMPLETION))
#define IS_ENTRY_MULTI_COMPLETION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_ENTRY_MULTI_COMPLETION))
#define ENTRY_MULTI_COMPLETION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_ENTRY_MULTI_COMPLETION, EntryMultiCompletionClass))

typedef struct _EntryMultiCompletion EntryMultiCompletion;
typedef struct _EntryMultiCompletionClass EntryMultiCompletionClass;
typedef struct _EntryMultiCompletionPrivate EntryMultiCompletionPrivate;

#define TYPE_SET_BACKGROUND_DIALOG (set_background_dialog_get_type ())
#define SET_BACKGROUND_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SET_BACKGROUND_DIALOG, SetBackgroundDialog))
#define SET_BACKGROUND_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SET_BACKGROUND_DIALOG, SetBackgroundDialogClass))
#define IS_SET_BACKGROUND_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SET_BACKGROUND_DIALOG))
#define IS_SET_BACKGROUND_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SET_BACKGROUND_DIALOG))
#define SET_BACKGROUND_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SET_BACKGROUND_DIALOG, SetBackgroundDialogClass))

typedef struct _SetBackgroundDialog SetBackgroundDialog;
typedef struct _SetBackgroundDialogClass SetBackgroundDialogClass;
typedef struct _SetBackgroundDialogPrivate SetBackgroundDialogPrivate;
typedef struct _ParamSpecSetBackgroundDialog ParamSpecSetBackgroundDialog;

#define TYPE_SET_BACKGROUND_PHOTO_DIALOG (set_background_photo_dialog_get_type ())
#define SET_BACKGROUND_PHOTO_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SET_BACKGROUND_PHOTO_DIALOG, SetBackgroundPhotoDialog))
#define SET_BACKGROUND_PHOTO_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SET_BACKGROUND_PHOTO_DIALOG, SetBackgroundPhotoDialogClass))
#define IS_SET_BACKGROUND_PHOTO_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SET_BACKGROUND_PHOTO_DIALOG))
#define IS_SET_BACKGROUND_PHOTO_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SET_BACKGROUND_PHOTO_DIALOG))
#define SET_BACKGROUND_PHOTO_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SET_BACKGROUND_PHOTO_DIALOG, SetBackgroundPhotoDialogClass))

typedef struct _SetBackgroundPhotoDialog SetBackgroundPhotoDialog;
typedef struct _SetBackgroundPhotoDialogClass SetBackgroundPhotoDialogClass;
typedef struct _SetBackgroundPhotoDialogPrivate SetBackgroundPhotoDialogPrivate;

#define TYPE_SET_BACKGROUND_SLIDESHOW_DIALOG (set_background_slideshow_dialog_get_type ())
#define SET_BACKGROUND_SLIDESHOW_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SET_BACKGROUND_SLIDESHOW_DIALOG, SetBackgroundSlideshowDialog))
#define SET_BACKGROUND_SLIDESHOW_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SET_BACKGROUND_SLIDESHOW_DIALOG, SetBackgroundSlideshowDialogClass))
#define IS_SET_BACKGROUND_SLIDESHOW_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SET_BACKGROUND_SLIDESHOW_DIALOG))
#define IS_SET_BACKGROUND_SLIDESHOW_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SET_BACKGROUND_SLIDESHOW_DIALOG))
#define SET_BACKGROUND_SLIDESHOW_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SET_BACKGROUND_SLIDESHOW_DIALOG, SetBackgroundSlideshowDialogClass))

typedef struct _SetBackgroundSlideshowDialog SetBackgroundSlideshowDialog;
typedef struct _SetBackgroundSlideshowDialogClass SetBackgroundSlideshowDialogClass;
typedef struct _SetBackgroundSlideshowDialogPrivate SetBackgroundSlideshowDialogPrivate;
typedef struct _TextEntryDialogPrivate TextEntryDialogPrivate;
typedef struct _MultiTextEntryDialogPrivate MultiTextEntryDialogPrivate;

#define TYPE_EVENT_RENAME_DIALOG (event_rename_dialog_get_type ())
#define EVENT_RENAME_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_EVENT_RENAME_DIALOG, EventRenameDialog))
#define EVENT_RENAME_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_EVENT_RENAME_DIALOG, EventRenameDialogClass))
#define IS_EVENT_RENAME_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_EVENT_RENAME_DIALOG))
#define IS_EVENT_RENAME_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_EVENT_RENAME_DIALOG))
#define EVENT_RENAME_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_EVENT_RENAME_DIALOG, EventRenameDialogClass))

typedef struct _EventRenameDialog EventRenameDialog;
typedef struct _EventRenameDialogClass EventRenameDialogClass;
typedef struct _EventRenameDialogPrivate EventRenameDialogPrivate;

#define TYPE_EDIT_TITLE_DIALOG (edit_title_dialog_get_type ())
#define EDIT_TITLE_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_EDIT_TITLE_DIALOG, EditTitleDialog))
#define EDIT_TITLE_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_EDIT_TITLE_DIALOG, EditTitleDialogClass))
#define IS_EDIT_TITLE_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_EDIT_TITLE_DIALOG))
#define IS_EDIT_TITLE_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_EDIT_TITLE_DIALOG))
#define EDIT_TITLE_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_EDIT_TITLE_DIALOG, EditTitleDialogClass))

typedef struct _EditTitleDialog EditTitleDialog;
typedef struct _EditTitleDialogClass EditTitleDialogClass;
typedef struct _EditTitleDialogPrivate EditTitleDialogPrivate;

#define TYPE_EDIT_COMMENT_DIALOG (edit_comment_dialog_get_type ())
#define EDIT_COMMENT_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_EDIT_COMMENT_DIALOG, EditCommentDialog))
#define EDIT_COMMENT_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_EDIT_COMMENT_DIALOG, EditCommentDialogClass))
#define IS_EDIT_COMMENT_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_EDIT_COMMENT_DIALOG))
#define IS_EDIT_COMMENT_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_EDIT_COMMENT_DIALOG))
#define EDIT_COMMENT_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_EDIT_COMMENT_DIALOG, EditCommentDialogClass))

typedef struct _EditCommentDialog EditCommentDialog;
typedef struct _EditCommentDialogClass EditCommentDialogClass;
typedef struct _EditCommentDialogPrivate EditCommentDialogPrivate;

#define TYPE_PROGRESS_DIALOG (progress_dialog_get_type ())
#define PROGRESS_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PROGRESS_DIALOG, ProgressDialog))
#define PROGRESS_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PROGRESS_DIALOG, ProgressDialogClass))
#define IS_PROGRESS_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PROGRESS_DIALOG))
#define IS_PROGRESS_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PROGRESS_DIALOG))
#define PROGRESS_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PROGRESS_DIALOG, ProgressDialogClass))

typedef struct _ProgressDialog ProgressDialog;
typedef struct _ProgressDialogClass ProgressDialogClass;
typedef struct _ProgressDialogPrivate ProgressDialogPrivate;

#define TYPE_ADJUST_DATE_TIME_DIALOG (adjust_date_time_dialog_get_type ())
#define ADJUST_DATE_TIME_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_ADJUST_DATE_TIME_DIALOG, AdjustDateTimeDialog))
#define ADJUST_DATE_TIME_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_ADJUST_DATE_TIME_DIALOG, AdjustDateTimeDialogClass))
#define IS_ADJUST_DATE_TIME_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_ADJUST_DATE_TIME_DIALOG))
#define IS_ADJUST_DATE_TIME_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_ADJUST_DATE_TIME_DIALOG))
#define ADJUST_DATE_TIME_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_ADJUST_DATE_TIME_DIALOG, AdjustDateTimeDialogClass))

typedef struct _AdjustDateTimeDialog AdjustDateTimeDialog;
typedef struct _AdjustDateTimeDialogClass AdjustDateTimeDialogClass;
typedef struct _AdjustDateTimeDialogPrivate AdjustDateTimeDialogPrivate;

#define ADJUST_DATE_TIME_DIALOG_TYPE_TIME_SYSTEM (adjust_date_time_dialog_time_system_get_type ())

#define TYPE_DATEABLE (dateable_get_type ())
#define DATEABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATEABLE, Dateable))
#define IS_DATEABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATEABLE))
#define DATEABLE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TYPE_DATEABLE, DateableIface))

typedef struct _Dateable Dateable;
typedef struct _DateableIface DateableIface;

#define TYPE_CONFIGURATION_FACADE (configuration_facade_get_type ())
#define CONFIGURATION_FACADE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_CONFIGURATION_FACADE, ConfigurationFacade))
#define CONFIGURATION_FACADE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_CONFIGURATION_FACADE, ConfigurationFacadeClass))
#define IS_CONFIGURATION_FACADE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_CONFIGURATION_FACADE))
#define IS_CONFIGURATION_FACADE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_CONFIGURATION_FACADE))
#define CONFIGURATION_FACADE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_CONFIGURATION_FACADE, ConfigurationFacadeClass))

typedef struct _ConfigurationFacade ConfigurationFacade;
typedef struct _ConfigurationFacadeClass ConfigurationFacadeClass;

#define CONFIG_TYPE_FACADE (config_facade_get_type ())
#define CONFIG_FACADE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CONFIG_TYPE_FACADE, ConfigFacade))
#define CONFIG_FACADE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), CONFIG_TYPE_FACADE, ConfigFacadeClass))
#define CONFIG_IS_FACADE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CONFIG_TYPE_FACADE))
#define CONFIG_IS_FACADE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CONFIG_TYPE_FACADE))
#define CONFIG_FACADE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), CONFIG_TYPE_FACADE, ConfigFacadeClass))

typedef struct _ConfigFacade ConfigFacade;
typedef struct _ConfigFacadeClass ConfigFacadeClass;

#define TYPE_TAGS_DIALOG (tags_dialog_get_type ())
#define TAGS_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_TAGS_DIALOG, TagsDialog))
#define TAGS_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_TAGS_DIALOG, TagsDialogClass))
#define IS_TAGS_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_TAGS_DIALOG))
#define IS_TAGS_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_TAGS_DIALOG))
#define TAGS_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_TAGS_DIALOG, TagsDialogClass))

typedef struct _TagsDialog TagsDialog;
typedef struct _TagsDialogClass TagsDialogClass;
typedef struct _TagsDialogPrivate TagsDialogPrivate;

#define TYPE_HIERARCHICAL_TAG_INDEX (hierarchical_tag_index_get_type ())
#define HIERARCHICAL_TAG_INDEX(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_HIERARCHICAL_TAG_INDEX, HierarchicalTagIndex))
#define HIERARCHICAL_TAG_INDEX_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_HIERARCHICAL_TAG_INDEX, HierarchicalTagIndexClass))
#define IS_HIERARCHICAL_TAG_INDEX(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_HIERARCHICAL_TAG_INDEX))
#define IS_HIERARCHICAL_TAG_INDEX_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_HIERARCHICAL_TAG_INDEX))
#define HIERARCHICAL_TAG_INDEX_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_HIERARCHICAL_TAG_INDEX, HierarchicalTagIndexClass))

typedef struct _HierarchicalTagIndex HierarchicalTagIndex;
typedef struct _HierarchicalTagIndexClass HierarchicalTagIndexClass;
#define _hierarchical_tag_index_unref0(var) ((var == NULL) ? NULL : (var = (hierarchical_tag_index_unref (var), NULL)))

#define TYPE_ADD_TAGS_DIALOG (add_tags_dialog_get_type ())
#define ADD_TAGS_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_ADD_TAGS_DIALOG, AddTagsDialog))
#define ADD_TAGS_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_ADD_TAGS_DIALOG, AddTagsDialogClass))
#define IS_ADD_TAGS_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_ADD_TAGS_DIALOG))
#define IS_ADD_TAGS_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_ADD_TAGS_DIALOG))
#define ADD_TAGS_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_ADD_TAGS_DIALOG, AddTagsDialogClass))

typedef struct _AddTagsDialog AddTagsDialog;
typedef struct _AddTagsDialogClass AddTagsDialogClass;
typedef struct _AddTagsDialogPrivate AddTagsDialogPrivate;

#define TYPE_MODIFY_TAGS_DIALOG (modify_tags_dialog_get_type ())
#define MODIFY_TAGS_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MODIFY_TAGS_DIALOG, ModifyTagsDialog))
#define MODIFY_TAGS_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MODIFY_TAGS_DIALOG, ModifyTagsDialogClass))
#define IS_MODIFY_TAGS_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MODIFY_TAGS_DIALOG))
#define IS_MODIFY_TAGS_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MODIFY_TAGS_DIALOG))
#define MODIFY_TAGS_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MODIFY_TAGS_DIALOG, ModifyTagsDialogClass))

typedef struct _ModifyTagsDialog ModifyTagsDialog;
typedef struct _ModifyTagsDialogClass ModifyTagsDialogClass;
typedef struct _ModifyTagsDialogPrivate ModifyTagsDialogPrivate;

#define TYPE_DATA_COLLECTION (data_collection_get_type ())
#define DATA_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATA_COLLECTION, DataCollection))
#define DATA_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATA_COLLECTION, DataCollectionClass))
#define IS_DATA_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATA_COLLECTION))
#define IS_DATA_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATA_COLLECTION))
#define DATA_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATA_COLLECTION, DataCollectionClass))

typedef struct _DataCollection DataCollection;
typedef struct _DataCollectionClass DataCollectionClass;

#define TYPE_SOURCE_COLLECTION (source_collection_get_type ())
#define SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SOURCE_COLLECTION, SourceCollection))
#define SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SOURCE_COLLECTION, SourceCollectionClass))
#define IS_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SOURCE_COLLECTION))
#define IS_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SOURCE_COLLECTION))
#define SOURCE_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SOURCE_COLLECTION, SourceCollectionClass))

typedef struct _SourceCollection SourceCollection;
typedef struct _SourceCollectionClass SourceCollectionClass;

#define TYPE_DATABASE_SOURCE_COLLECTION (database_source_collection_get_type ())
#define DATABASE_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATABASE_SOURCE_COLLECTION, DatabaseSourceCollection))
#define DATABASE_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATABASE_SOURCE_COLLECTION, DatabaseSourceCollectionClass))
#define IS_DATABASE_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATABASE_SOURCE_COLLECTION))
#define IS_DATABASE_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATABASE_SOURCE_COLLECTION))
#define DATABASE_SOURCE_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATABASE_SOURCE_COLLECTION, DatabaseSourceCollectionClass))

typedef struct _DatabaseSourceCollection DatabaseSourceCollection;
typedef struct _DatabaseSourceCollectionClass DatabaseSourceCollectionClass;

#define TYPE_CONTAINER_SOURCE_COLLECTION (container_source_collection_get_type ())
#define CONTAINER_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_CONTAINER_SOURCE_COLLECTION, ContainerSourceCollection))
#define CONTAINER_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_CONTAINER_SOURCE_COLLECTION, ContainerSourceCollectionClass))
#define IS_CONTAINER_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_CONTAINER_SOURCE_COLLECTION))
#define IS_CONTAINER_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_CONTAINER_SOURCE_COLLECTION))
#define CONTAINER_SOURCE_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_CONTAINER_SOURCE_COLLECTION, ContainerSourceCollectionClass))

typedef struct _ContainerSourceCollection ContainerSourceCollection;
typedef struct _ContainerSourceCollectionClass ContainerSourceCollectionClass;

#define TYPE_TAG_SOURCE_COLLECTION (tag_source_collection_get_type ())
#define TAG_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_TAG_SOURCE_COLLECTION, TagSourceCollection))
#define TAG_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_TAG_SOURCE_COLLECTION, TagSourceCollectionClass))
#define IS_TAG_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_TAG_SOURCE_COLLECTION))
#define IS_TAG_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_TAG_SOURCE_COLLECTION))
#define TAG_SOURCE_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_TAG_SOURCE_COLLECTION, TagSourceCollectionClass))

typedef struct _TagSourceCollection TagSourceCollection;
typedef struct _TagSourceCollectionClass TagSourceCollectionClass;

#define TYPE_WELCOME_SERVICE_ENTRY (welcome_service_entry_get_type ())
#define WELCOME_SERVICE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_WELCOME_SERVICE_ENTRY, WelcomeServiceEntry))
#define IS_WELCOME_SERVICE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_WELCOME_SERVICE_ENTRY))
#define WELCOME_SERVICE_ENTRY_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TYPE_WELCOME_SERVICE_ENTRY, WelcomeServiceEntryIface))

typedef struct _WelcomeServiceEntry WelcomeServiceEntry;
typedef struct _WelcomeServiceEntryIface WelcomeServiceEntryIface;

#define TYPE_WELCOME_DIALOG (welcome_dialog_get_type ())
#define WELCOME_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_WELCOME_DIALOG, WelcomeDialog))
#define WELCOME_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_WELCOME_DIALOG, WelcomeDialogClass))
#define IS_WELCOME_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_WELCOME_DIALOG))
#define IS_WELCOME_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_WELCOME_DIALOG))
#define WELCOME_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_WELCOME_DIALOG, WelcomeDialogClass))

typedef struct _WelcomeDialog WelcomeDialog;
typedef struct _WelcomeDialogClass WelcomeDialogClass;
typedef struct _WelcomeDialogPrivate WelcomeDialogPrivate;

#define SPIT_DATA_IMPORTS_TYPE_WELCOME_IMPORT_META_HOST (spit_data_imports_welcome_import_meta_host_get_type ())
#define SPIT_DATA_IMPORTS_WELCOME_IMPORT_META_HOST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPIT_DATA_IMPORTS_TYPE_WELCOME_IMPORT_META_HOST, SpitDataImportsWelcomeImportMetaHost))
#define SPIT_DATA_IMPORTS_WELCOME_IMPORT_META_HOST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPIT_DATA_IMPORTS_TYPE_WELCOME_IMPORT_META_HOST, SpitDataImportsWelcomeImportMetaHostClass))
#define SPIT_DATA_IMPORTS_IS_WELCOME_IMPORT_META_HOST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPIT_DATA_IMPORTS_TYPE_WELCOME_IMPORT_META_HOST))
#define SPIT_DATA_IMPORTS_IS_WELCOME_IMPORT_META_HOST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPIT_DATA_IMPORTS_TYPE_WELCOME_IMPORT_META_HOST))
#define SPIT_DATA_IMPORTS_WELCOME_IMPORT_META_HOST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPIT_DATA_IMPORTS_TYPE_WELCOME_IMPORT_META_HOST, SpitDataImportsWelcomeImportMetaHostClass))

typedef struct _SpitDataImportsWelcomeImportMetaHost SpitDataImportsWelcomeImportMetaHost;
typedef struct _SpitDataImportsWelcomeImportMetaHostClass SpitDataImportsWelcomeImportMetaHostClass;

#define TYPE_PREFERENCES_DIALOG (preferences_dialog_get_type ())
#define PREFERENCES_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PREFERENCES_DIALOG, PreferencesDialog))
#define PREFERENCES_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PREFERENCES_DIALOG, PreferencesDialogClass))
#define IS_PREFERENCES_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PREFERENCES_DIALOG))
#define IS_PREFERENCES_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PREFERENCES_DIALOG))
#define PREFERENCES_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PREFERENCES_DIALOG, PreferencesDialogClass))

typedef struct _PreferencesDialog PreferencesDialog;
typedef struct _PreferencesDialogClass PreferencesDialogClass;
typedef struct _PreferencesDialogPrivate PreferencesDialogPrivate;

#define TYPE_SORTED_LIST (sorted_list_get_type ())
#define SORTED_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SORTED_LIST, SortedList))
#define SORTED_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SORTED_LIST, SortedListClass))
#define IS_SORTED_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SORTED_LIST))
#define IS_SORTED_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SORTED_LIST))
#define SORTED_LIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SORTED_LIST, SortedListClass))

typedef struct _SortedList SortedList;
typedef struct _SortedListClass SortedListClass;

#define PREFERENCES_DIALOG_TYPE_PATH_FORMAT (preferences_dialog_path_format_get_type ())
#define PREFERENCES_DIALOG_PATH_FORMAT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PREFERENCES_DIALOG_TYPE_PATH_FORMAT, PreferencesDialogPathFormat))
#define PREFERENCES_DIALOG_PATH_FORMAT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PREFERENCES_DIALOG_TYPE_PATH_FORMAT, PreferencesDialogPathFormatClass))
#define PREFERENCES_DIALOG_IS_PATH_FORMAT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PREFERENCES_DIALOG_TYPE_PATH_FORMAT))
#define PREFERENCES_DIALOG_IS_PATH_FORMAT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PREFERENCES_DIALOG_TYPE_PATH_FORMAT))
#define PREFERENCES_DIALOG_PATH_FORMAT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PREFERENCES_DIALOG_TYPE_PATH_FORMAT, PreferencesDialogPathFormatClass))

typedef struct _PreferencesDialogPathFormat PreferencesDialogPathFormat;
typedef struct _PreferencesDialogPathFormatClass PreferencesDialogPathFormatClass;

#define PLUGINS_TYPE_MANIFEST_WIDGET_MEDIATOR (plugins_manifest_widget_mediator_get_type ())
#define PLUGINS_MANIFEST_WIDGET_MEDIATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PLUGINS_TYPE_MANIFEST_WIDGET_MEDIATOR, PluginsManifestWidgetMediator))
#define PLUGINS_MANIFEST_WIDGET_MEDIATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PLUGINS_TYPE_MANIFEST_WIDGET_MEDIATOR, PluginsManifestWidgetMediatorClass))
#define PLUGINS_IS_MANIFEST_WIDGET_MEDIATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PLUGINS_TYPE_MANIFEST_WIDGET_MEDIATOR))
#define PLUGINS_IS_MANIFEST_WIDGET_MEDIATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PLUGINS_TYPE_MANIFEST_WIDGET_MEDIATOR))
#define PLUGINS_MANIFEST_WIDGET_MEDIATOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PLUGINS_TYPE_MANIFEST_WIDGET_MEDIATOR, PluginsManifestWidgetMediatorClass))

typedef struct _PluginsManifestWidgetMediator PluginsManifestWidgetMediator;
typedef struct _PluginsManifestWidgetMediatorClass PluginsManifestWidgetMediatorClass;
#define _g_date_time_unref0(var) ((var == NULL) ? NULL : (var = (g_date_time_unref (var), NULL)))
#define _plugins_manifest_widget_mediator_unref0(var) ((var == NULL) ? NULL : (var = (plugins_manifest_widget_mediator_unref (var), NULL)))

#define TYPE_RAW_DEVELOPER (raw_developer_get_type ())
typedef struct _PreferencesDialogPathFormatPrivate PreferencesDialogPathFormatPrivate;
#define _preferences_dialog_path_format_unref0(var) ((var == NULL) ? NULL : (var = (preferences_dialog_path_format_unref (var), NULL)))
#define _preferences_dialog_unref0(var) ((var == NULL) ? NULL : (var = (preferences_dialog_unref (var), NULL)))
typedef struct _PreferencesDialogParamSpecPathFormat PreferencesDialogParamSpecPathFormat;
typedef struct _ParamSpecPreferencesDialog ParamSpecPreferencesDialog;

#define TYPE_LIBRARY_PHOTO (library_photo_get_type ())
#define LIBRARY_PHOTO(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_LIBRARY_PHOTO, LibraryPhoto))
#define LIBRARY_PHOTO_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_LIBRARY_PHOTO, LibraryPhotoClass))
#define IS_LIBRARY_PHOTO(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_LIBRARY_PHOTO))
#define IS_LIBRARY_PHOTO_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_LIBRARY_PHOTO))
#define LIBRARY_PHOTO_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_LIBRARY_PHOTO, LibraryPhotoClass))

typedef struct _LibraryPhoto LibraryPhoto;
typedef struct _LibraryPhotoClass LibraryPhotoClass;

#define TYPE_VIDEO_SOURCE (video_source_get_type ())
#define VIDEO_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_VIDEO_SOURCE, VideoSource))
#define VIDEO_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_VIDEO_SOURCE, VideoSourceClass))
#define IS_VIDEO_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_VIDEO_SOURCE))
#define IS_VIDEO_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_VIDEO_SOURCE))
#define VIDEO_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_VIDEO_SOURCE, VideoSourceClass))

typedef struct _VideoSource VideoSource;
typedef struct _VideoSourceClass VideoSourceClass;

#define TYPE_VIDEO (video_get_type ())
#define VIDEO(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_VIDEO, Video))
#define VIDEO_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_VIDEO, VideoClass))
#define IS_VIDEO(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_VIDEO))
#define IS_VIDEO_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_VIDEO))
#define VIDEO_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_VIDEO, VideoClass))

typedef struct _Video Video;
typedef struct _VideoClass VideoClass;

#define TYPE_MEDIA_SOURCE_COLLECTION (media_source_collection_get_type ())
#define MEDIA_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollection))
#define MEDIA_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollectionClass))
#define IS_MEDIA_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MEDIA_SOURCE_COLLECTION))
#define IS_MEDIA_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MEDIA_SOURCE_COLLECTION))
#define MEDIA_SOURCE_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollectionClass))

typedef struct _MediaSourceCollection MediaSourceCollection;
typedef struct _MediaSourceCollectionClass MediaSourceCollectionClass;

#define TYPE_LIBRARY_PHOTO_SOURCE_COLLECTION (library_photo_source_collection_get_type ())
#define LIBRARY_PHOTO_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_LIBRARY_PHOTO_SOURCE_COLLECTION, LibraryPhotoSourceCollection))
#define LIBRARY_PHOTO_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_LIBRARY_PHOTO_SOURCE_COLLECTION, LibraryPhotoSourceCollectionClass))
#define IS_LIBRARY_PHOTO_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_LIBRARY_PHOTO_SOURCE_COLLECTION))
#define IS_LIBRARY_PHOTO_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_LIBRARY_PHOTO_SOURCE_COLLECTION))
#define LIBRARY_PHOTO_SOURCE_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_LIBRARY_PHOTO_SOURCE_COLLECTION, LibraryPhotoSourceCollectionClass))

typedef struct _LibraryPhotoSourceCollection LibraryPhotoSourceCollection;
typedef struct _LibraryPhotoSourceCollectionClass LibraryPhotoSourceCollectionClass;

#define TYPE_VIDEO_SOURCE_COLLECTION (video_source_collection_get_type ())
#define VIDEO_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_VIDEO_SOURCE_COLLECTION, VideoSourceCollection))
#define VIDEO_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_VIDEO_SOURCE_COLLECTION, VideoSourceCollectionClass))
#define IS_VIDEO_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_VIDEO_SOURCE_COLLECTION))
#define IS_VIDEO_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_VIDEO_SOURCE_COLLECTION))
#define VIDEO_SOURCE_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_VIDEO_SOURCE_COLLECTION, VideoSourceCollectionClass))

typedef struct _VideoSourceCollection VideoSourceCollection;
typedef struct _VideoSourceCollectionClass VideoSourceCollectionClass;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _ExportDialog {
	GtkDialog parent_instance;
	ExportDialogPrivate * priv;
};

struct _ExportDialogClass {
	GtkDialogClass parent_class;
};

struct _ExportDialogPrivate {
	GtkGrid* table;
	GtkComboBoxText* quality_combo;
	GtkComboBoxText* constraint_combo;
	GtkComboBoxText* format_combo;
	GtkCheckButton* export_metadata;
	GeeArrayList* format_options;
	GtkEntry* pixels_entry;
	GtkWidget* ok_button;
	gboolean in_insert;
};

typedef enum  {
	SCALE_CONSTRAINT_ORIGINAL,
	SCALE_CONSTRAINT_DIMENSIONS,
	SCALE_CONSTRAINT_WIDTH,
	SCALE_CONSTRAINT_HEIGHT,
	SCALE_CONSTRAINT_FILL_VIEWPORT
} ScaleConstraint;

typedef enum  {
	EXPORT_FORMAT_MODE_UNMODIFIED,
	EXPORT_FORMAT_MODE_CURRENT,
	EXPORT_FORMAT_MODE_SPECIFIED,
	EXPORT_FORMAT_MODE_LAST
} ExportFormatMode;

typedef enum  {
	PHOTO_FILE_FORMAT_JFIF,
	PHOTO_FILE_FORMAT_RAW,
	PHOTO_FILE_FORMAT_PNG,
	PHOTO_FILE_FORMAT_TIFF,
	PHOTO_FILE_FORMAT_BMP,
	PHOTO_FILE_FORMAT_UNKNOWN
} PhotoFileFormat;

typedef enum  {
	JPEG_QUALITY_LOW = 50,
	JPEG_QUALITY_MEDIUM = 75,
	JPEG_QUALITY_HIGH = 90,
	JPEG_QUALITY_MAXIMUM = 100
} JpegQuality;

struct _ExportFormatParameters {
	ExportFormatMode mode;
	PhotoFileFormat specified_format;
	JpegQuality quality;
	gboolean export_metadata;
};

typedef enum  {
	IMPORT_RESULT_SUCCESS,
	IMPORT_RESULT_FILE_ERROR,
	IMPORT_RESULT_DECODE_ERROR,
	IMPORT_RESULT_DATABASE_ERROR,
	IMPORT_RESULT_USER_ABORT,
	IMPORT_RESULT_NOT_A_FILE,
	IMPORT_RESULT_PHOTO_EXISTS,
	IMPORT_RESULT_UNSUPPORTED_FORMAT,
	IMPORT_RESULT_NOT_AN_IMAGE,
	IMPORT_RESULT_DISK_FAILURE,
	IMPORT_RESULT_DISK_FULL,
	IMPORT_RESULT_CAMERA_ERROR,
	IMPORT_RESULT_FILE_WRITE_ERROR,
	IMPORT_RESULT_PIXBUF_CORRUPT_IMAGE
} ImportResult;

struct _BatchImportResult {
	GTypeInstance parent_instance;
	volatile int ref_count;
	BatchImportResultPrivate * priv;
	BatchImportJob* job;
	GFile* file;
	gchar* src_identifier;
	gchar* dest_identifier;
	ImportResult result;
	gchar* errmsg;
	DuplicatedFile* duplicate_of;
};

struct _BatchImportResultClass {
	GTypeClass parent_class;
	void (*finalize) (BatchImportResult *self);
};

struct _ImportUIQuestionParams {
	GTypeInstance parent_instance;
	volatile int ref_count;
	ImportUIQuestionParamsPrivate * priv;
	gchar* question;
	gchar* yes_button;
	gchar* no_button;
};

struct _ImportUIQuestionParamsClass {
	GTypeClass parent_class;
	void (*finalize) (ImportUIQuestionParams *self);
};

struct _ImportUIParamSpecQuestionParams {
	GParamSpec parent_instance;
};

struct _ImportManifest {
	GTypeInstance parent_instance;
	volatile int ref_count;
	ImportManifestPrivate * priv;
	GeeList* imported;
	GeeList* success;
	GeeList* camera_failed;
	GeeList* failed;
	GeeList* write_failed;
	GeeList* skipped_photos;
	GeeList* skipped_files;
	GeeList* aborted;
	GeeList* already_imported;
	GeeList* corrupt_files;
	GeeList* all;
};

struct _ImportManifestClass {
	GTypeClass parent_class;
	void (*finalize) (ImportManifest *self);
};

struct _TextEntryDialogMediator {
	GTypeInstance parent_instance;
	volatile int ref_count;
	TextEntryDialogMediatorPrivate * priv;
};

struct _TextEntryDialogMediatorClass {
	GTypeClass parent_class;
	void (*finalize) (TextEntryDialogMediator *self);
	gboolean (*on_modify_validate) (TextEntryDialogMediator* self, const gchar* text);
};

struct _TextEntryDialogMediatorPrivate {
	TextEntryDialog* dialog;
};

typedef gboolean (*TextEntryDialogOnModifyValidateType) (const gchar* text, void* user_data);
struct _ParamSpecTextEntryDialogMediator {
	GParamSpec parent_instance;
};

struct _MultiTextEntryDialogMediator {
	GTypeInstance parent_instance;
	volatile int ref_count;
	MultiTextEntryDialogMediatorPrivate * priv;
};

struct _MultiTextEntryDialogMediatorClass {
	GTypeClass parent_class;
	void (*finalize) (MultiTextEntryDialogMediator *self);
	gboolean (*on_modify_validate) (MultiTextEntryDialogMediator* self, const gchar* text);
};

struct _MultiTextEntryDialogMediatorPrivate {
	MultiTextEntryDialog* dialog;
};

typedef gboolean (*MultiTextEntryDialogOnModifyValidateType) (const gchar* text, void* user_data);
struct _ParamSpecMultiTextEntryDialogMediator {
	GParamSpec parent_instance;
};

struct _EntryMultiCompletion {
	GtkEntryCompletion parent_instance;
	EntryMultiCompletionPrivate * priv;
};

struct _EntryMultiCompletionClass {
	GtkEntryCompletionClass parent_class;
};

struct _EntryMultiCompletionPrivate {
	gchar* delimiter;
};

struct _SetBackgroundDialog {
	GTypeInstance parent_instance;
	volatile int ref_count;
	SetBackgroundDialogPrivate * priv;
	GtkDialog* dialog;
	GtkCheckButton* desktop_background_button;
	GtkCheckButton* screensaver_button;
	GtkButton* ok_button;
	gboolean desktop;
	gboolean screensaver;
};

struct _SetBackgroundDialogClass {
	GTypeClass parent_class;
	void (*finalize) (SetBackgroundDialog *self);
};

struct _ParamSpecSetBackgroundDialog {
	GParamSpec parent_instance;
};

struct _SetBackgroundPhotoDialog {
	SetBackgroundDialog parent_instance;
	SetBackgroundPhotoDialogPrivate * priv;
};

struct _SetBackgroundPhotoDialogClass {
	SetBackgroundDialogClass parent_class;
};

struct _SetBackgroundSlideshowDialog {
	SetBackgroundDialog parent_instance;
	SetBackgroundSlideshowDialogPrivate * priv;
};

struct _SetBackgroundSlideshowDialogClass {
	SetBackgroundDialogClass parent_class;
};

struct _SetBackgroundSlideshowDialogPrivate {
	GtkLabel* delay_value_label;
	GtkScale* delay_scale;
	gint delay_value;
};

struct _TextEntryDialog {
	GtkDialog parent_instance;
	TextEntryDialogPrivate * priv;
};

struct _TextEntryDialogClass {
	GtkDialogClass parent_class;
};

struct _TextEntryDialogPrivate {
	TextEntryDialogOnModifyValidateType on_modify_validate;
	gpointer on_modify_validate_target;
	GtkEntry* entry;
	GtkBuilder* builder;
	GtkButton* button1;
	GtkButton* button2;
	GtkButtonBox* action_area_box;
};

struct _MultiTextEntryDialog {
	GtkDialog parent_instance;
	MultiTextEntryDialogPrivate * priv;
};

struct _MultiTextEntryDialogClass {
	GtkDialogClass parent_class;
};

struct _MultiTextEntryDialogPrivate {
	MultiTextEntryDialogOnModifyValidateType on_modify_validate;
	gpointer on_modify_validate_target;
	GtkTextView* entry;
	GtkBuilder* builder;
	GtkButton* button1;
	GtkButton* button2;
	GtkButtonBox* action_area_box;
};

struct _EventRenameDialog {
	TextEntryDialogMediator parent_instance;
	EventRenameDialogPrivate * priv;
};

struct _EventRenameDialogClass {
	TextEntryDialogMediatorClass parent_class;
	gchar* (*execute) (EventRenameDialog* self);
};

struct _EditTitleDialog {
	TextEntryDialogMediator parent_instance;
	EditTitleDialogPrivate * priv;
};

struct _EditTitleDialogClass {
	TextEntryDialogMediatorClass parent_class;
	gchar* (*execute) (EditTitleDialog* self);
};

struct _EditCommentDialog {
	MultiTextEntryDialogMediator parent_instance;
	EditCommentDialogPrivate * priv;
};

struct _EditCommentDialogClass {
	MultiTextEntryDialogMediatorClass parent_class;
	gchar* (*execute) (EditCommentDialog* self);
};

struct _ProgressDialog {
	GtkWindow parent_instance;
	ProgressDialogPrivate * priv;
};

struct _ProgressDialogClass {
	GtkWindowClass parent_class;
};

struct _ProgressDialogPrivate {
	GtkProgressBar* progress_bar;
	GtkButton* cancel_button;
	GCancellable* cancellable;
	guint64 last_count;
	gint update_every;
	gint minimum_on_screen_time_msec;
	gulong time_started;
};

struct _AdjustDateTimeDialog {
	GtkDialog parent_instance;
	AdjustDateTimeDialogPrivate * priv;
};

struct _AdjustDateTimeDialogClass {
	GtkDialogClass parent_class;
};

typedef enum  {
	ADJUST_DATE_TIME_DIALOG_TIME_SYSTEM_AM,
	ADJUST_DATE_TIME_DIALOG_TIME_SYSTEM_PM,
	ADJUST_DATE_TIME_DIALOG_TIME_SYSTEM_24HR
} AdjustDateTimeDialogTimeSystem;

struct _AdjustDateTimeDialogPrivate {
	gboolean no_original_time;
	time_t original_time;
	GtkLabel* original_time_label;
	GtkCalendar* calendar;
	GtkSpinButton* hour;
	GtkSpinButton* minute;
	GtkSpinButton* second;
	GtkComboBoxText* system;
	GtkRadioButton* relativity_radio_button;
	GtkRadioButton* batch_radio_button;
	GtkCheckButton* modify_originals_check_button;
	GtkLabel* notification;
	AdjustDateTimeDialogTimeSystem previous_time_system;
};

struct _DateableIface {
	GTypeInterface parent_iface;
	void (*set_exposure_time) (Dateable* self, time_t target_time);
	time_t (*get_exposure_time) (Dateable* self);
};

struct _TagsDialog {
	TextEntryDialogMediator parent_instance;
	TagsDialogPrivate * priv;
};

struct _TagsDialogClass {
	TextEntryDialogMediatorClass parent_class;
};

struct _AddTagsDialog {
	TagsDialog parent_instance;
	AddTagsDialogPrivate * priv;
};

struct _AddTagsDialogClass {
	TagsDialogClass parent_class;
};

struct _ModifyTagsDialog {
	TagsDialog parent_instance;
	ModifyTagsDialogPrivate * priv;
};

struct _ModifyTagsDialogClass {
	TagsDialogClass parent_class;
};

struct _WelcomeServiceEntryIface {
	GTypeInterface parent_iface;
	gchar* (*get_service_name) (WelcomeServiceEntry* self);
	void (*execute) (WelcomeServiceEntry* self);
};

struct _WelcomeDialog {
	GtkDialog parent_instance;
	WelcomeDialogPrivate * priv;
};

struct _WelcomeDialogClass {
	GtkDialogClass parent_class;
};

struct _WelcomeDialogPrivate {
	GtkCheckButton* hide_button;
	GtkCheckButton* system_pictures_import_check;
	GtkCheckButton** external_import_checks;
	gint external_import_checks_length1;
	gint _external_import_checks_size_;
	WelcomeServiceEntry** external_import_entries;
	gint external_import_entries_length1;
	gint _external_import_entries_size_;
	GtkLabel* secondary_text;
	GtkLabel* instruction_header;
	GtkBox* import_content;
	GtkBox* import_action_checkbox_packer;
	GtkBox* external_import_action_checkbox_packer;
	SpitDataImportsWelcomeImportMetaHost* import_meta_host;
	gboolean import_content_already_installed;
	gboolean ok_clicked;
};

struct _PreferencesDialog {
	GTypeInstance parent_instance;
	volatile int ref_count;
	PreferencesDialogPrivate * priv;
};

struct _PreferencesDialogClass {
	GTypeClass parent_class;
	void (*finalize) (PreferencesDialog *self);
};

struct _PreferencesDialogPrivate {
	GtkDialog* dialog;
	GtkBuilder* builder;
	GtkAdjustment* bg_color_adjustment;
	GtkScale* bg_color_slider;
	GtkComboBox* photo_editor_combo;
	GtkComboBox* raw_editor_combo;
	SortedList* external_raw_apps;
	SortedList* external_photo_apps;
	GtkFileChooserButton* library_dir_button;
	GtkComboBoxText* dir_pattern_combo;
	GtkEntry* dir_pattern_entry;
	GtkLabel* dir_pattern_example;
	gboolean allow_closing;
	gchar* lib_dir;
	GeeArrayList* path_formats;
	GDateTime* example_date;
	GtkCheckButton* lowercase;
	PluginsManifestWidgetMediator* plugins_mediator;
	GtkComboBoxText* default_raw_developer_combo;
};

typedef enum  {
	RAW_DEVELOPER_SHOTWELL = 0,
	RAW_DEVELOPER_CAMERA,
	RAW_DEVELOPER_EMBEDDED
} RawDeveloper;

struct _PreferencesDialogPathFormat {
	GTypeInstance parent_instance;
	volatile int ref_count;
	PreferencesDialogPathFormatPrivate * priv;
	gchar* name;
	gchar* pattern;
};

struct _PreferencesDialogPathFormatClass {
	GTypeClass parent_class;
	void (*finalize) (PreferencesDialogPathFormat *self);
};

struct _PreferencesDialogParamSpecPathFormat {
	GParamSpec parent_instance;
};

struct _ParamSpecPreferencesDialog {
	GParamSpec parent_instance;
};

typedef gboolean (*ProgressMonitor) (guint64 current, guint64 total, gboolean do_event_loop, void* user_data);

extern GFile* export_ui_current_export_dir;
GFile* export_ui_current_export_dir = NULL;
static gpointer export_dialog_parent_class = NULL;
static ScaleConstraint export_dialog_current_constraint;
static ScaleConstraint export_dialog_current_constraint = SCALE_CONSTRAINT_ORIGINAL;
static ExportFormatParameters export_dialog_current_parameters;
static ExportFormatParameters export_dialog_current_parameters = {0};
static gint export_dialog_current_scale;
static gint export_dialog_current_scale = 0;
static gpointer import_ui_question_params_parent_class = NULL;
static gpointer text_entry_dialog_mediator_parent_class = NULL;
static gpointer multi_text_entry_dialog_mediator_parent_class = NULL;
static gpointer entry_multi_completion_parent_class = NULL;
static gpointer set_background_dialog_parent_class = NULL;
static gpointer set_background_photo_dialog_parent_class = NULL;
static gpointer set_background_slideshow_dialog_parent_class = NULL;
static gpointer text_entry_dialog_parent_class = NULL;
static gpointer multi_text_entry_dialog_parent_class = NULL;
static gpointer event_rename_dialog_parent_class = NULL;
static gpointer edit_title_dialog_parent_class = NULL;
static gpointer edit_comment_dialog_parent_class = NULL;
static gpointer progress_dialog_parent_class = NULL;
static gpointer adjust_date_time_dialog_parent_class = NULL;
static gpointer tags_dialog_parent_class = NULL;
static gpointer add_tags_dialog_parent_class = NULL;
static gpointer modify_tags_dialog_parent_class = NULL;
extern TagSourceCollection* tag_global;
static gpointer welcome_dialog_parent_class = NULL;
static gpointer preferences_dialog_parent_class = NULL;
static PreferencesDialog* preferences_dialog_preferences_dialog;
static PreferencesDialog* preferences_dialog_preferences_dialog = NULL;
static gpointer preferences_dialog_path_format_parent_class = NULL;
extern LibraryPhotoSourceCollection* library_photo_global;
extern VideoSourceCollection* video_global;

GType data_object_get_type (void) G_GNUC_CONST;
GType data_source_get_type (void) G_GNUC_CONST;
GType tag_get_type (void) G_GNUC_CONST;
gboolean dialogs_confirm_delete_tag (Tag* tag);
gint tag_get_sources_count (Tag* self);
gchar* tag_get_user_visible_name (Tag* self);
gboolean app_window_negate_affirm_question (const gchar* message, const gchar* negative, const gchar* affirmative, const gchar* title, GtkWindow* parent);
#define RESOURCES_DELETE_TAG_TITLE _ ("Delete Tag")
GType saved_search_get_type (void) G_GNUC_CONST;
gboolean dialogs_confirm_delete_saved_search (SavedSearch* search);
gchar* data_object_get_name (DataObject* self);
#define RESOURCES_DELETE_SAVED_SEARCH_DIALOG_TITLE _ ("Delete Search")
gboolean dialogs_confirm_warn_developer_changed (gint number);
GType page_window_get_type (void) G_GNUC_CONST;
GType app_window_get_type (void) G_GNUC_CONST;
AppWindow* app_window_get_instance (void);
#define RESOURCES_CANCEL_LABEL _ ("_Cancel")
GFile* export_ui_choose_file (const gchar* current_file_basename);
gboolean video_reader_is_supported_video_filename (const gchar* filename);
#define RESOURCES_SAVE_LABEL _ ("_Save")
void suppress_warnings (const gchar* log_domain, GLogLevelFlags log_levels, const gchar* message);
static void _suppress_warnings_glog_func (const gchar* log_domain, GLogLevelFlags log_levels, const gchar* message, gpointer self);
GFile* export_ui_choose_dir (const gchar* user_title);
#define RESOURCES_OK_LABEL _ ("_OK")
GType thumbnail_source_get_type (void) G_GNUC_CONST;
GType media_source_get_type (void) G_GNUC_CONST;
GType photo_source_get_type (void) G_GNUC_CONST;
GType photo_get_type (void) G_GNUC_CONST;
void open_external_editor_error_dialog (GError* err, Photo* photo);
void app_window_error_message (const gchar* message, GtkWindow* parent);
GFile* media_source_get_master_file (MediaSource* self);
gchar* resources_launch_editor_failed (GError* err);
GtkResponseType export_error_dialog (GFile* dest, gboolean photos_remaining);
GtkResponseType app_window_affirm_cancel_question (const gchar* message, const gchar* affirmative, const gchar* title, GtkWindow* parent);
GType export_dialog_get_type (void) G_GNUC_CONST;
#define EXPORT_DIALOG_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_EXPORT_DIALOG, ExportDialogPrivate))
enum  {
	EXPORT_DIALOG_DUMMY_PROPERTY
};
GType scale_constraint_get_type (void) G_GNUC_CONST;
GType export_format_parameters_get_type (void) G_GNUC_CONST;
GType export_format_mode_get_type (void) G_GNUC_CONST;
GType photo_file_format_get_type (void) G_GNUC_CONST;
GType jpeg_quality_get_type (void) G_GNUC_CONST;
ExportFormatParameters* export_format_parameters_dup (const ExportFormatParameters* self);
void export_format_parameters_free (ExportFormatParameters* self);
void export_format_parameters_current (ExportFormatParameters* result);
#define EXPORT_DIALOG_DEFAULT_SCALE 1200
#define EXPORT_DIALOG_NUM_SPECIAL_FORMATS 2
#define EXPORT_DIALOG_UNMODIFIED_FORMAT_LABEL _ ("Unmodified")
#define EXPORT_DIALOG_CURRENT_FORMAT_LABEL _ ("Current")
ExportDialog* export_dialog_new (const gchar* title);
ExportDialog* export_dialog_construct (GType object_type, const gchar* title);
gchar* jpeg_quality_to_string (JpegQuality self);
gchar* scale_constraint_to_string (ScaleConstraint self);
static void export_dialog_format_add_option (ExportDialog* self, const gchar* format_name);
PhotoFileFormat* photo_file_format_get_writeable (int* result_length1);
gpointer photo_file_format_properties_ref (gpointer instance);
void photo_file_format_properties_unref (gpointer instance);
GParamSpec* param_spec_photo_file_format_properties (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_photo_file_format_properties (GValue* value, gpointer v_object);
void value_take_photo_file_format_properties (GValue* value, gpointer v_object);
gpointer value_get_photo_file_format_properties (const GValue* value);
GType photo_file_format_properties_get_type (void) G_GNUC_CONST;
PhotoFileFormatProperties* photo_file_format_get_properties (PhotoFileFormat self);
gchar* photo_file_format_properties_get_user_visible_name (PhotoFileFormatProperties* self);
static void export_dialog_on_constraint_changed (ExportDialog* self);
static void _export_dialog_on_constraint_changed_gtk_combo_box_changed (GtkComboBox* _sender, gpointer self);
static void export_dialog_on_format_changed (ExportDialog* self);
static void _export_dialog_on_format_changed_gtk_combo_box_changed (GtkComboBox* _sender, gpointer self);
static void export_dialog_on_pixels_changed (ExportDialog* self);
static void _export_dialog_on_pixels_changed_gtk_editable_changed (GtkEditable* _sender, gpointer self);
static void export_dialog_on_pixels_insert_text (ExportDialog* self, const gchar* text, gint length, gint* position);
static void _export_dialog_on_pixels_insert_text_gtk_editable_insert_text (GtkEditable* _sender, const gchar* new_text, gint new_text_length, gint* position, gpointer self);
static void export_dialog_on_activate (ExportDialog* self);
static void _export_dialog_on_activate_gtk_entry_activate (GtkEntry* _sender, gpointer self);
static void export_dialog_add_label (ExportDialog* self, const gchar* text, gint x, gint y, GtkWidget* widget);
static void export_dialog_add_control (ExportDialog* self, GtkWidget* widget, gint x, gint y);
static void export_dialog_format_set_active_text (ExportDialog* self, const gchar* text);
static PhotoFileFormat export_dialog_get_specified_format (ExportDialog* self);
static gchar* export_dialog_get_label_for_parameters (ExportDialog* self, ExportFormatParameters* params);
gboolean export_dialog_execute (ExportDialog* self, gint* scale, ScaleConstraint* constraint, ExportFormatParameters* parameters);
gboolean photo_file_format_can_write (PhotoFileFormat self);
PhotoFileFormat photo_file_format_get_system_default_format (void);
static void export_dialog_finalize (GObject* obj);
#define IMPORT_UI_REPORT_FAILURE_COUNT 4
#define IMPORT_UI_SAVE_RESULTS_BUTTON_NAME _ ("Save Details...")
#define IMPORT_UI_SAVE_RESULTS_FILE_CHOOSER_TITLE _ ("Save Details")
#define IMPORT_UI_SAVE_RESULTS_RESPONSE_ID 1024
gpointer batch_import_result_ref (gpointer instance);
void batch_import_result_unref (gpointer instance);
GParamSpec* param_spec_batch_import_result (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_batch_import_result (GValue* value, gpointer v_object);
void value_take_batch_import_result (GValue* value, gpointer v_object);
gpointer value_get_batch_import_result (const GValue* value);
GType batch_import_result_get_type (void) G_GNUC_CONST;
gchar* import_ui_generate_import_failure_list (GeeList* failed, gboolean show_dest_id);
gpointer batch_import_job_ref (gpointer instance);
void batch_import_job_unref (gpointer instance);
GParamSpec* param_spec_batch_import_job (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_batch_import_job (GValue* value, gpointer v_object);
void value_take_batch_import_job (GValue* value, gpointer v_object);
gpointer value_get_batch_import_job (const GValue* value);
GType batch_import_job_get_type (void) G_GNUC_CONST;
GType import_result_get_type (void) G_GNUC_CONST;
GType duplicated_file_get_type (void) G_GNUC_CONST;
gpointer import_ui_question_params_ref (gpointer instance);
void import_ui_question_params_unref (gpointer instance);
GParamSpec* import_ui_param_spec_question_params (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void import_ui_value_set_question_params (GValue* value, gpointer v_object);
void import_ui_value_take_question_params (GValue* value, gpointer v_object);
gpointer import_ui_value_get_question_params (const GValue* value);
GType import_ui_question_params_get_type (void) G_GNUC_CONST;
enum  {
	IMPORT_UI_QUESTION_PARAMS_DUMMY_PROPERTY
};
ImportUIQuestionParams* import_ui_question_params_new (const gchar* question, const gchar* yes_button, const gchar* no_button);
ImportUIQuestionParams* import_ui_question_params_construct (GType object_type, const gchar* question, const gchar* yes_button, const gchar* no_button);
static void import_ui_question_params_finalize (ImportUIQuestionParams* obj);
gboolean import_ui_import_has_photos (GeeCollection* import_collection);
PhotoFileFormat photo_file_format_get_by_file_extension (GFile* file);
gboolean import_ui_import_has_videos (GeeCollection* import_collection);
gboolean video_reader_is_supported_video_file (GFile* file);
gchar* import_ui_get_media_specific_string (GeeCollection* import_collection, const gchar* photos_msg, const gchar* videos_msg, const gchar* both_msg, const gchar* neither_msg);
gpointer import_manifest_ref (gpointer instance);
void import_manifest_unref (gpointer instance);
GParamSpec* param_spec_import_manifest (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_import_manifest (GValue* value, gpointer v_object);
void value_take_import_manifest (GValue* value, gpointer v_object);
gpointer value_get_import_manifest (const GValue* value);
GType import_manifest_get_type (void) G_GNUC_CONST;
gchar* import_ui_create_result_report_from_manifest (ImportManifest* manifest);
#define RESOURCES_APP_VERSION _VERSION
GFile* duplicated_file_get_file (DuplicatedFile* self);
gboolean import_ui_report_manifest (ImportManifest* manifest, gboolean show_dest_id, ImportUIQuestionParams* question);
void import_ui_save_import_results (GtkWindow* chooser_dialog_parent, const gchar* results_log);
#define RESOURCES_SAVE_AS_LABEL _ ("Save _As")
gpointer text_entry_dialog_mediator_ref (gpointer instance);
void text_entry_dialog_mediator_unref (gpointer instance);
GParamSpec* param_spec_text_entry_dialog_mediator (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_text_entry_dialog_mediator (GValue* value, gpointer v_object);
void value_take_text_entry_dialog_mediator (GValue* value, gpointer v_object);
gpointer value_get_text_entry_dialog_mediator (const GValue* value);
GType text_entry_dialog_mediator_get_type (void) G_GNUC_CONST;
GType text_entry_dialog_get_type (void) G_GNUC_CONST;
#define TEXT_ENTRY_DIALOG_MEDIATOR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_TEXT_ENTRY_DIALOG_MEDIATOR, TextEntryDialogMediatorPrivate))
enum  {
	TEXT_ENTRY_DIALOG_MEDIATOR_DUMMY_PROPERTY
};
TextEntryDialogMediator* text_entry_dialog_mediator_construct (GType object_type, const gchar* title, const gchar* label, const gchar* initial_text, GeeCollection* completion_list, const gchar* completion_delimiter);
GtkBuilder* app_window_create_builder (const gchar* glade_filename, void* user);
TextEntryDialog* text_entry_dialog_new (void);
TextEntryDialog* text_entry_dialog_construct (GType object_type);
void text_entry_dialog_set_builder (TextEntryDialog* self, GtkBuilder* builder);
void text_entry_dialog_setup (TextEntryDialog* self, TextEntryDialogOnModifyValidateType modify_validate, void* modify_validate_target, const gchar* title, const gchar* label, const gchar* initial_text, GeeCollection* completion_list, const gchar* completion_delimiter);
gboolean text_entry_dialog_mediator_on_modify_validate (TextEntryDialogMediator* self, const gchar* text);
static gboolean _text_entry_dialog_mediator_on_modify_validate_text_entry_dialog_on_modify_validate_type (const gchar* text, gpointer self);
static gboolean text_entry_dialog_mediator_real_on_modify_validate (TextEntryDialogMediator* self, const gchar* text);
gchar* _text_entry_dialog_mediator_execute (TextEntryDialogMediator* self);
gchar* text_entry_dialog_execute (TextEntryDialog* self);
static void text_entry_dialog_mediator_finalize (TextEntryDialogMediator* obj);
gpointer multi_text_entry_dialog_mediator_ref (gpointer instance);
void multi_text_entry_dialog_mediator_unref (gpointer instance);
GParamSpec* param_spec_multi_text_entry_dialog_mediator (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_multi_text_entry_dialog_mediator (GValue* value, gpointer v_object);
void value_take_multi_text_entry_dialog_mediator (GValue* value, gpointer v_object);
gpointer value_get_multi_text_entry_dialog_mediator (const GValue* value);
GType multi_text_entry_dialog_mediator_get_type (void) G_GNUC_CONST;
GType multi_text_entry_dialog_get_type (void) G_GNUC_CONST;
#define MULTI_TEXT_ENTRY_DIALOG_MEDIATOR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR, MultiTextEntryDialogMediatorPrivate))
enum  {
	MULTI_TEXT_ENTRY_DIALOG_MEDIATOR_DUMMY_PROPERTY
};
MultiTextEntryDialogMediator* multi_text_entry_dialog_mediator_construct (GType object_type, const gchar* title, const gchar* label, const gchar* initial_text);
MultiTextEntryDialog* multi_text_entry_dialog_new (void);
MultiTextEntryDialog* multi_text_entry_dialog_construct (GType object_type);
void multi_text_entry_dialog_set_builder (MultiTextEntryDialog* self, GtkBuilder* builder);
void multi_text_entry_dialog_setup (MultiTextEntryDialog* self, MultiTextEntryDialogOnModifyValidateType modify_validate, void* modify_validate_target, const gchar* title, const gchar* label, const gchar* initial_text);
gboolean multi_text_entry_dialog_mediator_on_modify_validate (MultiTextEntryDialogMediator* self, const gchar* text);
static gboolean _multi_text_entry_dialog_mediator_on_modify_validate_multi_text_entry_dialog_on_modify_validate_type (const gchar* text, gpointer self);
static gboolean multi_text_entry_dialog_mediator_real_on_modify_validate (MultiTextEntryDialogMediator* self, const gchar* text);
gchar* _multi_text_entry_dialog_mediator_execute (MultiTextEntryDialogMediator* self);
gchar* multi_text_entry_dialog_execute (MultiTextEntryDialog* self);
static void multi_text_entry_dialog_mediator_finalize (MultiTextEntryDialogMediator* obj);
gchar* build_alert_body_text (const gchar* primary_text, const gchar* secondary_text, gboolean should_escape);
gchar* guarded_markup_escape_text (const gchar* plain);
GType entry_multi_completion_get_type (void) G_GNUC_CONST;
#define ENTRY_MULTI_COMPLETION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_ENTRY_MULTI_COMPLETION, EntryMultiCompletionPrivate))
enum  {
	ENTRY_MULTI_COMPLETION_DUMMY_PROPERTY
};
EntryMultiCompletion* entry_multi_completion_new (GeeCollection* completion_list, const gchar* delimiter);
EntryMultiCompletion* entry_multi_completion_construct (GType object_type, GeeCollection* completion_list, const gchar* delimiter);
static GtkListStore* entry_multi_completion_create_completion_store (GeeCollection* completion_list);
static gboolean entry_multi_completion_match_func (EntryMultiCompletion* self, GtkEntryCompletion* completion, const gchar* key, GtkTreeIter* iter);
static gboolean _entry_multi_completion_match_func_gtk_entry_completion_match_func (GtkEntryCompletion* completion, const gchar* key, GtkTreeIter* iter, gpointer self);
static gchar* entry_multi_completion_get_last_part (const gchar* s, const gchar* delimiter);
static gboolean entry_multi_completion_real_match_selected (GtkEntryCompletion* base, GtkTreeModel* model, GtkTreeIter* iter);
static void entry_multi_completion_finalize (GObject* obj);
gpointer set_background_dialog_ref (gpointer instance);
void set_background_dialog_unref (gpointer instance);
GParamSpec* param_spec_set_background_dialog (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_set_background_dialog (GValue* value, gpointer v_object);
void value_take_set_background_dialog (GValue* value, gpointer v_object);
gpointer value_get_set_background_dialog (const GValue* value);
GType set_background_dialog_get_type (void) G_GNUC_CONST;
enum  {
	SET_BACKGROUND_DIALOG_DUMMY_PROPERTY
};
SetBackgroundDialog* set_background_dialog_construct (GType object_type, GtkBuilder* builder);
void set_background_dialog_on_checkbox_clicked (SetBackgroundDialog* self);
static void _set_background_dialog_on_checkbox_clicked_gtk_toggle_button_toggled (GtkToggleButton* _sender, gpointer self);
gboolean set_background_dialog_execute_base (SetBackgroundDialog* self);
static void set_background_dialog_finalize (SetBackgroundDialog* obj);
GType set_background_photo_dialog_get_type (void) G_GNUC_CONST;
enum  {
	SET_BACKGROUND_PHOTO_DIALOG_DUMMY_PROPERTY
};
SetBackgroundPhotoDialog* set_background_photo_dialog_new (void);
SetBackgroundPhotoDialog* set_background_photo_dialog_construct (GType object_type);
gboolean set_background_photo_dialog_execute (SetBackgroundPhotoDialog* self, gboolean* desktop_background, gboolean* screensaver);
GType set_background_slideshow_dialog_get_type (void) G_GNUC_CONST;
#define SET_BACKGROUND_SLIDESHOW_DIALOG_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_SET_BACKGROUND_SLIDESHOW_DIALOG, SetBackgroundSlideshowDialogPrivate))
enum  {
	SET_BACKGROUND_SLIDESHOW_DIALOG_DUMMY_PROPERTY
};
SetBackgroundSlideshowDialog* set_background_slideshow_dialog_new (void);
SetBackgroundSlideshowDialog* set_background_slideshow_dialog_construct (GType object_type);
static void set_background_slideshow_dialog_on_delay_scale_value_changed (SetBackgroundSlideshowDialog* self);
static void _set_background_slideshow_dialog_on_delay_scale_value_changed_gtk_range_value_changed (GtkRange* _sender, gpointer self);
gboolean set_background_slideshow_dialog_execute (SetBackgroundSlideshowDialog* self, gint* delay_value, gboolean* desktop_background, gboolean* screensaver);
static void set_background_slideshow_dialog_finalize (SetBackgroundDialog* obj);
#define TEXT_ENTRY_DIALOG_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_TEXT_ENTRY_DIALOG, TextEntryDialogPrivate))
enum  {
	TEXT_ENTRY_DIALOG_DUMMY_PROPERTY
};
void text_entry_dialog_on_entry_changed (TextEntryDialog* self);
static void _text_entry_dialog_on_entry_changed_gtk_editable_changed (GtkEditable* _sender, gpointer self);
static void text_entry_dialog_finalize (GObject* obj);
#define MULTI_TEXT_ENTRY_DIALOG_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_MULTI_TEXT_ENTRY_DIALOG, MultiTextEntryDialogPrivate))
enum  {
	MULTI_TEXT_ENTRY_DIALOG_DUMMY_PROPERTY
};
static void multi_text_entry_dialog_finalize (GObject* obj);
GType event_rename_dialog_get_type (void) G_GNUC_CONST;
enum  {
	EVENT_RENAME_DIALOG_DUMMY_PROPERTY
};
EventRenameDialog* event_rename_dialog_new (const gchar* event_name);
EventRenameDialog* event_rename_dialog_construct (GType object_type, const gchar* event_name);
gchar* event_rename_dialog_execute (EventRenameDialog* self);
static gchar* event_rename_dialog_real_execute (EventRenameDialog* self);
gchar* event_prep_event_name (const gchar* name);
GType edit_title_dialog_get_type (void) G_GNUC_CONST;
enum  {
	EDIT_TITLE_DIALOG_DUMMY_PROPERTY
};
EditTitleDialog* edit_title_dialog_new (const gchar* photo_title);
EditTitleDialog* edit_title_dialog_construct (GType object_type, const gchar* photo_title);
gchar* edit_title_dialog_execute (EditTitleDialog* self);
static gchar* edit_title_dialog_real_execute (EditTitleDialog* self);
gchar* media_source_prep_title (const gchar* title);
static gboolean edit_title_dialog_real_on_modify_validate (TextEntryDialogMediator* base, const gchar* text);
GType edit_comment_dialog_get_type (void) G_GNUC_CONST;
enum  {
	EDIT_COMMENT_DIALOG_DUMMY_PROPERTY
};
EditCommentDialog* edit_comment_dialog_new (const gchar* comment, gboolean is_event);
EditCommentDialog* edit_comment_dialog_construct (GType object_type, const gchar* comment, gboolean is_event);
gchar* edit_comment_dialog_execute (EditCommentDialog* self);
static gchar* edit_comment_dialog_real_execute (EditCommentDialog* self);
gchar* media_source_prep_comment (const gchar* comment);
static gboolean edit_comment_dialog_real_on_modify_validate (MultiTextEntryDialogMediator* base, const gchar* text);
GtkResponseType remove_from_library_dialog (GtkWindow* owner, const gchar* title, const gchar* user_message, gint count);
GtkResponseType remove_from_filesystem_dialog (GtkWindow* owner, const gchar* title, const gchar* user_message);
gboolean revert_editable_dialog (GtkWindow* owner, GeeCollection* photos);
gboolean photo_has_editable (Photo* self);
gboolean remove_offline_dialog (GtkWindow* owner, gint count);
GType progress_dialog_get_type (void) G_GNUC_CONST;
#define PROGRESS_DIALOG_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_PROGRESS_DIALOG, ProgressDialogPrivate))
enum  {
	PROGRESS_DIALOG_DUMMY_PROPERTY
};
ProgressDialog* progress_dialog_new (GtkWindow* owner, const gchar* text, GCancellable* cancellable);
ProgressDialog* progress_dialog_construct (GType object_type, GtkWindow* owner, const gchar* text, GCancellable* cancellable);
static void progress_dialog_on_cancel (ProgressDialog* self);
static void _progress_dialog_on_cancel_gtk_button_clicked (GtkButton* _sender, gpointer self);
static gboolean progress_dialog_on_window_closed (ProgressDialog* self);
static gboolean _progress_dialog_on_window_closed_gtk_widget_delete_event (GtkWidget* _sender, GdkEventAny* event, gpointer self);
gulong now_ms (void);
static void progress_dialog_real_realize (GtkWidget* base);
void progress_dialog_update_display_every (ProgressDialog* self, gint update_every);
void progress_dialog_set_minimum_on_screen_time_msec (ProgressDialog* self, gint minimum_on_screen_time_msec);
void progress_dialog_set_fraction (ProgressDialog* self, gint current, gint total);
void progress_dialog_set_percentage (ProgressDialog* self, gdouble pct);
static void progress_dialog_maybe_show_all (ProgressDialog* self, gdouble pct);
void progress_dialog_set_status (ProgressDialog* self, const gchar* text);
gboolean progress_dialog_monitor (ProgressDialog* self, guint64 count, guint64 total, gboolean do_event_loop);
void spin_event_loop (void);
void progress_dialog_close (ProgressDialog* self);
static void progress_dialog_finalize (GObject* obj);
GType adjust_date_time_dialog_get_type (void) G_GNUC_CONST;
static GType adjust_date_time_dialog_time_system_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
#define ADJUST_DATE_TIME_DIALOG_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_ADJUST_DATE_TIME_DIALOG, AdjustDateTimeDialogPrivate))
enum  {
	ADJUST_DATE_TIME_DIALOG_DUMMY_PROPERTY
};
#define ADJUST_DATE_TIME_DIALOG_SECONDS_IN_DAY ((gint64) ((60 * 60) * 24))
#define ADJUST_DATE_TIME_DIALOG_SECONDS_IN_HOUR ((gint64) (60 * 60))
#define ADJUST_DATE_TIME_DIALOG_SECONDS_IN_MINUTE ((gint64) 60)
#define ADJUST_DATE_TIME_DIALOG_YEAR_OFFSET 1900
#define ADJUST_DATE_TIME_DIALOG_CALENDAR_THUMBNAIL_SCALE 1
GType dateable_get_type (void) G_GNUC_CONST;
AdjustDateTimeDialog* adjust_date_time_dialog_new (Dateable* source, gint photo_count, gboolean display_options, gboolean contains_video, gboolean only_video);
AdjustDateTimeDialog* adjust_date_time_dialog_construct (GType object_type, Dateable* source, gint photo_count, gboolean display_options, gboolean contains_video, gboolean only_video);
#define RESOURCES_ADJUST_DATE_TIME_LABEL _ ("Adjust Date and Time")
static void adjust_date_time_dialog_on_time_changed (AdjustDateTimeDialog* self);
static void _adjust_date_time_dialog_on_time_changed_gtk_calendar_day_selected (GtkCalendar* _sender, gpointer self);
static void _adjust_date_time_dialog_on_time_changed_gtk_calendar_month_changed (GtkCalendar* _sender, gpointer self);
static void _adjust_date_time_dialog_on_time_changed_gtk_calendar_next_year (GtkCalendar* _sender, gpointer self);
static void _adjust_date_time_dialog_on_time_changed_gtk_calendar_prev_year (GtkCalendar* _sender, gpointer self);
GType configuration_facade_get_type (void) G_GNUC_CONST;
GType config_facade_get_type (void) G_GNUC_CONST;
ConfigFacade* config_facade_get_instance (void);
gboolean configuration_facade_get_use_24_hour_time (ConfigurationFacade* self);
static gboolean adjust_date_time_dialog_on_spin_button_output (AdjustDateTimeDialog* self, GtkSpinButton* button);
static gboolean _adjust_date_time_dialog_on_spin_button_output_gtk_spin_button_output (GtkSpinButton* _sender, gpointer self);
static void adjust_date_time_dialog_on_time_system_changed (AdjustDateTimeDialog* self);
static void _adjust_date_time_dialog_on_time_system_changed_gtk_combo_box_changed (GtkComboBox* _sender, gpointer self);
gboolean configuration_facade_get_keep_relativity (ConfigurationFacade* self);
static void _adjust_date_time_dialog_on_time_changed_gtk_toggle_button_toggled (GtkToggleButton* _sender, gpointer self);
gboolean configuration_facade_get_commit_metadata_to_masters (ConfigurationFacade* self);
GdkPixbuf* thumbnail_source_get_thumbnail (ThumbnailSource* self, gint scale, GError** error);
gchar* data_object_to_string (DataObject* self);
time_t dateable_get_exposure_time (Dateable* self);
static void adjust_date_time_dialog_set_time (AdjustDateTimeDialog* self, struct tm* time);
static void adjust_date_time_dialog_set_original_time_label (AdjustDateTimeDialog* self, gboolean use_24_hr_format);
static time_t adjust_date_time_dialog_get_time (AdjustDateTimeDialog* self);
gboolean adjust_date_time_dialog_execute (AdjustDateTimeDialog* self, gint64* time_shift, gboolean* keep_relativity, gboolean* modify_originals);
void configuration_facade_set_keep_relativity (ConfigurationFacade* self, gboolean keep_relativity);
void configuration_facade_set_modify_originals (ConfigurationFacade* self, gboolean modify_originals);
void configuration_facade_set_use_24_hour_time (ConfigurationFacade* self, gboolean use_24_hour_time);
static void adjust_date_time_dialog_finalize (GObject* obj);
#define MAX_OBJECTS_DISPLAYED 3
void multiple_object_error_dialog (GeeArrayList* objects, const gchar* message, const gchar* title);
GType tags_dialog_get_type (void) G_GNUC_CONST;
enum  {
	TAGS_DIALOG_DUMMY_PROPERTY
};
TagsDialog* tags_dialog_construct (GType object_type, const gchar* title, const gchar* label, const gchar* initial_text);
gpointer hierarchical_tag_index_ref (gpointer instance);
void hierarchical_tag_index_unref (gpointer instance);
GParamSpec* param_spec_hierarchical_tag_index (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_hierarchical_tag_index (GValue* value, gpointer v_object);
void value_take_hierarchical_tag_index (GValue* value, gpointer v_object);
gpointer value_get_hierarchical_tag_index (const GValue* value);
GType hierarchical_tag_index_get_type (void) G_GNUC_CONST;
HierarchicalTagIndex* hierarchical_tag_index_get_global_index (void);
GeeCollection* hierarchical_tag_index_get_all_tags (HierarchicalTagIndex* self);
GType add_tags_dialog_get_type (void) G_GNUC_CONST;
enum  {
	ADD_TAGS_DIALOG_DUMMY_PROPERTY
};
AddTagsDialog* add_tags_dialog_new (void);
AddTagsDialog* add_tags_dialog_construct (GType object_type);
#define RESOURCES_ADD_TAGS_TITLE "Add Tags"
gchar** add_tags_dialog_execute (AddTagsDialog* self, int* result_length1);
gchar** tag_prep_tag_names (gchar** names, int names_length1, int* result_length1);
static gboolean add_tags_dialog_real_on_modify_validate (TextEntryDialogMediator* base, const gchar* text);
#define TAG_PATH_SEPARATOR_STRING "/"
GType modify_tags_dialog_get_type (void) G_GNUC_CONST;
enum  {
	MODIFY_TAGS_DIALOG_DUMMY_PROPERTY
};
ModifyTagsDialog* modify_tags_dialog_new (MediaSource* source);
ModifyTagsDialog* modify_tags_dialog_construct (GType object_type, MediaSource* source);
#define RESOURCES_MODIFY_TAGS_LABEL _ ("Modify Tags")
static gchar* modify_tags_dialog_get_initial_text (MediaSource* source);
gpointer data_collection_ref (gpointer instance);
void data_collection_unref (gpointer instance);
GParamSpec* param_spec_data_collection (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_data_collection (GValue* value, gpointer v_object);
void value_take_data_collection (GValue* value, gpointer v_object);
gpointer value_get_data_collection (const GValue* value);
GType data_collection_get_type (void) G_GNUC_CONST;
GType source_collection_get_type (void) G_GNUC_CONST;
GType database_source_collection_get_type (void) G_GNUC_CONST;
GType container_source_collection_get_type (void) G_GNUC_CONST;
GType tag_source_collection_get_type (void) G_GNUC_CONST;
GeeList* tag_source_collection_fetch_for_source (TagSourceCollection* self, MediaSource* source);
GeeCollection* tag_get_terminal_tags (GeeCollection* tags);
gchar* hierarchical_tag_utilities_get_basename (const gchar* in_path);
gchar* tag_get_path (Tag* self);
GeeArrayList* modify_tags_dialog_execute (ModifyTagsDialog* self);
gboolean is_string_empty (const gchar* s);
gchar** hierarchical_tag_index_get_paths_for_names_array (HierarchicalTagIndex* self, gchar** names, int names_length1, int* result_length1);
Tag* tag_for_path (const gchar* name);
static gboolean modify_tags_dialog_real_on_modify_validate (TextEntryDialogMediator* base, const gchar* text);
GType welcome_service_entry_get_type (void) G_GNUC_CONST;
gchar* welcome_service_entry_get_service_name (WelcomeServiceEntry* self);
void welcome_service_entry_execute (WelcomeServiceEntry* self);
GType welcome_dialog_get_type (void) G_GNUC_CONST;
GType spit_data_imports_welcome_import_meta_host_get_type (void) G_GNUC_CONST;
#define WELCOME_DIALOG_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_WELCOME_DIALOG, WelcomeDialogPrivate))
enum  {
	WELCOME_DIALOG_DUMMY_PROPERTY
};
WelcomeDialog* welcome_dialog_new (GtkWindow* owner);
WelcomeDialog* welcome_dialog_construct (GType object_type, GtkWindow* owner);
SpitDataImportsWelcomeImportMetaHost* spit_data_imports_welcome_import_meta_host_new (WelcomeDialog* dialog);
SpitDataImportsWelcomeImportMetaHost* spit_data_imports_welcome_import_meta_host_construct (GType object_type, WelcomeDialog* dialog);
static gboolean welcome_dialog_is_system_pictures_import_possible (void);
gchar* get_display_pathname (GFile* file);
GFile* app_dirs_get_import_dir (void);
static void welcome_dialog_install_import_content (WelcomeDialog* self);
void spit_data_imports_welcome_import_meta_host_start (SpitDataImportsWelcomeImportMetaHost* self);
void welcome_dialog_install_service_entry (WelcomeDialog* self, WelcomeServiceEntry* entry);
static void _vala_array_add275 (WelcomeServiceEntry*** array, int* length, int* size, WelcomeServiceEntry* value);
static void _vala_array_add276 (GtkCheckButton*** array, int* length, int* size, GtkCheckButton* value);
static void welcome_dialog_on_dismiss (WelcomeDialog* self, gint resp);
gboolean welcome_dialog_execute (WelcomeDialog* self, WelcomeServiceEntry*** selected_import_entries, int* selected_import_entries_length1, gboolean* do_system_pictures_import);
static void _welcome_dialog_on_dismiss_gtk_dialog_response (GtkDialog* _sender, gint response_id, gpointer self);
static void _vala_array_add277 (WelcomeServiceEntry*** array, int* length, int* size, WelcomeServiceEntry* value);
static WelcomeServiceEntry** _vala_array_dup30 (WelcomeServiceEntry** self, int length);
static void welcome_dialog_finalize (GObject* obj);
gpointer preferences_dialog_ref (gpointer instance);
void preferences_dialog_unref (gpointer instance);
GParamSpec* param_spec_preferences_dialog (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_preferences_dialog (GValue* value, gpointer v_object);
void value_take_preferences_dialog (GValue* value, gpointer v_object);
gpointer value_get_preferences_dialog (const GValue* value);
GType preferences_dialog_get_type (void) G_GNUC_CONST;
GType sorted_list_get_type (void) G_GNUC_CONST;
static gpointer preferences_dialog_path_format_ref (gpointer instance);
static void preferences_dialog_path_format_unref (gpointer instance);
static GParamSpec* preferences_dialog_param_spec_path_format (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) G_GNUC_UNUSED;
static void preferences_dialog_value_set_path_format (GValue* value, gpointer v_object) G_GNUC_UNUSED;
static void preferences_dialog_value_take_path_format (GValue* value, gpointer v_object) G_GNUC_UNUSED;
static gpointer preferences_dialog_value_get_path_format (const GValue* value) G_GNUC_UNUSED;
static GType preferences_dialog_path_format_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
gpointer plugins_manifest_widget_mediator_ref (gpointer instance);
void plugins_manifest_widget_mediator_unref (gpointer instance);
GParamSpec* plugins_param_spec_manifest_widget_mediator (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void plugins_value_set_manifest_widget_mediator (GValue* value, gpointer v_object);
void plugins_value_take_manifest_widget_mediator (GValue* value, gpointer v_object);
gpointer plugins_value_get_manifest_widget_mediator (const GValue* value);
GType plugins_manifest_widget_mediator_get_type (void) G_GNUC_CONST;
#define PREFERENCES_DIALOG_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_PREFERENCES_DIALOG, PreferencesDialogPrivate))
enum  {
	PREFERENCES_DIALOG_DUMMY_PROPERTY
};
PluginsManifestWidgetMediator* plugins_manifest_widget_mediator_new (void);
PluginsManifestWidgetMediator* plugins_manifest_widget_mediator_construct (GType object_type);
static PreferencesDialog* preferences_dialog_new (void);
static PreferencesDialog* preferences_dialog_construct (GType object_type);
static gboolean preferences_dialog_on_delete (PreferencesDialog* self);
static gboolean _preferences_dialog_on_delete_gtk_widget_delete_event (GtkWidget* _sender, GdkEventAny* event, gpointer self);
static void preferences_dialog_on_close (PreferencesDialog* self);
static void _preferences_dialog_on_close_gtk_dialog_response (GtkDialog* _sender, gint response_id, gpointer self);
void config_facade_get_bg_color (ConfigFacade* self, GdkRGBA* result);
static void preferences_dialog_on_value_changed (PreferencesDialog* self);
static void _preferences_dialog_on_value_changed_gtk_adjustment_value_changed (GtkAdjustment* _sender, gpointer self);
static gboolean preferences_dialog_on_bg_color_reset (PreferencesDialog* self, GdkEventButton* event);
static gboolean _preferences_dialog_on_bg_color_reset_gtk_widget_button_press_event (GtkWidget* _sender, GdkEventButton* event, gpointer self);
gchar* resources_get_help_path (void);
#define RESOURCES_DIR_PATTERN_URI_SYSWIDE "help:shotwell/other-files"
static gboolean preferences_dialog_on_local_pattern_help (PreferencesDialog* self, const gchar* ignore);
static gboolean _preferences_dialog_on_local_pattern_help_gtk_label_activate_link (GtkLabel* _sender, const gchar* uri, gpointer self);
static void preferences_dialog_add_to_dir_formats (PreferencesDialog* self, const gchar* name, const gchar* pattern);
static void preferences_dialog_on_dir_pattern_combo_changed (PreferencesDialog* self);
static void _preferences_dialog_on_dir_pattern_combo_changed_gtk_combo_box_changed (GtkComboBox* _sender, gpointer self);
static void preferences_dialog_on_dir_pattern_entry_changed (PreferencesDialog* self);
static void _preferences_dialog_on_dir_pattern_entry_changed_gtk_editable_changed (GtkEditable* _sender, gpointer self);
static void preferences_dialog_on_lowercase_toggled (PreferencesDialog* self);
static void _preferences_dialog_on_lowercase_toggled_gtk_toggle_button_toggled (GtkToggleButton* _sender, gpointer self);
GtkWidget* plugins_manifest_widget_mediator_get_widget (PluginsManifestWidgetMediator* self);
void preferences_dialog_populate_preference_options (PreferencesDialog* self);
static void preferences_dialog_on_photo_editor_changed (PreferencesDialog* self);
static void _preferences_dialog_on_photo_editor_changed_gtk_combo_box_changed (GtkComboBox* _sender, gpointer self);
static void preferences_dialog_on_raw_editor_changed (PreferencesDialog* self);
static void _preferences_dialog_on_raw_editor_changed_gtk_combo_box_changed (GtkComboBox* _sender, gpointer self);
gboolean configuration_facade_get_auto_import_from_library (ConfigurationFacade* self);
GType raw_developer_get_type (void) G_GNUC_CONST;
gchar* raw_developer_get_label (RawDeveloper self);
static void preferences_dialog_set_raw_developer_combo (PreferencesDialog* self, RawDeveloper d);
RawDeveloper configuration_facade_get_default_raw_developer (ConfigurationFacade* self);
static void preferences_dialog_on_default_raw_developer_changed (PreferencesDialog* self);
static void _preferences_dialog_on_default_raw_developer_changed_gtk_combo_box_changed (GtkComboBox* _sender, gpointer self);
static gboolean preferences_dialog_map_event (PreferencesDialog* self);
static gboolean _preferences_dialog_map_event_gtk_widget_map_event (GtkWidget* _sender, GdkEventAny* event, gpointer self);
static void preferences_dialog_populate_app_combo_box (PreferencesDialog* self, GtkComboBox* combo_box, gchar** mime_types, int mime_types_length1, const gchar* current_app_executable, SortedList** external_apps);
gchar** photo_file_format_get_editable_mime_types (int* result_length1);
gchar* configuration_facade_get_external_photo_app (ConfigurationFacade* self);
gchar** photo_file_format_get_mime_types (PhotoFileFormat self, int* result_length1);
gchar* configuration_facade_get_external_raw_app (ConfigurationFacade* self);
static void preferences_dialog_setup_dir_pattern (PreferencesDialog* self, GtkComboBox* combo_box, GtkEntry* entry);
gboolean configuration_facade_get_use_lowercase_filenames (ConfigurationFacade* self);
void resources_launch_help (GdkScreen* screen, const gchar* anchor, GError** error);
SortedList* desktop_integration_get_apps_for_mime_types (gchar** mime_types, int mime_types_length1);
GdkPixbuf* scale_pixbuf (GdkPixbuf* pixbuf, gint scale, GdkInterpType interp, gboolean scale_up);
#define RESOURCES_DEFAULT_ICON_SCALE 24
gint sorted_list_index_of (SortedList* self, gconstpointer search);
gchar* configuration_facade_get_directory_pattern (ConfigurationFacade* self);
gchar* configuration_facade_get_directory_pattern_custom (ConfigurationFacade* self);
void preferences_dialog_show (void);
static void preferences_dialog_commit_on_close (PreferencesDialog* self);
void config_facade_commit_bg_color (ConfigFacade* self);
void configuration_facade_set_auto_import_from_library (ConfigurationFacade* self, gboolean auto_import);
void configuration_facade_set_commit_metadata_to_masters (ConfigurationFacade* self, gboolean commit_metadata);
void app_dirs_set_import_dir (const gchar* path);
void configuration_facade_set_directory_pattern_custom (ConfigurationFacade* self, const gchar* s);
void configuration_facade_set_directory_pattern (ConfigurationFacade* self, const gchar* s);
static gboolean preferences_dialog_get_allow_closing (PreferencesDialog* self);
static void preferences_dialog_set_background_color (PreferencesDialog* self, gdouble bg_color_value);
gboolean has_only_key_modifier (GdkModifierType field, GdkModifierType mask);
void parse_color (const gchar* spec, GdkRGBA* result);
#define CONFIG_FACADE_DEFAULT_BG_COLOR "#444"
static void preferences_dialog_set_allow_closing (PreferencesDialog* self, gboolean allow);
void config_facade_set_bg_color (ConfigFacade* self, GdkRGBA* color);
static void preferences_dialog_to_grayscale (PreferencesDialog* self, gdouble color_value, GdkRGBA* result);
gpointer sorted_list_get_at (SortedList* self, gint index);
void configuration_facade_set_external_photo_app (ConfigurationFacade* self, const gchar* external_photo_app);
gchar* desktop_integration_get_app_open_command (GAppInfo* app_info);
void configuration_facade_set_external_raw_app (ConfigurationFacade* self, const gchar* external_raw_app);
static RawDeveloper preferences_dialog_raw_developer_from_combo (PreferencesDialog* self);
void configuration_facade_set_default_raw_developer (ConfigurationFacade* self, RawDeveloper d);
static void preferences_dialog_on_current_folder_changed (PreferencesDialog* self);
static void _preferences_dialog_on_current_folder_changed_gtk_file_chooser_current_folder_changed (GtkFileChooser* _sender, gpointer self);
static PreferencesDialogPathFormat* preferences_dialog_path_format_new (const gchar* name, const gchar* pattern);
static PreferencesDialogPathFormat* preferences_dialog_path_format_construct (GType object_type, const gchar* name, const gchar* pattern);
void configuration_facade_set_use_lowercase_filenames (ConfigurationFacade* self, gboolean b);
enum  {
	PREFERENCES_DIALOG_PATH_FORMAT_DUMMY_PROPERTY
};
static void preferences_dialog_path_format_finalize (PreferencesDialogPathFormat* obj);
static void preferences_dialog_finalize (PreferencesDialog* obj);
GtkResponseType copy_files_dialog (void);
GType library_photo_get_type (void) G_GNUC_CONST;
void remove_photos_from_library (GeeCollection* photos);
void remove_from_app (GeeCollection* sources, const gchar* dialog_title, const gchar* progress_dialog_text);
GType video_source_get_type (void) G_GNUC_CONST;
GType video_get_type (void) G_GNUC_CONST;
void media_source_collection_filter_media (GeeCollection* media, GeeCollection* photos, GeeCollection* videos);
void page_window_set_busy_cursor (PageWindow* self);
static gboolean _progress_dialog_monitor_progress_monitor (guint64 current, guint64 total, gboolean do_event_loop, gpointer self);
GType media_source_collection_get_type (void) G_GNUC_CONST;
GType library_photo_source_collection_get_type (void) G_GNUC_CONST;
void media_source_collection_remove_from_app (MediaSourceCollection* self, GeeCollection* sources, gboolean delete_backing, ProgressMonitor monitor, void* monitor_target, GeeList* not_removed);
GType video_source_collection_get_type (void) G_GNUC_CONST;
void media_source_collection_delete_backing_files (MediaSourceCollection* self, GeeCollection* sources, ProgressMonitor monitor, void* monitor_target, GeeList* not_deleted);
void app_window_error_message_with_title (const gchar* title, const gchar* message, GtkWindow* parent, gboolean should_escape);
void page_window_set_normal_cursor (PageWindow* self);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
static gint _vala_array_length (gpointer array);

const ScaleConstraint EXPORT_DIALOG_CONSTRAINT_ARRAY[4] = {SCALE_CONSTRAINT_ORIGINAL, SCALE_CONSTRAINT_DIMENSIONS, SCALE_CONSTRAINT_WIDTH, SCALE_CONSTRAINT_HEIGHT};
const JpegQuality EXPORT_DIALOG_QUALITY_ARRAY[4] = {JPEG_QUALITY_LOW, JPEG_QUALITY_MEDIUM, JPEG_QUALITY_HIGH, JPEG_QUALITY_MAXIMUM};

gboolean dialogs_confirm_delete_tag (Tag* tag) {
	gboolean result = FALSE;
	gint count = 0;
	Tag* _tmp0_ = NULL;
	gint _tmp1_ = 0;
	gint _tmp2_ = 0;
	gchar* msg = NULL;
	gint _tmp3_ = 0;
	const gchar* _tmp4_ = NULL;
	Tag* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
	gint _tmp8_ = 0;
	gchar* _tmp9_ = NULL;
	gchar* _tmp10_ = NULL;
	const gchar* _tmp11_ = NULL;
	const gchar* _tmp12_ = NULL;
	const gchar* _tmp13_ = NULL;
	gboolean _tmp14_ = FALSE;
#line 11 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_TAG (tag), FALSE);
#line 12 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = tag;
#line 12 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = tag_get_sources_count (_tmp0_);
#line 12 "/home/jens/Source/shotwell/src/Dialogs.vala"
	count = _tmp1_;
#line 13 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = count;
#line 13 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp2_ == 0) {
#line 14 "/home/jens/Source/shotwell/src/Dialogs.vala"
		result = TRUE;
#line 14 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return result;
#line 1746 "Dialogs.c"
	}
#line 15 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = count;
#line 15 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = ngettext ("This will remove the tag \"%s\" from one photo.  Continue?", "This will remove the tag \"%s\" from %d photos.  Continue?", (gulong) _tmp3_);
#line 15 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = tag;
#line 15 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = tag_get_user_visible_name (_tmp5_);
#line 15 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = _tmp6_;
#line 15 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = count;
#line 15 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = g_strdup_printf (_tmp4_, _tmp7_, _tmp8_);
#line 15 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp10_ = _tmp9_;
#line 15 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp7_);
#line 15 "/home/jens/Source/shotwell/src/Dialogs.vala"
	msg = _tmp10_;
#line 20 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp11_ = msg;
#line 20 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp12_ = _ ("_Cancel");
#line 20 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp13_ = _ ("_Delete");
#line 20 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp14_ = app_window_negate_affirm_question (_tmp11_, _tmp12_, _tmp13_, RESOURCES_DELETE_TAG_TITLE, NULL);
#line 20 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = _tmp14_;
#line 20 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (msg);
#line 20 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 1782 "Dialogs.c"
}


gboolean dialogs_confirm_delete_saved_search (SavedSearch* search) {
	gboolean result = FALSE;
	gchar* msg = NULL;
	const gchar* _tmp0_ = NULL;
	SavedSearch* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	const gchar* _tmp6_ = NULL;
	const gchar* _tmp7_ = NULL;
	gboolean _tmp8_ = FALSE;
#line 24 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_SAVED_SEARCH (search), FALSE);
#line 25 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = _ ("This will remove the saved search \"%s\".  Continue?");
#line 25 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = search;
#line 25 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = data_object_get_name (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, TYPE_DATA_OBJECT, DataObject));
#line 25 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = _tmp2_;
#line 25 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = g_strdup_printf (_tmp0_, _tmp3_);
#line 25 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = _tmp4_;
#line 25 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp3_);
#line 25 "/home/jens/Source/shotwell/src/Dialogs.vala"
	msg = _tmp5_;
#line 28 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = _ ("_Cancel");
#line 28 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = _ ("_Delete");
#line 28 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = app_window_negate_affirm_question (msg, _tmp6_, _tmp7_, RESOURCES_DELETE_SAVED_SEARCH_DIALOG_TITLE, NULL);
#line 28 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = _tmp8_;
#line 28 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (msg);
#line 28 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 1828 "Dialogs.c"
}


gboolean dialogs_confirm_warn_developer_changed (gint number) {
	gboolean result = FALSE;
	GtkMessageDialog* dialog = NULL;
	AppWindow* _tmp0_ = NULL;
	AppWindow* _tmp1_ = NULL;
	gint _tmp2_ = 0;
	const gchar* _tmp3_ = NULL;
	GtkMessageDialog* _tmp4_ = NULL;
	GtkMessageDialog* _tmp5_ = NULL;
	const gchar* _tmp6_ = NULL;
	gint response = 0;
	gint _tmp7_ = 0;
#line 33 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = app_window_get_instance ();
#line 33 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = _tmp0_;
#line 33 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = number;
#line 33 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = ngettext ("Switching developers will undo all changes you have made to this photo" \
" in Shotwell", "Switching developers will undo all changes you have made to these phot" \
"os in Shotwell", (gulong) _tmp2_);
#line 33 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = (GtkMessageDialog*) gtk_message_dialog_new_with_markup (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, gtk_window_get_type (), GtkWindow), GTK_DIALOG_MODAL, GTK_MESSAGE_WARNING, GTK_BUTTONS_NONE, "<span weight=\"bold\" size=\"larger\">%s</span>", _tmp3_);
#line 33 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp4_);
#line 33 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = _tmp4_;
#line 33 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp1_);
#line 33 "/home/jens/Source/shotwell/src/Dialogs.vala"
	dialog = _tmp5_;
#line 39 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_dialog_add_buttons (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_dialog_get_type (), GtkDialog), RESOURCES_CANCEL_LABEL, GTK_RESPONSE_CANCEL, NULL);
#line 40 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = _ ("_Switch Developer");
#line 40 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_dialog_add_buttons (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_dialog_get_type (), GtkDialog), _tmp6_, GTK_RESPONSE_YES, NULL);
#line 42 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_dialog_get_type (), GtkDialog));
#line 42 "/home/jens/Source/shotwell/src/Dialogs.vala"
	response = _tmp7_;
#line 44 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_widget_get_type (), GtkWidget));
#line 46 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = response == ((gint) GTK_RESPONSE_YES);
#line 46 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (dialog);
#line 46 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 1880 "Dialogs.c"
}


static void _suppress_warnings_glog_func (const gchar* log_domain, GLogLevelFlags log_levels, const gchar* message, gpointer self) {
#line 71 "/home/jens/Source/shotwell/src/Dialogs.vala"
	suppress_warnings (log_domain, log_levels, message);
#line 1887 "Dialogs.c"
}


GFile* export_ui_choose_file (const gchar* current_file_basename) {
	GFile* result = NULL;
	GFile* _tmp0_ = NULL;
	const gchar* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	gboolean _tmp5_ = FALSE;
	gchar* file_chooser_title = NULL;
	gchar* _tmp8_ = NULL;
	GtkFileChooserDialog* chooser = NULL;
	const gchar* _tmp9_ = NULL;
	AppWindow* _tmp10_ = NULL;
	AppWindow* _tmp11_ = NULL;
	GtkFileChooserDialog* _tmp12_ = NULL;
	GtkFileChooserDialog* _tmp13_ = NULL;
	GtkFileChooserDialog* _tmp14_ = NULL;
	GtkFileChooserDialog* _tmp15_ = NULL;
	GFile* _tmp16_ = NULL;
	gchar* _tmp17_ = NULL;
	gchar* _tmp18_ = NULL;
	GtkFileChooserDialog* _tmp19_ = NULL;
	const gchar* _tmp20_ = NULL;
	GtkFileChooserDialog* _tmp21_ = NULL;
	GFile* file = NULL;
	GtkFileChooserDialog* _tmp22_ = NULL;
	gint _tmp23_ = 0;
	GLogFunc _tmp30_ = NULL;
	void* _tmp30__target = NULL;
	GtkFileChooserDialog* _tmp31_ = NULL;
#line 54 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (current_file_basename != NULL, NULL);
#line 55 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = export_ui_current_export_dir;
#line 55 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp0_ == NULL) {
#line 1925 "Dialogs.c"
		const gchar* _tmp1_ = NULL;
		GFile* _tmp2_ = NULL;
#line 56 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp1_ = g_get_home_dir ();
#line 56 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp2_ = g_file_new_for_path (_tmp1_);
#line 56 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (export_ui_current_export_dir);
#line 56 "/home/jens/Source/shotwell/src/Dialogs.vala"
		export_ui_current_export_dir = _tmp2_;
#line 1936 "Dialogs.c"
	}
#line 58 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = current_file_basename;
#line 58 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = video_reader_is_supported_video_filename (_tmp4_);
#line 58 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp5_) {
#line 1944 "Dialogs.c"
		const gchar* _tmp6_ = NULL;
#line 59 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp6_ = _ ("Export Video");
#line 59 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp3_ = _tmp6_;
#line 1950 "Dialogs.c"
	} else {
		const gchar* _tmp7_ = NULL;
#line 59 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp7_ = _ ("Export Photo");
#line 59 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp3_ = _tmp7_;
#line 1957 "Dialogs.c"
	}
#line 58 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = g_strdup (_tmp3_);
#line 58 "/home/jens/Source/shotwell/src/Dialogs.vala"
	file_chooser_title = _tmp8_;
#line 61 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = file_chooser_title;
#line 61 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp10_ = app_window_get_instance ();
#line 61 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp11_ = _tmp10_;
#line 61 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp12_ = (GtkFileChooserDialog*) gtk_file_chooser_dialog_new (_tmp9_, G_TYPE_CHECK_INSTANCE_CAST (_tmp11_, gtk_window_get_type (), GtkWindow), GTK_FILE_CHOOSER_ACTION_SAVE, RESOURCES_CANCEL_LABEL, GTK_RESPONSE_CANCEL, RESOURCES_SAVE_LABEL, GTK_RESPONSE_ACCEPT, NULL, NULL);
#line 61 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp12_);
#line 61 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp13_ = _tmp12_;
#line 61 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp11_);
#line 61 "/home/jens/Source/shotwell/src/Dialogs.vala"
	chooser = _tmp13_;
#line 64 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp14_ = chooser;
#line 64 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_file_chooser_set_do_overwrite_confirmation (G_TYPE_CHECK_INSTANCE_CAST (_tmp14_, GTK_TYPE_FILE_CHOOSER, GtkFileChooser), TRUE);
#line 65 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp15_ = chooser;
#line 65 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp16_ = export_ui_current_export_dir;
#line 65 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp17_ = g_file_get_path (_tmp16_);
#line 65 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp18_ = _tmp17_;
#line 65 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_file_chooser_set_current_folder (G_TYPE_CHECK_INSTANCE_CAST (_tmp15_, GTK_TYPE_FILE_CHOOSER, GtkFileChooser), _tmp18_);
#line 65 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp18_);
#line 66 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp19_ = chooser;
#line 66 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp20_ = current_file_basename;
#line 66 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_file_chooser_set_current_name (G_TYPE_CHECK_INSTANCE_CAST (_tmp19_, GTK_TYPE_FILE_CHOOSER, GtkFileChooser), _tmp20_);
#line 67 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp21_ = chooser;
#line 67 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_file_chooser_set_local_only (G_TYPE_CHECK_INSTANCE_CAST (_tmp21_, GTK_TYPE_FILE_CHOOSER, GtkFileChooser), FALSE);
#line 71 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_log_set_handler ("Gtk", G_LOG_LEVEL_WARNING, _suppress_warnings_glog_func, NULL);
#line 72 "/home/jens/Source/shotwell/src/Dialogs.vala"
	file = NULL;
#line 73 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp22_ = chooser;
#line 73 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp23_ = gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (_tmp22_, gtk_dialog_get_type (), GtkDialog));
#line 73 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp23_ == ((gint) GTK_RESPONSE_ACCEPT)) {
#line 2015 "Dialogs.c"
		GtkFileChooserDialog* _tmp24_ = NULL;
		gchar* _tmp25_ = NULL;
		gchar* _tmp26_ = NULL;
		GFile* _tmp27_ = NULL;
		GFile* _tmp28_ = NULL;
		GFile* _tmp29_ = NULL;
#line 74 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp24_ = chooser;
#line 74 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp25_ = gtk_file_chooser_get_filename (G_TYPE_CHECK_INSTANCE_CAST (_tmp24_, GTK_TYPE_FILE_CHOOSER, GtkFileChooser));
#line 74 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp26_ = _tmp25_;
#line 74 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp27_ = g_file_new_for_path (_tmp26_);
#line 74 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (file);
#line 74 "/home/jens/Source/shotwell/src/Dialogs.vala"
		file = _tmp27_;
#line 74 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp26_);
#line 75 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp28_ = file;
#line 75 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp29_ = g_file_get_parent (_tmp28_);
#line 75 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (export_ui_current_export_dir);
#line 75 "/home/jens/Source/shotwell/src/Dialogs.vala"
		export_ui_current_export_dir = _tmp29_;
#line 2044 "Dialogs.c"
	}
#line 77 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp30_ = g_log_default_handler;
#line 77 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp30__target = NULL;
#line 77 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_log_set_handler ("Gtk", G_LOG_LEVEL_WARNING, _tmp30_, _tmp30__target);
#line 78 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp31_ = chooser;
#line 78 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (_tmp31_, gtk_widget_get_type (), GtkWidget));
#line 80 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = file;
#line 80 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (chooser);
#line 80 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (file_chooser_title);
#line 80 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 2064 "Dialogs.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 99 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return self ? g_object_ref (self) : NULL;
#line 2071 "Dialogs.c"
}


GFile* export_ui_choose_dir (const gchar* user_title) {
	GFile* result = NULL;
	GFile* _tmp0_ = NULL;
	const gchar* _tmp3_ = NULL;
	GtkFileChooserDialog* chooser = NULL;
	const gchar* _tmp5_ = NULL;
	AppWindow* _tmp6_ = NULL;
	AppWindow* _tmp7_ = NULL;
	GtkFileChooserDialog* _tmp8_ = NULL;
	GtkFileChooserDialog* _tmp9_ = NULL;
	GtkFileChooserDialog* _tmp10_ = NULL;
	GFile* _tmp11_ = NULL;
	gchar* _tmp12_ = NULL;
	gchar* _tmp13_ = NULL;
	GtkFileChooserDialog* _tmp14_ = NULL;
	GFile* dir = NULL;
	GtkFileChooserDialog* _tmp15_ = NULL;
	gint _tmp16_ = 0;
	GtkFileChooserDialog* _tmp23_ = NULL;
#line 84 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = export_ui_current_export_dir;
#line 84 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp0_ == NULL) {
#line 2098 "Dialogs.c"
		const gchar* _tmp1_ = NULL;
		GFile* _tmp2_ = NULL;
#line 85 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp1_ = g_get_home_dir ();
#line 85 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp2_ = g_file_new_for_path (_tmp1_);
#line 85 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (export_ui_current_export_dir);
#line 85 "/home/jens/Source/shotwell/src/Dialogs.vala"
		export_ui_current_export_dir = _tmp2_;
#line 2109 "Dialogs.c"
	}
#line 87 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = user_title;
#line 87 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp3_ == NULL) {
#line 2115 "Dialogs.c"
		const gchar* _tmp4_ = NULL;
#line 88 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp4_ = _ ("Export Photos");
#line 88 "/home/jens/Source/shotwell/src/Dialogs.vala"
		user_title = _tmp4_;
#line 2121 "Dialogs.c"
	}
#line 90 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = user_title;
#line 90 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = app_window_get_instance ();
#line 90 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = _tmp6_;
#line 90 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = (GtkFileChooserDialog*) gtk_file_chooser_dialog_new (_tmp5_, G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, gtk_window_get_type (), GtkWindow), GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER, RESOURCES_CANCEL_LABEL, GTK_RESPONSE_CANCEL, RESOURCES_OK_LABEL, GTK_RESPONSE_ACCEPT, NULL, NULL);
#line 90 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp8_);
#line 90 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = _tmp8_;
#line 90 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp7_);
#line 90 "/home/jens/Source/shotwell/src/Dialogs.vala"
	chooser = _tmp9_;
#line 93 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp10_ = chooser;
#line 93 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp11_ = export_ui_current_export_dir;
#line 93 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp12_ = g_file_get_path (_tmp11_);
#line 93 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp13_ = _tmp12_;
#line 93 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_file_chooser_set_current_folder (G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, GTK_TYPE_FILE_CHOOSER, GtkFileChooser), _tmp13_);
#line 93 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp13_);
#line 94 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp14_ = chooser;
#line 94 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_file_chooser_set_local_only (G_TYPE_CHECK_INSTANCE_CAST (_tmp14_, GTK_TYPE_FILE_CHOOSER, GtkFileChooser), FALSE);
#line 96 "/home/jens/Source/shotwell/src/Dialogs.vala"
	dir = NULL;
#line 97 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp15_ = chooser;
#line 97 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp16_ = gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (_tmp15_, gtk_dialog_get_type (), GtkDialog));
#line 97 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp16_ == ((gint) GTK_RESPONSE_ACCEPT)) {
#line 2163 "Dialogs.c"
		GtkFileChooserDialog* _tmp17_ = NULL;
		gchar* _tmp18_ = NULL;
		gchar* _tmp19_ = NULL;
		GFile* _tmp20_ = NULL;
		GFile* _tmp21_ = NULL;
		GFile* _tmp22_ = NULL;
#line 98 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp17_ = chooser;
#line 98 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp18_ = gtk_file_chooser_get_filename (G_TYPE_CHECK_INSTANCE_CAST (_tmp17_, GTK_TYPE_FILE_CHOOSER, GtkFileChooser));
#line 98 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp19_ = _tmp18_;
#line 98 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp20_ = g_file_new_for_path (_tmp19_);
#line 98 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (dir);
#line 98 "/home/jens/Source/shotwell/src/Dialogs.vala"
		dir = _tmp20_;
#line 98 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp19_);
#line 99 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp21_ = dir;
#line 99 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp22_ = _g_object_ref0 (_tmp21_);
#line 99 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (export_ui_current_export_dir);
#line 99 "/home/jens/Source/shotwell/src/Dialogs.vala"
		export_ui_current_export_dir = _tmp22_;
#line 2192 "Dialogs.c"
	}
#line 102 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp23_ = chooser;
#line 102 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (_tmp23_, gtk_widget_get_type (), GtkWidget));
#line 104 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = dir;
#line 104 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (chooser);
#line 104 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 2204 "Dialogs.c"
}


void open_external_editor_error_dialog (GError* err, Photo* photo) {
	gboolean _tmp0_ = FALSE;
	GError* _tmp1_ = NULL;
#line 111 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_PHOTO (photo));
#line 113 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = err;
#line 113 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (g_error_matches (_tmp1_, G_IO_ERROR, G_IO_ERROR_PERMISSION_DENIED)) {
#line 113 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = TRUE;
#line 2219 "Dialogs.c"
	} else {
		GError* _tmp2_ = NULL;
#line 113 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp2_ = err;
#line 113 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = g_error_matches (_tmp2_, G_FILE_ERROR, G_FILE_ERROR_PERM);
#line 2226 "Dialogs.c"
	}
#line 113 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp0_) {
#line 2230 "Dialogs.c"
		const gchar* _tmp3_ = NULL;
		Photo* _tmp4_ = NULL;
		GFile* _tmp5_ = NULL;
		GFile* _tmp6_ = NULL;
		GFile* _tmp7_ = NULL;
		GFile* _tmp8_ = NULL;
		gchar* _tmp9_ = NULL;
		gchar* _tmp10_ = NULL;
		gchar* _tmp11_ = NULL;
		gchar* _tmp12_ = NULL;
#line 115 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp3_ = _ ("Shotwell couldn't create a file for editing this photo because you do " \
"not have permission to write to %s.");
#line 115 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp4_ = photo;
#line 115 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp5_ = media_source_get_master_file (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, TYPE_MEDIA_SOURCE, MediaSource));
#line 115 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp6_ = _tmp5_;
#line 115 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp7_ = g_file_get_parent (_tmp6_);
#line 115 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp8_ = _tmp7_;
#line 115 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp9_ = g_file_get_path (_tmp8_);
#line 115 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp10_ = _tmp9_;
#line 115 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp11_ = g_strdup_printf (_tmp3_, _tmp10_);
#line 115 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp12_ = _tmp11_;
#line 115 "/home/jens/Source/shotwell/src/Dialogs.vala"
		app_window_error_message (_tmp12_, NULL);
#line 115 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp12_);
#line 115 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp10_);
#line 115 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (_tmp8_);
#line 115 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (_tmp6_);
#line 2271 "Dialogs.c"
	} else {
		GError* _tmp13_ = NULL;
		gchar* _tmp14_ = NULL;
		gchar* _tmp15_ = NULL;
#line 120 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp13_ = err;
#line 120 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp14_ = resources_launch_editor_failed (_tmp13_);
#line 120 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp15_ = _tmp14_;
#line 120 "/home/jens/Source/shotwell/src/Dialogs.vala"
		app_window_error_message (_tmp15_, NULL);
#line 120 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp15_);
#line 2286 "Dialogs.c"
	}
}


GtkResponseType export_error_dialog (GFile* dest, gboolean photos_remaining) {
	GtkResponseType result = 0;
	gchar* message = NULL;
	const gchar* _tmp0_ = NULL;
	GFile* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	GtkResponseType response = 0;
	gboolean _tmp6_ = FALSE;
#line 124 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (G_IS_FILE (dest), 0);
#line 125 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = _ ("Unable to export the following photo due to a file error.\n\n");
#line 125 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = dest;
#line 125 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = g_file_get_path (_tmp1_);
#line 125 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = _tmp2_;
#line 125 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = g_strconcat (_tmp0_, _tmp3_, NULL);
#line 125 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = _tmp4_;
#line 125 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp3_);
#line 125 "/home/jens/Source/shotwell/src/Dialogs.vala"
	message = _tmp5_;
#line 128 "/home/jens/Source/shotwell/src/Dialogs.vala"
	response = GTK_RESPONSE_NONE;
#line 130 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = photos_remaining;
#line 130 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp6_) {
#line 2326 "Dialogs.c"
		const gchar* _tmp7_ = NULL;
		const gchar* _tmp8_ = NULL;
		gchar* _tmp9_ = NULL;
		const gchar* _tmp10_ = NULL;
		const gchar* _tmp11_ = NULL;
		GtkResponseType _tmp12_ = 0;
#line 131 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp7_ = message;
#line 131 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp8_ = _ ("\n\nWould you like to continue exporting?");
#line 131 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp9_ = g_strconcat (_tmp7_, _tmp8_, NULL);
#line 131 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (message);
#line 131 "/home/jens/Source/shotwell/src/Dialogs.vala"
		message = _tmp9_;
#line 132 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp10_ = message;
#line 132 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp11_ = _ ("Con_tinue");
#line 132 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp12_ = app_window_affirm_cancel_question (_tmp10_, _tmp11_, NULL, NULL);
#line 132 "/home/jens/Source/shotwell/src/Dialogs.vala"
		response = _tmp12_;
#line 2351 "Dialogs.c"
	} else {
		const gchar* _tmp13_ = NULL;
#line 134 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp13_ = message;
#line 134 "/home/jens/Source/shotwell/src/Dialogs.vala"
		app_window_error_message (_tmp13_, NULL);
#line 2358 "Dialogs.c"
	}
#line 137 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = response;
#line 137 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (message);
#line 137 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 2366 "Dialogs.c"
}


static void _export_dialog_on_constraint_changed_gtk_combo_box_changed (GtkComboBox* _sender, gpointer self) {
#line 209 "/home/jens/Source/shotwell/src/Dialogs.vala"
	export_dialog_on_constraint_changed ((ExportDialog*) self);
#line 2373 "Dialogs.c"
}


static void _export_dialog_on_format_changed_gtk_combo_box_changed (GtkComboBox* _sender, gpointer self) {
#line 210 "/home/jens/Source/shotwell/src/Dialogs.vala"
	export_dialog_on_format_changed ((ExportDialog*) self);
#line 2380 "Dialogs.c"
}


static void _export_dialog_on_pixels_changed_gtk_editable_changed (GtkEditable* _sender, gpointer self) {
#line 211 "/home/jens/Source/shotwell/src/Dialogs.vala"
	export_dialog_on_pixels_changed ((ExportDialog*) self);
#line 2387 "Dialogs.c"
}


static void _export_dialog_on_pixels_insert_text_gtk_editable_insert_text (GtkEditable* _sender, const gchar* new_text, gint new_text_length, gint* position, gpointer self) {
#line 212 "/home/jens/Source/shotwell/src/Dialogs.vala"
	export_dialog_on_pixels_insert_text ((ExportDialog*) self, new_text, new_text_length, position);
#line 2394 "Dialogs.c"
}


static void _export_dialog_on_activate_gtk_entry_activate (GtkEntry* _sender, gpointer self) {
#line 213 "/home/jens/Source/shotwell/src/Dialogs.vala"
	export_dialog_on_activate ((ExportDialog*) self);
#line 2401 "Dialogs.c"
}


ExportDialog* export_dialog_construct (GType object_type, const gchar* title) {
	ExportDialog * self = NULL;
	gboolean use_header = FALSE;
	GtkSettings* _tmp0_ = NULL;
	gint _tmp1_ = 0;
	gboolean _tmp2_ = FALSE;
	const gchar* _tmp3_ = NULL;
	GtkComboBoxText* _tmp4_ = NULL;
	gint ctr = 0;
	GtkComboBoxText* _tmp15_ = NULL;
	GtkComboBoxText* _tmp25_ = NULL;
	gint _tmp26_ = 0;
	PhotoFileFormat* _tmp27_ = NULL;
	GtkEntry* _tmp33_ = NULL;
	GtkEntry* _tmp34_ = NULL;
	GtkEntry* _tmp35_ = NULL;
	gint _tmp36_ = 0;
	gchar* _tmp37_ = NULL;
	gchar* _tmp38_ = NULL;
	GtkComboBoxText* _tmp39_ = NULL;
	GtkComboBoxText* _tmp40_ = NULL;
	GtkEntry* _tmp41_ = NULL;
	GtkEntry* _tmp42_ = NULL;
	GtkEntry* _tmp43_ = NULL;
	const gchar* _tmp44_ = NULL;
	GtkComboBoxText* _tmp45_ = NULL;
	GtkComboBoxText* _tmp46_ = NULL;
	const gchar* _tmp47_ = NULL;
	GtkComboBoxText* _tmp48_ = NULL;
	GtkComboBoxText* _tmp49_ = NULL;
	const gchar* _tmp50_ = NULL;
	GtkComboBoxText* _tmp51_ = NULL;
	GtkComboBoxText* _tmp52_ = NULL;
	const gchar* _tmp53_ = NULL;
	GtkEntry* _tmp54_ = NULL;
	GtkEntry* _tmp55_ = NULL;
	const gchar* _tmp56_ = NULL;
	GtkCheckButton* _tmp57_ = NULL;
	GtkCheckButton* _tmp58_ = NULL;
	GtkCheckButton* _tmp59_ = NULL;
	GtkGrid* _tmp60_ = NULL;
	GtkGrid* _tmp61_ = NULL;
	GtkGrid* _tmp62_ = NULL;
	GtkBox* _tmp63_ = NULL;
	GtkGrid* _tmp64_ = NULL;
	GtkWidget* _tmp65_ = NULL;
	GtkWidget* _tmp66_ = NULL;
	GtkWidget* _tmp67_ = NULL;
	GtkWidget* _tmp68_ = NULL;
	GtkWidget* _tmp69_ = NULL;
	ScaleConstraint _tmp70_ = 0;
	GtkWidget* _tmp73_ = NULL;
#line 171 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (title != NULL, NULL);
#line 173 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = gtk_settings_get_default ();
#line 173 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_get (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, G_TYPE_OBJECT, GObject), "gtk-dialogs-use-header", &use_header, NULL);
#line 174 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = use_header;
#line 174 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp2_) {
#line 174 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp1_ = 1;
#line 2469 "Dialogs.c"
	} else {
#line 174 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp1_ = 0;
#line 2473 "Dialogs.c"
	}
#line 174 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = (ExportDialog*) g_object_new (object_type, "use-header-bar", _tmp1_, NULL);
#line 176 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = title;
#line 176 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_window_set_title (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), _tmp3_);
#line 177 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_window_set_resizable (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), FALSE);
#line 179 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = (GtkComboBoxText*) gtk_combo_box_text_new ();
#line 179 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp4_);
#line 179 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->quality_combo);
#line 179 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->quality_combo = _tmp4_;
#line 180 "/home/jens/Source/shotwell/src/Dialogs.vala"
	ctr = 0;
#line 2493 "Dialogs.c"
	{
		JpegQuality* quality_collection = NULL;
		gint quality_collection_length1 = 0;
		gint _quality_collection_size_ = 0;
		gint quality_it = 0;
#line 181 "/home/jens/Source/shotwell/src/Dialogs.vala"
		quality_collection = EXPORT_DIALOG_QUALITY_ARRAY;
#line 181 "/home/jens/Source/shotwell/src/Dialogs.vala"
		quality_collection_length1 = G_N_ELEMENTS (EXPORT_DIALOG_QUALITY_ARRAY);
#line 181 "/home/jens/Source/shotwell/src/Dialogs.vala"
		for (quality_it = 0; quality_it < G_N_ELEMENTS (EXPORT_DIALOG_QUALITY_ARRAY); quality_it = quality_it + 1) {
#line 2505 "Dialogs.c"
			JpegQuality quality = 0;
#line 181 "/home/jens/Source/shotwell/src/Dialogs.vala"
			quality = quality_collection[quality_it];
#line 2509 "Dialogs.c"
			{
				GtkComboBoxText* _tmp5_ = NULL;
				JpegQuality _tmp6_ = 0;
				gchar* _tmp7_ = NULL;
				gchar* _tmp8_ = NULL;
				JpegQuality _tmp9_ = 0;
				ExportFormatParameters _tmp10_ = {0};
				JpegQuality _tmp11_ = 0;
				gint _tmp14_ = 0;
#line 182 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp5_ = self->priv->quality_combo;
#line 182 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp6_ = quality;
#line 182 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp7_ = jpeg_quality_to_string (_tmp6_);
#line 182 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp8_ = _tmp7_;
#line 182 "/home/jens/Source/shotwell/src/Dialogs.vala"
				gtk_combo_box_text_append_text (_tmp5_, _tmp8_);
#line 182 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp8_);
#line 183 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp9_ = quality;
#line 183 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp10_ = export_dialog_current_parameters;
#line 183 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp11_ = _tmp10_.quality;
#line 183 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (_tmp9_ == _tmp11_) {
#line 2539 "Dialogs.c"
					GtkComboBoxText* _tmp12_ = NULL;
					gint _tmp13_ = 0;
#line 184 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp12_ = self->priv->quality_combo;
#line 184 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp13_ = ctr;
#line 184 "/home/jens/Source/shotwell/src/Dialogs.vala"
					gtk_combo_box_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp12_, gtk_combo_box_get_type (), GtkComboBox), _tmp13_);
#line 2548 "Dialogs.c"
				}
#line 185 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp14_ = ctr;
#line 185 "/home/jens/Source/shotwell/src/Dialogs.vala"
				ctr = _tmp14_ + 1;
#line 2554 "Dialogs.c"
			}
		}
	}
#line 188 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp15_ = (GtkComboBoxText*) gtk_combo_box_text_new ();
#line 188 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp15_);
#line 188 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->constraint_combo);
#line 188 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->constraint_combo = _tmp15_;
#line 189 "/home/jens/Source/shotwell/src/Dialogs.vala"
	ctr = 0;
#line 2568 "Dialogs.c"
	{
		ScaleConstraint* constraint_collection = NULL;
		gint constraint_collection_length1 = 0;
		gint _constraint_collection_size_ = 0;
		gint constraint_it = 0;
#line 190 "/home/jens/Source/shotwell/src/Dialogs.vala"
		constraint_collection = EXPORT_DIALOG_CONSTRAINT_ARRAY;
#line 190 "/home/jens/Source/shotwell/src/Dialogs.vala"
		constraint_collection_length1 = G_N_ELEMENTS (EXPORT_DIALOG_CONSTRAINT_ARRAY);
#line 190 "/home/jens/Source/shotwell/src/Dialogs.vala"
		for (constraint_it = 0; constraint_it < G_N_ELEMENTS (EXPORT_DIALOG_CONSTRAINT_ARRAY); constraint_it = constraint_it + 1) {
#line 2580 "Dialogs.c"
			ScaleConstraint constraint = 0;
#line 190 "/home/jens/Source/shotwell/src/Dialogs.vala"
			constraint = constraint_collection[constraint_it];
#line 2584 "Dialogs.c"
			{
				GtkComboBoxText* _tmp16_ = NULL;
				ScaleConstraint _tmp17_ = 0;
				gchar* _tmp18_ = NULL;
				gchar* _tmp19_ = NULL;
				ScaleConstraint _tmp20_ = 0;
				ScaleConstraint _tmp21_ = 0;
				gint _tmp24_ = 0;
#line 191 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp16_ = self->priv->constraint_combo;
#line 191 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp17_ = constraint;
#line 191 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp18_ = scale_constraint_to_string (_tmp17_);
#line 191 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp19_ = _tmp18_;
#line 191 "/home/jens/Source/shotwell/src/Dialogs.vala"
				gtk_combo_box_text_append_text (_tmp16_, _tmp19_);
#line 191 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp19_);
#line 192 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp20_ = constraint;
#line 192 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp21_ = export_dialog_current_constraint;
#line 192 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (_tmp20_ == _tmp21_) {
#line 2611 "Dialogs.c"
					GtkComboBoxText* _tmp22_ = NULL;
					gint _tmp23_ = 0;
#line 193 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp22_ = self->priv->constraint_combo;
#line 193 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp23_ = ctr;
#line 193 "/home/jens/Source/shotwell/src/Dialogs.vala"
					gtk_combo_box_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp22_, gtk_combo_box_get_type (), GtkComboBox), _tmp23_);
#line 2620 "Dialogs.c"
				}
#line 194 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp24_ = ctr;
#line 194 "/home/jens/Source/shotwell/src/Dialogs.vala"
				ctr = _tmp24_ + 1;
#line 2626 "Dialogs.c"
			}
		}
	}
#line 197 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp25_ = (GtkComboBoxText*) gtk_combo_box_text_new ();
#line 197 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp25_);
#line 197 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->format_combo);
#line 197 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->format_combo = _tmp25_;
#line 198 "/home/jens/Source/shotwell/src/Dialogs.vala"
	export_dialog_format_add_option (self, EXPORT_DIALOG_UNMODIFIED_FORMAT_LABEL);
#line 199 "/home/jens/Source/shotwell/src/Dialogs.vala"
	export_dialog_format_add_option (self, EXPORT_DIALOG_CURRENT_FORMAT_LABEL);
#line 200 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp27_ = photo_file_format_get_writeable (&_tmp26_);
#line 2644 "Dialogs.c"
	{
		PhotoFileFormat* format_collection = NULL;
		gint format_collection_length1 = 0;
		gint _format_collection_size_ = 0;
		gint format_it = 0;
#line 200 "/home/jens/Source/shotwell/src/Dialogs.vala"
		format_collection = _tmp27_;
#line 200 "/home/jens/Source/shotwell/src/Dialogs.vala"
		format_collection_length1 = _tmp26_;
#line 200 "/home/jens/Source/shotwell/src/Dialogs.vala"
		for (format_it = 0; format_it < _tmp26_; format_it = format_it + 1) {
#line 2656 "Dialogs.c"
			PhotoFileFormat format = 0;
#line 200 "/home/jens/Source/shotwell/src/Dialogs.vala"
			format = format_collection[format_it];
#line 2660 "Dialogs.c"
			{
				PhotoFileFormat _tmp28_ = 0;
				PhotoFileFormatProperties* _tmp29_ = NULL;
				PhotoFileFormatProperties* _tmp30_ = NULL;
				gchar* _tmp31_ = NULL;
				gchar* _tmp32_ = NULL;
#line 201 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp28_ = format;
#line 201 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp29_ = photo_file_format_get_properties (_tmp28_);
#line 201 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp30_ = _tmp29_;
#line 201 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp31_ = photo_file_format_properties_get_user_visible_name (_tmp30_);
#line 201 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp32_ = _tmp31_;
#line 201 "/home/jens/Source/shotwell/src/Dialogs.vala"
				export_dialog_format_add_option (self, _tmp32_);
#line 201 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp32_);
#line 201 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_photo_file_format_properties_unref0 (_tmp30_);
#line 2683 "Dialogs.c"
			}
		}
#line 200 "/home/jens/Source/shotwell/src/Dialogs.vala"
		format_collection = (g_free (format_collection), NULL);
#line 2688 "Dialogs.c"
	}
#line 204 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp33_ = (GtkEntry*) gtk_entry_new ();
#line 204 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp33_);
#line 204 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->pixels_entry);
#line 204 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->pixels_entry = _tmp33_;
#line 205 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp34_ = self->priv->pixels_entry;
#line 205 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_entry_set_max_length (_tmp34_, 6);
#line 206 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp35_ = self->priv->pixels_entry;
#line 206 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp36_ = export_dialog_current_scale;
#line 206 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp37_ = g_strdup_printf ("%d", _tmp36_);
#line 206 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp38_ = _tmp37_;
#line 206 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_entry_set_text (_tmp35_, _tmp38_);
#line 206 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp38_);
#line 209 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp39_ = self->priv->constraint_combo;
#line 209 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp39_, gtk_combo_box_get_type (), GtkComboBox), "changed", (GCallback) _export_dialog_on_constraint_changed_gtk_combo_box_changed, self, 0);
#line 210 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp40_ = self->priv->format_combo;
#line 210 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp40_, gtk_combo_box_get_type (), GtkComboBox), "changed", (GCallback) _export_dialog_on_format_changed_gtk_combo_box_changed, self, 0);
#line 211 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp41_ = self->priv->pixels_entry;
#line 211 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp41_, GTK_TYPE_EDITABLE, GtkEditable), "changed", (GCallback) _export_dialog_on_pixels_changed_gtk_editable_changed, self, 0);
#line 212 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp42_ = self->priv->pixels_entry;
#line 212 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp42_, GTK_TYPE_EDITABLE, GtkEditable), "insert-text", (GCallback) _export_dialog_on_pixels_insert_text_gtk_editable_insert_text, self, 0);
#line 213 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp43_ = self->priv->pixels_entry;
#line 213 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_connect_object (_tmp43_, "activate", (GCallback) _export_dialog_on_activate_gtk_entry_activate, self, 0);
#line 216 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp44_ = _ ("_Format:");
#line 216 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp45_ = self->priv->format_combo;
#line 216 "/home/jens/Source/shotwell/src/Dialogs.vala"
	export_dialog_add_label (self, _tmp44_, 0, 0, G_TYPE_CHECK_INSTANCE_CAST (_tmp45_, gtk_widget_get_type (), GtkWidget));
#line 217 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp46_ = self->priv->format_combo;
#line 217 "/home/jens/Source/shotwell/src/Dialogs.vala"
	export_dialog_add_control (self, G_TYPE_CHECK_INSTANCE_CAST (_tmp46_, gtk_widget_get_type (), GtkWidget), 1, 0);
#line 219 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp47_ = _ ("_Quality:");
#line 219 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp48_ = self->priv->quality_combo;
#line 219 "/home/jens/Source/shotwell/src/Dialogs.vala"
	export_dialog_add_label (self, _tmp47_, 0, 1, G_TYPE_CHECK_INSTANCE_CAST (_tmp48_, gtk_widget_get_type (), GtkWidget));
#line 220 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp49_ = self->priv->quality_combo;
#line 220 "/home/jens/Source/shotwell/src/Dialogs.vala"
	export_dialog_add_control (self, G_TYPE_CHECK_INSTANCE_CAST (_tmp49_, gtk_widget_get_type (), GtkWidget), 1, 1);
#line 222 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp50_ = _ ("_Scaling constraint:");
#line 222 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp51_ = self->priv->constraint_combo;
#line 222 "/home/jens/Source/shotwell/src/Dialogs.vala"
	export_dialog_add_label (self, _tmp50_, 0, 2, G_TYPE_CHECK_INSTANCE_CAST (_tmp51_, gtk_widget_get_type (), GtkWidget));
#line 223 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp52_ = self->priv->constraint_combo;
#line 223 "/home/jens/Source/shotwell/src/Dialogs.vala"
	export_dialog_add_control (self, G_TYPE_CHECK_INSTANCE_CAST (_tmp52_, gtk_widget_get_type (), GtkWidget), 1, 2);
#line 225 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp53_ = _ ("_Pixels:");
#line 225 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp54_ = self->priv->pixels_entry;
#line 225 "/home/jens/Source/shotwell/src/Dialogs.vala"
	export_dialog_add_label (self, _tmp53_, 0, 3, G_TYPE_CHECK_INSTANCE_CAST (_tmp54_, gtk_widget_get_type (), GtkWidget));
#line 226 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp55_ = self->priv->pixels_entry;
#line 226 "/home/jens/Source/shotwell/src/Dialogs.vala"
	export_dialog_add_control (self, G_TYPE_CHECK_INSTANCE_CAST (_tmp55_, gtk_widget_get_type (), GtkWidget), 1, 3);
#line 228 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp56_ = _ ("Export metadata");
#line 228 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp57_ = (GtkCheckButton*) gtk_check_button_new_with_label (_tmp56_);
#line 228 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp57_);
#line 228 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->export_metadata);
#line 228 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->export_metadata = _tmp57_;
#line 229 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp58_ = self->priv->export_metadata;
#line 229 "/home/jens/Source/shotwell/src/Dialogs.vala"
	export_dialog_add_control (self, G_TYPE_CHECK_INSTANCE_CAST (_tmp58_, gtk_widget_get_type (), GtkWidget), 1, 4);
#line 230 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp59_ = self->priv->export_metadata;
#line 230 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_toggle_button_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp59_, gtk_toggle_button_get_type (), GtkToggleButton), TRUE);
#line 232 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp60_ = self->priv->table;
#line 232 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_grid_set_row_spacing (_tmp60_, (guint) 5);
#line 233 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp61_ = self->priv->table;
#line 233 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_grid_set_column_spacing (_tmp61_, (guint) 5);
#line 234 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp62_ = self->priv->table;
#line 234 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_container_set_border_width (G_TYPE_CHECK_INSTANCE_CAST (_tmp62_, gtk_container_get_type (), GtkContainer), (guint) 3);
#line 236 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp63_ = (GtkBox*) gtk_dialog_get_content_area (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog));
#line 236 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp64_ = self->priv->table;
#line 236 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_container_add (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (_tmp63_, gtk_box_get_type (), GtkBox), gtk_container_get_type (), GtkContainer), G_TYPE_CHECK_INSTANCE_CAST (_tmp64_, gtk_widget_get_type (), GtkWidget));
#line 239 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_dialog_add_button (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog), RESOURCES_CANCEL_LABEL, (gint) GTK_RESPONSE_CANCEL);
#line 240 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp65_ = gtk_dialog_add_button (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog), RESOURCES_OK_LABEL, (gint) GTK_RESPONSE_OK);
#line 240 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp66_ = _g_object_ref0 (_tmp65_);
#line 240 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->ok_button);
#line 240 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->ok_button = _tmp66_;
#line 241 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_dialog_set_default_response (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog), (gint) GTK_RESPONSE_OK);
#line 243 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp67_ = self->priv->ok_button;
#line 243 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_set_can_default (_tmp67_, TRUE);
#line 244 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp68_ = self->priv->ok_button;
#line 244 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_set (_tmp68_, "has-default", TRUE, NULL);
#line 245 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp69_ = self->priv->ok_button;
#line 245 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_window_set_default (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), _tmp69_);
#line 247 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp70_ = export_dialog_current_constraint;
#line 247 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp70_ == SCALE_CONSTRAINT_ORIGINAL) {
#line 2838 "Dialogs.c"
		GtkEntry* _tmp71_ = NULL;
		GtkComboBoxText* _tmp72_ = NULL;
#line 248 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp71_ = self->priv->pixels_entry;
#line 248 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp71_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 249 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp72_ = self->priv->quality_combo;
#line 249 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp72_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 2849 "Dialogs.c"
	}
#line 252 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp73_ = self->priv->ok_button;
#line 252 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_grab_focus (_tmp73_);
#line 171 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return self;
#line 2857 "Dialogs.c"
}


ExportDialog* export_dialog_new (const gchar* title) {
#line 171 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return export_dialog_construct (TYPE_EXPORT_DIALOG, title);
#line 2864 "Dialogs.c"
}


static void export_dialog_format_add_option (ExportDialog* self, const gchar* format_name) {
	GeeArrayList* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	GtkComboBoxText* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
#line 255 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_EXPORT_DIALOG (self));
#line 255 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (format_name != NULL);
#line 256 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = self->priv->format_options;
#line 256 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = format_name;
#line 256 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gee_abstract_collection_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection), _tmp1_);
#line 257 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = self->priv->format_combo;
#line 257 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = format_name;
#line 257 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_combo_box_text_append_text (_tmp2_, _tmp3_);
#line 2889 "Dialogs.c"
}


static void export_dialog_format_set_active_text (ExportDialog* self, const gchar* text) {
	gint selection_ticker = 0;
	const gchar* _tmp16_ = NULL;
#line 260 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_EXPORT_DIALOG (self));
#line 260 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (text != NULL);
#line 261 "/home/jens/Source/shotwell/src/Dialogs.vala"
	selection_ticker = 0;
#line 2902 "Dialogs.c"
	{
		GeeArrayList* _current_text_list = NULL;
		GeeArrayList* _tmp0_ = NULL;
		GeeArrayList* _tmp1_ = NULL;
		gint _current_text_size = 0;
		GeeArrayList* _tmp2_ = NULL;
		gint _tmp3_ = 0;
		gint _tmp4_ = 0;
		gint _current_text_index = 0;
#line 263 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = self->priv->format_options;
#line 263 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp1_ = _g_object_ref0 (_tmp0_);
#line 263 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_current_text_list = _tmp1_;
#line 263 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp2_ = _current_text_list;
#line 263 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp3_ = gee_abstract_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, GEE_TYPE_COLLECTION, GeeCollection));
#line 263 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp4_ = _tmp3_;
#line 263 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_current_text_size = _tmp4_;
#line 263 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_current_text_index = -1;
#line 263 "/home/jens/Source/shotwell/src/Dialogs.vala"
		while (TRUE) {
#line 2930 "Dialogs.c"
			gint _tmp5_ = 0;
			gint _tmp6_ = 0;
			gint _tmp7_ = 0;
			gchar* current_text = NULL;
			GeeArrayList* _tmp8_ = NULL;
			gint _tmp9_ = 0;
			gpointer _tmp10_ = NULL;
			const gchar* _tmp11_ = NULL;
			const gchar* _tmp12_ = NULL;
			gint _tmp15_ = 0;
#line 263 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp5_ = _current_text_index;
#line 263 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_current_text_index = _tmp5_ + 1;
#line 263 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp6_ = _current_text_index;
#line 263 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp7_ = _current_text_size;
#line 263 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (!(_tmp6_ < _tmp7_)) {
#line 263 "/home/jens/Source/shotwell/src/Dialogs.vala"
				break;
#line 2953 "Dialogs.c"
			}
#line 263 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp8_ = _current_text_list;
#line 263 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp9_ = _current_text_index;
#line 263 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp10_ = gee_abstract_list_get (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, GEE_TYPE_ABSTRACT_LIST, GeeAbstractList), _tmp9_);
#line 263 "/home/jens/Source/shotwell/src/Dialogs.vala"
			current_text = (gchar*) _tmp10_;
#line 264 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp11_ = current_text;
#line 264 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp12_ = text;
#line 264 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (g_strcmp0 (_tmp11_, _tmp12_) == 0) {
#line 2969 "Dialogs.c"
				GtkComboBoxText* _tmp13_ = NULL;
				gint _tmp14_ = 0;
#line 265 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp13_ = self->priv->format_combo;
#line 265 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp14_ = selection_ticker;
#line 265 "/home/jens/Source/shotwell/src/Dialogs.vala"
				gtk_combo_box_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp13_, gtk_combo_box_get_type (), GtkComboBox), _tmp14_);
#line 266 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (current_text);
#line 266 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_object_unref0 (_current_text_list);
#line 266 "/home/jens/Source/shotwell/src/Dialogs.vala"
				return;
#line 2984 "Dialogs.c"
			}
#line 268 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp15_ = selection_ticker;
#line 268 "/home/jens/Source/shotwell/src/Dialogs.vala"
			selection_ticker = _tmp15_ + 1;
#line 263 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (current_text);
#line 2992 "Dialogs.c"
		}
#line 263 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (_current_text_list);
#line 2996 "Dialogs.c"
	}
#line 271 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp16_ = text;
#line 271 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_error ("Dialogs.vala:271: format_set_active_text: text '%s' isn't in combo box", _tmp16_);
#line 3002 "Dialogs.c"
}


static PhotoFileFormat export_dialog_get_specified_format (ExportDialog* self) {
	PhotoFileFormat result = 0;
	gint index = 0;
	GtkComboBoxText* _tmp0_ = NULL;
	gint _tmp1_ = 0;
	gint _tmp2_ = 0;
	gint _tmp3_ = 0;
	PhotoFileFormat* writeable_formats = NULL;
	gint _tmp4_ = 0;
	PhotoFileFormat* _tmp5_ = NULL;
	gint writeable_formats_length1 = 0;
	gint _writeable_formats_size_ = 0;
	gint _tmp6_ = 0;
	PhotoFileFormat _tmp7_ = 0;
#line 274 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_EXPORT_DIALOG (self), 0);
#line 275 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = self->priv->format_combo;
#line 275 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = gtk_combo_box_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_combo_box_get_type (), GtkComboBox));
#line 275 "/home/jens/Source/shotwell/src/Dialogs.vala"
	index = _tmp1_;
#line 276 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = index;
#line 276 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp2_ < EXPORT_DIALOG_NUM_SPECIAL_FORMATS) {
#line 277 "/home/jens/Source/shotwell/src/Dialogs.vala"
		index = EXPORT_DIALOG_NUM_SPECIAL_FORMATS;
#line 3034 "Dialogs.c"
	}
#line 279 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = index;
#line 279 "/home/jens/Source/shotwell/src/Dialogs.vala"
	index = _tmp3_ - EXPORT_DIALOG_NUM_SPECIAL_FORMATS;
#line 280 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = photo_file_format_get_writeable (&_tmp4_);
#line 280 "/home/jens/Source/shotwell/src/Dialogs.vala"
	writeable_formats = _tmp5_;
#line 280 "/home/jens/Source/shotwell/src/Dialogs.vala"
	writeable_formats_length1 = _tmp4_;
#line 280 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_writeable_formats_size_ = writeable_formats_length1;
#line 281 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = index;
#line 281 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = writeable_formats[_tmp6_];
#line 281 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = _tmp7_;
#line 281 "/home/jens/Source/shotwell/src/Dialogs.vala"
	writeable_formats = (g_free (writeable_formats), NULL);
#line 281 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 3058 "Dialogs.c"
}


static gchar* export_dialog_get_label_for_parameters (ExportDialog* self, ExportFormatParameters* params) {
	gchar* result = NULL;
	ExportFormatParameters _tmp0_ = {0};
	ExportFormatMode _tmp1_ = 0;
#line 284 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_EXPORT_DIALOG (self), NULL);
#line 284 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (params != NULL, NULL);
#line 285 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = *params;
#line 285 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = _tmp0_.mode;
#line 285 "/home/jens/Source/shotwell/src/Dialogs.vala"
	switch (_tmp1_) {
#line 285 "/home/jens/Source/shotwell/src/Dialogs.vala"
		case EXPORT_FORMAT_MODE_UNMODIFIED:
#line 3078 "Dialogs.c"
		{
			gchar* _tmp2_ = NULL;
#line 287 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp2_ = g_strdup (EXPORT_DIALOG_UNMODIFIED_FORMAT_LABEL);
#line 287 "/home/jens/Source/shotwell/src/Dialogs.vala"
			result = _tmp2_;
#line 287 "/home/jens/Source/shotwell/src/Dialogs.vala"
			return result;
#line 3087 "Dialogs.c"
		}
#line 285 "/home/jens/Source/shotwell/src/Dialogs.vala"
		case EXPORT_FORMAT_MODE_CURRENT:
#line 3091 "Dialogs.c"
		{
			gchar* _tmp3_ = NULL;
#line 290 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp3_ = g_strdup (EXPORT_DIALOG_CURRENT_FORMAT_LABEL);
#line 290 "/home/jens/Source/shotwell/src/Dialogs.vala"
			result = _tmp3_;
#line 290 "/home/jens/Source/shotwell/src/Dialogs.vala"
			return result;
#line 3100 "Dialogs.c"
		}
#line 285 "/home/jens/Source/shotwell/src/Dialogs.vala"
		case EXPORT_FORMAT_MODE_SPECIFIED:
#line 3104 "Dialogs.c"
		{
			ExportFormatParameters _tmp4_ = {0};
			PhotoFileFormat _tmp5_ = 0;
			PhotoFileFormatProperties* _tmp6_ = NULL;
			PhotoFileFormatProperties* _tmp7_ = NULL;
			gchar* _tmp8_ = NULL;
			gchar* _tmp9_ = NULL;
#line 293 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp4_ = *params;
#line 293 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp5_ = _tmp4_.specified_format;
#line 293 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp6_ = photo_file_format_get_properties (_tmp5_);
#line 293 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp7_ = _tmp6_;
#line 293 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp8_ = photo_file_format_properties_get_user_visible_name (_tmp7_);
#line 293 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp9_ = _tmp8_;
#line 293 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_photo_file_format_properties_unref0 (_tmp7_);
#line 293 "/home/jens/Source/shotwell/src/Dialogs.vala"
			result = _tmp9_;
#line 293 "/home/jens/Source/shotwell/src/Dialogs.vala"
			return result;
#line 3130 "Dialogs.c"
		}
		default:
		{
#line 296 "/home/jens/Source/shotwell/src/Dialogs.vala"
			g_error ("Dialogs.vala:296: get_label_for_parameters: unrecognized export format" \
" mode");
#line 3136 "Dialogs.c"
		}
	}
}


gboolean export_dialog_execute (ExportDialog* self, gint* scale, ScaleConstraint* constraint, ExportFormatParameters* parameters) {
	gint _vala_scale = 0;
	ScaleConstraint _vala_constraint = 0;
	gboolean result = FALSE;
	ExportFormatParameters _tmp0_ = {0};
	ExportFormatMode _tmp1_ = 0;
	ExportFormatParameters _tmp4_ = {0};
	ExportFormatMode _tmp5_ = 0;
	ExportFormatParameters _tmp14_ = {0};
	gchar* _tmp15_ = NULL;
	gchar* _tmp16_ = NULL;
	gboolean ok = FALSE;
	gint _tmp17_ = 0;
	gboolean _tmp18_ = FALSE;
#line 303 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_EXPORT_DIALOG (self), FALSE);
#line 303 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (parameters != NULL, FALSE);
#line 305 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_show_all (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 309 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = *parameters;
#line 309 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = _tmp0_.mode;
#line 309 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp1_ != EXPORT_FORMAT_MODE_LAST) {
#line 3168 "Dialogs.c"
		ScaleConstraint _tmp2_ = 0;
		GtkComboBoxText* _tmp3_ = NULL;
#line 310 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_vala_constraint = SCALE_CONSTRAINT_ORIGINAL;
#line 310 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp2_ = _vala_constraint;
#line 310 "/home/jens/Source/shotwell/src/Dialogs.vala"
		export_dialog_current_constraint = _tmp2_;
#line 311 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp3_ = self->priv->constraint_combo;
#line 311 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_combo_box_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, gtk_combo_box_get_type (), GtkComboBox), 0);
#line 3181 "Dialogs.c"
	}
#line 314 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = *parameters;
#line 314 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = _tmp4_.mode;
#line 314 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp5_ == EXPORT_FORMAT_MODE_LAST) {
#line 3189 "Dialogs.c"
		ExportFormatParameters _tmp6_ = {0};
#line 315 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp6_ = export_dialog_current_parameters;
#line 315 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*parameters = _tmp6_;
#line 3195 "Dialogs.c"
	} else {
		gboolean _tmp7_ = FALSE;
		ExportFormatParameters _tmp8_ = {0};
		ExportFormatMode _tmp9_ = 0;
#line 316 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp8_ = *parameters;
#line 316 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp9_ = _tmp8_.mode;
#line 316 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp9_ == EXPORT_FORMAT_MODE_SPECIFIED) {
#line 3206 "Dialogs.c"
			ExportFormatParameters _tmp10_ = {0};
			PhotoFileFormat _tmp11_ = 0;
			gboolean _tmp12_ = FALSE;
#line 316 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp10_ = *parameters;
#line 316 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp11_ = _tmp10_.specified_format;
#line 316 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp12_ = photo_file_format_can_write (_tmp11_);
#line 316 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp7_ = !_tmp12_;
#line 3218 "Dialogs.c"
		} else {
#line 316 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp7_ = FALSE;
#line 3222 "Dialogs.c"
		}
#line 316 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp7_) {
#line 3226 "Dialogs.c"
			PhotoFileFormat _tmp13_ = 0;
#line 317 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp13_ = photo_file_format_get_system_default_format ();
#line 317 "/home/jens/Source/shotwell/src/Dialogs.vala"
			(*parameters).specified_format = _tmp13_;
#line 3232 "Dialogs.c"
		}
	}
#line 319 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp14_ = *parameters;
#line 319 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp15_ = export_dialog_get_label_for_parameters (self, &_tmp14_);
#line 319 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp16_ = _tmp15_;
#line 319 "/home/jens/Source/shotwell/src/Dialogs.vala"
	export_dialog_format_set_active_text (self, _tmp16_);
#line 319 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp16_);
#line 320 "/home/jens/Source/shotwell/src/Dialogs.vala"
	export_dialog_on_format_changed (self);
#line 322 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp17_ = gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog));
#line 322 "/home/jens/Source/shotwell/src/Dialogs.vala"
	ok = _tmp17_ == ((gint) GTK_RESPONSE_OK);
#line 323 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp18_ = ok;
#line 323 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp18_) {
#line 3255 "Dialogs.c"
		gint index = 0;
		GtkComboBoxText* _tmp19_ = NULL;
		gint _tmp20_ = 0;
		gint _tmp21_ = 0;
		gint _tmp22_ = 0;
		ScaleConstraint _tmp23_ = 0;
		ScaleConstraint _tmp24_ = 0;
		GtkEntry* _tmp25_ = NULL;
		const gchar* _tmp26_ = NULL;
		gint _tmp27_ = 0;
		ScaleConstraint _tmp28_ = 0;
		gint _tmp30_ = 0;
		gboolean _tmp31_ = FALSE;
		GtkCheckButton* _tmp32_ = NULL;
		gboolean _tmp33_ = FALSE;
		gboolean _tmp34_ = FALSE;
		GtkComboBoxText* _tmp38_ = NULL;
		gchar* _tmp39_ = NULL;
		gchar* _tmp40_ = NULL;
		gboolean _tmp41_ = FALSE;
#line 324 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp19_ = self->priv->constraint_combo;
#line 324 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp20_ = gtk_combo_box_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp19_, gtk_combo_box_get_type (), GtkComboBox));
#line 324 "/home/jens/Source/shotwell/src/Dialogs.vala"
		index = _tmp20_;
#line 325 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp21_ = index;
#line 325 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_vala_assert (_tmp21_ >= 0, "index >= 0");
#line 326 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp22_ = index;
#line 326 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp23_ = EXPORT_DIALOG_CONSTRAINT_ARRAY[_tmp22_];
#line 326 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_vala_constraint = _tmp23_;
#line 327 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp24_ = _vala_constraint;
#line 327 "/home/jens/Source/shotwell/src/Dialogs.vala"
		export_dialog_current_constraint = _tmp24_;
#line 329 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp25_ = self->priv->pixels_entry;
#line 329 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp26_ = gtk_entry_get_text (_tmp25_);
#line 329 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp27_ = atoi (_tmp26_);
#line 329 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_vala_scale = _tmp27_;
#line 330 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp28_ = _vala_constraint;
#line 330 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp28_ != SCALE_CONSTRAINT_ORIGINAL) {
#line 3308 "Dialogs.c"
			gint _tmp29_ = 0;
#line 331 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp29_ = _vala_scale;
#line 331 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_vala_assert (_tmp29_ > 0, "scale > 0");
#line 3314 "Dialogs.c"
		}
#line 332 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp30_ = _vala_scale;
#line 332 "/home/jens/Source/shotwell/src/Dialogs.vala"
		export_dialog_current_scale = _tmp30_;
#line 334 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp32_ = self->priv->export_metadata;
#line 334 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp33_ = gtk_widget_get_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp32_, gtk_widget_get_type (), GtkWidget));
#line 334 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp34_ = _tmp33_;
#line 334 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp34_) {
#line 3328 "Dialogs.c"
			GtkCheckButton* _tmp35_ = NULL;
			gboolean _tmp36_ = FALSE;
			gboolean _tmp37_ = FALSE;
#line 334 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp35_ = self->priv->export_metadata;
#line 334 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp36_ = gtk_toggle_button_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp35_, gtk_toggle_button_get_type (), GtkToggleButton));
#line 334 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp37_ = _tmp36_;
#line 334 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp31_ = _tmp37_;
#line 3340 "Dialogs.c"
		} else {
#line 334 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp31_ = FALSE;
#line 3344 "Dialogs.c"
		}
#line 334 "/home/jens/Source/shotwell/src/Dialogs.vala"
		(*parameters).export_metadata = _tmp31_;
#line 336 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp38_ = self->priv->format_combo;
#line 336 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp39_ = gtk_combo_box_text_get_active_text (_tmp38_);
#line 336 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp40_ = _tmp39_;
#line 336 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp41_ = g_strcmp0 (_tmp40_, EXPORT_DIALOG_UNMODIFIED_FORMAT_LABEL) == 0;
#line 336 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp40_);
#line 336 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp41_) {
#line 3360 "Dialogs.c"
			ExportFormatMode _tmp42_ = 0;
#line 337 "/home/jens/Source/shotwell/src/Dialogs.vala"
			export_dialog_current_parameters.mode = EXPORT_FORMAT_MODE_UNMODIFIED;
#line 337 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp42_ = export_dialog_current_parameters.mode;
#line 337 "/home/jens/Source/shotwell/src/Dialogs.vala"
			(*parameters).mode = _tmp42_;
#line 3368 "Dialogs.c"
		} else {
			GtkComboBoxText* _tmp43_ = NULL;
			gchar* _tmp44_ = NULL;
			gchar* _tmp45_ = NULL;
			gboolean _tmp46_ = FALSE;
#line 338 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp43_ = self->priv->format_combo;
#line 338 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp44_ = gtk_combo_box_text_get_active_text (_tmp43_);
#line 338 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp45_ = _tmp44_;
#line 338 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp46_ = g_strcmp0 (_tmp45_, EXPORT_DIALOG_CURRENT_FORMAT_LABEL) == 0;
#line 338 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (_tmp45_);
#line 338 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (_tmp46_) {
#line 3386 "Dialogs.c"
				ExportFormatMode _tmp47_ = 0;
#line 339 "/home/jens/Source/shotwell/src/Dialogs.vala"
				export_dialog_current_parameters.mode = EXPORT_FORMAT_MODE_CURRENT;
#line 339 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp47_ = export_dialog_current_parameters.mode;
#line 339 "/home/jens/Source/shotwell/src/Dialogs.vala"
				(*parameters).mode = _tmp47_;
#line 3394 "Dialogs.c"
			} else {
				ExportFormatMode _tmp48_ = 0;
				PhotoFileFormat _tmp49_ = 0;
				PhotoFileFormat _tmp50_ = 0;
				ExportFormatParameters _tmp51_ = {0};
				PhotoFileFormat _tmp52_ = 0;
#line 341 "/home/jens/Source/shotwell/src/Dialogs.vala"
				export_dialog_current_parameters.mode = EXPORT_FORMAT_MODE_SPECIFIED;
#line 341 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp48_ = export_dialog_current_parameters.mode;
#line 341 "/home/jens/Source/shotwell/src/Dialogs.vala"
				(*parameters).mode = _tmp48_;
#line 342 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp49_ = export_dialog_get_specified_format (self);
#line 342 "/home/jens/Source/shotwell/src/Dialogs.vala"
				export_dialog_current_parameters.specified_format = _tmp49_;
#line 342 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp50_ = export_dialog_current_parameters.specified_format;
#line 342 "/home/jens/Source/shotwell/src/Dialogs.vala"
				(*parameters).specified_format = _tmp50_;
#line 343 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp51_ = export_dialog_current_parameters;
#line 343 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp52_ = _tmp51_.specified_format;
#line 343 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (_tmp52_ == PHOTO_FILE_FORMAT_JFIF) {
#line 3421 "Dialogs.c"
					GtkComboBoxText* _tmp53_ = NULL;
					gint _tmp54_ = 0;
					JpegQuality _tmp55_ = 0;
					JpegQuality _tmp56_ = 0;
#line 344 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp53_ = self->priv->quality_combo;
#line 344 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp54_ = gtk_combo_box_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp53_, gtk_combo_box_get_type (), GtkComboBox));
#line 344 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp55_ = EXPORT_DIALOG_QUALITY_ARRAY[_tmp54_];
#line 344 "/home/jens/Source/shotwell/src/Dialogs.vala"
					export_dialog_current_parameters.quality = _tmp55_;
#line 344 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp56_ = export_dialog_current_parameters.quality;
#line 344 "/home/jens/Source/shotwell/src/Dialogs.vala"
					(*parameters).quality = _tmp56_;
#line 3438 "Dialogs.c"
				}
			}
		}
	} else {
#line 347 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_vala_scale = 0;
#line 348 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_vala_constraint = SCALE_CONSTRAINT_ORIGINAL;
#line 3447 "Dialogs.c"
	}
#line 351 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 353 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = ok;
#line 353 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (scale) {
#line 353 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*scale = _vala_scale;
#line 3457 "Dialogs.c"
	}
#line 353 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (constraint) {
#line 353 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*constraint = _vala_constraint;
#line 3463 "Dialogs.c"
	}
#line 353 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 3467 "Dialogs.c"
}


static void export_dialog_add_label (ExportDialog* self, const gchar* text, gint x, gint y, GtkWidget* widget) {
	GtkAlignment* left_aligned = NULL;
	GtkAlignment* _tmp0_ = NULL;
	GtkLabel* new_label = NULL;
	const gchar* _tmp1_ = NULL;
	GtkLabel* _tmp2_ = NULL;
	GtkLabel* _tmp3_ = NULL;
	GtkWidget* _tmp4_ = NULL;
	GtkAlignment* _tmp7_ = NULL;
	GtkLabel* _tmp8_ = NULL;
	GtkGrid* _tmp9_ = NULL;
	GtkAlignment* _tmp10_ = NULL;
	gint _tmp11_ = 0;
	gint _tmp12_ = 0;
#line 356 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_EXPORT_DIALOG (self));
#line 356 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (text != NULL);
#line 356 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail ((widget == NULL) || GTK_IS_WIDGET (widget));
#line 357 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = (GtkAlignment*) gtk_alignment_new ((gfloat) 1, 0.5f, (gfloat) 0, (gfloat) 0);
#line 357 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp0_);
#line 357 "/home/jens/Source/shotwell/src/Dialogs.vala"
	left_aligned = _tmp0_;
#line 359 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = text;
#line 359 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = (GtkLabel*) gtk_label_new_with_mnemonic (_tmp1_);
#line 359 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp2_);
#line 359 "/home/jens/Source/shotwell/src/Dialogs.vala"
	new_label = _tmp2_;
#line 360 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = new_label;
#line 360 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_label_set_use_underline (_tmp3_, TRUE);
#line 362 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = widget;
#line 362 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp4_ != NULL) {
#line 3513 "Dialogs.c"
		GtkLabel* _tmp5_ = NULL;
		GtkWidget* _tmp6_ = NULL;
#line 363 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp5_ = new_label;
#line 363 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp6_ = widget;
#line 363 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_label_set_mnemonic_widget (_tmp5_, _tmp6_);
#line 3522 "Dialogs.c"
	}
#line 365 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = left_aligned;
#line 365 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = new_label;
#line 365 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_container_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, gtk_container_get_type (), GtkContainer), G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, gtk_widget_get_type (), GtkWidget));
#line 367 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = self->priv->table;
#line 367 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp10_ = left_aligned;
#line 367 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp11_ = x;
#line 367 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp12_ = y;
#line 367 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_grid_attach (_tmp9_, G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, gtk_widget_get_type (), GtkWidget), _tmp11_, _tmp12_, 1, 1);
#line 356 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (new_label);
#line 356 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (left_aligned);
#line 3544 "Dialogs.c"
}


static void export_dialog_add_control (ExportDialog* self, GtkWidget* widget, gint x, gint y) {
	GtkAlignment* left_aligned = NULL;
	GtkAlignment* _tmp0_ = NULL;
	GtkWidget* _tmp1_ = NULL;
	GtkGrid* _tmp2_ = NULL;
	gint _tmp3_ = 0;
	gint _tmp4_ = 0;
#line 370 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_EXPORT_DIALOG (self));
#line 370 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (GTK_IS_WIDGET (widget));
#line 371 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = (GtkAlignment*) gtk_alignment_new ((gfloat) 0, 0.5f, (gfloat) 1, (gfloat) 0);
#line 371 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp0_);
#line 371 "/home/jens/Source/shotwell/src/Dialogs.vala"
	left_aligned = _tmp0_;
#line 372 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = widget;
#line 372 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_container_add (G_TYPE_CHECK_INSTANCE_CAST (left_aligned, gtk_container_get_type (), GtkContainer), _tmp1_);
#line 374 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = self->priv->table;
#line 374 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = x;
#line 374 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = y;
#line 374 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_grid_attach (_tmp2_, G_TYPE_CHECK_INSTANCE_CAST (left_aligned, gtk_widget_get_type (), GtkWidget), _tmp3_, _tmp4_, 1, 1);
#line 370 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (left_aligned);
#line 3579 "Dialogs.c"
}


static void export_dialog_on_constraint_changed (ExportDialog* self) {
	gboolean original = FALSE;
	GtkComboBoxText* _tmp0_ = NULL;
	gint _tmp1_ = 0;
	ScaleConstraint _tmp2_ = 0;
	gboolean jpeg = FALSE;
	GtkComboBoxText* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	PhotoFileFormatProperties* _tmp6_ = NULL;
	PhotoFileFormatProperties* _tmp7_ = NULL;
	gchar* _tmp8_ = NULL;
	gchar* _tmp9_ = NULL;
	gboolean _tmp10_ = FALSE;
	GtkEntry* _tmp11_ = NULL;
	gboolean _tmp12_ = FALSE;
	gboolean _tmp13_ = FALSE;
	gboolean _tmp14_ = FALSE;
	GtkComboBoxText* _tmp16_ = NULL;
	gboolean _tmp17_ = FALSE;
#line 377 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_EXPORT_DIALOG (self));
#line 378 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = self->priv->constraint_combo;
#line 378 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = gtk_combo_box_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_combo_box_get_type (), GtkComboBox));
#line 378 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = EXPORT_DIALOG_CONSTRAINT_ARRAY[_tmp1_];
#line 378 "/home/jens/Source/shotwell/src/Dialogs.vala"
	original = _tmp2_ == SCALE_CONSTRAINT_ORIGINAL;
#line 379 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = self->priv->format_combo;
#line 379 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = gtk_combo_box_text_get_active_text (_tmp3_);
#line 379 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = _tmp4_;
#line 379 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = photo_file_format_get_properties (PHOTO_FILE_FORMAT_JFIF);
#line 379 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = _tmp6_;
#line 379 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = photo_file_format_properties_get_user_visible_name (_tmp7_);
#line 379 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = _tmp8_;
#line 379 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp10_ = g_strcmp0 (_tmp5_, _tmp9_) == 0;
#line 379 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp9_);
#line 379 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_photo_file_format_properties_unref0 (_tmp7_);
#line 379 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp5_);
#line 379 "/home/jens/Source/shotwell/src/Dialogs.vala"
	jpeg = _tmp10_;
#line 381 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp11_ = self->priv->pixels_entry;
#line 381 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp12_ = original;
#line 381 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp11_, gtk_widget_get_type (), GtkWidget), !_tmp12_);
#line 382 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp14_ = original;
#line 382 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (!_tmp14_) {
#line 3647 "Dialogs.c"
		gboolean _tmp15_ = FALSE;
#line 382 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp15_ = jpeg;
#line 382 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp13_ = _tmp15_;
#line 3653 "Dialogs.c"
	} else {
#line 382 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp13_ = FALSE;
#line 3657 "Dialogs.c"
	}
#line 382 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp16_ = self->priv->quality_combo;
#line 382 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp16_, gtk_widget_get_type (), GtkWidget), _tmp13_);
#line 383 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp17_ = original;
#line 383 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp17_) {
#line 3667 "Dialogs.c"
		GtkWidget* _tmp18_ = NULL;
#line 384 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp18_ = self->priv->ok_button;
#line 384 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_widget_set_sensitive (_tmp18_, TRUE);
#line 3673 "Dialogs.c"
	} else {
#line 386 "/home/jens/Source/shotwell/src/Dialogs.vala"
		export_dialog_on_pixels_changed (self);
#line 3677 "Dialogs.c"
	}
}


static void export_dialog_on_format_changed (ExportDialog* self) {
	gboolean original = FALSE;
	GtkComboBoxText* _tmp0_ = NULL;
	gint _tmp1_ = 0;
	ScaleConstraint _tmp2_ = 0;
	GtkComboBoxText* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	gboolean _tmp6_ = FALSE;
#line 389 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_EXPORT_DIALOG (self));
#line 390 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = self->priv->constraint_combo;
#line 390 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = gtk_combo_box_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_combo_box_get_type (), GtkComboBox));
#line 390 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = EXPORT_DIALOG_CONSTRAINT_ARRAY[_tmp1_];
#line 390 "/home/jens/Source/shotwell/src/Dialogs.vala"
	original = _tmp2_ == SCALE_CONSTRAINT_ORIGINAL;
#line 392 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = self->priv->format_combo;
#line 392 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = gtk_combo_box_text_get_active_text (_tmp3_);
#line 392 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = _tmp4_;
#line 392 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = g_strcmp0 (_tmp5_, EXPORT_DIALOG_UNMODIFIED_FORMAT_LABEL) == 0;
#line 392 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp5_);
#line 392 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp6_) {
#line 3713 "Dialogs.c"
		GtkComboBoxText* _tmp7_ = NULL;
		GtkComboBoxText* _tmp8_ = NULL;
		GtkComboBoxText* _tmp9_ = NULL;
		GtkEntry* _tmp10_ = NULL;
		GtkCheckButton* _tmp11_ = NULL;
		GtkCheckButton* _tmp12_ = NULL;
#line 397 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp7_ = self->priv->constraint_combo;
#line 397 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_combo_box_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, gtk_combo_box_get_type (), GtkComboBox), 0);
#line 398 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp8_ = self->priv->constraint_combo;
#line 398 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 399 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp9_ = self->priv->quality_combo;
#line 399 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 400 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp10_ = self->priv->pixels_entry;
#line 400 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 401 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp11_ = self->priv->export_metadata;
#line 401 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_toggle_button_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp11_, gtk_toggle_button_get_type (), GtkToggleButton), FALSE);
#line 402 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp12_ = self->priv->export_metadata;
#line 402 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp12_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 3744 "Dialogs.c"
	} else {
		GtkComboBoxText* _tmp13_ = NULL;
		gchar* _tmp14_ = NULL;
		gchar* _tmp15_ = NULL;
		gboolean _tmp16_ = FALSE;
#line 403 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp13_ = self->priv->format_combo;
#line 403 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp14_ = gtk_combo_box_text_get_active_text (_tmp13_);
#line 403 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp15_ = _tmp14_;
#line 403 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp16_ = g_strcmp0 (_tmp15_, EXPORT_DIALOG_CURRENT_FORMAT_LABEL) == 0;
#line 403 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp15_);
#line 403 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp16_) {
#line 3762 "Dialogs.c"
			GtkComboBoxText* _tmp17_ = NULL;
			GtkComboBoxText* _tmp18_ = NULL;
			GtkEntry* _tmp19_ = NULL;
			gboolean _tmp20_ = FALSE;
			GtkCheckButton* _tmp21_ = NULL;
#line 410 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp17_ = self->priv->constraint_combo;
#line 410 "/home/jens/Source/shotwell/src/Dialogs.vala"
			gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp17_, gtk_widget_get_type (), GtkWidget), TRUE);
#line 411 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp18_ = self->priv->quality_combo;
#line 411 "/home/jens/Source/shotwell/src/Dialogs.vala"
			gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp18_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 412 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp19_ = self->priv->pixels_entry;
#line 412 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp20_ = original;
#line 412 "/home/jens/Source/shotwell/src/Dialogs.vala"
			gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp19_, gtk_widget_get_type (), GtkWidget), !_tmp20_);
#line 413 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp21_ = self->priv->export_metadata;
#line 413 "/home/jens/Source/shotwell/src/Dialogs.vala"
			gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp21_, gtk_widget_get_type (), GtkWidget), TRUE);
#line 3786 "Dialogs.c"
		} else {
			GtkComboBoxText* _tmp22_ = NULL;
			gboolean jpeg = FALSE;
			PhotoFileFormat _tmp23_ = 0;
			gboolean _tmp24_ = FALSE;
			gboolean _tmp25_ = FALSE;
			GtkComboBoxText* _tmp27_ = NULL;
			GtkCheckButton* _tmp28_ = NULL;
#line 418 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp22_ = self->priv->constraint_combo;
#line 418 "/home/jens/Source/shotwell/src/Dialogs.vala"
			gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp22_, gtk_widget_get_type (), GtkWidget), TRUE);
#line 419 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp23_ = export_dialog_get_specified_format (self);
#line 419 "/home/jens/Source/shotwell/src/Dialogs.vala"
			jpeg = _tmp23_ == PHOTO_FILE_FORMAT_JFIF;
#line 420 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp25_ = original;
#line 420 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (!_tmp25_) {
#line 3807 "Dialogs.c"
				gboolean _tmp26_ = FALSE;
#line 420 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp26_ = jpeg;
#line 420 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp24_ = _tmp26_;
#line 3813 "Dialogs.c"
			} else {
#line 420 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp24_ = FALSE;
#line 3817 "Dialogs.c"
			}
#line 420 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp27_ = self->priv->quality_combo;
#line 420 "/home/jens/Source/shotwell/src/Dialogs.vala"
			gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp27_, gtk_widget_get_type (), GtkWidget), _tmp24_);
#line 421 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp28_ = self->priv->export_metadata;
#line 421 "/home/jens/Source/shotwell/src/Dialogs.vala"
			gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp28_, gtk_widget_get_type (), GtkWidget), TRUE);
#line 3827 "Dialogs.c"
		}
	}
}


static void export_dialog_on_activate (ExportDialog* self) {
#line 425 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_EXPORT_DIALOG (self));
#line 426 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_dialog_response (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog), (gint) GTK_RESPONSE_OK);
#line 3838 "Dialogs.c"
}


static void export_dialog_on_pixels_changed (ExportDialog* self) {
	gboolean _tmp0_ = FALSE;
	GtkEntry* _tmp1_ = NULL;
	guint16 _tmp2_ = 0U;
	GtkWidget* _tmp6_ = NULL;
#line 429 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_EXPORT_DIALOG (self));
#line 430 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = self->priv->pixels_entry;
#line 430 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = gtk_entry_get_text_length (_tmp1_);
#line 430 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (((gint) _tmp2_) > 0) {
#line 3855 "Dialogs.c"
		GtkEntry* _tmp3_ = NULL;
		const gchar* _tmp4_ = NULL;
		gint _tmp5_ = 0;
#line 430 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp3_ = self->priv->pixels_entry;
#line 430 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp4_ = gtk_entry_get_text (_tmp3_);
#line 430 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp5_ = atoi (_tmp4_);
#line 430 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = _tmp5_ > 0;
#line 3867 "Dialogs.c"
	} else {
#line 430 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = FALSE;
#line 3871 "Dialogs.c"
	}
#line 430 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = self->priv->ok_button;
#line 430 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_set_sensitive (_tmp6_, _tmp0_);
#line 3877 "Dialogs.c"
}


static gchar string_get (const gchar* self, glong index) {
	gchar result = '\0';
	glong _tmp0_ = 0L;
	gchar _tmp1_ = '\0';
#line 1086 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, '\0');
#line 1087 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp0_ = index;
#line 1087 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp1_ = ((gchar*) self)[_tmp0_];
#line 1087 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	result = _tmp1_;
#line 1087 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	return result;
#line 3895 "Dialogs.c"
}


static void export_dialog_on_pixels_insert_text (ExportDialog* self, const gchar* text, gint length, gint* position) {
	gboolean _tmp0_ = FALSE;
	gint _tmp1_ = 0;
	gchar* new_text = NULL;
	gchar* _tmp5_ = NULL;
	const gchar* _tmp21_ = NULL;
	gint _tmp22_ = 0;
	gint _tmp23_ = 0;
	GtkEntry* _tmp29_ = NULL;
#line 433 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_EXPORT_DIALOG (self));
#line 433 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (text != NULL);
#line 435 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = self->priv->in_insert;
#line 435 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp0_) {
#line 436 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return;
#line 3918 "Dialogs.c"
	}
#line 438 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->in_insert = TRUE;
#line 440 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = length;
#line 440 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp1_ == -1) {
#line 3926 "Dialogs.c"
		const gchar* _tmp2_ = NULL;
		gint _tmp3_ = 0;
		gint _tmp4_ = 0;
#line 441 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp2_ = text;
#line 441 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp3_ = strlen (_tmp2_);
#line 441 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp4_ = _tmp3_;
#line 441 "/home/jens/Source/shotwell/src/Dialogs.vala"
		length = (gint) _tmp4_;
#line 3938 "Dialogs.c"
	}
#line 444 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = g_strdup ("");
#line 444 "/home/jens/Source/shotwell/src/Dialogs.vala"
	new_text = _tmp5_;
#line 3944 "Dialogs.c"
	{
		gint ctr = 0;
#line 445 "/home/jens/Source/shotwell/src/Dialogs.vala"
		ctr = 0;
#line 3949 "Dialogs.c"
		{
			gboolean _tmp6_ = FALSE;
#line 445 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp6_ = TRUE;
#line 445 "/home/jens/Source/shotwell/src/Dialogs.vala"
			while (TRUE) {
#line 3956 "Dialogs.c"
				gint _tmp8_ = 0;
				gint _tmp9_ = 0;
				const gchar* _tmp10_ = NULL;
				gint _tmp11_ = 0;
				gchar _tmp12_ = '\0';
				gboolean _tmp13_ = FALSE;
#line 445 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (!_tmp6_) {
#line 3965 "Dialogs.c"
					gint _tmp7_ = 0;
#line 445 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp7_ = ctr;
#line 445 "/home/jens/Source/shotwell/src/Dialogs.vala"
					ctr = _tmp7_ + 1;
#line 3971 "Dialogs.c"
				}
#line 445 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp6_ = FALSE;
#line 445 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp8_ = ctr;
#line 445 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp9_ = length;
#line 445 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (!(_tmp8_ < _tmp9_)) {
#line 445 "/home/jens/Source/shotwell/src/Dialogs.vala"
					break;
#line 3983 "Dialogs.c"
				}
#line 446 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp10_ = text;
#line 446 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp11_ = ctr;
#line 446 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp12_ = string_get (_tmp10_, (glong) _tmp11_);
#line 446 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp13_ = g_ascii_isdigit (_tmp12_);
#line 446 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (_tmp13_) {
#line 3995 "Dialogs.c"
					const gchar* _tmp14_ = NULL;
					const gchar* _tmp15_ = NULL;
					gint _tmp16_ = 0;
					gchar _tmp17_ = '\0';
					gchar* _tmp18_ = NULL;
					gchar* _tmp19_ = NULL;
					gchar* _tmp20_ = NULL;
#line 447 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp14_ = new_text;
#line 447 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp15_ = text;
#line 447 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp16_ = ctr;
#line 447 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp17_ = string_get (_tmp15_, (glong) _tmp16_);
#line 447 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp18_ = g_strdup_printf ("%c", (gchar) _tmp17_);
#line 447 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp19_ = _tmp18_;
#line 447 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp20_ = g_strconcat (_tmp14_, _tmp19_, NULL);
#line 447 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_g_free0 (new_text);
#line 447 "/home/jens/Source/shotwell/src/Dialogs.vala"
					new_text = _tmp20_;
#line 447 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_g_free0 (_tmp19_);
#line 4023 "Dialogs.c"
				}
			}
		}
	}
#line 451 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp21_ = new_text;
#line 451 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp22_ = strlen (_tmp21_);
#line 451 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp23_ = _tmp22_;
#line 451 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp23_ > 0) {
#line 4036 "Dialogs.c"
		GtkEntry* _tmp24_ = NULL;
		const gchar* _tmp25_ = NULL;
		const gchar* _tmp26_ = NULL;
		gint _tmp27_ = 0;
		gint _tmp28_ = 0;
#line 452 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp24_ = self->priv->pixels_entry;
#line 452 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp25_ = new_text;
#line 452 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp26_ = new_text;
#line 452 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp27_ = strlen (_tmp26_);
#line 452 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp28_ = _tmp27_;
#line 452 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_editable_insert_text (G_TYPE_CHECK_INSTANCE_CAST (_tmp24_, GTK_TYPE_EDITABLE, GtkEditable), _tmp25_, (gint) _tmp28_, position);
#line 4054 "Dialogs.c"
	}
#line 454 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp29_ = self->priv->pixels_entry;
#line 454 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_stop_emission_by_name (_tmp29_, "insert-text");
#line 456 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->in_insert = FALSE;
#line 433 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (new_text);
#line 4064 "Dialogs.c"
}


static void export_dialog_class_init (ExportDialogClass * klass) {
	ExportFormatParameters _tmp0_ = {0};
#line 141 "/home/jens/Source/shotwell/src/Dialogs.vala"
	export_dialog_parent_class = g_type_class_peek_parent (klass);
#line 141 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_type_class_add_private (klass, sizeof (ExportDialogPrivate));
#line 141 "/home/jens/Source/shotwell/src/Dialogs.vala"
	G_OBJECT_CLASS (klass)->finalize = export_dialog_finalize;
#line 158 "/home/jens/Source/shotwell/src/Dialogs.vala"
	export_format_parameters_current (&_tmp0_);
#line 158 "/home/jens/Source/shotwell/src/Dialogs.vala"
	export_dialog_current_parameters = _tmp0_;
#line 159 "/home/jens/Source/shotwell/src/Dialogs.vala"
	export_dialog_current_scale = EXPORT_DIALOG_DEFAULT_SCALE;
#line 4082 "Dialogs.c"
}


static void export_dialog_instance_init (ExportDialog * self) {
	GtkGrid* _tmp0_ = NULL;
	GeeArrayList* _tmp1_ = NULL;
#line 141 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv = EXPORT_DIALOG_GET_PRIVATE (self);
#line 161 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = (GtkGrid*) gtk_grid_new ();
#line 161 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp0_);
#line 161 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->table = _tmp0_;
#line 166 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = gee_array_list_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL);
#line 166 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->format_options = _tmp1_;
#line 169 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->in_insert = FALSE;
#line 4103 "Dialogs.c"
}


static void export_dialog_finalize (GObject* obj) {
	ExportDialog * self;
#line 141 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_EXPORT_DIALOG, ExportDialog);
#line 161 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->table);
#line 162 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->quality_combo);
#line 163 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->constraint_combo);
#line 164 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->format_combo);
#line 165 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->export_metadata);
#line 166 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->format_options);
#line 167 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->pixels_entry);
#line 168 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->ok_button);
#line 141 "/home/jens/Source/shotwell/src/Dialogs.vala"
	G_OBJECT_CLASS (export_dialog_parent_class)->finalize (obj);
#line 4129 "Dialogs.c"
}


GType export_dialog_get_type (void) {
	static volatile gsize export_dialog_type_id__volatile = 0;
	if (g_once_init_enter (&export_dialog_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (ExportDialogClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) export_dialog_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ExportDialog), 0, (GInstanceInitFunc) export_dialog_instance_init, NULL };
		GType export_dialog_type_id;
		export_dialog_type_id = g_type_register_static (gtk_dialog_get_type (), "ExportDialog", &g_define_type_info, 0);
		g_once_init_leave (&export_dialog_type_id__volatile, export_dialog_type_id);
	}
	return export_dialog_type_id__volatile;
}


gchar* import_ui_generate_import_failure_list (GeeList* failed, gboolean show_dest_id) {
	gchar* result = NULL;
	GeeList* _tmp0_ = NULL;
	gint _tmp1_ = 0;
	gint _tmp2_ = 0;
	gchar* list = NULL;
	gchar* _tmp3_ = NULL;
	gint remaining = 0;
	GeeList* _tmp28_ = NULL;
	gint _tmp29_ = 0;
	gint _tmp30_ = 0;
	gint _tmp31_ = 0;
#line 466 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (GEE_IS_LIST (failed), NULL);
#line 467 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = failed;
#line 467 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, GEE_TYPE_COLLECTION, GeeCollection));
#line 467 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = _tmp1_;
#line 467 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp2_ == 0) {
#line 468 "/home/jens/Source/shotwell/src/Dialogs.vala"
		result = NULL;
#line 468 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return result;
#line 4171 "Dialogs.c"
	}
#line 470 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = g_strdup ("");
#line 470 "/home/jens/Source/shotwell/src/Dialogs.vala"
	list = _tmp3_;
#line 4177 "Dialogs.c"
	{
		gint ctr = 0;
#line 471 "/home/jens/Source/shotwell/src/Dialogs.vala"
		ctr = 0;
#line 4182 "Dialogs.c"
		{
			gboolean _tmp4_ = FALSE;
#line 471 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp4_ = TRUE;
#line 471 "/home/jens/Source/shotwell/src/Dialogs.vala"
			while (TRUE) {
#line 4189 "Dialogs.c"
				gboolean _tmp6_ = FALSE;
				gint _tmp7_ = 0;
				const gchar* _tmp12_ = NULL;
				gboolean _tmp13_ = FALSE;
				const gchar* _tmp24_ = NULL;
				gchar* _tmp25_ = NULL;
				gchar* _tmp26_ = NULL;
				gchar* _tmp27_ = NULL;
#line 471 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (!_tmp4_) {
#line 4200 "Dialogs.c"
					gint _tmp5_ = 0;
#line 471 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp5_ = ctr;
#line 471 "/home/jens/Source/shotwell/src/Dialogs.vala"
					ctr = _tmp5_ + 1;
#line 4206 "Dialogs.c"
				}
#line 471 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp4_ = FALSE;
#line 471 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp7_ = ctr;
#line 471 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (_tmp7_ < IMPORT_UI_REPORT_FAILURE_COUNT) {
#line 4214 "Dialogs.c"
					gint _tmp8_ = 0;
					GeeList* _tmp9_ = NULL;
					gint _tmp10_ = 0;
					gint _tmp11_ = 0;
#line 471 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp8_ = ctr;
#line 471 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp9_ = failed;
#line 471 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp10_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, GEE_TYPE_COLLECTION, GeeCollection));
#line 471 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp11_ = _tmp10_;
#line 471 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp6_ = _tmp8_ < _tmp11_;
#line 4229 "Dialogs.c"
				} else {
#line 471 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp6_ = FALSE;
#line 4233 "Dialogs.c"
				}
#line 471 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (!_tmp6_) {
#line 471 "/home/jens/Source/shotwell/src/Dialogs.vala"
					break;
#line 4239 "Dialogs.c"
				}
#line 472 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp13_ = show_dest_id;
#line 472 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (_tmp13_) {
#line 4245 "Dialogs.c"
					GeeList* _tmp14_ = NULL;
					gint _tmp15_ = 0;
					gpointer _tmp16_ = NULL;
					BatchImportResult* _tmp17_ = NULL;
					const gchar* _tmp18_ = NULL;
#line 472 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp14_ = failed;
#line 472 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp15_ = ctr;
#line 472 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp16_ = gee_list_get (_tmp14_, _tmp15_);
#line 472 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp17_ = (BatchImportResult*) _tmp16_;
#line 472 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp18_ = _tmp17_->dest_identifier;
#line 472 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp12_ = _tmp18_;
#line 472 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_batch_import_result_unref0 (_tmp17_);
#line 4265 "Dialogs.c"
				} else {
					GeeList* _tmp19_ = NULL;
					gint _tmp20_ = 0;
					gpointer _tmp21_ = NULL;
					BatchImportResult* _tmp22_ = NULL;
					const gchar* _tmp23_ = NULL;
#line 473 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp19_ = failed;
#line 473 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp20_ = ctr;
#line 473 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp21_ = gee_list_get (_tmp19_, _tmp20_);
#line 473 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp22_ = (BatchImportResult*) _tmp21_;
#line 473 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp23_ = _tmp22_->src_identifier;
#line 473 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp12_ = _tmp23_;
#line 473 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_batch_import_result_unref0 (_tmp22_);
#line 4286 "Dialogs.c"
				}
#line 472 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp24_ = list;
#line 472 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp25_ = g_strdup_printf ("%s\n", _tmp12_);
#line 472 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp26_ = _tmp25_;
#line 472 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp27_ = g_strconcat (_tmp24_, _tmp26_, NULL);
#line 472 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (list);
#line 472 "/home/jens/Source/shotwell/src/Dialogs.vala"
				list = _tmp27_;
#line 472 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp26_);
#line 4302 "Dialogs.c"
			}
		}
	}
#line 476 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp28_ = failed;
#line 476 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp29_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp28_, GEE_TYPE_COLLECTION, GeeCollection));
#line 476 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp30_ = _tmp29_;
#line 476 "/home/jens/Source/shotwell/src/Dialogs.vala"
	remaining = _tmp30_ - IMPORT_UI_REPORT_FAILURE_COUNT;
#line 477 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp31_ = remaining;
#line 477 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp31_ > 0) {
#line 4318 "Dialogs.c"
		const gchar* _tmp32_ = NULL;
		const gchar* _tmp33_ = NULL;
		gint _tmp34_ = 0;
		gchar* _tmp35_ = NULL;
		gchar* _tmp36_ = NULL;
		gchar* _tmp37_ = NULL;
#line 478 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp32_ = list;
#line 478 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp33_ = _ ("(and %d more)\n");
#line 478 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp34_ = remaining;
#line 478 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp35_ = g_strdup_printf (_tmp33_, _tmp34_);
#line 478 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp36_ = _tmp35_;
#line 478 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp37_ = g_strconcat (_tmp32_, _tmp36_, NULL);
#line 478 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (list);
#line 478 "/home/jens/Source/shotwell/src/Dialogs.vala"
		list = _tmp37_;
#line 478 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp36_);
#line 4343 "Dialogs.c"
	}
#line 480 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = list;
#line 480 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 4349 "Dialogs.c"
}


ImportUIQuestionParams* import_ui_question_params_construct (GType object_type, const gchar* question, const gchar* yes_button, const gchar* no_button) {
	ImportUIQuestionParams* self = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
#line 488 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (question != NULL, NULL);
#line 488 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (yes_button != NULL, NULL);
#line 488 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (no_button != NULL, NULL);
#line 488 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = (ImportUIQuestionParams*) g_type_create_instance (object_type);
#line 489 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = question;
#line 489 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 489 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (self->question);
#line 489 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->question = _tmp1_;
#line 490 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = yes_button;
#line 490 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = g_strdup (_tmp2_);
#line 490 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (self->yes_button);
#line 490 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->yes_button = _tmp3_;
#line 491 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = no_button;
#line 491 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = g_strdup (_tmp4_);
#line 491 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (self->no_button);
#line 491 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->no_button = _tmp5_;
#line 488 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return self;
#line 4395 "Dialogs.c"
}


ImportUIQuestionParams* import_ui_question_params_new (const gchar* question, const gchar* yes_button, const gchar* no_button) {
#line 488 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return import_ui_question_params_construct (IMPORT_UI_TYPE_QUESTION_PARAMS, question, yes_button, no_button);
#line 4402 "Dialogs.c"
}


static void import_ui_value_question_params_init (GValue* value) {
#line 483 "/home/jens/Source/shotwell/src/Dialogs.vala"
	value->data[0].v_pointer = NULL;
#line 4409 "Dialogs.c"
}


static void import_ui_value_question_params_free_value (GValue* value) {
#line 483 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (value->data[0].v_pointer) {
#line 483 "/home/jens/Source/shotwell/src/Dialogs.vala"
		import_ui_question_params_unref (value->data[0].v_pointer);
#line 4418 "Dialogs.c"
	}
}


static void import_ui_value_question_params_copy_value (const GValue* src_value, GValue* dest_value) {
#line 483 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (src_value->data[0].v_pointer) {
#line 483 "/home/jens/Source/shotwell/src/Dialogs.vala"
		dest_value->data[0].v_pointer = import_ui_question_params_ref (src_value->data[0].v_pointer);
#line 4428 "Dialogs.c"
	} else {
#line 483 "/home/jens/Source/shotwell/src/Dialogs.vala"
		dest_value->data[0].v_pointer = NULL;
#line 4432 "Dialogs.c"
	}
}


static gpointer import_ui_value_question_params_peek_pointer (const GValue* value) {
#line 483 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return value->data[0].v_pointer;
#line 4440 "Dialogs.c"
}


static gchar* import_ui_value_question_params_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
#line 483 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (collect_values[0].v_pointer) {
#line 4447 "Dialogs.c"
		ImportUIQuestionParams* object;
		object = collect_values[0].v_pointer;
#line 483 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (object->parent_instance.g_class == NULL) {
#line 483 "/home/jens/Source/shotwell/src/Dialogs.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 4454 "Dialogs.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 483 "/home/jens/Source/shotwell/src/Dialogs.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 4458 "Dialogs.c"
		}
#line 483 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = import_ui_question_params_ref (object);
#line 4462 "Dialogs.c"
	} else {
#line 483 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = NULL;
#line 4466 "Dialogs.c"
	}
#line 483 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return NULL;
#line 4470 "Dialogs.c"
}


static gchar* import_ui_value_question_params_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	ImportUIQuestionParams** object_p;
	object_p = collect_values[0].v_pointer;
#line 483 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (!object_p) {
#line 483 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 4481 "Dialogs.c"
	}
#line 483 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (!value->data[0].v_pointer) {
#line 483 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*object_p = NULL;
#line 4487 "Dialogs.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 483 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*object_p = value->data[0].v_pointer;
#line 4491 "Dialogs.c"
	} else {
#line 483 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*object_p = import_ui_question_params_ref (value->data[0].v_pointer);
#line 4495 "Dialogs.c"
	}
#line 483 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return NULL;
#line 4499 "Dialogs.c"
}


GParamSpec* import_ui_param_spec_question_params (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
	ImportUIParamSpecQuestionParams* spec;
#line 483 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (g_type_is_a (object_type, IMPORT_UI_TYPE_QUESTION_PARAMS), NULL);
#line 483 "/home/jens/Source/shotwell/src/Dialogs.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 483 "/home/jens/Source/shotwell/src/Dialogs.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 483 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return G_PARAM_SPEC (spec);
#line 4513 "Dialogs.c"
}


gpointer import_ui_value_get_question_params (const GValue* value) {
#line 483 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, IMPORT_UI_TYPE_QUESTION_PARAMS), NULL);
#line 483 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return value->data[0].v_pointer;
#line 4522 "Dialogs.c"
}


void import_ui_value_set_question_params (GValue* value, gpointer v_object) {
	ImportUIQuestionParams* old;
#line 483 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, IMPORT_UI_TYPE_QUESTION_PARAMS));
#line 483 "/home/jens/Source/shotwell/src/Dialogs.vala"
	old = value->data[0].v_pointer;
#line 483 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (v_object) {
#line 483 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, IMPORT_UI_TYPE_QUESTION_PARAMS));
#line 483 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 483 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = v_object;
#line 483 "/home/jens/Source/shotwell/src/Dialogs.vala"
		import_ui_question_params_ref (value->data[0].v_pointer);
#line 4542 "Dialogs.c"
	} else {
#line 483 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = NULL;
#line 4546 "Dialogs.c"
	}
#line 483 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (old) {
#line 483 "/home/jens/Source/shotwell/src/Dialogs.vala"
		import_ui_question_params_unref (old);
#line 4552 "Dialogs.c"
	}
}


void import_ui_value_take_question_params (GValue* value, gpointer v_object) {
	ImportUIQuestionParams* old;
#line 483 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, IMPORT_UI_TYPE_QUESTION_PARAMS));
#line 483 "/home/jens/Source/shotwell/src/Dialogs.vala"
	old = value->data[0].v_pointer;
#line 483 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (v_object) {
#line 483 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, IMPORT_UI_TYPE_QUESTION_PARAMS));
#line 483 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 483 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = v_object;
#line 4571 "Dialogs.c"
	} else {
#line 483 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = NULL;
#line 4575 "Dialogs.c"
	}
#line 483 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (old) {
#line 483 "/home/jens/Source/shotwell/src/Dialogs.vala"
		import_ui_question_params_unref (old);
#line 4581 "Dialogs.c"
	}
}


static void import_ui_question_params_class_init (ImportUIQuestionParamsClass * klass) {
#line 483 "/home/jens/Source/shotwell/src/Dialogs.vala"
	import_ui_question_params_parent_class = g_type_class_peek_parent (klass);
#line 483 "/home/jens/Source/shotwell/src/Dialogs.vala"
	((ImportUIQuestionParamsClass *) klass)->finalize = import_ui_question_params_finalize;
#line 4591 "Dialogs.c"
}


static void import_ui_question_params_instance_init (ImportUIQuestionParams * self) {
#line 483 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->ref_count = 1;
#line 4598 "Dialogs.c"
}


static void import_ui_question_params_finalize (ImportUIQuestionParams* obj) {
	ImportUIQuestionParams * self;
#line 483 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, IMPORT_UI_TYPE_QUESTION_PARAMS, ImportUIQuestionParams);
#line 483 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_handlers_destroy (self);
#line 484 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (self->question);
#line 485 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (self->yes_button);
#line 486 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (self->no_button);
#line 4614 "Dialogs.c"
}


GType import_ui_question_params_get_type (void) {
	static volatile gsize import_ui_question_params_type_id__volatile = 0;
	if (g_once_init_enter (&import_ui_question_params_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { import_ui_value_question_params_init, import_ui_value_question_params_free_value, import_ui_value_question_params_copy_value, import_ui_value_question_params_peek_pointer, "p", import_ui_value_question_params_collect_value, "p", import_ui_value_question_params_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (ImportUIQuestionParamsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) import_ui_question_params_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ImportUIQuestionParams), 0, (GInstanceInitFunc) import_ui_question_params_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType import_ui_question_params_type_id;
		import_ui_question_params_type_id = g_type_register_fundamental (g_type_fundamental_next (), "ImportUIQuestionParams", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&import_ui_question_params_type_id__volatile, import_ui_question_params_type_id);
	}
	return import_ui_question_params_type_id__volatile;
}


gpointer import_ui_question_params_ref (gpointer instance) {
	ImportUIQuestionParams* self;
	self = instance;
#line 483 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_atomic_int_inc (&self->ref_count);
#line 483 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return instance;
#line 4639 "Dialogs.c"
}


void import_ui_question_params_unref (gpointer instance) {
	ImportUIQuestionParams* self;
	self = instance;
#line 483 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 483 "/home/jens/Source/shotwell/src/Dialogs.vala"
		IMPORT_UI_QUESTION_PARAMS_GET_CLASS (self)->finalize (self);
#line 483 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 4652 "Dialogs.c"
	}
}


gboolean import_ui_import_has_photos (GeeCollection* import_collection) {
	gboolean result = FALSE;
#line 495 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (GEE_IS_COLLECTION (import_collection), FALSE);
#line 4661 "Dialogs.c"
	{
		GeeIterator* _current_result_it = NULL;
		GeeCollection* _tmp0_ = NULL;
		GeeIterator* _tmp1_ = NULL;
#line 496 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = import_collection;
#line 496 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp1_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, GEE_TYPE_ITERABLE, GeeIterable));
#line 496 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_current_result_it = _tmp1_;
#line 496 "/home/jens/Source/shotwell/src/Dialogs.vala"
		while (TRUE) {
#line 4674 "Dialogs.c"
			GeeIterator* _tmp2_ = NULL;
			gboolean _tmp3_ = FALSE;
			BatchImportResult* current_result = NULL;
			GeeIterator* _tmp4_ = NULL;
			gpointer _tmp5_ = NULL;
			gboolean _tmp6_ = FALSE;
			BatchImportResult* _tmp7_ = NULL;
			GFile* _tmp8_ = NULL;
#line 496 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp2_ = _current_result_it;
#line 496 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp3_ = gee_iterator_next (_tmp2_);
#line 496 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (!_tmp3_) {
#line 496 "/home/jens/Source/shotwell/src/Dialogs.vala"
				break;
#line 4691 "Dialogs.c"
			}
#line 496 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp4_ = _current_result_it;
#line 496 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp5_ = gee_iterator_get (_tmp4_);
#line 496 "/home/jens/Source/shotwell/src/Dialogs.vala"
			current_result = (BatchImportResult*) _tmp5_;
#line 497 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp7_ = current_result;
#line 497 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp8_ = _tmp7_->file;
#line 497 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (_tmp8_ != NULL) {
#line 4705 "Dialogs.c"
				BatchImportResult* _tmp9_ = NULL;
				GFile* _tmp10_ = NULL;
				PhotoFileFormat _tmp11_ = 0;
#line 498 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp9_ = current_result;
#line 498 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp10_ = _tmp9_->file;
#line 498 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp11_ = photo_file_format_get_by_file_extension (_tmp10_);
#line 498 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp6_ = _tmp11_ != PHOTO_FILE_FORMAT_UNKNOWN;
#line 4717 "Dialogs.c"
			} else {
#line 497 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp6_ = FALSE;
#line 4721 "Dialogs.c"
			}
#line 497 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (_tmp6_) {
#line 499 "/home/jens/Source/shotwell/src/Dialogs.vala"
				result = TRUE;
#line 499 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_batch_import_result_unref0 (current_result);
#line 499 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_object_unref0 (_current_result_it);
#line 499 "/home/jens/Source/shotwell/src/Dialogs.vala"
				return result;
#line 4733 "Dialogs.c"
			}
#line 496 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_batch_import_result_unref0 (current_result);
#line 4737 "Dialogs.c"
		}
#line 496 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (_current_result_it);
#line 4741 "Dialogs.c"
	}
#line 502 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = FALSE;
#line 502 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 4747 "Dialogs.c"
}


gboolean import_ui_import_has_videos (GeeCollection* import_collection) {
	gboolean result = FALSE;
#line 505 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (GEE_IS_COLLECTION (import_collection), FALSE);
#line 4755 "Dialogs.c"
	{
		GeeIterator* _current_result_it = NULL;
		GeeCollection* _tmp0_ = NULL;
		GeeIterator* _tmp1_ = NULL;
#line 506 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = import_collection;
#line 506 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp1_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, GEE_TYPE_ITERABLE, GeeIterable));
#line 506 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_current_result_it = _tmp1_;
#line 506 "/home/jens/Source/shotwell/src/Dialogs.vala"
		while (TRUE) {
#line 4768 "Dialogs.c"
			GeeIterator* _tmp2_ = NULL;
			gboolean _tmp3_ = FALSE;
			BatchImportResult* current_result = NULL;
			GeeIterator* _tmp4_ = NULL;
			gpointer _tmp5_ = NULL;
			gboolean _tmp6_ = FALSE;
			BatchImportResult* _tmp7_ = NULL;
			GFile* _tmp8_ = NULL;
#line 506 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp2_ = _current_result_it;
#line 506 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp3_ = gee_iterator_next (_tmp2_);
#line 506 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (!_tmp3_) {
#line 506 "/home/jens/Source/shotwell/src/Dialogs.vala"
				break;
#line 4785 "Dialogs.c"
			}
#line 506 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp4_ = _current_result_it;
#line 506 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp5_ = gee_iterator_get (_tmp4_);
#line 506 "/home/jens/Source/shotwell/src/Dialogs.vala"
			current_result = (BatchImportResult*) _tmp5_;
#line 507 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp7_ = current_result;
#line 507 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp8_ = _tmp7_->file;
#line 507 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (_tmp8_ != NULL) {
#line 4799 "Dialogs.c"
				BatchImportResult* _tmp9_ = NULL;
				GFile* _tmp10_ = NULL;
				gboolean _tmp11_ = FALSE;
#line 507 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp9_ = current_result;
#line 507 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp10_ = _tmp9_->file;
#line 507 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp11_ = video_reader_is_supported_video_file (_tmp10_);
#line 507 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp6_ = _tmp11_;
#line 4811 "Dialogs.c"
			} else {
#line 507 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp6_ = FALSE;
#line 4815 "Dialogs.c"
			}
#line 507 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (_tmp6_) {
#line 508 "/home/jens/Source/shotwell/src/Dialogs.vala"
				result = TRUE;
#line 508 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_batch_import_result_unref0 (current_result);
#line 508 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_object_unref0 (_current_result_it);
#line 508 "/home/jens/Source/shotwell/src/Dialogs.vala"
				return result;
#line 4827 "Dialogs.c"
			}
#line 506 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_batch_import_result_unref0 (current_result);
#line 4831 "Dialogs.c"
		}
#line 506 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (_current_result_it);
#line 4835 "Dialogs.c"
	}
#line 510 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = FALSE;
#line 510 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 4841 "Dialogs.c"
}


gchar* import_ui_get_media_specific_string (GeeCollection* import_collection, const gchar* photos_msg, const gchar* videos_msg, const gchar* both_msg, const gchar* neither_msg) {
	gchar* result = NULL;
	gboolean has_photos = FALSE;
	GeeCollection* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	gboolean has_videos = FALSE;
	GeeCollection* _tmp2_ = NULL;
	gboolean _tmp3_ = FALSE;
	gboolean _tmp4_ = FALSE;
	gboolean _tmp5_ = FALSE;
#line 513 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (GEE_IS_COLLECTION (import_collection), NULL);
#line 513 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (photos_msg != NULL, NULL);
#line 513 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (videos_msg != NULL, NULL);
#line 513 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (both_msg != NULL, NULL);
#line 513 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (neither_msg != NULL, NULL);
#line 515 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = import_collection;
#line 515 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = import_ui_import_has_photos (_tmp0_);
#line 515 "/home/jens/Source/shotwell/src/Dialogs.vala"
	has_photos = _tmp1_;
#line 516 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = import_collection;
#line 516 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = import_ui_import_has_videos (_tmp2_);
#line 516 "/home/jens/Source/shotwell/src/Dialogs.vala"
	has_videos = _tmp3_;
#line 518 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = has_photos;
#line 518 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp5_) {
#line 4881 "Dialogs.c"
		gboolean _tmp6_ = FALSE;
#line 518 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp6_ = has_videos;
#line 518 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp4_ = _tmp6_;
#line 4887 "Dialogs.c"
	} else {
#line 518 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp4_ = FALSE;
#line 4891 "Dialogs.c"
	}
#line 518 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp4_) {
#line 4895 "Dialogs.c"
		const gchar* _tmp7_ = NULL;
		gchar* _tmp8_ = NULL;
#line 519 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp7_ = both_msg;
#line 519 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp8_ = g_strdup (_tmp7_);
#line 519 "/home/jens/Source/shotwell/src/Dialogs.vala"
		result = _tmp8_;
#line 519 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return result;
#line 4906 "Dialogs.c"
	} else {
		gboolean _tmp9_ = FALSE;
#line 520 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp9_ = has_photos;
#line 520 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp9_) {
#line 4913 "Dialogs.c"
			const gchar* _tmp10_ = NULL;
			gchar* _tmp11_ = NULL;
#line 521 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp10_ = photos_msg;
#line 521 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp11_ = g_strdup (_tmp10_);
#line 521 "/home/jens/Source/shotwell/src/Dialogs.vala"
			result = _tmp11_;
#line 521 "/home/jens/Source/shotwell/src/Dialogs.vala"
			return result;
#line 4924 "Dialogs.c"
		} else {
			gboolean _tmp12_ = FALSE;
#line 522 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp12_ = has_videos;
#line 522 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (_tmp12_) {
#line 4931 "Dialogs.c"
				const gchar* _tmp13_ = NULL;
				gchar* _tmp14_ = NULL;
#line 523 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp13_ = videos_msg;
#line 523 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp14_ = g_strdup (_tmp13_);
#line 523 "/home/jens/Source/shotwell/src/Dialogs.vala"
				result = _tmp14_;
#line 523 "/home/jens/Source/shotwell/src/Dialogs.vala"
				return result;
#line 4942 "Dialogs.c"
			} else {
				const gchar* _tmp15_ = NULL;
				gchar* _tmp16_ = NULL;
#line 525 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp15_ = neither_msg;
#line 525 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp16_ = g_strdup (_tmp15_);
#line 525 "/home/jens/Source/shotwell/src/Dialogs.vala"
				result = _tmp16_;
#line 525 "/home/jens/Source/shotwell/src/Dialogs.vala"
				return result;
#line 4954 "Dialogs.c"
			}
		}
	}
}


gchar* import_ui_create_result_report_from_manifest (ImportManifest* manifest) {
	gchar* result = NULL;
	GString* builder = NULL;
	GString* _tmp0_ = NULL;
	gchar* header = NULL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
	GTimeVal _tmp8_ = {0};
	gchar* _tmp9_ = NULL;
	gchar* _tmp10_ = NULL;
	gchar* _tmp11_ = NULL;
	gchar* _tmp12_ = NULL;
	gchar* _tmp13_ = NULL;
	gchar* _tmp14_ = NULL;
	GString* _tmp15_ = NULL;
	const gchar* _tmp16_ = NULL;
	gchar* subhead = NULL;
	ImportManifest* _tmp17_ = NULL;
	GeeList* _tmp18_ = NULL;
	gint _tmp19_ = 0;
	gint _tmp20_ = 0;
	const gchar* _tmp21_ = NULL;
	ImportManifest* _tmp22_ = NULL;
	GeeList* _tmp23_ = NULL;
	gint _tmp24_ = 0;
	gint _tmp25_ = 0;
	gchar* _tmp26_ = NULL;
	const gchar* _tmp27_ = NULL;
	gchar* _tmp28_ = NULL;
	const gchar* _tmp29_ = NULL;
	ImportManifest* _tmp30_ = NULL;
	GeeList* _tmp31_ = NULL;
	gint _tmp32_ = 0;
	gint _tmp33_ = 0;
	const gchar* _tmp34_ = NULL;
	ImportManifest* _tmp35_ = NULL;
	GeeList* _tmp36_ = NULL;
	gint _tmp37_ = 0;
	gint _tmp38_ = 0;
	gchar* _tmp39_ = NULL;
	gchar* _tmp40_ = NULL;
	gchar* _tmp41_ = NULL;
	const gchar* _tmp42_ = NULL;
	gchar* _tmp43_ = NULL;
	GString* _tmp44_ = NULL;
	const gchar* _tmp45_ = NULL;
	gchar* current_file_summary = NULL;
	gchar* _tmp46_ = NULL;
	ImportManifest* _tmp47_ = NULL;
	GeeList* _tmp48_ = NULL;
	gint _tmp49_ = 0;
	gint _tmp50_ = 0;
	ImportManifest* _tmp87_ = NULL;
	GeeList* _tmp88_ = NULL;
	gint _tmp89_ = 0;
	gint _tmp90_ = 0;
	ImportManifest* _tmp123_ = NULL;
	GeeList* _tmp124_ = NULL;
	gint _tmp125_ = 0;
	gint _tmp126_ = 0;
	ImportManifest* _tmp159_ = NULL;
	GeeList* _tmp160_ = NULL;
	gint _tmp161_ = 0;
	gint _tmp162_ = 0;
	ImportManifest* _tmp195_ = NULL;
	GeeList* _tmp196_ = NULL;
	gint _tmp197_ = 0;
	gint _tmp198_ = 0;
	ImportManifest* _tmp236_ = NULL;
	GeeList* _tmp237_ = NULL;
	gint _tmp238_ = 0;
	gint _tmp239_ = 0;
	ImportManifest* _tmp272_ = NULL;
	GeeList* _tmp273_ = NULL;
	gint _tmp274_ = 0;
	gint _tmp275_ = 0;
	GString* _tmp308_ = NULL;
	const gchar* _tmp309_ = NULL;
	gchar* _tmp310_ = NULL;
#line 528 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_IMPORT_MANIFEST (manifest), NULL);
#line 529 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = g_string_new ("");
#line 529 "/home/jens/Source/shotwell/src/Dialogs.vala"
	builder = _tmp0_;
#line 531 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = _ ("Import Results Report");
#line 531 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = g_strconcat (_tmp1_, " (Shotwell ", NULL);
#line 531 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = _tmp2_;
#line 531 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = g_strconcat (_tmp3_, RESOURCES_APP_VERSION, NULL);
#line 531 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = _tmp4_;
#line 531 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = g_strconcat (_tmp5_, " @ ", NULL);
#line 531 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = _tmp6_;
#line 531 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_get_current_time (&_tmp8_);
#line 531 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = g_time_val_to_iso8601 (&_tmp8_);
#line 531 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp10_ = _tmp9_;
#line 531 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp11_ = g_strconcat (_tmp7_, _tmp10_, NULL);
#line 531 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp12_ = _tmp11_;
#line 531 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp13_ = g_strconcat (_tmp12_, ")\n\n", NULL);
#line 531 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp14_ = _tmp13_;
#line 531 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp12_);
#line 531 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp10_);
#line 531 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp7_);
#line 531 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp5_);
#line 531 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp3_);
#line 531 "/home/jens/Source/shotwell/src/Dialogs.vala"
	header = _tmp14_;
#line 533 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp15_ = builder;
#line 533 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp16_ = header;
#line 533 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_string_append (_tmp15_, _tmp16_);
#line 535 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp17_ = manifest;
#line 535 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp18_ = _tmp17_->all;
#line 535 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp19_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp18_, GEE_TYPE_COLLECTION, GeeCollection));
#line 535 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp20_ = _tmp19_;
#line 535 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp21_ = ngettext ("Attempted to import %d file.", "Attempted to import %d files.", (gulong) _tmp20_);
#line 535 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp22_ = manifest;
#line 535 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp23_ = _tmp22_->all;
#line 535 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp24_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp23_, GEE_TYPE_COLLECTION, GeeCollection));
#line 535 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp25_ = _tmp24_;
#line 535 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp26_ = g_strdup_printf (_tmp21_, _tmp25_);
#line 535 "/home/jens/Source/shotwell/src/Dialogs.vala"
	subhead = _tmp26_;
#line 537 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp27_ = subhead;
#line 537 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp28_ = g_strconcat (_tmp27_, " ", NULL);
#line 537 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (subhead);
#line 537 "/home/jens/Source/shotwell/src/Dialogs.vala"
	subhead = _tmp28_;
#line 538 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp29_ = subhead;
#line 538 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp30_ = manifest;
#line 538 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp31_ = _tmp30_->success;
#line 538 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp32_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp31_, GEE_TYPE_COLLECTION, GeeCollection));
#line 538 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp33_ = _tmp32_;
#line 538 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp34_ = ngettext ("Of these, %d file was successfully imported.", "Of these, %d files were successfully imported.", (gulong) _tmp33_);
#line 538 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp35_ = manifest;
#line 538 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp36_ = _tmp35_->success;
#line 538 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp37_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp36_, GEE_TYPE_COLLECTION, GeeCollection));
#line 538 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp38_ = _tmp37_;
#line 538 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp39_ = g_strdup_printf (_tmp34_, _tmp38_);
#line 538 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp40_ = _tmp39_;
#line 538 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp41_ = g_strconcat (_tmp29_, _tmp40_, NULL);
#line 538 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (subhead);
#line 538 "/home/jens/Source/shotwell/src/Dialogs.vala"
	subhead = _tmp41_;
#line 538 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp40_);
#line 541 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp42_ = subhead;
#line 541 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp43_ = g_strconcat (_tmp42_, "\n\n", NULL);
#line 541 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (subhead);
#line 541 "/home/jens/Source/shotwell/src/Dialogs.vala"
	subhead = _tmp43_;
#line 542 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp44_ = builder;
#line 542 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp45_ = subhead;
#line 542 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_string_append (_tmp44_, _tmp45_);
#line 544 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp46_ = g_strdup ("");
#line 544 "/home/jens/Source/shotwell/src/Dialogs.vala"
	current_file_summary = _tmp46_;
#line 549 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp47_ = manifest;
#line 549 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp48_ = _tmp47_->already_imported;
#line 549 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp49_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp48_, GEE_TYPE_COLLECTION, GeeCollection));
#line 549 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp50_ = _tmp49_;
#line 549 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp50_ > 0) {
#line 5187 "Dialogs.c"
		GString* _tmp51_ = NULL;
		const gchar* _tmp52_ = NULL;
		gchar* _tmp53_ = NULL;
		gchar* _tmp54_ = NULL;
#line 550 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp51_ = builder;
#line 550 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp52_ = _ ("Duplicate Photos/Videos Not Imported:");
#line 550 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp53_ = g_strconcat (_tmp52_, "\n\n", NULL);
#line 550 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp54_ = _tmp53_;
#line 550 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_string_append (_tmp51_, _tmp54_);
#line 550 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp54_);
#line 5204 "Dialogs.c"
		{
			GeeList* _result_list = NULL;
			ImportManifest* _tmp55_ = NULL;
			GeeList* _tmp56_ = NULL;
			GeeList* _tmp57_ = NULL;
			gint _result_size = 0;
			GeeList* _tmp58_ = NULL;
			gint _tmp59_ = 0;
			gint _tmp60_ = 0;
			gint _result_index = 0;
#line 552 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp55_ = manifest;
#line 552 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp56_ = _tmp55_->already_imported;
#line 552 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp57_ = _g_object_ref0 (_tmp56_);
#line 552 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_list = _tmp57_;
#line 552 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp58_ = _result_list;
#line 552 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp59_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp58_, GEE_TYPE_COLLECTION, GeeCollection));
#line 552 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp60_ = _tmp59_;
#line 552 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_size = _tmp60_;
#line 552 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_index = -1;
#line 552 "/home/jens/Source/shotwell/src/Dialogs.vala"
			while (TRUE) {
#line 5235 "Dialogs.c"
				gint _tmp61_ = 0;
				gint _tmp62_ = 0;
				gint _tmp63_ = 0;
				BatchImportResult* _result_ = NULL;
				GeeList* _tmp64_ = NULL;
				gint _tmp65_ = 0;
				gpointer _tmp66_ = NULL;
				BatchImportResult* _tmp67_ = NULL;
				const gchar* _tmp68_ = NULL;
				gchar* _tmp69_ = NULL;
				gchar* _tmp70_ = NULL;
				const gchar* _tmp71_ = NULL;
				gchar* _tmp72_ = NULL;
				gchar* _tmp73_ = NULL;
				gchar* _tmp74_ = NULL;
				gchar* _tmp75_ = NULL;
				BatchImportResult* _tmp76_ = NULL;
				DuplicatedFile* _tmp77_ = NULL;
				GFile* _tmp78_ = NULL;
				GFile* _tmp79_ = NULL;
				gchar* _tmp80_ = NULL;
				gchar* _tmp81_ = NULL;
				gchar* _tmp82_ = NULL;
				gchar* _tmp83_ = NULL;
				gchar* _tmp84_ = NULL;
				GString* _tmp85_ = NULL;
				const gchar* _tmp86_ = NULL;
#line 552 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp61_ = _result_index;
#line 552 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_result_index = _tmp61_ + 1;
#line 552 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp62_ = _result_index;
#line 552 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp63_ = _result_size;
#line 552 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (!(_tmp62_ < _tmp63_)) {
#line 552 "/home/jens/Source/shotwell/src/Dialogs.vala"
					break;
#line 5275 "Dialogs.c"
				}
#line 552 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp64_ = _result_list;
#line 552 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp65_ = _result_index;
#line 552 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp66_ = gee_list_get (_tmp64_, _tmp65_);
#line 552 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_result_ = (BatchImportResult*) _tmp66_;
#line 553 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp67_ = _result_;
#line 553 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp68_ = _tmp67_->src_identifier;
#line 553 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp69_ = g_strconcat (_tmp68_, " ", NULL);
#line 553 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp70_ = _tmp69_;
#line 553 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp71_ = _ ("duplicates existing media item");
#line 553 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp72_ = g_strconcat (_tmp70_, _tmp71_, NULL);
#line 553 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp73_ = _tmp72_;
#line 553 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp74_ = g_strconcat (_tmp73_, "\n\t", NULL);
#line 553 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp75_ = _tmp74_;
#line 553 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp76_ = _result_;
#line 553 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp77_ = _tmp76_->duplicate_of;
#line 553 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp78_ = duplicated_file_get_file (_tmp77_);
#line 553 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp79_ = _tmp78_;
#line 553 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp80_ = g_file_get_path (_tmp79_);
#line 553 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp81_ = _tmp80_;
#line 553 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp82_ = g_strconcat (_tmp75_, _tmp81_, NULL);
#line 553 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp83_ = _tmp82_;
#line 553 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp84_ = g_strconcat (_tmp83_, "\n\n", NULL);
#line 553 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (current_file_summary);
#line 553 "/home/jens/Source/shotwell/src/Dialogs.vala"
				current_file_summary = _tmp84_;
#line 553 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp83_);
#line 553 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp81_);
#line 553 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_object_unref0 (_tmp79_);
#line 553 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp75_);
#line 553 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp73_);
#line 553 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp70_);
#line 557 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp85_ = builder;
#line 557 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp86_ = current_file_summary;
#line 557 "/home/jens/Source/shotwell/src/Dialogs.vala"
				g_string_append (_tmp85_, _tmp86_);
#line 552 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_batch_import_result_unref0 (_result_);
#line 5345 "Dialogs.c"
			}
#line 552 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_object_unref0 (_result_list);
#line 5349 "Dialogs.c"
		}
	}
#line 564 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp87_ = manifest;
#line 564 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp88_ = _tmp87_->camera_failed;
#line 564 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp89_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp88_, GEE_TYPE_COLLECTION, GeeCollection));
#line 564 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp90_ = _tmp89_;
#line 564 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp90_ > 0) {
#line 5362 "Dialogs.c"
		GString* _tmp91_ = NULL;
		const gchar* _tmp92_ = NULL;
		gchar* _tmp93_ = NULL;
		gchar* _tmp94_ = NULL;
#line 565 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp91_ = builder;
#line 565 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp92_ = _ ("Photos/Videos Not Imported Due to Camera Errors:");
#line 565 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp93_ = g_strconcat (_tmp92_, "\n\n", NULL);
#line 565 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp94_ = _tmp93_;
#line 565 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_string_append (_tmp91_, _tmp94_);
#line 565 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp94_);
#line 5379 "Dialogs.c"
		{
			GeeList* _result_list = NULL;
			ImportManifest* _tmp95_ = NULL;
			GeeList* _tmp96_ = NULL;
			GeeList* _tmp97_ = NULL;
			gint _result_size = 0;
			GeeList* _tmp98_ = NULL;
			gint _tmp99_ = 0;
			gint _tmp100_ = 0;
			gint _result_index = 0;
#line 567 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp95_ = manifest;
#line 567 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp96_ = _tmp95_->camera_failed;
#line 567 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp97_ = _g_object_ref0 (_tmp96_);
#line 567 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_list = _tmp97_;
#line 567 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp98_ = _result_list;
#line 567 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp99_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp98_, GEE_TYPE_COLLECTION, GeeCollection));
#line 567 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp100_ = _tmp99_;
#line 567 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_size = _tmp100_;
#line 567 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_index = -1;
#line 567 "/home/jens/Source/shotwell/src/Dialogs.vala"
			while (TRUE) {
#line 5410 "Dialogs.c"
				gint _tmp101_ = 0;
				gint _tmp102_ = 0;
				gint _tmp103_ = 0;
				BatchImportResult* _result_ = NULL;
				GeeList* _tmp104_ = NULL;
				gint _tmp105_ = 0;
				gpointer _tmp106_ = NULL;
				BatchImportResult* _tmp107_ = NULL;
				const gchar* _tmp108_ = NULL;
				gchar* _tmp109_ = NULL;
				gchar* _tmp110_ = NULL;
				const gchar* _tmp111_ = NULL;
				gchar* _tmp112_ = NULL;
				gchar* _tmp113_ = NULL;
				gchar* _tmp114_ = NULL;
				gchar* _tmp115_ = NULL;
				BatchImportResult* _tmp116_ = NULL;
				const gchar* _tmp117_ = NULL;
				gchar* _tmp118_ = NULL;
				gchar* _tmp119_ = NULL;
				gchar* _tmp120_ = NULL;
				GString* _tmp121_ = NULL;
				const gchar* _tmp122_ = NULL;
#line 567 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp101_ = _result_index;
#line 567 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_result_index = _tmp101_ + 1;
#line 567 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp102_ = _result_index;
#line 567 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp103_ = _result_size;
#line 567 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (!(_tmp102_ < _tmp103_)) {
#line 567 "/home/jens/Source/shotwell/src/Dialogs.vala"
					break;
#line 5446 "Dialogs.c"
				}
#line 567 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp104_ = _result_list;
#line 567 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp105_ = _result_index;
#line 567 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp106_ = gee_list_get (_tmp104_, _tmp105_);
#line 567 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_result_ = (BatchImportResult*) _tmp106_;
#line 568 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp107_ = _result_;
#line 568 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp108_ = _tmp107_->src_identifier;
#line 568 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp109_ = g_strconcat (_tmp108_, "\n\t", NULL);
#line 568 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp110_ = _tmp109_;
#line 568 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp111_ = _ ("error message:");
#line 568 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp112_ = g_strconcat (_tmp110_, _tmp111_, NULL);
#line 568 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp113_ = _tmp112_;
#line 568 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp114_ = g_strconcat (_tmp113_, " ", NULL);
#line 568 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp115_ = _tmp114_;
#line 568 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp116_ = _result_;
#line 568 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp117_ = _tmp116_->errmsg;
#line 568 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp118_ = g_strconcat (_tmp115_, _tmp117_, NULL);
#line 568 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp119_ = _tmp118_;
#line 568 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp120_ = g_strconcat (_tmp119_, "\n\n", NULL);
#line 568 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (current_file_summary);
#line 568 "/home/jens/Source/shotwell/src/Dialogs.vala"
				current_file_summary = _tmp120_;
#line 568 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp119_);
#line 568 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp115_);
#line 568 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp113_);
#line 568 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp110_);
#line 571 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp121_ = builder;
#line 571 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp122_ = current_file_summary;
#line 571 "/home/jens/Source/shotwell/src/Dialogs.vala"
				g_string_append (_tmp121_, _tmp122_);
#line 567 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_batch_import_result_unref0 (_result_);
#line 5504 "Dialogs.c"
			}
#line 567 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_object_unref0 (_result_list);
#line 5508 "Dialogs.c"
		}
	}
#line 578 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp123_ = manifest;
#line 578 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp124_ = _tmp123_->skipped_files;
#line 578 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp125_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp124_, GEE_TYPE_COLLECTION, GeeCollection));
#line 578 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp126_ = _tmp125_;
#line 578 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp126_ > 0) {
#line 5521 "Dialogs.c"
		GString* _tmp127_ = NULL;
		const gchar* _tmp128_ = NULL;
		gchar* _tmp129_ = NULL;
		gchar* _tmp130_ = NULL;
#line 579 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp127_ = builder;
#line 579 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp128_ = _ ("Files Not Imported Because They Weren't Recognized as Photos or Videos" \
":");
#line 579 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp129_ = g_strconcat (_tmp128_, "\n\n", NULL);
#line 579 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp130_ = _tmp129_;
#line 579 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_string_append (_tmp127_, _tmp130_);
#line 579 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp130_);
#line 5538 "Dialogs.c"
		{
			GeeList* _result_list = NULL;
			ImportManifest* _tmp131_ = NULL;
			GeeList* _tmp132_ = NULL;
			GeeList* _tmp133_ = NULL;
			gint _result_size = 0;
			GeeList* _tmp134_ = NULL;
			gint _tmp135_ = 0;
			gint _tmp136_ = 0;
			gint _result_index = 0;
#line 582 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp131_ = manifest;
#line 582 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp132_ = _tmp131_->skipped_files;
#line 582 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp133_ = _g_object_ref0 (_tmp132_);
#line 582 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_list = _tmp133_;
#line 582 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp134_ = _result_list;
#line 582 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp135_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp134_, GEE_TYPE_COLLECTION, GeeCollection));
#line 582 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp136_ = _tmp135_;
#line 582 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_size = _tmp136_;
#line 582 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_index = -1;
#line 582 "/home/jens/Source/shotwell/src/Dialogs.vala"
			while (TRUE) {
#line 5569 "Dialogs.c"
				gint _tmp137_ = 0;
				gint _tmp138_ = 0;
				gint _tmp139_ = 0;
				BatchImportResult* _result_ = NULL;
				GeeList* _tmp140_ = NULL;
				gint _tmp141_ = 0;
				gpointer _tmp142_ = NULL;
				BatchImportResult* _tmp143_ = NULL;
				const gchar* _tmp144_ = NULL;
				gchar* _tmp145_ = NULL;
				gchar* _tmp146_ = NULL;
				const gchar* _tmp147_ = NULL;
				gchar* _tmp148_ = NULL;
				gchar* _tmp149_ = NULL;
				gchar* _tmp150_ = NULL;
				gchar* _tmp151_ = NULL;
				BatchImportResult* _tmp152_ = NULL;
				const gchar* _tmp153_ = NULL;
				gchar* _tmp154_ = NULL;
				gchar* _tmp155_ = NULL;
				gchar* _tmp156_ = NULL;
				GString* _tmp157_ = NULL;
				const gchar* _tmp158_ = NULL;
#line 582 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp137_ = _result_index;
#line 582 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_result_index = _tmp137_ + 1;
#line 582 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp138_ = _result_index;
#line 582 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp139_ = _result_size;
#line 582 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (!(_tmp138_ < _tmp139_)) {
#line 582 "/home/jens/Source/shotwell/src/Dialogs.vala"
					break;
#line 5605 "Dialogs.c"
				}
#line 582 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp140_ = _result_list;
#line 582 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp141_ = _result_index;
#line 582 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp142_ = gee_list_get (_tmp140_, _tmp141_);
#line 582 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_result_ = (BatchImportResult*) _tmp142_;
#line 583 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp143_ = _result_;
#line 583 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp144_ = _tmp143_->src_identifier;
#line 583 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp145_ = g_strconcat (_tmp144_, "\n\t", NULL);
#line 583 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp146_ = _tmp145_;
#line 583 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp147_ = _ ("error message:");
#line 583 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp148_ = g_strconcat (_tmp146_, _tmp147_, NULL);
#line 583 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp149_ = _tmp148_;
#line 583 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp150_ = g_strconcat (_tmp149_, " ", NULL);
#line 583 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp151_ = _tmp150_;
#line 583 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp152_ = _result_;
#line 583 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp153_ = _tmp152_->errmsg;
#line 583 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp154_ = g_strconcat (_tmp151_, _tmp153_, NULL);
#line 583 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp155_ = _tmp154_;
#line 583 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp156_ = g_strconcat (_tmp155_, "\n\n", NULL);
#line 583 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (current_file_summary);
#line 583 "/home/jens/Source/shotwell/src/Dialogs.vala"
				current_file_summary = _tmp156_;
#line 583 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp155_);
#line 583 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp151_);
#line 583 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp149_);
#line 583 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp146_);
#line 586 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp157_ = builder;
#line 586 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp158_ = current_file_summary;
#line 586 "/home/jens/Source/shotwell/src/Dialogs.vala"
				g_string_append (_tmp157_, _tmp158_);
#line 582 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_batch_import_result_unref0 (_result_);
#line 5663 "Dialogs.c"
			}
#line 582 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_object_unref0 (_result_list);
#line 5667 "Dialogs.c"
		}
	}
#line 593 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp159_ = manifest;
#line 593 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp160_ = _tmp159_->skipped_photos;
#line 593 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp161_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp160_, GEE_TYPE_COLLECTION, GeeCollection));
#line 593 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp162_ = _tmp161_;
#line 593 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp162_ > 0) {
#line 5680 "Dialogs.c"
		GString* _tmp163_ = NULL;
		const gchar* _tmp164_ = NULL;
		gchar* _tmp165_ = NULL;
		gchar* _tmp166_ = NULL;
#line 594 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp163_ = builder;
#line 594 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp164_ = _ ("Photos/Videos Not Imported Because They Weren't in a Format Shotwell U" \
"nderstands:");
#line 594 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp165_ = g_strconcat (_tmp164_, "\n\n", NULL);
#line 594 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp166_ = _tmp165_;
#line 594 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_string_append (_tmp163_, _tmp166_);
#line 594 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp166_);
#line 5697 "Dialogs.c"
		{
			GeeList* _result_list = NULL;
			ImportManifest* _tmp167_ = NULL;
			GeeList* _tmp168_ = NULL;
			GeeList* _tmp169_ = NULL;
			gint _result_size = 0;
			GeeList* _tmp170_ = NULL;
			gint _tmp171_ = 0;
			gint _tmp172_ = 0;
			gint _result_index = 0;
#line 597 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp167_ = manifest;
#line 597 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp168_ = _tmp167_->skipped_photos;
#line 597 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp169_ = _g_object_ref0 (_tmp168_);
#line 597 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_list = _tmp169_;
#line 597 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp170_ = _result_list;
#line 597 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp171_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp170_, GEE_TYPE_COLLECTION, GeeCollection));
#line 597 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp172_ = _tmp171_;
#line 597 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_size = _tmp172_;
#line 597 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_index = -1;
#line 597 "/home/jens/Source/shotwell/src/Dialogs.vala"
			while (TRUE) {
#line 5728 "Dialogs.c"
				gint _tmp173_ = 0;
				gint _tmp174_ = 0;
				gint _tmp175_ = 0;
				BatchImportResult* _result_ = NULL;
				GeeList* _tmp176_ = NULL;
				gint _tmp177_ = 0;
				gpointer _tmp178_ = NULL;
				BatchImportResult* _tmp179_ = NULL;
				const gchar* _tmp180_ = NULL;
				gchar* _tmp181_ = NULL;
				gchar* _tmp182_ = NULL;
				const gchar* _tmp183_ = NULL;
				gchar* _tmp184_ = NULL;
				gchar* _tmp185_ = NULL;
				gchar* _tmp186_ = NULL;
				gchar* _tmp187_ = NULL;
				BatchImportResult* _tmp188_ = NULL;
				const gchar* _tmp189_ = NULL;
				gchar* _tmp190_ = NULL;
				gchar* _tmp191_ = NULL;
				gchar* _tmp192_ = NULL;
				GString* _tmp193_ = NULL;
				const gchar* _tmp194_ = NULL;
#line 597 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp173_ = _result_index;
#line 597 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_result_index = _tmp173_ + 1;
#line 597 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp174_ = _result_index;
#line 597 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp175_ = _result_size;
#line 597 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (!(_tmp174_ < _tmp175_)) {
#line 597 "/home/jens/Source/shotwell/src/Dialogs.vala"
					break;
#line 5764 "Dialogs.c"
				}
#line 597 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp176_ = _result_list;
#line 597 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp177_ = _result_index;
#line 597 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp178_ = gee_list_get (_tmp176_, _tmp177_);
#line 597 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_result_ = (BatchImportResult*) _tmp178_;
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp179_ = _result_;
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp180_ = _tmp179_->src_identifier;
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp181_ = g_strconcat (_tmp180_, "\n\t", NULL);
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp182_ = _tmp181_;
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp183_ = _ ("error message:");
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp184_ = g_strconcat (_tmp182_, _tmp183_, NULL);
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp185_ = _tmp184_;
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp186_ = g_strconcat (_tmp185_, " ", NULL);
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp187_ = _tmp186_;
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp188_ = _result_;
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp189_ = _tmp188_->errmsg;
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp190_ = g_strconcat (_tmp187_, _tmp189_, NULL);
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp191_ = _tmp190_;
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp192_ = g_strconcat (_tmp191_, "\n\n", NULL);
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (current_file_summary);
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
				current_file_summary = _tmp192_;
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp191_);
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp187_);
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp185_);
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp182_);
#line 601 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp193_ = builder;
#line 601 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp194_ = current_file_summary;
#line 601 "/home/jens/Source/shotwell/src/Dialogs.vala"
				g_string_append (_tmp193_, _tmp194_);
#line 597 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_batch_import_result_unref0 (_result_);
#line 5822 "Dialogs.c"
			}
#line 597 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_object_unref0 (_result_list);
#line 5826 "Dialogs.c"
		}
	}
#line 608 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp195_ = manifest;
#line 608 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp196_ = _tmp195_->write_failed;
#line 608 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp197_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp196_, GEE_TYPE_COLLECTION, GeeCollection));
#line 608 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp198_ = _tmp197_;
#line 608 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp198_ > 0) {
#line 5839 "Dialogs.c"
		GString* _tmp199_ = NULL;
		const gchar* _tmp200_ = NULL;
		gchar* _tmp201_ = NULL;
		gchar* _tmp202_ = NULL;
#line 609 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp199_ = builder;
#line 609 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp200_ = _ ("Photos/Videos Not Imported Because Shotwell Couldn't Copy Them into it" \
"s Library:");
#line 609 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp201_ = g_strconcat (_tmp200_, "\n\n", NULL);
#line 609 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp202_ = _tmp201_;
#line 609 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_string_append (_tmp199_, _tmp202_);
#line 609 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp202_);
#line 5856 "Dialogs.c"
		{
			GeeList* _result_list = NULL;
			ImportManifest* _tmp203_ = NULL;
			GeeList* _tmp204_ = NULL;
			GeeList* _tmp205_ = NULL;
			gint _result_size = 0;
			GeeList* _tmp206_ = NULL;
			gint _tmp207_ = 0;
			gint _tmp208_ = 0;
			gint _result_index = 0;
#line 612 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp203_ = manifest;
#line 612 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp204_ = _tmp203_->write_failed;
#line 612 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp205_ = _g_object_ref0 (_tmp204_);
#line 612 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_list = _tmp205_;
#line 612 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp206_ = _result_list;
#line 612 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp207_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp206_, GEE_TYPE_COLLECTION, GeeCollection));
#line 612 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp208_ = _tmp207_;
#line 612 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_size = _tmp208_;
#line 612 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_index = -1;
#line 612 "/home/jens/Source/shotwell/src/Dialogs.vala"
			while (TRUE) {
#line 5887 "Dialogs.c"
				gint _tmp209_ = 0;
				gint _tmp210_ = 0;
				gint _tmp211_ = 0;
				BatchImportResult* _result_ = NULL;
				GeeList* _tmp212_ = NULL;
				gint _tmp213_ = 0;
				gpointer _tmp214_ = NULL;
				const gchar* _tmp215_ = NULL;
				BatchImportResult* _tmp216_ = NULL;
				const gchar* _tmp217_ = NULL;
				BatchImportResult* _tmp218_ = NULL;
				const gchar* _tmp219_ = NULL;
				gchar* _tmp220_ = NULL;
				gchar* _tmp221_ = NULL;
				gchar* _tmp222_ = NULL;
				gchar* _tmp223_ = NULL;
				const gchar* _tmp224_ = NULL;
				gchar* _tmp225_ = NULL;
				gchar* _tmp226_ = NULL;
				gchar* _tmp227_ = NULL;
				gchar* _tmp228_ = NULL;
				BatchImportResult* _tmp229_ = NULL;
				const gchar* _tmp230_ = NULL;
				gchar* _tmp231_ = NULL;
				gchar* _tmp232_ = NULL;
				gchar* _tmp233_ = NULL;
				GString* _tmp234_ = NULL;
				const gchar* _tmp235_ = NULL;
#line 612 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp209_ = _result_index;
#line 612 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_result_index = _tmp209_ + 1;
#line 612 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp210_ = _result_index;
#line 612 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp211_ = _result_size;
#line 612 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (!(_tmp210_ < _tmp211_)) {
#line 612 "/home/jens/Source/shotwell/src/Dialogs.vala"
					break;
#line 5928 "Dialogs.c"
				}
#line 612 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp212_ = _result_list;
#line 612 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp213_ = _result_index;
#line 612 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp214_ = gee_list_get (_tmp212_, _tmp213_);
#line 612 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_result_ = (BatchImportResult*) _tmp214_;
#line 613 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp215_ = _ ("couldn't copy %s\n\tto %s");
#line 613 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp216_ = _result_;
#line 613 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp217_ = _tmp216_->src_identifier;
#line 613 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp218_ = _result_;
#line 613 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp219_ = _tmp218_->dest_identifier;
#line 613 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp220_ = g_strdup_printf (_tmp215_, _tmp217_, _tmp219_);
#line 613 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp221_ = _tmp220_;
#line 613 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp222_ = g_strconcat (_tmp221_, "\n\t", NULL);
#line 613 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp223_ = _tmp222_;
#line 613 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp224_ = _ ("error message:");
#line 613 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp225_ = g_strconcat (_tmp223_, _tmp224_, NULL);
#line 613 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp226_ = _tmp225_;
#line 613 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp227_ = g_strconcat (_tmp226_, " ", NULL);
#line 613 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp228_ = _tmp227_;
#line 613 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp229_ = _result_;
#line 613 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp230_ = _tmp229_->errmsg;
#line 613 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp231_ = g_strconcat (_tmp228_, _tmp230_, NULL);
#line 613 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp232_ = _tmp231_;
#line 613 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp233_ = g_strconcat (_tmp232_, "\n\n", NULL);
#line 613 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (current_file_summary);
#line 613 "/home/jens/Source/shotwell/src/Dialogs.vala"
				current_file_summary = _tmp233_;
#line 613 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp232_);
#line 613 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp228_);
#line 613 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp226_);
#line 613 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp223_);
#line 613 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp221_);
#line 617 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp234_ = builder;
#line 617 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp235_ = current_file_summary;
#line 617 "/home/jens/Source/shotwell/src/Dialogs.vala"
				g_string_append (_tmp234_, _tmp235_);
#line 612 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_batch_import_result_unref0 (_result_);
#line 5998 "Dialogs.c"
			}
#line 612 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_object_unref0 (_result_list);
#line 6002 "Dialogs.c"
		}
	}
#line 624 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp236_ = manifest;
#line 624 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp237_ = _tmp236_->corrupt_files;
#line 624 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp238_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp237_, GEE_TYPE_COLLECTION, GeeCollection));
#line 624 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp239_ = _tmp238_;
#line 624 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp239_ > 0) {
#line 6015 "Dialogs.c"
		GString* _tmp240_ = NULL;
		const gchar* _tmp241_ = NULL;
		gchar* _tmp242_ = NULL;
		gchar* _tmp243_ = NULL;
#line 625 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp240_ = builder;
#line 625 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp241_ = _ ("Photos/Videos Not Imported Because Files Are Corrupt:");
#line 625 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp242_ = g_strconcat (_tmp241_, "\n\n", NULL);
#line 625 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp243_ = _tmp242_;
#line 625 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_string_append (_tmp240_, _tmp243_);
#line 625 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp243_);
#line 6032 "Dialogs.c"
		{
			GeeList* _result_list = NULL;
			ImportManifest* _tmp244_ = NULL;
			GeeList* _tmp245_ = NULL;
			GeeList* _tmp246_ = NULL;
			gint _result_size = 0;
			GeeList* _tmp247_ = NULL;
			gint _tmp248_ = 0;
			gint _tmp249_ = 0;
			gint _result_index = 0;
#line 628 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp244_ = manifest;
#line 628 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp245_ = _tmp244_->corrupt_files;
#line 628 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp246_ = _g_object_ref0 (_tmp245_);
#line 628 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_list = _tmp246_;
#line 628 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp247_ = _result_list;
#line 628 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp248_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp247_, GEE_TYPE_COLLECTION, GeeCollection));
#line 628 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp249_ = _tmp248_;
#line 628 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_size = _tmp249_;
#line 628 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_index = -1;
#line 628 "/home/jens/Source/shotwell/src/Dialogs.vala"
			while (TRUE) {
#line 6063 "Dialogs.c"
				gint _tmp250_ = 0;
				gint _tmp251_ = 0;
				gint _tmp252_ = 0;
				BatchImportResult* _result_ = NULL;
				GeeList* _tmp253_ = NULL;
				gint _tmp254_ = 0;
				gpointer _tmp255_ = NULL;
				BatchImportResult* _tmp256_ = NULL;
				const gchar* _tmp257_ = NULL;
				gchar* _tmp258_ = NULL;
				gchar* _tmp259_ = NULL;
				const gchar* _tmp260_ = NULL;
				gchar* _tmp261_ = NULL;
				gchar* _tmp262_ = NULL;
				gchar* _tmp263_ = NULL;
				gchar* _tmp264_ = NULL;
				BatchImportResult* _tmp265_ = NULL;
				const gchar* _tmp266_ = NULL;
				gchar* _tmp267_ = NULL;
				gchar* _tmp268_ = NULL;
				gchar* _tmp269_ = NULL;
				GString* _tmp270_ = NULL;
				const gchar* _tmp271_ = NULL;
#line 628 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp250_ = _result_index;
#line 628 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_result_index = _tmp250_ + 1;
#line 628 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp251_ = _result_index;
#line 628 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp252_ = _result_size;
#line 628 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (!(_tmp251_ < _tmp252_)) {
#line 628 "/home/jens/Source/shotwell/src/Dialogs.vala"
					break;
#line 6099 "Dialogs.c"
				}
#line 628 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp253_ = _result_list;
#line 628 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp254_ = _result_index;
#line 628 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp255_ = gee_list_get (_tmp253_, _tmp254_);
#line 628 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_result_ = (BatchImportResult*) _tmp255_;
#line 629 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp256_ = _result_;
#line 629 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp257_ = _tmp256_->src_identifier;
#line 629 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp258_ = g_strconcat (_tmp257_, "\n\t", NULL);
#line 629 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp259_ = _tmp258_;
#line 629 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp260_ = _ ("error message:");
#line 629 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp261_ = g_strconcat (_tmp259_, _tmp260_, NULL);
#line 629 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp262_ = _tmp261_;
#line 629 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp263_ = g_strconcat (_tmp262_, " |", NULL);
#line 629 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp264_ = _tmp263_;
#line 629 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp265_ = _result_;
#line 629 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp266_ = _tmp265_->errmsg;
#line 629 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp267_ = g_strconcat (_tmp264_, _tmp266_, NULL);
#line 629 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp268_ = _tmp267_;
#line 629 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp269_ = g_strconcat (_tmp268_, "|\n\n", NULL);
#line 629 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (current_file_summary);
#line 629 "/home/jens/Source/shotwell/src/Dialogs.vala"
				current_file_summary = _tmp269_;
#line 629 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp268_);
#line 629 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp264_);
#line 629 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp262_);
#line 629 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp259_);
#line 632 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp270_ = builder;
#line 632 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp271_ = current_file_summary;
#line 632 "/home/jens/Source/shotwell/src/Dialogs.vala"
				g_string_append (_tmp270_, _tmp271_);
#line 628 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_batch_import_result_unref0 (_result_);
#line 6157 "Dialogs.c"
			}
#line 628 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_object_unref0 (_result_list);
#line 6161 "Dialogs.c"
		}
	}
#line 639 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp272_ = manifest;
#line 639 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp273_ = _tmp272_->failed;
#line 639 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp274_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp273_, GEE_TYPE_COLLECTION, GeeCollection));
#line 639 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp275_ = _tmp274_;
#line 639 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp275_ > 0) {
#line 6174 "Dialogs.c"
		GString* _tmp276_ = NULL;
		const gchar* _tmp277_ = NULL;
		gchar* _tmp278_ = NULL;
		gchar* _tmp279_ = NULL;
#line 640 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp276_ = builder;
#line 640 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp277_ = _ ("Photos/Videos Not Imported for Other Reasons:");
#line 640 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp278_ = g_strconcat (_tmp277_, "\n\n", NULL);
#line 640 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp279_ = _tmp278_;
#line 640 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_string_append (_tmp276_, _tmp279_);
#line 640 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp279_);
#line 6191 "Dialogs.c"
		{
			GeeList* _result_list = NULL;
			ImportManifest* _tmp280_ = NULL;
			GeeList* _tmp281_ = NULL;
			GeeList* _tmp282_ = NULL;
			gint _result_size = 0;
			GeeList* _tmp283_ = NULL;
			gint _tmp284_ = 0;
			gint _tmp285_ = 0;
			gint _result_index = 0;
#line 642 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp280_ = manifest;
#line 642 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp281_ = _tmp280_->failed;
#line 642 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp282_ = _g_object_ref0 (_tmp281_);
#line 642 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_list = _tmp282_;
#line 642 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp283_ = _result_list;
#line 642 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp284_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp283_, GEE_TYPE_COLLECTION, GeeCollection));
#line 642 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp285_ = _tmp284_;
#line 642 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_size = _tmp285_;
#line 642 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_index = -1;
#line 642 "/home/jens/Source/shotwell/src/Dialogs.vala"
			while (TRUE) {
#line 6222 "Dialogs.c"
				gint _tmp286_ = 0;
				gint _tmp287_ = 0;
				gint _tmp288_ = 0;
				BatchImportResult* _result_ = NULL;
				GeeList* _tmp289_ = NULL;
				gint _tmp290_ = 0;
				gpointer _tmp291_ = NULL;
				BatchImportResult* _tmp292_ = NULL;
				const gchar* _tmp293_ = NULL;
				gchar* _tmp294_ = NULL;
				gchar* _tmp295_ = NULL;
				const gchar* _tmp296_ = NULL;
				gchar* _tmp297_ = NULL;
				gchar* _tmp298_ = NULL;
				gchar* _tmp299_ = NULL;
				gchar* _tmp300_ = NULL;
				BatchImportResult* _tmp301_ = NULL;
				const gchar* _tmp302_ = NULL;
				gchar* _tmp303_ = NULL;
				gchar* _tmp304_ = NULL;
				gchar* _tmp305_ = NULL;
				GString* _tmp306_ = NULL;
				const gchar* _tmp307_ = NULL;
#line 642 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp286_ = _result_index;
#line 642 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_result_index = _tmp286_ + 1;
#line 642 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp287_ = _result_index;
#line 642 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp288_ = _result_size;
#line 642 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (!(_tmp287_ < _tmp288_)) {
#line 642 "/home/jens/Source/shotwell/src/Dialogs.vala"
					break;
#line 6258 "Dialogs.c"
				}
#line 642 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp289_ = _result_list;
#line 642 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp290_ = _result_index;
#line 642 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp291_ = gee_list_get (_tmp289_, _tmp290_);
#line 642 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_result_ = (BatchImportResult*) _tmp291_;
#line 643 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp292_ = _result_;
#line 643 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp293_ = _tmp292_->src_identifier;
#line 643 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp294_ = g_strconcat (_tmp293_, "\n\t", NULL);
#line 643 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp295_ = _tmp294_;
#line 643 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp296_ = _ ("error message:");
#line 643 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp297_ = g_strconcat (_tmp295_, _tmp296_, NULL);
#line 643 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp298_ = _tmp297_;
#line 643 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp299_ = g_strconcat (_tmp298_, " ", NULL);
#line 643 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp300_ = _tmp299_;
#line 643 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp301_ = _result_;
#line 643 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp302_ = _tmp301_->errmsg;
#line 643 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp303_ = g_strconcat (_tmp300_, _tmp302_, NULL);
#line 643 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp304_ = _tmp303_;
#line 643 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp305_ = g_strconcat (_tmp304_, "\n\n", NULL);
#line 643 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (current_file_summary);
#line 643 "/home/jens/Source/shotwell/src/Dialogs.vala"
				current_file_summary = _tmp305_;
#line 643 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp304_);
#line 643 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp300_);
#line 643 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp298_);
#line 643 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp295_);
#line 646 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp306_ = builder;
#line 646 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp307_ = current_file_summary;
#line 646 "/home/jens/Source/shotwell/src/Dialogs.vala"
				g_string_append (_tmp306_, _tmp307_);
#line 642 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_batch_import_result_unref0 (_result_);
#line 6316 "Dialogs.c"
			}
#line 642 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_object_unref0 (_result_list);
#line 6320 "Dialogs.c"
		}
	}
#line 650 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp308_ = builder;
#line 650 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp309_ = _tmp308_->str;
#line 650 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp310_ = g_strdup (_tmp309_);
#line 650 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = _tmp310_;
#line 650 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (current_file_summary);
#line 650 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (subhead);
#line 650 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (header);
#line 650 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_string_free0 (builder);
#line 650 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 6341 "Dialogs.c"
}


gboolean import_ui_report_manifest (ImportManifest* manifest, gboolean show_dest_id, ImportUIQuestionParams* question) {
	gboolean result = FALSE;
	gchar* message = NULL;
	gchar* _tmp0_ = NULL;
	ImportManifest* _tmp1_ = NULL;
	GeeList* _tmp2_ = NULL;
	gint _tmp3_ = 0;
	gint _tmp4_ = 0;
	ImportManifest* _tmp52_ = NULL;
	GeeList* _tmp53_ = NULL;
	gint _tmp54_ = 0;
	gint _tmp55_ = 0;
	ImportManifest* _tmp118_ = NULL;
	GeeList* _tmp119_ = NULL;
	gint _tmp120_ = 0;
	gint _tmp121_ = 0;
	ImportManifest* _tmp184_ = NULL;
	GeeList* _tmp185_ = NULL;
	gint _tmp186_ = 0;
	gint _tmp187_ = 0;
	ImportManifest* _tmp250_ = NULL;
	GeeList* _tmp251_ = NULL;
	gint _tmp252_ = 0;
	gint _tmp253_ = 0;
	ImportManifest* _tmp316_ = NULL;
	GeeList* _tmp317_ = NULL;
	gint _tmp318_ = 0;
	gint _tmp319_ = 0;
	ImportManifest* _tmp345_ = NULL;
	GeeList* _tmp346_ = NULL;
	gint _tmp347_ = 0;
	gint _tmp348_ = 0;
	ImportManifest* _tmp367_ = NULL;
	GeeList* _tmp368_ = NULL;
	gint _tmp369_ = 0;
	gint _tmp370_ = 0;
	ImportManifest* _tmp433_ = NULL;
	GeeList* _tmp434_ = NULL;
	gint _tmp435_ = 0;
	gint _tmp436_ = 0;
	gint total = 0;
	ImportManifest* _tmp481_ = NULL;
	GeeList* _tmp482_ = NULL;
	gint _tmp483_ = 0;
	gint _tmp484_ = 0;
	ImportManifest* _tmp485_ = NULL;
	GeeList* _tmp486_ = NULL;
	gint _tmp487_ = 0;
	gint _tmp488_ = 0;
	ImportManifest* _tmp489_ = NULL;
	GeeList* _tmp490_ = NULL;
	gint _tmp491_ = 0;
	gint _tmp492_ = 0;
	ImportManifest* _tmp493_ = NULL;
	GeeList* _tmp494_ = NULL;
	gint _tmp495_ = 0;
	gint _tmp496_ = 0;
	ImportManifest* _tmp497_ = NULL;
	GeeList* _tmp498_ = NULL;
	gint _tmp499_ = 0;
	gint _tmp500_ = 0;
	ImportManifest* _tmp501_ = NULL;
	GeeList* _tmp502_ = NULL;
	gint _tmp503_ = 0;
	gint _tmp504_ = 0;
	ImportManifest* _tmp505_ = NULL;
	GeeList* _tmp506_ = NULL;
	gint _tmp507_ = 0;
	gint _tmp508_ = 0;
	ImportManifest* _tmp509_ = NULL;
	GeeList* _tmp510_ = NULL;
	gint _tmp511_ = 0;
	gint _tmp512_ = 0;
	ImportManifest* _tmp513_ = NULL;
	GeeList* _tmp514_ = NULL;
	gint _tmp515_ = 0;
	gint _tmp516_ = 0;
	gint _tmp517_ = 0;
	ImportManifest* _tmp518_ = NULL;
	GeeList* _tmp519_ = NULL;
	gint _tmp520_ = 0;
	gint _tmp521_ = 0;
	gint _tmp522_ = 0;
	GtkMessageDialog* dialog = NULL;
	gint dialog_response = 0;
	ImportUIQuestionParams* _tmp526_ = NULL;
	gint _tmp606_ = 0;
#line 655 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_IMPORT_MANIFEST (manifest), FALSE);
#line 655 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail ((question == NULL) || IMPORT_UI_IS_QUESTION_PARAMS (question), FALSE);
#line 657 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = g_strdup ("");
#line 657 "/home/jens/Source/shotwell/src/Dialogs.vala"
	message = _tmp0_;
#line 659 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = manifest;
#line 659 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = _tmp1_->already_imported;
#line 659 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, GEE_TYPE_COLLECTION, GeeCollection));
#line 659 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = _tmp3_;
#line 659 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp4_ > 0) {
#line 6450 "Dialogs.c"
		gchar* photos_message = NULL;
		ImportManifest* _tmp5_ = NULL;
		GeeList* _tmp6_ = NULL;
		gint _tmp7_ = 0;
		gint _tmp8_ = 0;
		const gchar* _tmp9_ = NULL;
		ImportManifest* _tmp10_ = NULL;
		GeeList* _tmp11_ = NULL;
		gint _tmp12_ = 0;
		gint _tmp13_ = 0;
		gchar* _tmp14_ = NULL;
		gchar* videos_message = NULL;
		ImportManifest* _tmp15_ = NULL;
		GeeList* _tmp16_ = NULL;
		gint _tmp17_ = 0;
		gint _tmp18_ = 0;
		const gchar* _tmp19_ = NULL;
		ImportManifest* _tmp20_ = NULL;
		GeeList* _tmp21_ = NULL;
		gint _tmp22_ = 0;
		gint _tmp23_ = 0;
		gchar* _tmp24_ = NULL;
		gchar* both_message = NULL;
		ImportManifest* _tmp25_ = NULL;
		GeeList* _tmp26_ = NULL;
		gint _tmp27_ = 0;
		gint _tmp28_ = 0;
		const gchar* _tmp29_ = NULL;
		ImportManifest* _tmp30_ = NULL;
		GeeList* _tmp31_ = NULL;
		gint _tmp32_ = 0;
		gint _tmp33_ = 0;
		gchar* _tmp34_ = NULL;
		const gchar* _tmp35_ = NULL;
		ImportManifest* _tmp36_ = NULL;
		GeeList* _tmp37_ = NULL;
		const gchar* _tmp38_ = NULL;
		const gchar* _tmp39_ = NULL;
		const gchar* _tmp40_ = NULL;
		const gchar* _tmp41_ = NULL;
		gchar* _tmp42_ = NULL;
		gchar* _tmp43_ = NULL;
		gchar* _tmp44_ = NULL;
		const gchar* _tmp45_ = NULL;
		ImportManifest* _tmp46_ = NULL;
		GeeList* _tmp47_ = NULL;
		gboolean _tmp48_ = FALSE;
		gchar* _tmp49_ = NULL;
		gchar* _tmp50_ = NULL;
		gchar* _tmp51_ = NULL;
#line 660 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp5_ = manifest;
#line 660 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp6_ = _tmp5_->already_imported;
#line 660 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp7_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, GEE_TYPE_COLLECTION, GeeCollection));
#line 660 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp8_ = _tmp7_;
#line 660 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp9_ = ngettext ("1 duplicate photo was not imported:\n", "%d duplicate photos were not imported:\n", (gulong) _tmp8_);
#line 660 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp10_ = manifest;
#line 660 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp11_ = _tmp10_->already_imported;
#line 660 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp12_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp11_, GEE_TYPE_COLLECTION, GeeCollection));
#line 660 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp13_ = _tmp12_;
#line 660 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp14_ = g_strdup_printf (_tmp9_, _tmp13_);
#line 660 "/home/jens/Source/shotwell/src/Dialogs.vala"
		photos_message = _tmp14_;
#line 663 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp15_ = manifest;
#line 663 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp16_ = _tmp15_->already_imported;
#line 663 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp17_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp16_, GEE_TYPE_COLLECTION, GeeCollection));
#line 663 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp18_ = _tmp17_;
#line 663 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp19_ = ngettext ("1 duplicate video was not imported:\n", "%d duplicate videos were not imported:\n", (gulong) _tmp18_);
#line 663 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp20_ = manifest;
#line 663 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp21_ = _tmp20_->already_imported;
#line 663 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp22_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp21_, GEE_TYPE_COLLECTION, GeeCollection));
#line 663 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp23_ = _tmp22_;
#line 663 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp24_ = g_strdup_printf (_tmp19_, _tmp23_);
#line 663 "/home/jens/Source/shotwell/src/Dialogs.vala"
		videos_message = _tmp24_;
#line 666 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp25_ = manifest;
#line 666 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp26_ = _tmp25_->already_imported;
#line 666 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp27_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp26_, GEE_TYPE_COLLECTION, GeeCollection));
#line 666 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp28_ = _tmp27_;
#line 666 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp29_ = ngettext ("1 duplicate photo/video was not imported:\n", "%d duplicate photos/videos were not imported:\n", (gulong) _tmp28_);
#line 666 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp30_ = manifest;
#line 666 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp31_ = _tmp30_->already_imported;
#line 666 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp32_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp31_, GEE_TYPE_COLLECTION, GeeCollection));
#line 666 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp33_ = _tmp32_;
#line 666 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp34_ = g_strdup_printf (_tmp29_, _tmp33_);
#line 666 "/home/jens/Source/shotwell/src/Dialogs.vala"
		both_message = _tmp34_;
#line 670 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp35_ = message;
#line 670 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp36_ = manifest;
#line 670 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp37_ = _tmp36_->already_imported;
#line 670 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp38_ = photos_message;
#line 670 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp39_ = videos_message;
#line 670 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp40_ = both_message;
#line 670 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp41_ = both_message;
#line 670 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp42_ = import_ui_get_media_specific_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp37_, GEE_TYPE_COLLECTION, GeeCollection), _tmp38_, _tmp39_, _tmp40_, _tmp41_);
#line 670 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp43_ = _tmp42_;
#line 670 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp44_ = g_strconcat (_tmp35_, _tmp43_, NULL);
#line 670 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (message);
#line 670 "/home/jens/Source/shotwell/src/Dialogs.vala"
		message = _tmp44_;
#line 670 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp43_);
#line 673 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp45_ = message;
#line 673 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp46_ = manifest;
#line 673 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp47_ = _tmp46_->already_imported;
#line 673 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp48_ = show_dest_id;
#line 673 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp49_ = import_ui_generate_import_failure_list (_tmp47_, _tmp48_);
#line 673 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp50_ = _tmp49_;
#line 673 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp51_ = g_strconcat (_tmp45_, _tmp50_, NULL);
#line 673 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (message);
#line 673 "/home/jens/Source/shotwell/src/Dialogs.vala"
		message = _tmp51_;
#line 673 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp50_);
#line 659 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (both_message);
#line 659 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (videos_message);
#line 659 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (photos_message);
#line 6619 "Dialogs.c"
	}
#line 676 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp52_ = manifest;
#line 676 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp53_ = _tmp52_->failed;
#line 676 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp54_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp53_, GEE_TYPE_COLLECTION, GeeCollection));
#line 676 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp55_ = _tmp54_;
#line 676 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp55_ > 0) {
#line 6631 "Dialogs.c"
		const gchar* _tmp56_ = NULL;
		gint _tmp57_ = 0;
		gint _tmp58_ = 0;
		gchar* photos_message = NULL;
		ImportManifest* _tmp61_ = NULL;
		GeeList* _tmp62_ = NULL;
		gint _tmp63_ = 0;
		gint _tmp64_ = 0;
		const gchar* _tmp65_ = NULL;
		ImportManifest* _tmp66_ = NULL;
		GeeList* _tmp67_ = NULL;
		gint _tmp68_ = 0;
		gint _tmp69_ = 0;
		gchar* _tmp70_ = NULL;
		gchar* videos_message = NULL;
		ImportManifest* _tmp71_ = NULL;
		GeeList* _tmp72_ = NULL;
		gint _tmp73_ = 0;
		gint _tmp74_ = 0;
		const gchar* _tmp75_ = NULL;
		ImportManifest* _tmp76_ = NULL;
		GeeList* _tmp77_ = NULL;
		gint _tmp78_ = 0;
		gint _tmp79_ = 0;
		gchar* _tmp80_ = NULL;
		gchar* both_message = NULL;
		ImportManifest* _tmp81_ = NULL;
		GeeList* _tmp82_ = NULL;
		gint _tmp83_ = 0;
		gint _tmp84_ = 0;
		const gchar* _tmp85_ = NULL;
		ImportManifest* _tmp86_ = NULL;
		GeeList* _tmp87_ = NULL;
		gint _tmp88_ = 0;
		gint _tmp89_ = 0;
		gchar* _tmp90_ = NULL;
		gchar* neither_message = NULL;
		ImportManifest* _tmp91_ = NULL;
		GeeList* _tmp92_ = NULL;
		gint _tmp93_ = 0;
		gint _tmp94_ = 0;
		const gchar* _tmp95_ = NULL;
		ImportManifest* _tmp96_ = NULL;
		GeeList* _tmp97_ = NULL;
		gint _tmp98_ = 0;
		gint _tmp99_ = 0;
		gchar* _tmp100_ = NULL;
		const gchar* _tmp101_ = NULL;
		ImportManifest* _tmp102_ = NULL;
		GeeList* _tmp103_ = NULL;
		const gchar* _tmp104_ = NULL;
		const gchar* _tmp105_ = NULL;
		const gchar* _tmp106_ = NULL;
		const gchar* _tmp107_ = NULL;
		gchar* _tmp108_ = NULL;
		gchar* _tmp109_ = NULL;
		gchar* _tmp110_ = NULL;
		const gchar* _tmp111_ = NULL;
		ImportManifest* _tmp112_ = NULL;
		GeeList* _tmp113_ = NULL;
		gboolean _tmp114_ = FALSE;
		gchar* _tmp115_ = NULL;
		gchar* _tmp116_ = NULL;
		gchar* _tmp117_ = NULL;
#line 677 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp56_ = message;
#line 677 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp57_ = strlen (_tmp56_);
#line 677 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp58_ = _tmp57_;
#line 677 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp58_ > 0) {
#line 6704 "Dialogs.c"
			const gchar* _tmp59_ = NULL;
			gchar* _tmp60_ = NULL;
#line 678 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp59_ = message;
#line 678 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp60_ = g_strconcat (_tmp59_, "\n", NULL);
#line 678 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (message);
#line 678 "/home/jens/Source/shotwell/src/Dialogs.vala"
			message = _tmp60_;
#line 6715 "Dialogs.c"
		}
#line 680 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp61_ = manifest;
#line 680 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp62_ = _tmp61_->failed;
#line 680 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp63_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp62_, GEE_TYPE_COLLECTION, GeeCollection));
#line 680 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp64_ = _tmp63_;
#line 680 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp65_ = ngettext ("1 photo failed to import due to a file or hardware error:\n", "%d photos failed to import due to a file or hardware error:\n", (gulong) _tmp64_);
#line 680 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp66_ = manifest;
#line 680 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp67_ = _tmp66_->failed;
#line 680 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp68_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp67_, GEE_TYPE_COLLECTION, GeeCollection));
#line 680 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp69_ = _tmp68_;
#line 680 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp70_ = g_strdup_printf (_tmp65_, _tmp69_);
#line 680 "/home/jens/Source/shotwell/src/Dialogs.vala"
		photos_message = _tmp70_;
#line 683 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp71_ = manifest;
#line 683 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp72_ = _tmp71_->failed;
#line 683 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp73_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp72_, GEE_TYPE_COLLECTION, GeeCollection));
#line 683 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp74_ = _tmp73_;
#line 683 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp75_ = ngettext ("1 video failed to import due to a file or hardware error:\n", "%d videos failed to import due to a file or hardware error:\n", (gulong) _tmp74_);
#line 683 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp76_ = manifest;
#line 683 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp77_ = _tmp76_->failed;
#line 683 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp78_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp77_, GEE_TYPE_COLLECTION, GeeCollection));
#line 683 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp79_ = _tmp78_;
#line 683 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp80_ = g_strdup_printf (_tmp75_, _tmp79_);
#line 683 "/home/jens/Source/shotwell/src/Dialogs.vala"
		videos_message = _tmp80_;
#line 686 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp81_ = manifest;
#line 686 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp82_ = _tmp81_->failed;
#line 686 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp83_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp82_, GEE_TYPE_COLLECTION, GeeCollection));
#line 686 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp84_ = _tmp83_;
#line 686 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp85_ = ngettext ("1 photo/video failed to import due to a file or hardware error:\n", "%d photos/videos failed to import due to a file or hardware error:\n", (gulong) _tmp84_);
#line 686 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp86_ = manifest;
#line 686 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp87_ = _tmp86_->failed;
#line 686 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp88_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp87_, GEE_TYPE_COLLECTION, GeeCollection));
#line 686 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp89_ = _tmp88_;
#line 686 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp90_ = g_strdup_printf (_tmp85_, _tmp89_);
#line 686 "/home/jens/Source/shotwell/src/Dialogs.vala"
		both_message = _tmp90_;
#line 689 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp91_ = manifest;
#line 689 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp92_ = _tmp91_->failed;
#line 689 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp93_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp92_, GEE_TYPE_COLLECTION, GeeCollection));
#line 689 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp94_ = _tmp93_;
#line 689 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp95_ = ngettext ("1 file failed to import due to a file or hardware error:\n", "%d files failed to import due to a file or hardware error:\n", (gulong) _tmp94_);
#line 689 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp96_ = manifest;
#line 689 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp97_ = _tmp96_->failed;
#line 689 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp98_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp97_, GEE_TYPE_COLLECTION, GeeCollection));
#line 689 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp99_ = _tmp98_;
#line 689 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp100_ = g_strdup_printf (_tmp95_, _tmp99_);
#line 689 "/home/jens/Source/shotwell/src/Dialogs.vala"
		neither_message = _tmp100_;
#line 693 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp101_ = message;
#line 693 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp102_ = manifest;
#line 693 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp103_ = _tmp102_->failed;
#line 693 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp104_ = photos_message;
#line 693 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp105_ = videos_message;
#line 693 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp106_ = both_message;
#line 693 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp107_ = neither_message;
#line 693 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp108_ = import_ui_get_media_specific_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp103_, GEE_TYPE_COLLECTION, GeeCollection), _tmp104_, _tmp105_, _tmp106_, _tmp107_);
#line 693 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp109_ = _tmp108_;
#line 693 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp110_ = g_strconcat (_tmp101_, _tmp109_, NULL);
#line 693 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (message);
#line 693 "/home/jens/Source/shotwell/src/Dialogs.vala"
		message = _tmp110_;
#line 693 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp109_);
#line 696 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp111_ = message;
#line 696 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp112_ = manifest;
#line 696 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp113_ = _tmp112_->failed;
#line 696 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp114_ = show_dest_id;
#line 696 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp115_ = import_ui_generate_import_failure_list (_tmp113_, _tmp114_);
#line 696 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp116_ = _tmp115_;
#line 696 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp117_ = g_strconcat (_tmp111_, _tmp116_, NULL);
#line 696 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (message);
#line 696 "/home/jens/Source/shotwell/src/Dialogs.vala"
		message = _tmp117_;
#line 696 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp116_);
#line 676 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (neither_message);
#line 676 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (both_message);
#line 676 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (videos_message);
#line 676 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (photos_message);
#line 6859 "Dialogs.c"
	}
#line 699 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp118_ = manifest;
#line 699 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp119_ = _tmp118_->write_failed;
#line 699 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp120_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp119_, GEE_TYPE_COLLECTION, GeeCollection));
#line 699 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp121_ = _tmp120_;
#line 699 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp121_ > 0) {
#line 6871 "Dialogs.c"
		const gchar* _tmp122_ = NULL;
		gint _tmp123_ = 0;
		gint _tmp124_ = 0;
		gchar* photos_message = NULL;
		ImportManifest* _tmp127_ = NULL;
		GeeList* _tmp128_ = NULL;
		gint _tmp129_ = 0;
		gint _tmp130_ = 0;
		const gchar* _tmp131_ = NULL;
		ImportManifest* _tmp132_ = NULL;
		GeeList* _tmp133_ = NULL;
		gint _tmp134_ = 0;
		gint _tmp135_ = 0;
		gchar* _tmp136_ = NULL;
		gchar* videos_message = NULL;
		ImportManifest* _tmp137_ = NULL;
		GeeList* _tmp138_ = NULL;
		gint _tmp139_ = 0;
		gint _tmp140_ = 0;
		const gchar* _tmp141_ = NULL;
		ImportManifest* _tmp142_ = NULL;
		GeeList* _tmp143_ = NULL;
		gint _tmp144_ = 0;
		gint _tmp145_ = 0;
		gchar* _tmp146_ = NULL;
		gchar* both_message = NULL;
		ImportManifest* _tmp147_ = NULL;
		GeeList* _tmp148_ = NULL;
		gint _tmp149_ = 0;
		gint _tmp150_ = 0;
		const gchar* _tmp151_ = NULL;
		ImportManifest* _tmp152_ = NULL;
		GeeList* _tmp153_ = NULL;
		gint _tmp154_ = 0;
		gint _tmp155_ = 0;
		gchar* _tmp156_ = NULL;
		gchar* neither_message = NULL;
		ImportManifest* _tmp157_ = NULL;
		GeeList* _tmp158_ = NULL;
		gint _tmp159_ = 0;
		gint _tmp160_ = 0;
		const gchar* _tmp161_ = NULL;
		ImportManifest* _tmp162_ = NULL;
		GeeList* _tmp163_ = NULL;
		gint _tmp164_ = 0;
		gint _tmp165_ = 0;
		gchar* _tmp166_ = NULL;
		const gchar* _tmp167_ = NULL;
		ImportManifest* _tmp168_ = NULL;
		GeeList* _tmp169_ = NULL;
		const gchar* _tmp170_ = NULL;
		const gchar* _tmp171_ = NULL;
		const gchar* _tmp172_ = NULL;
		const gchar* _tmp173_ = NULL;
		gchar* _tmp174_ = NULL;
		gchar* _tmp175_ = NULL;
		gchar* _tmp176_ = NULL;
		const gchar* _tmp177_ = NULL;
		ImportManifest* _tmp178_ = NULL;
		GeeList* _tmp179_ = NULL;
		gboolean _tmp180_ = FALSE;
		gchar* _tmp181_ = NULL;
		gchar* _tmp182_ = NULL;
		gchar* _tmp183_ = NULL;
#line 700 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp122_ = message;
#line 700 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp123_ = strlen (_tmp122_);
#line 700 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp124_ = _tmp123_;
#line 700 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp124_ > 0) {
#line 6944 "Dialogs.c"
			const gchar* _tmp125_ = NULL;
			gchar* _tmp126_ = NULL;
#line 701 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp125_ = message;
#line 701 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp126_ = g_strconcat (_tmp125_, "\n", NULL);
#line 701 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (message);
#line 701 "/home/jens/Source/shotwell/src/Dialogs.vala"
			message = _tmp126_;
#line 6955 "Dialogs.c"
		}
#line 703 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp127_ = manifest;
#line 703 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp128_ = _tmp127_->write_failed;
#line 703 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp129_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp128_, GEE_TYPE_COLLECTION, GeeCollection));
#line 703 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp130_ = _tmp129_;
#line 703 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp131_ = ngettext ("1 photo failed to import because the photo library folder was not writ" \
"able:\n", "%d photos failed to import because the photo library folder was not wr" \
"itable:\n", (gulong) _tmp130_);
#line 703 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp132_ = manifest;
#line 703 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp133_ = _tmp132_->write_failed;
#line 703 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp134_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp133_, GEE_TYPE_COLLECTION, GeeCollection));
#line 703 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp135_ = _tmp134_;
#line 703 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp136_ = g_strdup_printf (_tmp131_, _tmp135_);
#line 703 "/home/jens/Source/shotwell/src/Dialogs.vala"
		photos_message = _tmp136_;
#line 706 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp137_ = manifest;
#line 706 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp138_ = _tmp137_->write_failed;
#line 706 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp139_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp138_, GEE_TYPE_COLLECTION, GeeCollection));
#line 706 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp140_ = _tmp139_;
#line 706 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp141_ = ngettext ("1 video failed to import because the photo library folder was not writ" \
"able:\n", "%d videos failed to import because the photo library folder was not wr" \
"itable:\n", (gulong) _tmp140_);
#line 706 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp142_ = manifest;
#line 706 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp143_ = _tmp142_->write_failed;
#line 706 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp144_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp143_, GEE_TYPE_COLLECTION, GeeCollection));
#line 706 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp145_ = _tmp144_;
#line 706 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp146_ = g_strdup_printf (_tmp141_, _tmp145_);
#line 706 "/home/jens/Source/shotwell/src/Dialogs.vala"
		videos_message = _tmp146_;
#line 709 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp147_ = manifest;
#line 709 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp148_ = _tmp147_->write_failed;
#line 709 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp149_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp148_, GEE_TYPE_COLLECTION, GeeCollection));
#line 709 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp150_ = _tmp149_;
#line 709 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp151_ = ngettext ("1 photo/video failed to import because the photo library folder was no" \
"t writable:\n", "%d photos/videos failed to import because the photo library folder was" \
" not writable:\n", (gulong) _tmp150_);
#line 709 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp152_ = manifest;
#line 709 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp153_ = _tmp152_->write_failed;
#line 709 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp154_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp153_, GEE_TYPE_COLLECTION, GeeCollection));
#line 709 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp155_ = _tmp154_;
#line 709 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp156_ = g_strdup_printf (_tmp151_, _tmp155_);
#line 709 "/home/jens/Source/shotwell/src/Dialogs.vala"
		both_message = _tmp156_;
#line 712 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp157_ = manifest;
#line 712 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp158_ = _tmp157_->write_failed;
#line 712 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp159_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp158_, GEE_TYPE_COLLECTION, GeeCollection));
#line 712 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp160_ = _tmp159_;
#line 712 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp161_ = ngettext ("1 file failed to import because the photo library folder was not writa" \
"ble:\n", "%d files failed to import because the photo library folder was not wri" \
"table:\n", (gulong) _tmp160_);
#line 712 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp162_ = manifest;
#line 712 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp163_ = _tmp162_->write_failed;
#line 712 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp164_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp163_, GEE_TYPE_COLLECTION, GeeCollection));
#line 712 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp165_ = _tmp164_;
#line 712 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp166_ = g_strdup_printf (_tmp161_, _tmp165_);
#line 712 "/home/jens/Source/shotwell/src/Dialogs.vala"
		neither_message = _tmp166_;
#line 716 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp167_ = message;
#line 716 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp168_ = manifest;
#line 716 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp169_ = _tmp168_->write_failed;
#line 716 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp170_ = photos_message;
#line 716 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp171_ = videos_message;
#line 716 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp172_ = both_message;
#line 716 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp173_ = neither_message;
#line 716 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp174_ = import_ui_get_media_specific_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp169_, GEE_TYPE_COLLECTION, GeeCollection), _tmp170_, _tmp171_, _tmp172_, _tmp173_);
#line 716 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp175_ = _tmp174_;
#line 716 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp176_ = g_strconcat (_tmp167_, _tmp175_, NULL);
#line 716 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (message);
#line 716 "/home/jens/Source/shotwell/src/Dialogs.vala"
		message = _tmp176_;
#line 716 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp175_);
#line 719 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp177_ = message;
#line 719 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp178_ = manifest;
#line 719 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp179_ = _tmp178_->write_failed;
#line 719 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp180_ = show_dest_id;
#line 719 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp181_ = import_ui_generate_import_failure_list (_tmp179_, _tmp180_);
#line 719 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp182_ = _tmp181_;
#line 719 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp183_ = g_strconcat (_tmp177_, _tmp182_, NULL);
#line 719 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (message);
#line 719 "/home/jens/Source/shotwell/src/Dialogs.vala"
		message = _tmp183_;
#line 719 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp182_);
#line 699 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (neither_message);
#line 699 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (both_message);
#line 699 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (videos_message);
#line 699 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (photos_message);
#line 7099 "Dialogs.c"
	}
#line 722 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp184_ = manifest;
#line 722 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp185_ = _tmp184_->camera_failed;
#line 722 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp186_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp185_, GEE_TYPE_COLLECTION, GeeCollection));
#line 722 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp187_ = _tmp186_;
#line 722 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp187_ > 0) {
#line 7111 "Dialogs.c"
		const gchar* _tmp188_ = NULL;
		gint _tmp189_ = 0;
		gint _tmp190_ = 0;
		gchar* photos_message = NULL;
		ImportManifest* _tmp193_ = NULL;
		GeeList* _tmp194_ = NULL;
		gint _tmp195_ = 0;
		gint _tmp196_ = 0;
		const gchar* _tmp197_ = NULL;
		ImportManifest* _tmp198_ = NULL;
		GeeList* _tmp199_ = NULL;
		gint _tmp200_ = 0;
		gint _tmp201_ = 0;
		gchar* _tmp202_ = NULL;
		gchar* videos_message = NULL;
		ImportManifest* _tmp203_ = NULL;
		GeeList* _tmp204_ = NULL;
		gint _tmp205_ = 0;
		gint _tmp206_ = 0;
		const gchar* _tmp207_ = NULL;
		ImportManifest* _tmp208_ = NULL;
		GeeList* _tmp209_ = NULL;
		gint _tmp210_ = 0;
		gint _tmp211_ = 0;
		gchar* _tmp212_ = NULL;
		gchar* both_message = NULL;
		ImportManifest* _tmp213_ = NULL;
		GeeList* _tmp214_ = NULL;
		gint _tmp215_ = 0;
		gint _tmp216_ = 0;
		const gchar* _tmp217_ = NULL;
		ImportManifest* _tmp218_ = NULL;
		GeeList* _tmp219_ = NULL;
		gint _tmp220_ = 0;
		gint _tmp221_ = 0;
		gchar* _tmp222_ = NULL;
		gchar* neither_message = NULL;
		ImportManifest* _tmp223_ = NULL;
		GeeList* _tmp224_ = NULL;
		gint _tmp225_ = 0;
		gint _tmp226_ = 0;
		const gchar* _tmp227_ = NULL;
		ImportManifest* _tmp228_ = NULL;
		GeeList* _tmp229_ = NULL;
		gint _tmp230_ = 0;
		gint _tmp231_ = 0;
		gchar* _tmp232_ = NULL;
		const gchar* _tmp233_ = NULL;
		ImportManifest* _tmp234_ = NULL;
		GeeList* _tmp235_ = NULL;
		const gchar* _tmp236_ = NULL;
		const gchar* _tmp237_ = NULL;
		const gchar* _tmp238_ = NULL;
		const gchar* _tmp239_ = NULL;
		gchar* _tmp240_ = NULL;
		gchar* _tmp241_ = NULL;
		gchar* _tmp242_ = NULL;
		const gchar* _tmp243_ = NULL;
		ImportManifest* _tmp244_ = NULL;
		GeeList* _tmp245_ = NULL;
		gboolean _tmp246_ = FALSE;
		gchar* _tmp247_ = NULL;
		gchar* _tmp248_ = NULL;
		gchar* _tmp249_ = NULL;
#line 723 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp188_ = message;
#line 723 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp189_ = strlen (_tmp188_);
#line 723 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp190_ = _tmp189_;
#line 723 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp190_ > 0) {
#line 7184 "Dialogs.c"
			const gchar* _tmp191_ = NULL;
			gchar* _tmp192_ = NULL;
#line 724 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp191_ = message;
#line 724 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp192_ = g_strconcat (_tmp191_, "\n", NULL);
#line 724 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (message);
#line 724 "/home/jens/Source/shotwell/src/Dialogs.vala"
			message = _tmp192_;
#line 7195 "Dialogs.c"
		}
#line 726 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp193_ = manifest;
#line 726 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp194_ = _tmp193_->camera_failed;
#line 726 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp195_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp194_, GEE_TYPE_COLLECTION, GeeCollection));
#line 726 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp196_ = _tmp195_;
#line 726 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp197_ = ngettext ("1 photo failed to import due to a camera error:\n", "%d photos failed to import due to a camera error:\n", (gulong) _tmp196_);
#line 726 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp198_ = manifest;
#line 726 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp199_ = _tmp198_->camera_failed;
#line 726 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp200_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp199_, GEE_TYPE_COLLECTION, GeeCollection));
#line 726 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp201_ = _tmp200_;
#line 726 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp202_ = g_strdup_printf (_tmp197_, _tmp201_);
#line 726 "/home/jens/Source/shotwell/src/Dialogs.vala"
		photos_message = _tmp202_;
#line 729 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp203_ = manifest;
#line 729 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp204_ = _tmp203_->camera_failed;
#line 729 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp205_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp204_, GEE_TYPE_COLLECTION, GeeCollection));
#line 729 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp206_ = _tmp205_;
#line 729 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp207_ = ngettext ("1 video failed to import due to a camera error:\n", "%d videos failed to import due to a camera error:\n", (gulong) _tmp206_);
#line 729 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp208_ = manifest;
#line 729 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp209_ = _tmp208_->camera_failed;
#line 729 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp210_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp209_, GEE_TYPE_COLLECTION, GeeCollection));
#line 729 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp211_ = _tmp210_;
#line 729 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp212_ = g_strdup_printf (_tmp207_, _tmp211_);
#line 729 "/home/jens/Source/shotwell/src/Dialogs.vala"
		videos_message = _tmp212_;
#line 732 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp213_ = manifest;
#line 732 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp214_ = _tmp213_->camera_failed;
#line 732 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp215_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp214_, GEE_TYPE_COLLECTION, GeeCollection));
#line 732 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp216_ = _tmp215_;
#line 732 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp217_ = ngettext ("1 photo/video failed to import due to a camera error:\n", "%d photos/videos failed to import due to a camera error:\n", (gulong) _tmp216_);
#line 732 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp218_ = manifest;
#line 732 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp219_ = _tmp218_->camera_failed;
#line 732 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp220_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp219_, GEE_TYPE_COLLECTION, GeeCollection));
#line 732 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp221_ = _tmp220_;
#line 732 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp222_ = g_strdup_printf (_tmp217_, _tmp221_);
#line 732 "/home/jens/Source/shotwell/src/Dialogs.vala"
		both_message = _tmp222_;
#line 735 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp223_ = manifest;
#line 735 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp224_ = _tmp223_->camera_failed;
#line 735 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp225_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp224_, GEE_TYPE_COLLECTION, GeeCollection));
#line 735 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp226_ = _tmp225_;
#line 735 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp227_ = ngettext ("1 file failed to import due to a camera error:\n", "%d files failed to import due to a camera error:\n", (gulong) _tmp226_);
#line 735 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp228_ = manifest;
#line 735 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp229_ = _tmp228_->camera_failed;
#line 735 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp230_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp229_, GEE_TYPE_COLLECTION, GeeCollection));
#line 735 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp231_ = _tmp230_;
#line 735 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp232_ = g_strdup_printf (_tmp227_, _tmp231_);
#line 735 "/home/jens/Source/shotwell/src/Dialogs.vala"
		neither_message = _tmp232_;
#line 739 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp233_ = message;
#line 739 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp234_ = manifest;
#line 739 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp235_ = _tmp234_->camera_failed;
#line 739 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp236_ = photos_message;
#line 739 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp237_ = videos_message;
#line 739 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp238_ = both_message;
#line 739 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp239_ = neither_message;
#line 739 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp240_ = import_ui_get_media_specific_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp235_, GEE_TYPE_COLLECTION, GeeCollection), _tmp236_, _tmp237_, _tmp238_, _tmp239_);
#line 739 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp241_ = _tmp240_;
#line 739 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp242_ = g_strconcat (_tmp233_, _tmp241_, NULL);
#line 739 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (message);
#line 739 "/home/jens/Source/shotwell/src/Dialogs.vala"
		message = _tmp242_;
#line 739 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp241_);
#line 742 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp243_ = message;
#line 742 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp244_ = manifest;
#line 742 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp245_ = _tmp244_->camera_failed;
#line 742 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp246_ = show_dest_id;
#line 742 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp247_ = import_ui_generate_import_failure_list (_tmp245_, _tmp246_);
#line 742 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp248_ = _tmp247_;
#line 742 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp249_ = g_strconcat (_tmp243_, _tmp248_, NULL);
#line 742 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (message);
#line 742 "/home/jens/Source/shotwell/src/Dialogs.vala"
		message = _tmp249_;
#line 742 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp248_);
#line 722 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (neither_message);
#line 722 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (both_message);
#line 722 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (videos_message);
#line 722 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (photos_message);
#line 7339 "Dialogs.c"
	}
#line 745 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp250_ = manifest;
#line 745 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp251_ = _tmp250_->corrupt_files;
#line 745 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp252_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp251_, GEE_TYPE_COLLECTION, GeeCollection));
#line 745 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp253_ = _tmp252_;
#line 745 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp253_ > 0) {
#line 7351 "Dialogs.c"
		const gchar* _tmp254_ = NULL;
		gint _tmp255_ = 0;
		gint _tmp256_ = 0;
		gchar* photos_message = NULL;
		ImportManifest* _tmp259_ = NULL;
		GeeList* _tmp260_ = NULL;
		gint _tmp261_ = 0;
		gint _tmp262_ = 0;
		const gchar* _tmp263_ = NULL;
		ImportManifest* _tmp264_ = NULL;
		GeeList* _tmp265_ = NULL;
		gint _tmp266_ = 0;
		gint _tmp267_ = 0;
		gchar* _tmp268_ = NULL;
		gchar* videos_message = NULL;
		ImportManifest* _tmp269_ = NULL;
		GeeList* _tmp270_ = NULL;
		gint _tmp271_ = 0;
		gint _tmp272_ = 0;
		const gchar* _tmp273_ = NULL;
		ImportManifest* _tmp274_ = NULL;
		GeeList* _tmp275_ = NULL;
		gint _tmp276_ = 0;
		gint _tmp277_ = 0;
		gchar* _tmp278_ = NULL;
		gchar* both_message = NULL;
		ImportManifest* _tmp279_ = NULL;
		GeeList* _tmp280_ = NULL;
		gint _tmp281_ = 0;
		gint _tmp282_ = 0;
		const gchar* _tmp283_ = NULL;
		ImportManifest* _tmp284_ = NULL;
		GeeList* _tmp285_ = NULL;
		gint _tmp286_ = 0;
		gint _tmp287_ = 0;
		gchar* _tmp288_ = NULL;
		gchar* neither_message = NULL;
		ImportManifest* _tmp289_ = NULL;
		GeeList* _tmp290_ = NULL;
		gint _tmp291_ = 0;
		gint _tmp292_ = 0;
		const gchar* _tmp293_ = NULL;
		ImportManifest* _tmp294_ = NULL;
		GeeList* _tmp295_ = NULL;
		gint _tmp296_ = 0;
		gint _tmp297_ = 0;
		gchar* _tmp298_ = NULL;
		const gchar* _tmp299_ = NULL;
		ImportManifest* _tmp300_ = NULL;
		GeeList* _tmp301_ = NULL;
		const gchar* _tmp302_ = NULL;
		const gchar* _tmp303_ = NULL;
		const gchar* _tmp304_ = NULL;
		const gchar* _tmp305_ = NULL;
		gchar* _tmp306_ = NULL;
		gchar* _tmp307_ = NULL;
		gchar* _tmp308_ = NULL;
		const gchar* _tmp309_ = NULL;
		ImportManifest* _tmp310_ = NULL;
		GeeList* _tmp311_ = NULL;
		gboolean _tmp312_ = FALSE;
		gchar* _tmp313_ = NULL;
		gchar* _tmp314_ = NULL;
		gchar* _tmp315_ = NULL;
#line 746 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp254_ = message;
#line 746 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp255_ = strlen (_tmp254_);
#line 746 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp256_ = _tmp255_;
#line 746 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp256_ > 0) {
#line 7424 "Dialogs.c"
			const gchar* _tmp257_ = NULL;
			gchar* _tmp258_ = NULL;
#line 747 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp257_ = message;
#line 747 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp258_ = g_strconcat (_tmp257_, "\n", NULL);
#line 747 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (message);
#line 747 "/home/jens/Source/shotwell/src/Dialogs.vala"
			message = _tmp258_;
#line 7435 "Dialogs.c"
		}
#line 749 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp259_ = manifest;
#line 749 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp260_ = _tmp259_->corrupt_files;
#line 749 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp261_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp260_, GEE_TYPE_COLLECTION, GeeCollection));
#line 749 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp262_ = _tmp261_;
#line 749 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp263_ = ngettext ("1 photo failed to import because it was corrupt:\n", "%d photos failed to import because they were corrupt:\n", (gulong) _tmp262_);
#line 749 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp264_ = manifest;
#line 749 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp265_ = _tmp264_->corrupt_files;
#line 749 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp266_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp265_, GEE_TYPE_COLLECTION, GeeCollection));
#line 749 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp267_ = _tmp266_;
#line 749 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp268_ = g_strdup_printf (_tmp263_, _tmp267_);
#line 749 "/home/jens/Source/shotwell/src/Dialogs.vala"
		photos_message = _tmp268_;
#line 752 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp269_ = manifest;
#line 752 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp270_ = _tmp269_->corrupt_files;
#line 752 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp271_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp270_, GEE_TYPE_COLLECTION, GeeCollection));
#line 752 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp272_ = _tmp271_;
#line 752 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp273_ = ngettext ("1 video failed to import because it was corrupt:\n", "%d videos failed to import because they were corrupt:\n", (gulong) _tmp272_);
#line 752 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp274_ = manifest;
#line 752 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp275_ = _tmp274_->corrupt_files;
#line 752 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp276_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp275_, GEE_TYPE_COLLECTION, GeeCollection));
#line 752 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp277_ = _tmp276_;
#line 752 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp278_ = g_strdup_printf (_tmp273_, _tmp277_);
#line 752 "/home/jens/Source/shotwell/src/Dialogs.vala"
		videos_message = _tmp278_;
#line 755 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp279_ = manifest;
#line 755 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp280_ = _tmp279_->corrupt_files;
#line 755 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp281_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp280_, GEE_TYPE_COLLECTION, GeeCollection));
#line 755 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp282_ = _tmp281_;
#line 755 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp283_ = ngettext ("1 photo/video failed to import because it was corrupt:\n", "%d photos/videos failed to import because they were corrupt:\n", (gulong) _tmp282_);
#line 755 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp284_ = manifest;
#line 755 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp285_ = _tmp284_->corrupt_files;
#line 755 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp286_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp285_, GEE_TYPE_COLLECTION, GeeCollection));
#line 755 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp287_ = _tmp286_;
#line 755 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp288_ = g_strdup_printf (_tmp283_, _tmp287_);
#line 755 "/home/jens/Source/shotwell/src/Dialogs.vala"
		both_message = _tmp288_;
#line 758 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp289_ = manifest;
#line 758 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp290_ = _tmp289_->corrupt_files;
#line 758 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp291_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp290_, GEE_TYPE_COLLECTION, GeeCollection));
#line 758 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp292_ = _tmp291_;
#line 758 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp293_ = ngettext ("1 file failed to import because it was corrupt:\n", "%d files failed to import because it was corrupt:\n", (gulong) _tmp292_);
#line 758 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp294_ = manifest;
#line 758 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp295_ = _tmp294_->corrupt_files;
#line 758 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp296_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp295_, GEE_TYPE_COLLECTION, GeeCollection));
#line 758 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp297_ = _tmp296_;
#line 758 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp298_ = g_strdup_printf (_tmp293_, _tmp297_);
#line 758 "/home/jens/Source/shotwell/src/Dialogs.vala"
		neither_message = _tmp298_;
#line 762 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp299_ = message;
#line 762 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp300_ = manifest;
#line 762 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp301_ = _tmp300_->corrupt_files;
#line 762 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp302_ = photos_message;
#line 762 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp303_ = videos_message;
#line 762 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp304_ = both_message;
#line 762 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp305_ = neither_message;
#line 762 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp306_ = import_ui_get_media_specific_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp301_, GEE_TYPE_COLLECTION, GeeCollection), _tmp302_, _tmp303_, _tmp304_, _tmp305_);
#line 762 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp307_ = _tmp306_;
#line 762 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp308_ = g_strconcat (_tmp299_, _tmp307_, NULL);
#line 762 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (message);
#line 762 "/home/jens/Source/shotwell/src/Dialogs.vala"
		message = _tmp308_;
#line 762 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp307_);
#line 765 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp309_ = message;
#line 765 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp310_ = manifest;
#line 765 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp311_ = _tmp310_->corrupt_files;
#line 765 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp312_ = show_dest_id;
#line 765 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp313_ = import_ui_generate_import_failure_list (_tmp311_, _tmp312_);
#line 765 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp314_ = _tmp313_;
#line 765 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp315_ = g_strconcat (_tmp309_, _tmp314_, NULL);
#line 765 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (message);
#line 765 "/home/jens/Source/shotwell/src/Dialogs.vala"
		message = _tmp315_;
#line 765 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp314_);
#line 745 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (neither_message);
#line 745 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (both_message);
#line 745 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (videos_message);
#line 745 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (photos_message);
#line 7579 "Dialogs.c"
	}
#line 768 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp316_ = manifest;
#line 768 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp317_ = _tmp316_->skipped_photos;
#line 768 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp318_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp317_, GEE_TYPE_COLLECTION, GeeCollection));
#line 768 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp319_ = _tmp318_;
#line 768 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp319_ > 0) {
#line 7591 "Dialogs.c"
		const gchar* _tmp320_ = NULL;
		gint _tmp321_ = 0;
		gint _tmp322_ = 0;
		gchar* skipped_photos_message = NULL;
		ImportManifest* _tmp325_ = NULL;
		GeeList* _tmp326_ = NULL;
		gint _tmp327_ = 0;
		gint _tmp328_ = 0;
		const gchar* _tmp329_ = NULL;
		ImportManifest* _tmp330_ = NULL;
		GeeList* _tmp331_ = NULL;
		gint _tmp332_ = 0;
		gint _tmp333_ = 0;
		gchar* _tmp334_ = NULL;
		const gchar* _tmp335_ = NULL;
		const gchar* _tmp336_ = NULL;
		gchar* _tmp337_ = NULL;
		const gchar* _tmp338_ = NULL;
		ImportManifest* _tmp339_ = NULL;
		GeeList* _tmp340_ = NULL;
		gboolean _tmp341_ = FALSE;
		gchar* _tmp342_ = NULL;
		gchar* _tmp343_ = NULL;
		gchar* _tmp344_ = NULL;
#line 769 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp320_ = message;
#line 769 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp321_ = strlen (_tmp320_);
#line 769 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp322_ = _tmp321_;
#line 769 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp322_ > 0) {
#line 7624 "Dialogs.c"
			const gchar* _tmp323_ = NULL;
			gchar* _tmp324_ = NULL;
#line 770 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp323_ = message;
#line 770 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp324_ = g_strconcat (_tmp323_, "\n", NULL);
#line 770 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (message);
#line 770 "/home/jens/Source/shotwell/src/Dialogs.vala"
			message = _tmp324_;
#line 7635 "Dialogs.c"
		}
#line 775 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp325_ = manifest;
#line 775 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp326_ = _tmp325_->skipped_photos;
#line 775 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp327_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp326_, GEE_TYPE_COLLECTION, GeeCollection));
#line 775 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp328_ = _tmp327_;
#line 775 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp329_ = ngettext ("1 unsupported photo skipped:\n", "%d unsupported photos skipped:\n", (gulong) _tmp328_);
#line 775 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp330_ = manifest;
#line 775 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp331_ = _tmp330_->skipped_photos;
#line 775 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp332_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp331_, GEE_TYPE_COLLECTION, GeeCollection));
#line 775 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp333_ = _tmp332_;
#line 775 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp334_ = g_strdup_printf (_tmp329_, _tmp333_);
#line 775 "/home/jens/Source/shotwell/src/Dialogs.vala"
		skipped_photos_message = _tmp334_;
#line 779 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp335_ = message;
#line 779 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp336_ = skipped_photos_message;
#line 779 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp337_ = g_strconcat (_tmp335_, _tmp336_, NULL);
#line 779 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (message);
#line 779 "/home/jens/Source/shotwell/src/Dialogs.vala"
		message = _tmp337_;
#line 781 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp338_ = message;
#line 781 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp339_ = manifest;
#line 781 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp340_ = _tmp339_->skipped_photos;
#line 781 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp341_ = show_dest_id;
#line 781 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp342_ = import_ui_generate_import_failure_list (_tmp340_, _tmp341_);
#line 781 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp343_ = _tmp342_;
#line 781 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp344_ = g_strconcat (_tmp338_, _tmp343_, NULL);
#line 781 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (message);
#line 781 "/home/jens/Source/shotwell/src/Dialogs.vala"
		message = _tmp344_;
#line 781 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp343_);
#line 768 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (skipped_photos_message);
#line 7691 "Dialogs.c"
	}
#line 784 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp345_ = manifest;
#line 784 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp346_ = _tmp345_->skipped_files;
#line 784 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp347_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp346_, GEE_TYPE_COLLECTION, GeeCollection));
#line 784 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp348_ = _tmp347_;
#line 784 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp348_ > 0) {
#line 7703 "Dialogs.c"
		const gchar* _tmp349_ = NULL;
		gint _tmp350_ = 0;
		gint _tmp351_ = 0;
		gchar* skipped_files_message = NULL;
		ImportManifest* _tmp354_ = NULL;
		GeeList* _tmp355_ = NULL;
		gint _tmp356_ = 0;
		gint _tmp357_ = 0;
		const gchar* _tmp358_ = NULL;
		ImportManifest* _tmp359_ = NULL;
		GeeList* _tmp360_ = NULL;
		gint _tmp361_ = 0;
		gint _tmp362_ = 0;
		gchar* _tmp363_ = NULL;
		const gchar* _tmp364_ = NULL;
		const gchar* _tmp365_ = NULL;
		gchar* _tmp366_ = NULL;
#line 785 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp349_ = message;
#line 785 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp350_ = strlen (_tmp349_);
#line 785 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp351_ = _tmp350_;
#line 785 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp351_ > 0) {
#line 7729 "Dialogs.c"
			const gchar* _tmp352_ = NULL;
			gchar* _tmp353_ = NULL;
#line 786 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp352_ = message;
#line 786 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp353_ = g_strconcat (_tmp352_, "\n", NULL);
#line 786 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (message);
#line 786 "/home/jens/Source/shotwell/src/Dialogs.vala"
			message = _tmp353_;
#line 7740 "Dialogs.c"
		}
#line 790 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp354_ = manifest;
#line 790 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp355_ = _tmp354_->skipped_files;
#line 790 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp356_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp355_, GEE_TYPE_COLLECTION, GeeCollection));
#line 790 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp357_ = _tmp356_;
#line 790 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp358_ = ngettext ("1 non-image file skipped.\n", "%d non-image files skipped.\n", (gulong) _tmp357_);
#line 790 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp359_ = manifest;
#line 790 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp360_ = _tmp359_->skipped_files;
#line 790 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp361_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp360_, GEE_TYPE_COLLECTION, GeeCollection));
#line 790 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp362_ = _tmp361_;
#line 790 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp363_ = g_strdup_printf (_tmp358_, _tmp362_);
#line 790 "/home/jens/Source/shotwell/src/Dialogs.vala"
		skipped_files_message = _tmp363_;
#line 794 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp364_ = message;
#line 794 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp365_ = skipped_files_message;
#line 794 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp366_ = g_strconcat (_tmp364_, _tmp365_, NULL);
#line 794 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (message);
#line 794 "/home/jens/Source/shotwell/src/Dialogs.vala"
		message = _tmp366_;
#line 784 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (skipped_files_message);
#line 7776 "Dialogs.c"
	}
#line 797 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp367_ = manifest;
#line 797 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp368_ = _tmp367_->aborted;
#line 797 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp369_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp368_, GEE_TYPE_COLLECTION, GeeCollection));
#line 797 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp370_ = _tmp369_;
#line 797 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp370_ > 0) {
#line 7788 "Dialogs.c"
		const gchar* _tmp371_ = NULL;
		gint _tmp372_ = 0;
		gint _tmp373_ = 0;
		gchar* photos_message = NULL;
		ImportManifest* _tmp376_ = NULL;
		GeeList* _tmp377_ = NULL;
		gint _tmp378_ = 0;
		gint _tmp379_ = 0;
		const gchar* _tmp380_ = NULL;
		ImportManifest* _tmp381_ = NULL;
		GeeList* _tmp382_ = NULL;
		gint _tmp383_ = 0;
		gint _tmp384_ = 0;
		gchar* _tmp385_ = NULL;
		gchar* videos_message = NULL;
		ImportManifest* _tmp386_ = NULL;
		GeeList* _tmp387_ = NULL;
		gint _tmp388_ = 0;
		gint _tmp389_ = 0;
		const gchar* _tmp390_ = NULL;
		ImportManifest* _tmp391_ = NULL;
		GeeList* _tmp392_ = NULL;
		gint _tmp393_ = 0;
		gint _tmp394_ = 0;
		gchar* _tmp395_ = NULL;
		gchar* both_message = NULL;
		ImportManifest* _tmp396_ = NULL;
		GeeList* _tmp397_ = NULL;
		gint _tmp398_ = 0;
		gint _tmp399_ = 0;
		const gchar* _tmp400_ = NULL;
		ImportManifest* _tmp401_ = NULL;
		GeeList* _tmp402_ = NULL;
		gint _tmp403_ = 0;
		gint _tmp404_ = 0;
		gchar* _tmp405_ = NULL;
		gchar* neither_message = NULL;
		ImportManifest* _tmp406_ = NULL;
		GeeList* _tmp407_ = NULL;
		gint _tmp408_ = 0;
		gint _tmp409_ = 0;
		const gchar* _tmp410_ = NULL;
		ImportManifest* _tmp411_ = NULL;
		GeeList* _tmp412_ = NULL;
		gint _tmp413_ = 0;
		gint _tmp414_ = 0;
		gchar* _tmp415_ = NULL;
		const gchar* _tmp416_ = NULL;
		ImportManifest* _tmp417_ = NULL;
		GeeList* _tmp418_ = NULL;
		const gchar* _tmp419_ = NULL;
		const gchar* _tmp420_ = NULL;
		const gchar* _tmp421_ = NULL;
		const gchar* _tmp422_ = NULL;
		gchar* _tmp423_ = NULL;
		gchar* _tmp424_ = NULL;
		gchar* _tmp425_ = NULL;
		const gchar* _tmp426_ = NULL;
		ImportManifest* _tmp427_ = NULL;
		GeeList* _tmp428_ = NULL;
		gboolean _tmp429_ = FALSE;
		gchar* _tmp430_ = NULL;
		gchar* _tmp431_ = NULL;
		gchar* _tmp432_ = NULL;
#line 798 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp371_ = message;
#line 798 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp372_ = strlen (_tmp371_);
#line 798 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp373_ = _tmp372_;
#line 798 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp373_ > 0) {
#line 7861 "Dialogs.c"
			const gchar* _tmp374_ = NULL;
			gchar* _tmp375_ = NULL;
#line 799 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp374_ = message;
#line 799 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp375_ = g_strconcat (_tmp374_, "\n", NULL);
#line 799 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (message);
#line 799 "/home/jens/Source/shotwell/src/Dialogs.vala"
			message = _tmp375_;
#line 7872 "Dialogs.c"
		}
#line 801 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp376_ = manifest;
#line 801 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp377_ = _tmp376_->aborted;
#line 801 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp378_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp377_, GEE_TYPE_COLLECTION, GeeCollection));
#line 801 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp379_ = _tmp378_;
#line 801 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp380_ = ngettext ("1 photo skipped due to user cancel:\n", "%d photos skipped due to user cancel:\n", (gulong) _tmp379_);
#line 801 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp381_ = manifest;
#line 801 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp382_ = _tmp381_->aborted;
#line 801 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp383_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp382_, GEE_TYPE_COLLECTION, GeeCollection));
#line 801 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp384_ = _tmp383_;
#line 801 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp385_ = g_strdup_printf (_tmp380_, _tmp384_);
#line 801 "/home/jens/Source/shotwell/src/Dialogs.vala"
		photos_message = _tmp385_;
#line 804 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp386_ = manifest;
#line 804 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp387_ = _tmp386_->aborted;
#line 804 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp388_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp387_, GEE_TYPE_COLLECTION, GeeCollection));
#line 804 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp389_ = _tmp388_;
#line 804 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp390_ = ngettext ("1 video skipped due to user cancel:\n", "%d videos skipped due to user cancel:\n", (gulong) _tmp389_);
#line 804 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp391_ = manifest;
#line 804 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp392_ = _tmp391_->aborted;
#line 804 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp393_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp392_, GEE_TYPE_COLLECTION, GeeCollection));
#line 804 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp394_ = _tmp393_;
#line 804 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp395_ = g_strdup_printf (_tmp390_, _tmp394_);
#line 804 "/home/jens/Source/shotwell/src/Dialogs.vala"
		videos_message = _tmp395_;
#line 807 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp396_ = manifest;
#line 807 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp397_ = _tmp396_->aborted;
#line 807 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp398_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp397_, GEE_TYPE_COLLECTION, GeeCollection));
#line 807 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp399_ = _tmp398_;
#line 807 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp400_ = ngettext ("1 photo/video skipped due to user cancel:\n", "%d photos/videos skipped due to user cancel:\n", (gulong) _tmp399_);
#line 807 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp401_ = manifest;
#line 807 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp402_ = _tmp401_->aborted;
#line 807 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp403_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp402_, GEE_TYPE_COLLECTION, GeeCollection));
#line 807 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp404_ = _tmp403_;
#line 807 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp405_ = g_strdup_printf (_tmp400_, _tmp404_);
#line 807 "/home/jens/Source/shotwell/src/Dialogs.vala"
		both_message = _tmp405_;
#line 810 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp406_ = manifest;
#line 810 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp407_ = _tmp406_->aborted;
#line 810 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp408_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp407_, GEE_TYPE_COLLECTION, GeeCollection));
#line 810 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp409_ = _tmp408_;
#line 810 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp410_ = ngettext ("1 file skipped due to user cancel:\n", "%d file skipped due to user cancel:\n", (gulong) _tmp409_);
#line 810 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp411_ = manifest;
#line 810 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp412_ = _tmp411_->aborted;
#line 810 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp413_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp412_, GEE_TYPE_COLLECTION, GeeCollection));
#line 810 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp414_ = _tmp413_;
#line 810 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp415_ = g_strdup_printf (_tmp410_, _tmp414_);
#line 810 "/home/jens/Source/shotwell/src/Dialogs.vala"
		neither_message = _tmp415_;
#line 814 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp416_ = message;
#line 814 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp417_ = manifest;
#line 814 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp418_ = _tmp417_->aborted;
#line 814 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp419_ = photos_message;
#line 814 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp420_ = videos_message;
#line 814 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp421_ = both_message;
#line 814 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp422_ = neither_message;
#line 814 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp423_ = import_ui_get_media_specific_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp418_, GEE_TYPE_COLLECTION, GeeCollection), _tmp419_, _tmp420_, _tmp421_, _tmp422_);
#line 814 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp424_ = _tmp423_;
#line 814 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp425_ = g_strconcat (_tmp416_, _tmp424_, NULL);
#line 814 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (message);
#line 814 "/home/jens/Source/shotwell/src/Dialogs.vala"
		message = _tmp425_;
#line 814 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp424_);
#line 817 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp426_ = message;
#line 817 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp427_ = manifest;
#line 817 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp428_ = _tmp427_->aborted;
#line 817 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp429_ = show_dest_id;
#line 817 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp430_ = import_ui_generate_import_failure_list (_tmp428_, _tmp429_);
#line 817 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp431_ = _tmp430_;
#line 817 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp432_ = g_strconcat (_tmp426_, _tmp431_, NULL);
#line 817 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (message);
#line 817 "/home/jens/Source/shotwell/src/Dialogs.vala"
		message = _tmp432_;
#line 817 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp431_);
#line 797 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (neither_message);
#line 797 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (both_message);
#line 797 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (videos_message);
#line 797 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (photos_message);
#line 8016 "Dialogs.c"
	}
#line 820 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp433_ = manifest;
#line 820 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp434_ = _tmp433_->success;
#line 820 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp435_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp434_, GEE_TYPE_COLLECTION, GeeCollection));
#line 820 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp436_ = _tmp435_;
#line 820 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp436_ > 0) {
#line 8028 "Dialogs.c"
		const gchar* _tmp437_ = NULL;
		gint _tmp438_ = 0;
		gint _tmp439_ = 0;
		gchar* photos_message = NULL;
		ImportManifest* _tmp442_ = NULL;
		GeeList* _tmp443_ = NULL;
		gint _tmp444_ = 0;
		gint _tmp445_ = 0;
		const gchar* _tmp446_ = NULL;
		ImportManifest* _tmp447_ = NULL;
		GeeList* _tmp448_ = NULL;
		gint _tmp449_ = 0;
		gint _tmp450_ = 0;
		gchar* _tmp451_ = NULL;
		gchar* videos_message = NULL;
		ImportManifest* _tmp452_ = NULL;
		GeeList* _tmp453_ = NULL;
		gint _tmp454_ = 0;
		gint _tmp455_ = 0;
		const gchar* _tmp456_ = NULL;
		ImportManifest* _tmp457_ = NULL;
		GeeList* _tmp458_ = NULL;
		gint _tmp459_ = 0;
		gint _tmp460_ = 0;
		gchar* _tmp461_ = NULL;
		gchar* both_message = NULL;
		ImportManifest* _tmp462_ = NULL;
		GeeList* _tmp463_ = NULL;
		gint _tmp464_ = 0;
		gint _tmp465_ = 0;
		const gchar* _tmp466_ = NULL;
		ImportManifest* _tmp467_ = NULL;
		GeeList* _tmp468_ = NULL;
		gint _tmp469_ = 0;
		gint _tmp470_ = 0;
		gchar* _tmp471_ = NULL;
		const gchar* _tmp472_ = NULL;
		ImportManifest* _tmp473_ = NULL;
		GeeList* _tmp474_ = NULL;
		const gchar* _tmp475_ = NULL;
		const gchar* _tmp476_ = NULL;
		const gchar* _tmp477_ = NULL;
		gchar* _tmp478_ = NULL;
		gchar* _tmp479_ = NULL;
		gchar* _tmp480_ = NULL;
#line 821 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp437_ = message;
#line 821 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp438_ = strlen (_tmp437_);
#line 821 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp439_ = _tmp438_;
#line 821 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp439_ > 0) {
#line 8082 "Dialogs.c"
			const gchar* _tmp440_ = NULL;
			gchar* _tmp441_ = NULL;
#line 822 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp440_ = message;
#line 822 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp441_ = g_strconcat (_tmp440_, "\n", NULL);
#line 822 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (message);
#line 822 "/home/jens/Source/shotwell/src/Dialogs.vala"
			message = _tmp441_;
#line 8093 "Dialogs.c"
		}
#line 824 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp442_ = manifest;
#line 824 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp443_ = _tmp442_->success;
#line 824 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp444_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp443_, GEE_TYPE_COLLECTION, GeeCollection));
#line 824 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp445_ = _tmp444_;
#line 824 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp446_ = ngettext ("1 photo successfully imported.\n", "%d photos successfully imported.\n", (gulong) _tmp445_);
#line 824 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp447_ = manifest;
#line 824 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp448_ = _tmp447_->success;
#line 824 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp449_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp448_, GEE_TYPE_COLLECTION, GeeCollection));
#line 824 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp450_ = _tmp449_;
#line 824 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp451_ = g_strdup_printf (_tmp446_, _tmp450_);
#line 824 "/home/jens/Source/shotwell/src/Dialogs.vala"
		photos_message = _tmp451_;
#line 827 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp452_ = manifest;
#line 827 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp453_ = _tmp452_->success;
#line 827 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp454_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp453_, GEE_TYPE_COLLECTION, GeeCollection));
#line 827 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp455_ = _tmp454_;
#line 827 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp456_ = ngettext ("1 video successfully imported.\n", "%d videos successfully imported.\n", (gulong) _tmp455_);
#line 827 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp457_ = manifest;
#line 827 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp458_ = _tmp457_->success;
#line 827 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp459_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp458_, GEE_TYPE_COLLECTION, GeeCollection));
#line 827 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp460_ = _tmp459_;
#line 827 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp461_ = g_strdup_printf (_tmp456_, _tmp460_);
#line 827 "/home/jens/Source/shotwell/src/Dialogs.vala"
		videos_message = _tmp461_;
#line 830 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp462_ = manifest;
#line 830 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp463_ = _tmp462_->success;
#line 830 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp464_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp463_, GEE_TYPE_COLLECTION, GeeCollection));
#line 830 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp465_ = _tmp464_;
#line 830 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp466_ = ngettext ("1 photo/video successfully imported.\n", "%d photos/videos successfully imported.\n", (gulong) _tmp465_);
#line 830 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp467_ = manifest;
#line 830 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp468_ = _tmp467_->success;
#line 830 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp469_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp468_, GEE_TYPE_COLLECTION, GeeCollection));
#line 830 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp470_ = _tmp469_;
#line 830 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp471_ = g_strdup_printf (_tmp466_, _tmp470_);
#line 830 "/home/jens/Source/shotwell/src/Dialogs.vala"
		both_message = _tmp471_;
#line 834 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp472_ = message;
#line 834 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp473_ = manifest;
#line 834 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp474_ = _tmp473_->success;
#line 834 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp475_ = photos_message;
#line 834 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp476_ = videos_message;
#line 834 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp477_ = both_message;
#line 834 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp478_ = import_ui_get_media_specific_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp474_, GEE_TYPE_COLLECTION, GeeCollection), _tmp475_, _tmp476_, _tmp477_, "");
#line 834 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp479_ = _tmp478_;
#line 834 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp480_ = g_strconcat (_tmp472_, _tmp479_, NULL);
#line 834 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (message);
#line 834 "/home/jens/Source/shotwell/src/Dialogs.vala"
		message = _tmp480_;
#line 834 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp479_);
#line 820 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (both_message);
#line 820 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (videos_message);
#line 820 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (photos_message);
#line 8191 "Dialogs.c"
	}
#line 838 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp481_ = manifest;
#line 838 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp482_ = _tmp481_->success;
#line 838 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp483_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp482_, GEE_TYPE_COLLECTION, GeeCollection));
#line 838 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp484_ = _tmp483_;
#line 838 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp485_ = manifest;
#line 838 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp486_ = _tmp485_->failed;
#line 838 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp487_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp486_, GEE_TYPE_COLLECTION, GeeCollection));
#line 838 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp488_ = _tmp487_;
#line 838 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp489_ = manifest;
#line 838 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp490_ = _tmp489_->camera_failed;
#line 838 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp491_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp490_, GEE_TYPE_COLLECTION, GeeCollection));
#line 838 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp492_ = _tmp491_;
#line 838 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp493_ = manifest;
#line 838 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp494_ = _tmp493_->skipped_photos;
#line 838 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp495_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp494_, GEE_TYPE_COLLECTION, GeeCollection));
#line 838 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp496_ = _tmp495_;
#line 838 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp497_ = manifest;
#line 838 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp498_ = _tmp497_->skipped_files;
#line 838 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp499_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp498_, GEE_TYPE_COLLECTION, GeeCollection));
#line 838 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp500_ = _tmp499_;
#line 838 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp501_ = manifest;
#line 838 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp502_ = _tmp501_->corrupt_files;
#line 838 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp503_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp502_, GEE_TYPE_COLLECTION, GeeCollection));
#line 838 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp504_ = _tmp503_;
#line 838 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp505_ = manifest;
#line 838 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp506_ = _tmp505_->already_imported;
#line 838 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp507_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp506_, GEE_TYPE_COLLECTION, GeeCollection));
#line 838 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp508_ = _tmp507_;
#line 838 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp509_ = manifest;
#line 838 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp510_ = _tmp509_->aborted;
#line 838 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp511_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp510_, GEE_TYPE_COLLECTION, GeeCollection));
#line 838 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp512_ = _tmp511_;
#line 838 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp513_ = manifest;
#line 838 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp514_ = _tmp513_->write_failed;
#line 838 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp515_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp514_, GEE_TYPE_COLLECTION, GeeCollection));
#line 838 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp516_ = _tmp515_;
#line 838 "/home/jens/Source/shotwell/src/Dialogs.vala"
	total = (((((((_tmp484_ + _tmp488_) + _tmp492_) + _tmp496_) + _tmp500_) + _tmp504_) + _tmp508_) + _tmp512_) + _tmp516_;
#line 841 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp517_ = total;
#line 841 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp518_ = manifest;
#line 841 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp519_ = _tmp518_->all;
#line 841 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp520_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp519_, GEE_TYPE_COLLECTION, GeeCollection));
#line 841 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp521_ = _tmp520_;
#line 841 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_vala_assert (_tmp517_ == _tmp521_, "total == manifest.all.size");
#line 845 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp522_ = total;
#line 845 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp522_ == 0) {
#line 8283 "Dialogs.c"
		const gchar* _tmp523_ = NULL;
		const gchar* _tmp524_ = NULL;
		gchar* _tmp525_ = NULL;
#line 846 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp523_ = message;
#line 846 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp524_ = _ ("No photos or videos imported.\n");
#line 846 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp525_ = g_strconcat (_tmp523_, _tmp524_, NULL);
#line 846 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (message);
#line 846 "/home/jens/Source/shotwell/src/Dialogs.vala"
		message = _tmp525_;
#line 8297 "Dialogs.c"
	}
#line 848 "/home/jens/Source/shotwell/src/Dialogs.vala"
	dialog = NULL;
#line 849 "/home/jens/Source/shotwell/src/Dialogs.vala"
	dialog_response = (gint) GTK_RESPONSE_NONE;
#line 850 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp526_ = question;
#line 850 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp526_ == NULL) {
#line 8307 "Dialogs.c"
		AppWindow* _tmp527_ = NULL;
		AppWindow* _tmp528_ = NULL;
		const gchar* _tmp529_ = NULL;
		GtkMessageDialog* _tmp530_ = NULL;
		GtkMessageDialog* _tmp531_ = NULL;
		const gchar* _tmp532_ = NULL;
		GtkWidget* save_results_button = NULL;
		GtkMessageDialog* _tmp533_ = NULL;
		GtkWidget* _tmp534_ = NULL;
		GtkWidget* _tmp535_ = NULL;
		GtkWidget* _tmp536_ = NULL;
		ImportManifest* _tmp537_ = NULL;
		GeeList* _tmp538_ = NULL;
		gint _tmp539_ = 0;
		gint _tmp540_ = 0;
		ImportManifest* _tmp541_ = NULL;
		GeeList* _tmp542_ = NULL;
		gint _tmp543_ = 0;
		gint _tmp544_ = 0;
		GtkWidget* ok_button = NULL;
		GtkMessageDialog* _tmp545_ = NULL;
		GtkWidget* _tmp546_ = NULL;
		GtkWidget* _tmp547_ = NULL;
		GtkMessageDialog* _tmp548_ = NULL;
		GtkWidget* _tmp549_ = NULL;
		GtkWindow* dialog_parent = NULL;
		GtkMessageDialog* _tmp550_ = NULL;
		GtkContainer* _tmp551_ = NULL;
		GtkWindow* _tmp552_ = NULL;
		GtkMessageDialog* _tmp553_ = NULL;
		gint _tmp554_ = 0;
		GtkMessageDialog* _tmp555_ = NULL;
		gint _tmp556_ = 0;
#line 851 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp527_ = app_window_get_instance ();
#line 851 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp528_ = _tmp527_;
#line 851 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp529_ = message;
#line 851 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp530_ = (GtkMessageDialog*) gtk_message_dialog_new (G_TYPE_CHECK_INSTANCE_CAST (_tmp528_, gtk_window_get_type (), GtkWindow), GTK_DIALOG_MODAL, GTK_MESSAGE_INFO, GTK_BUTTONS_NONE, "%s", _tmp529_);
#line 851 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_object_ref_sink (_tmp530_);
#line 851 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (dialog);
#line 851 "/home/jens/Source/shotwell/src/Dialogs.vala"
		dialog = _tmp530_;
#line 851 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (_tmp528_);
#line 853 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp531_ = dialog;
#line 853 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp532_ = _ ("Import Complete");
#line 853 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_window_set_title (G_TYPE_CHECK_INSTANCE_CAST (_tmp531_, gtk_window_get_type (), GtkWindow), _tmp532_);
#line 854 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp533_ = dialog;
#line 854 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp534_ = gtk_dialog_add_button (G_TYPE_CHECK_INSTANCE_CAST (_tmp533_, gtk_dialog_get_type (), GtkDialog), IMPORT_UI_SAVE_RESULTS_BUTTON_NAME, IMPORT_UI_SAVE_RESULTS_RESPONSE_ID);
#line 854 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp535_ = _g_object_ref0 (_tmp534_);
#line 854 "/home/jens/Source/shotwell/src/Dialogs.vala"
		save_results_button = _tmp535_;
#line 856 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp536_ = save_results_button;
#line 856 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp537_ = manifest;
#line 856 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp538_ = _tmp537_->success;
#line 856 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp539_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp538_, GEE_TYPE_COLLECTION, GeeCollection));
#line 856 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp540_ = _tmp539_;
#line 856 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp541_ = manifest;
#line 856 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp542_ = _tmp541_->all;
#line 856 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp543_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp542_, GEE_TYPE_COLLECTION, GeeCollection));
#line 856 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp544_ = _tmp543_;
#line 856 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_widget_set_visible (_tmp536_, _tmp540_ < _tmp544_);
#line 857 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp545_ = dialog;
#line 857 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp546_ = gtk_dialog_add_button (G_TYPE_CHECK_INSTANCE_CAST (_tmp545_, gtk_dialog_get_type (), GtkDialog), RESOURCES_OK_LABEL, (gint) GTK_RESPONSE_OK);
#line 857 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp547_ = _g_object_ref0 (_tmp546_);
#line 857 "/home/jens/Source/shotwell/src/Dialogs.vala"
		ok_button = _tmp547_;
#line 858 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp548_ = dialog;
#line 858 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp549_ = ok_button;
#line 858 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_window_set_default (G_TYPE_CHECK_INSTANCE_CAST (_tmp548_, gtk_window_get_type (), GtkWindow), _tmp549_);
#line 860 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp550_ = dialog;
#line 860 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp551_ = (GtkContainer*) gtk_widget_get_parent (G_TYPE_CHECK_INSTANCE_CAST (_tmp550_, gtk_widget_get_type (), GtkWidget));
#line 860 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp552_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp551_, gtk_window_get_type (), GtkWindow));
#line 860 "/home/jens/Source/shotwell/src/Dialogs.vala"
		dialog_parent = _tmp552_;
#line 861 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp553_ = dialog;
#line 861 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp554_ = gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (_tmp553_, gtk_dialog_get_type (), GtkDialog));
#line 861 "/home/jens/Source/shotwell/src/Dialogs.vala"
		dialog_response = _tmp554_;
#line 862 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp555_ = dialog;
#line 862 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (_tmp555_, gtk_widget_get_type (), GtkWidget));
#line 864 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp556_ = dialog_response;
#line 864 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp556_ == IMPORT_UI_SAVE_RESULTS_RESPONSE_ID) {
#line 8427 "Dialogs.c"
			GtkWindow* _tmp557_ = NULL;
			ImportManifest* _tmp558_ = NULL;
			gchar* _tmp559_ = NULL;
			gchar* _tmp560_ = NULL;
#line 865 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp557_ = dialog_parent;
#line 865 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp558_ = manifest;
#line 865 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp559_ = import_ui_create_result_report_from_manifest (_tmp558_);
#line 865 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp560_ = _tmp559_;
#line 865 "/home/jens/Source/shotwell/src/Dialogs.vala"
			import_ui_save_import_results (_tmp557_, _tmp560_);
#line 865 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (_tmp560_);
#line 8444 "Dialogs.c"
		}
#line 850 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (dialog_parent);
#line 850 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (ok_button);
#line 850 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (save_results_button);
#line 8452 "Dialogs.c"
	} else {
		const gchar* _tmp561_ = NULL;
		ImportUIQuestionParams* _tmp562_ = NULL;
		const gchar* _tmp563_ = NULL;
		gchar* _tmp564_ = NULL;
		gchar* _tmp565_ = NULL;
		gchar* _tmp566_ = NULL;
		AppWindow* _tmp567_ = NULL;
		AppWindow* _tmp568_ = NULL;
		const gchar* _tmp569_ = NULL;
		GtkMessageDialog* _tmp570_ = NULL;
		GtkMessageDialog* _tmp571_ = NULL;
		const gchar* _tmp572_ = NULL;
		GtkWidget* save_results_button = NULL;
		GtkMessageDialog* _tmp573_ = NULL;
		GtkWidget* _tmp574_ = NULL;
		GtkWidget* _tmp575_ = NULL;
		GtkWidget* _tmp576_ = NULL;
		ImportManifest* _tmp577_ = NULL;
		GeeList* _tmp578_ = NULL;
		gint _tmp579_ = 0;
		gint _tmp580_ = 0;
		ImportManifest* _tmp581_ = NULL;
		GeeList* _tmp582_ = NULL;
		gint _tmp583_ = 0;
		gint _tmp584_ = 0;
		GtkWidget* no_button = NULL;
		GtkMessageDialog* _tmp585_ = NULL;
		ImportUIQuestionParams* _tmp586_ = NULL;
		const gchar* _tmp587_ = NULL;
		GtkWidget* _tmp588_ = NULL;
		GtkWidget* _tmp589_ = NULL;
		GtkMessageDialog* _tmp590_ = NULL;
		ImportUIQuestionParams* _tmp591_ = NULL;
		const gchar* _tmp592_ = NULL;
		GtkMessageDialog* _tmp593_ = NULL;
		GtkWidget* _tmp594_ = NULL;
		GtkMessageDialog* _tmp595_ = NULL;
		gint _tmp596_ = 0;
		GtkMessageDialog* _tmp604_ = NULL;
		GtkMessageDialog* _tmp605_ = NULL;
#line 868 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp561_ = message;
#line 868 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp562_ = question;
#line 868 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp563_ = _tmp562_->question;
#line 868 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp564_ = g_strconcat ("\n", _tmp563_, NULL);
#line 868 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp565_ = _tmp564_;
#line 868 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp566_ = g_strconcat (_tmp561_, _tmp565_, NULL);
#line 868 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (message);
#line 868 "/home/jens/Source/shotwell/src/Dialogs.vala"
		message = _tmp566_;
#line 868 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp565_);
#line 870 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp567_ = app_window_get_instance ();
#line 870 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp568_ = _tmp567_;
#line 870 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp569_ = message;
#line 870 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp570_ = (GtkMessageDialog*) gtk_message_dialog_new (G_TYPE_CHECK_INSTANCE_CAST (_tmp568_, gtk_window_get_type (), GtkWindow), GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_NONE, "%s", _tmp569_);
#line 870 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_object_ref_sink (_tmp570_);
#line 870 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (dialog);
#line 870 "/home/jens/Source/shotwell/src/Dialogs.vala"
		dialog = _tmp570_;
#line 870 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (_tmp568_);
#line 872 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp571_ = dialog;
#line 872 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp572_ = _ ("Import Complete");
#line 872 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_window_set_title (G_TYPE_CHECK_INSTANCE_CAST (_tmp571_, gtk_window_get_type (), GtkWindow), _tmp572_);
#line 873 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp573_ = dialog;
#line 873 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp574_ = gtk_dialog_add_button (G_TYPE_CHECK_INSTANCE_CAST (_tmp573_, gtk_dialog_get_type (), GtkDialog), IMPORT_UI_SAVE_RESULTS_BUTTON_NAME, IMPORT_UI_SAVE_RESULTS_RESPONSE_ID);
#line 873 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp575_ = _g_object_ref0 (_tmp574_);
#line 873 "/home/jens/Source/shotwell/src/Dialogs.vala"
		save_results_button = _tmp575_;
#line 875 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp576_ = save_results_button;
#line 875 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp577_ = manifest;
#line 875 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp578_ = _tmp577_->success;
#line 875 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp579_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp578_, GEE_TYPE_COLLECTION, GeeCollection));
#line 875 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp580_ = _tmp579_;
#line 875 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp581_ = manifest;
#line 875 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp582_ = _tmp581_->all;
#line 875 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp583_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp582_, GEE_TYPE_COLLECTION, GeeCollection));
#line 875 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp584_ = _tmp583_;
#line 875 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_widget_set_visible (_tmp576_, _tmp580_ < _tmp584_);
#line 876 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp585_ = dialog;
#line 876 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp586_ = question;
#line 876 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp587_ = _tmp586_->no_button;
#line 876 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp588_ = gtk_dialog_add_button (G_TYPE_CHECK_INSTANCE_CAST (_tmp585_, gtk_dialog_get_type (), GtkDialog), _tmp587_, (gint) GTK_RESPONSE_NO);
#line 876 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp589_ = _g_object_ref0 (_tmp588_);
#line 876 "/home/jens/Source/shotwell/src/Dialogs.vala"
		no_button = _tmp589_;
#line 877 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp590_ = dialog;
#line 877 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp591_ = question;
#line 877 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp592_ = _tmp591_->yes_button;
#line 877 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_dialog_add_button (G_TYPE_CHECK_INSTANCE_CAST (_tmp590_, gtk_dialog_get_type (), GtkDialog), _tmp592_, (gint) GTK_RESPONSE_YES);
#line 878 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp593_ = dialog;
#line 878 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp594_ = no_button;
#line 878 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_window_set_default (G_TYPE_CHECK_INSTANCE_CAST (_tmp593_, gtk_window_get_type (), GtkWindow), _tmp594_);
#line 880 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp595_ = dialog;
#line 880 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp596_ = gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (_tmp595_, gtk_dialog_get_type (), GtkDialog));
#line 880 "/home/jens/Source/shotwell/src/Dialogs.vala"
		dialog_response = _tmp596_;
#line 881 "/home/jens/Source/shotwell/src/Dialogs.vala"
		while (TRUE) {
#line 8596 "Dialogs.c"
			gint _tmp597_ = 0;
			GtkMessageDialog* _tmp598_ = NULL;
			ImportManifest* _tmp599_ = NULL;
			gchar* _tmp600_ = NULL;
			gchar* _tmp601_ = NULL;
			GtkMessageDialog* _tmp602_ = NULL;
			gint _tmp603_ = 0;
#line 881 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp597_ = dialog_response;
#line 881 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (!(_tmp597_ == IMPORT_UI_SAVE_RESULTS_RESPONSE_ID)) {
#line 881 "/home/jens/Source/shotwell/src/Dialogs.vala"
				break;
#line 8610 "Dialogs.c"
			}
#line 882 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp598_ = dialog;
#line 882 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp599_ = manifest;
#line 882 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp600_ = import_ui_create_result_report_from_manifest (_tmp599_);
#line 882 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp601_ = _tmp600_;
#line 882 "/home/jens/Source/shotwell/src/Dialogs.vala"
			import_ui_save_import_results (G_TYPE_CHECK_INSTANCE_CAST (_tmp598_, gtk_window_get_type (), GtkWindow), _tmp601_);
#line 882 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (_tmp601_);
#line 883 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp602_ = dialog;
#line 883 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp603_ = gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (_tmp602_, gtk_dialog_get_type (), GtkDialog));
#line 883 "/home/jens/Source/shotwell/src/Dialogs.vala"
			dialog_response = _tmp603_;
#line 8630 "Dialogs.c"
		}
#line 886 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp604_ = dialog;
#line 886 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_widget_hide (G_TYPE_CHECK_INSTANCE_CAST (_tmp604_, gtk_widget_get_type (), GtkWidget));
#line 887 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp605_ = dialog;
#line 887 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (_tmp605_, gtk_widget_get_type (), GtkWidget));
#line 850 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (no_button);
#line 850 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (save_results_button);
#line 8644 "Dialogs.c"
	}
#line 890 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp606_ = dialog_response;
#line 890 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = _tmp606_ == ((gint) GTK_RESPONSE_YES);
#line 890 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (dialog);
#line 890 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (message);
#line 890 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 8656 "Dialogs.c"
}


static guint8* string_get_data (const gchar* self, int* result_length1) {
	guint8* result;
	guint8* res = NULL;
	gint res_length1 = 0;
	gint _res_size_ = 0;
	gint _tmp0_ = 0;
	gint _tmp1_ = 0;
	gint _tmp2_ = 0;
	guint8* _tmp3_ = NULL;
	gint _tmp3__length1 = 0;
	guint8* _tmp4_ = NULL;
	gint _tmp4__length1 = 0;
#line 1398 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1399 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	res = (guint8*) self;
#line 1399 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	res_length1 = -1;
#line 1399 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_res_size_ = res_length1;
#line 1400 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp0_ = strlen (self);
#line 1400 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp1_ = _tmp0_;
#line 1400 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	res_length1 = (gint) _tmp1_;
#line 1400 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp2_ = res_length1;
#line 1401 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp3_ = res;
#line 1401 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp3__length1 = res_length1;
#line 1401 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp4_ = _tmp3_;
#line 1401 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp4__length1 = _tmp3__length1;
#line 1401 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	if (result_length1) {
#line 1401 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		*result_length1 = _tmp4__length1;
#line 8700 "Dialogs.c"
	}
#line 1401 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	result = _tmp4_;
#line 1401 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	return result;
#line 8706 "Dialogs.c"
}


void import_ui_save_import_results (GtkWindow* chooser_dialog_parent, const gchar* results_log) {
	GtkFileChooserDialog* chooser_dialog = NULL;
	GtkWindow* _tmp0_ = NULL;
	GtkFileChooserDialog* _tmp1_ = NULL;
	GtkFileChooserDialog* _tmp2_ = NULL;
	GtkFileChooserDialog* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	GtkFileChooserDialog* _tmp5_ = NULL;
	GtkFileChooserDialog* _tmp6_ = NULL;
	gint dialog_result = 0;
	GtkFileChooserDialog* _tmp7_ = NULL;
	gint _tmp8_ = 0;
	GFile* chosen_file = NULL;
	GtkFileChooserDialog* _tmp9_ = NULL;
	GFile* _tmp10_ = NULL;
	GtkFileChooserDialog* _tmp11_ = NULL;
	GtkFileChooserDialog* _tmp12_ = NULL;
	gboolean _tmp13_ = FALSE;
	gint _tmp14_ = 0;
	GError * _inner_error_ = NULL;
#line 893 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail ((chooser_dialog_parent == NULL) || GTK_IS_WINDOW (chooser_dialog_parent));
#line 893 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (results_log != NULL);
#line 894 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = chooser_dialog_parent;
#line 894 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = (GtkFileChooserDialog*) gtk_file_chooser_dialog_new (IMPORT_UI_SAVE_RESULTS_FILE_CHOOSER_TITLE, _tmp0_, GTK_FILE_CHOOSER_ACTION_SAVE, RESOURCES_CANCEL_LABEL, GTK_RESPONSE_CANCEL, RESOURCES_SAVE_AS_LABEL, GTK_RESPONSE_ACCEPT, NULL, NULL);
#line 894 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp1_);
#line 894 "/home/jens/Source/shotwell/src/Dialogs.vala"
	chooser_dialog = _tmp1_;
#line 897 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = chooser_dialog;
#line 897 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_file_chooser_set_do_overwrite_confirmation (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, GTK_TYPE_FILE_CHOOSER, GtkFileChooser), TRUE);
#line 898 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = chooser_dialog;
#line 898 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = g_get_home_dir ();
#line 898 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_file_chooser_set_current_folder (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, GTK_TYPE_FILE_CHOOSER, GtkFileChooser), _tmp4_);
#line 899 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = chooser_dialog;
#line 899 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_file_chooser_set_current_name (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, GTK_TYPE_FILE_CHOOSER, GtkFileChooser), "Shotwell Import Log.txt");
#line 900 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = chooser_dialog;
#line 900 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_file_chooser_set_local_only (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, GTK_TYPE_FILE_CHOOSER, GtkFileChooser), FALSE);
#line 902 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = chooser_dialog;
#line 902 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, gtk_dialog_get_type (), GtkDialog));
#line 902 "/home/jens/Source/shotwell/src/Dialogs.vala"
	dialog_result = _tmp8_;
#line 903 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = chooser_dialog;
#line 903 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp10_ = gtk_file_chooser_get_file (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, GTK_TYPE_FILE_CHOOSER, GtkFileChooser));
#line 903 "/home/jens/Source/shotwell/src/Dialogs.vala"
	chosen_file = _tmp10_;
#line 904 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp11_ = chooser_dialog;
#line 904 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_hide (G_TYPE_CHECK_INSTANCE_CAST (_tmp11_, gtk_widget_get_type (), GtkWidget));
#line 905 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp12_ = chooser_dialog;
#line 905 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (_tmp12_, gtk_widget_get_type (), GtkWidget));
#line 907 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp14_ = dialog_result;
#line 907 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp14_ == ((gint) GTK_RESPONSE_ACCEPT)) {
#line 8784 "Dialogs.c"
		GFile* _tmp15_ = NULL;
#line 907 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp15_ = chosen_file;
#line 907 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp13_ = _tmp15_ != NULL;
#line 8790 "Dialogs.c"
	} else {
#line 907 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp13_ = FALSE;
#line 8794 "Dialogs.c"
	}
#line 907 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp13_) {
#line 8798 "Dialogs.c"
		{
			GFileOutputStream* outstream = NULL;
			GFile* _tmp16_ = NULL;
			GFileOutputStream* _tmp17_ = NULL;
			GFileOutputStream* _tmp18_ = NULL;
			const gchar* _tmp19_ = NULL;
			guint8* _tmp20_ = NULL;
			gint _tmp20__length1 = 0;
			guint8* _tmp21_ = NULL;
			gint _tmp21__length1 = 0;
			GFileOutputStream* _tmp22_ = NULL;
#line 909 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp16_ = chosen_file;
#line 909 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp17_ = g_file_replace (_tmp16_, NULL, FALSE, G_FILE_CREATE_NONE, NULL, &_inner_error_);
#line 909 "/home/jens/Source/shotwell/src/Dialogs.vala"
			outstream = _tmp17_;
#line 909 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 8818 "Dialogs.c"
				goto __catch411_g_error;
			}
#line 910 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp18_ = outstream;
#line 910 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp19_ = results_log;
#line 910 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp20_ = string_get_data (_tmp19_, &_tmp20__length1);
#line 910 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp21_ = _tmp20_;
#line 910 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp21__length1 = _tmp20__length1;
#line 910 "/home/jens/Source/shotwell/src/Dialogs.vala"
			g_output_stream_write (G_TYPE_CHECK_INSTANCE_CAST (_tmp18_, G_TYPE_OUTPUT_STREAM, GOutputStream), _tmp21_, (gsize) _tmp21__length1, NULL, &_inner_error_);
#line 910 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 910 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_object_unref0 (outstream);
#line 8837 "Dialogs.c"
				goto __catch411_g_error;
			}
#line 911 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp22_ = outstream;
#line 911 "/home/jens/Source/shotwell/src/Dialogs.vala"
			g_output_stream_close (G_TYPE_CHECK_INSTANCE_CAST (_tmp22_, G_TYPE_OUTPUT_STREAM, GOutputStream), NULL, &_inner_error_);
#line 911 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 911 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_object_unref0 (outstream);
#line 8848 "Dialogs.c"
				goto __catch411_g_error;
			}
#line 908 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_object_unref0 (outstream);
#line 8853 "Dialogs.c"
		}
		goto __finally411;
		__catch411_g_error:
		{
			GError* err = NULL;
			GFile* _tmp23_ = NULL;
			gchar* _tmp24_ = NULL;
			gchar* _tmp25_ = NULL;
			GError* _tmp26_ = NULL;
			const gchar* _tmp27_ = NULL;
#line 908 "/home/jens/Source/shotwell/src/Dialogs.vala"
			err = _inner_error_;
#line 908 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_inner_error_ = NULL;
#line 913 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp23_ = chosen_file;
#line 913 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp24_ = g_file_get_path (_tmp23_);
#line 913 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp25_ = _tmp24_;
#line 913 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp26_ = err;
#line 913 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp27_ = _tmp26_->message;
#line 913 "/home/jens/Source/shotwell/src/Dialogs.vala"
			g_critical ("Dialogs.vala:913: couldn't save import results to log file %s: %s", _tmp25_, _tmp27_);
#line 913 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (_tmp25_);
#line 908 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_error_free0 (err);
#line 8884 "Dialogs.c"
		}
		__finally411:
#line 908 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 908 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_object_unref0 (chosen_file);
#line 908 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_object_unref0 (chooser_dialog);
#line 908 "/home/jens/Source/shotwell/src/Dialogs.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 908 "/home/jens/Source/shotwell/src/Dialogs.vala"
			g_clear_error (&_inner_error_);
#line 908 "/home/jens/Source/shotwell/src/Dialogs.vala"
			return;
#line 8899 "Dialogs.c"
		}
	}
#line 893 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (chosen_file);
#line 893 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (chooser_dialog);
#line 8906 "Dialogs.c"
}


static gboolean _text_entry_dialog_mediator_on_modify_validate_text_entry_dialog_on_modify_validate_type (const gchar* text, gpointer self) {
	gboolean result;
	result = text_entry_dialog_mediator_on_modify_validate ((TextEntryDialogMediator*) self, text);
#line 930 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 8915 "Dialogs.c"
}


TextEntryDialogMediator* text_entry_dialog_mediator_construct (GType object_type, const gchar* title, const gchar* label, const gchar* initial_text, GeeCollection* completion_list, const gchar* completion_delimiter) {
	TextEntryDialogMediator* self = NULL;
	GtkBuilder* builder = NULL;
	GtkBuilder* _tmp0_ = NULL;
	TextEntryDialog* _tmp1_ = NULL;
	TextEntryDialog* _tmp2_ = NULL;
	GtkBox* _tmp3_ = NULL;
	GObject* _tmp4_ = NULL;
	TextEntryDialog* _tmp5_ = NULL;
	TextEntryDialog* _tmp6_ = NULL;
	const gchar* _tmp7_ = NULL;
	const gchar* _tmp8_ = NULL;
	const gchar* _tmp9_ = NULL;
	GeeCollection* _tmp10_ = NULL;
	const gchar* _tmp11_ = NULL;
#line 924 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (title != NULL, NULL);
#line 924 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (label != NULL, NULL);
#line 924 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail ((completion_list == NULL) || GEE_IS_COLLECTION (completion_list), NULL);
#line 924 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = (TextEntryDialogMediator*) g_type_create_instance (object_type);
#line 926 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = app_window_create_builder ("shotwell.ui", NULL);
#line 926 "/home/jens/Source/shotwell/src/Dialogs.vala"
	builder = _tmp0_;
#line 927 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = text_entry_dialog_new ();
#line 927 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp1_);
#line 927 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->dialog);
#line 927 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->dialog = _tmp1_;
#line 928 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = self->priv->dialog;
#line 928 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = (GtkBox*) gtk_dialog_get_content_area (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, gtk_dialog_get_type (), GtkDialog));
#line 928 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = gtk_builder_get_object (builder, "dialog-vbox2");
#line 928 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_container_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, gtk_container_get_type (), GtkContainer), G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, gtk_box_get_type (), GtkBox), gtk_widget_get_type (), GtkWidget));
#line 929 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = self->priv->dialog;
#line 929 "/home/jens/Source/shotwell/src/Dialogs.vala"
	text_entry_dialog_set_builder (_tmp5_, builder);
#line 930 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = self->priv->dialog;
#line 930 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = title;
#line 930 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = label;
#line 930 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = initial_text;
#line 930 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp10_ = completion_list;
#line 930 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp11_ = completion_delimiter;
#line 930 "/home/jens/Source/shotwell/src/Dialogs.vala"
	text_entry_dialog_setup (_tmp6_, _text_entry_dialog_mediator_on_modify_validate_text_entry_dialog_on_modify_validate_type, self, _tmp7_, _tmp8_, _tmp9_, _tmp10_, _tmp11_);
#line 924 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (builder);
#line 924 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return self;
#line 8984 "Dialogs.c"
}


static gboolean text_entry_dialog_mediator_real_on_modify_validate (TextEntryDialogMediator* self, const gchar* text) {
	gboolean result = FALSE;
#line 933 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (text != NULL, FALSE);
#line 934 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = TRUE;
#line 934 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 8996 "Dialogs.c"
}


gboolean text_entry_dialog_mediator_on_modify_validate (TextEntryDialogMediator* self, const gchar* text) {
#line 933 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_TEXT_ENTRY_DIALOG_MEDIATOR (self), FALSE);
#line 933 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return TEXT_ENTRY_DIALOG_MEDIATOR_GET_CLASS (self)->on_modify_validate (self, text);
#line 9005 "Dialogs.c"
}


gchar* _text_entry_dialog_mediator_execute (TextEntryDialogMediator* self) {
	gchar* result = NULL;
	TextEntryDialog* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 937 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_TEXT_ENTRY_DIALOG_MEDIATOR (self), NULL);
#line 938 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = self->priv->dialog;
#line 938 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = text_entry_dialog_execute (_tmp0_);
#line 938 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = _tmp1_;
#line 938 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 9023 "Dialogs.c"
}


static void value_text_entry_dialog_mediator_init (GValue* value) {
#line 921 "/home/jens/Source/shotwell/src/Dialogs.vala"
	value->data[0].v_pointer = NULL;
#line 9030 "Dialogs.c"
}


static void value_text_entry_dialog_mediator_free_value (GValue* value) {
#line 921 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (value->data[0].v_pointer) {
#line 921 "/home/jens/Source/shotwell/src/Dialogs.vala"
		text_entry_dialog_mediator_unref (value->data[0].v_pointer);
#line 9039 "Dialogs.c"
	}
}


static void value_text_entry_dialog_mediator_copy_value (const GValue* src_value, GValue* dest_value) {
#line 921 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (src_value->data[0].v_pointer) {
#line 921 "/home/jens/Source/shotwell/src/Dialogs.vala"
		dest_value->data[0].v_pointer = text_entry_dialog_mediator_ref (src_value->data[0].v_pointer);
#line 9049 "Dialogs.c"
	} else {
#line 921 "/home/jens/Source/shotwell/src/Dialogs.vala"
		dest_value->data[0].v_pointer = NULL;
#line 9053 "Dialogs.c"
	}
}


static gpointer value_text_entry_dialog_mediator_peek_pointer (const GValue* value) {
#line 921 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return value->data[0].v_pointer;
#line 9061 "Dialogs.c"
}


static gchar* value_text_entry_dialog_mediator_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
#line 921 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (collect_values[0].v_pointer) {
#line 9068 "Dialogs.c"
		TextEntryDialogMediator* object;
		object = collect_values[0].v_pointer;
#line 921 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (object->parent_instance.g_class == NULL) {
#line 921 "/home/jens/Source/shotwell/src/Dialogs.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 9075 "Dialogs.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 921 "/home/jens/Source/shotwell/src/Dialogs.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 9079 "Dialogs.c"
		}
#line 921 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = text_entry_dialog_mediator_ref (object);
#line 9083 "Dialogs.c"
	} else {
#line 921 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = NULL;
#line 9087 "Dialogs.c"
	}
#line 921 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return NULL;
#line 9091 "Dialogs.c"
}


static gchar* value_text_entry_dialog_mediator_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	TextEntryDialogMediator** object_p;
	object_p = collect_values[0].v_pointer;
#line 921 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (!object_p) {
#line 921 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 9102 "Dialogs.c"
	}
#line 921 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (!value->data[0].v_pointer) {
#line 921 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*object_p = NULL;
#line 9108 "Dialogs.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 921 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*object_p = value->data[0].v_pointer;
#line 9112 "Dialogs.c"
	} else {
#line 921 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*object_p = text_entry_dialog_mediator_ref (value->data[0].v_pointer);
#line 9116 "Dialogs.c"
	}
#line 921 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return NULL;
#line 9120 "Dialogs.c"
}


GParamSpec* param_spec_text_entry_dialog_mediator (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
	ParamSpecTextEntryDialogMediator* spec;
#line 921 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (g_type_is_a (object_type, TYPE_TEXT_ENTRY_DIALOG_MEDIATOR), NULL);
#line 921 "/home/jens/Source/shotwell/src/Dialogs.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 921 "/home/jens/Source/shotwell/src/Dialogs.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 921 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return G_PARAM_SPEC (spec);
#line 9134 "Dialogs.c"
}


gpointer value_get_text_entry_dialog_mediator (const GValue* value) {
#line 921 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_TEXT_ENTRY_DIALOG_MEDIATOR), NULL);
#line 921 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return value->data[0].v_pointer;
#line 9143 "Dialogs.c"
}


void value_set_text_entry_dialog_mediator (GValue* value, gpointer v_object) {
	TextEntryDialogMediator* old;
#line 921 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_TEXT_ENTRY_DIALOG_MEDIATOR));
#line 921 "/home/jens/Source/shotwell/src/Dialogs.vala"
	old = value->data[0].v_pointer;
#line 921 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (v_object) {
#line 921 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, TYPE_TEXT_ENTRY_DIALOG_MEDIATOR));
#line 921 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 921 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = v_object;
#line 921 "/home/jens/Source/shotwell/src/Dialogs.vala"
		text_entry_dialog_mediator_ref (value->data[0].v_pointer);
#line 9163 "Dialogs.c"
	} else {
#line 921 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = NULL;
#line 9167 "Dialogs.c"
	}
#line 921 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (old) {
#line 921 "/home/jens/Source/shotwell/src/Dialogs.vala"
		text_entry_dialog_mediator_unref (old);
#line 9173 "Dialogs.c"
	}
}


void value_take_text_entry_dialog_mediator (GValue* value, gpointer v_object) {
	TextEntryDialogMediator* old;
#line 921 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_TEXT_ENTRY_DIALOG_MEDIATOR));
#line 921 "/home/jens/Source/shotwell/src/Dialogs.vala"
	old = value->data[0].v_pointer;
#line 921 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (v_object) {
#line 921 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, TYPE_TEXT_ENTRY_DIALOG_MEDIATOR));
#line 921 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 921 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = v_object;
#line 9192 "Dialogs.c"
	} else {
#line 921 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = NULL;
#line 9196 "Dialogs.c"
	}
#line 921 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (old) {
#line 921 "/home/jens/Source/shotwell/src/Dialogs.vala"
		text_entry_dialog_mediator_unref (old);
#line 9202 "Dialogs.c"
	}
}


static void text_entry_dialog_mediator_class_init (TextEntryDialogMediatorClass * klass) {
#line 921 "/home/jens/Source/shotwell/src/Dialogs.vala"
	text_entry_dialog_mediator_parent_class = g_type_class_peek_parent (klass);
#line 921 "/home/jens/Source/shotwell/src/Dialogs.vala"
	((TextEntryDialogMediatorClass *) klass)->finalize = text_entry_dialog_mediator_finalize;
#line 921 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_type_class_add_private (klass, sizeof (TextEntryDialogMediatorPrivate));
#line 921 "/home/jens/Source/shotwell/src/Dialogs.vala"
	((TextEntryDialogMediatorClass *) klass)->on_modify_validate = text_entry_dialog_mediator_real_on_modify_validate;
#line 9216 "Dialogs.c"
}


static void text_entry_dialog_mediator_instance_init (TextEntryDialogMediator * self) {
#line 921 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv = TEXT_ENTRY_DIALOG_MEDIATOR_GET_PRIVATE (self);
#line 921 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->ref_count = 1;
#line 9225 "Dialogs.c"
}


static void text_entry_dialog_mediator_finalize (TextEntryDialogMediator* obj) {
	TextEntryDialogMediator * self;
#line 921 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_TEXT_ENTRY_DIALOG_MEDIATOR, TextEntryDialogMediator);
#line 921 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_handlers_destroy (self);
#line 922 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->dialog);
#line 9237 "Dialogs.c"
}


GType text_entry_dialog_mediator_get_type (void) {
	static volatile gsize text_entry_dialog_mediator_type_id__volatile = 0;
	if (g_once_init_enter (&text_entry_dialog_mediator_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { value_text_entry_dialog_mediator_init, value_text_entry_dialog_mediator_free_value, value_text_entry_dialog_mediator_copy_value, value_text_entry_dialog_mediator_peek_pointer, "p", value_text_entry_dialog_mediator_collect_value, "p", value_text_entry_dialog_mediator_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (TextEntryDialogMediatorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) text_entry_dialog_mediator_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TextEntryDialogMediator), 0, (GInstanceInitFunc) text_entry_dialog_mediator_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType text_entry_dialog_mediator_type_id;
		text_entry_dialog_mediator_type_id = g_type_register_fundamental (g_type_fundamental_next (), "TextEntryDialogMediator", &g_define_type_info, &g_define_type_fundamental_info, G_TYPE_FLAG_ABSTRACT);
		g_once_init_leave (&text_entry_dialog_mediator_type_id__volatile, text_entry_dialog_mediator_type_id);
	}
	return text_entry_dialog_mediator_type_id__volatile;
}


gpointer text_entry_dialog_mediator_ref (gpointer instance) {
	TextEntryDialogMediator* self;
	self = instance;
#line 921 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_atomic_int_inc (&self->ref_count);
#line 921 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return instance;
#line 9262 "Dialogs.c"
}


void text_entry_dialog_mediator_unref (gpointer instance) {
	TextEntryDialogMediator* self;
	self = instance;
#line 921 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 921 "/home/jens/Source/shotwell/src/Dialogs.vala"
		TEXT_ENTRY_DIALOG_MEDIATOR_GET_CLASS (self)->finalize (self);
#line 921 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 9275 "Dialogs.c"
	}
}


static gboolean _multi_text_entry_dialog_mediator_on_modify_validate_multi_text_entry_dialog_on_modify_validate_type (const gchar* text, gpointer self) {
	gboolean result;
	result = multi_text_entry_dialog_mediator_on_modify_validate ((MultiTextEntryDialogMediator*) self, text);
#line 950 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 9285 "Dialogs.c"
}


MultiTextEntryDialogMediator* multi_text_entry_dialog_mediator_construct (GType object_type, const gchar* title, const gchar* label, const gchar* initial_text) {
	MultiTextEntryDialogMediator* self = NULL;
	GtkBuilder* builder = NULL;
	GtkBuilder* _tmp0_ = NULL;
	MultiTextEntryDialog* _tmp1_ = NULL;
	MultiTextEntryDialog* _tmp2_ = NULL;
	GtkBox* _tmp3_ = NULL;
	GObject* _tmp4_ = NULL;
	MultiTextEntryDialog* _tmp5_ = NULL;
	MultiTextEntryDialog* _tmp6_ = NULL;
	const gchar* _tmp7_ = NULL;
	const gchar* _tmp8_ = NULL;
	const gchar* _tmp9_ = NULL;
#line 945 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (title != NULL, NULL);
#line 945 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (label != NULL, NULL);
#line 945 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = (MultiTextEntryDialogMediator*) g_type_create_instance (object_type);
#line 946 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = app_window_create_builder ("shotwell.ui", NULL);
#line 946 "/home/jens/Source/shotwell/src/Dialogs.vala"
	builder = _tmp0_;
#line 947 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = multi_text_entry_dialog_new ();
#line 947 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp1_);
#line 947 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->dialog);
#line 947 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->dialog = _tmp1_;
#line 948 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = self->priv->dialog;
#line 948 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = (GtkBox*) gtk_dialog_get_content_area (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, gtk_dialog_get_type (), GtkDialog));
#line 948 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = gtk_builder_get_object (builder, "dialog-vbox4");
#line 948 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_container_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, gtk_container_get_type (), GtkContainer), G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, gtk_box_get_type (), GtkBox), gtk_widget_get_type (), GtkWidget));
#line 949 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = self->priv->dialog;
#line 949 "/home/jens/Source/shotwell/src/Dialogs.vala"
	multi_text_entry_dialog_set_builder (_tmp5_, builder);
#line 950 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = self->priv->dialog;
#line 950 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = title;
#line 950 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = label;
#line 950 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = initial_text;
#line 950 "/home/jens/Source/shotwell/src/Dialogs.vala"
	multi_text_entry_dialog_setup (_tmp6_, _multi_text_entry_dialog_mediator_on_modify_validate_multi_text_entry_dialog_on_modify_validate_type, self, _tmp7_, _tmp8_, _tmp9_);
#line 945 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (builder);
#line 945 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return self;
#line 9346 "Dialogs.c"
}


static gboolean multi_text_entry_dialog_mediator_real_on_modify_validate (MultiTextEntryDialogMediator* self, const gchar* text) {
	gboolean result = FALSE;
#line 953 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (text != NULL, FALSE);
#line 954 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = TRUE;
#line 954 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 9358 "Dialogs.c"
}


gboolean multi_text_entry_dialog_mediator_on_modify_validate (MultiTextEntryDialogMediator* self, const gchar* text) {
#line 953 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR (self), FALSE);
#line 953 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return MULTI_TEXT_ENTRY_DIALOG_MEDIATOR_GET_CLASS (self)->on_modify_validate (self, text);
#line 9367 "Dialogs.c"
}


gchar* _multi_text_entry_dialog_mediator_execute (MultiTextEntryDialogMediator* self) {
	gchar* result = NULL;
	MultiTextEntryDialog* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 957 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR (self), NULL);
#line 958 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = self->priv->dialog;
#line 958 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = multi_text_entry_dialog_execute (_tmp0_);
#line 958 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = _tmp1_;
#line 958 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 9385 "Dialogs.c"
}


static void value_multi_text_entry_dialog_mediator_init (GValue* value) {
#line 942 "/home/jens/Source/shotwell/src/Dialogs.vala"
	value->data[0].v_pointer = NULL;
#line 9392 "Dialogs.c"
}


static void value_multi_text_entry_dialog_mediator_free_value (GValue* value) {
#line 942 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (value->data[0].v_pointer) {
#line 942 "/home/jens/Source/shotwell/src/Dialogs.vala"
		multi_text_entry_dialog_mediator_unref (value->data[0].v_pointer);
#line 9401 "Dialogs.c"
	}
}


static void value_multi_text_entry_dialog_mediator_copy_value (const GValue* src_value, GValue* dest_value) {
#line 942 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (src_value->data[0].v_pointer) {
#line 942 "/home/jens/Source/shotwell/src/Dialogs.vala"
		dest_value->data[0].v_pointer = multi_text_entry_dialog_mediator_ref (src_value->data[0].v_pointer);
#line 9411 "Dialogs.c"
	} else {
#line 942 "/home/jens/Source/shotwell/src/Dialogs.vala"
		dest_value->data[0].v_pointer = NULL;
#line 9415 "Dialogs.c"
	}
}


static gpointer value_multi_text_entry_dialog_mediator_peek_pointer (const GValue* value) {
#line 942 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return value->data[0].v_pointer;
#line 9423 "Dialogs.c"
}


static gchar* value_multi_text_entry_dialog_mediator_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
#line 942 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (collect_values[0].v_pointer) {
#line 9430 "Dialogs.c"
		MultiTextEntryDialogMediator* object;
		object = collect_values[0].v_pointer;
#line 942 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (object->parent_instance.g_class == NULL) {
#line 942 "/home/jens/Source/shotwell/src/Dialogs.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 9437 "Dialogs.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 942 "/home/jens/Source/shotwell/src/Dialogs.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 9441 "Dialogs.c"
		}
#line 942 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = multi_text_entry_dialog_mediator_ref (object);
#line 9445 "Dialogs.c"
	} else {
#line 942 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = NULL;
#line 9449 "Dialogs.c"
	}
#line 942 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return NULL;
#line 9453 "Dialogs.c"
}


static gchar* value_multi_text_entry_dialog_mediator_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	MultiTextEntryDialogMediator** object_p;
	object_p = collect_values[0].v_pointer;
#line 942 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (!object_p) {
#line 942 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 9464 "Dialogs.c"
	}
#line 942 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (!value->data[0].v_pointer) {
#line 942 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*object_p = NULL;
#line 9470 "Dialogs.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 942 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*object_p = value->data[0].v_pointer;
#line 9474 "Dialogs.c"
	} else {
#line 942 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*object_p = multi_text_entry_dialog_mediator_ref (value->data[0].v_pointer);
#line 9478 "Dialogs.c"
	}
#line 942 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return NULL;
#line 9482 "Dialogs.c"
}


GParamSpec* param_spec_multi_text_entry_dialog_mediator (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
	ParamSpecMultiTextEntryDialogMediator* spec;
#line 942 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (g_type_is_a (object_type, TYPE_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR), NULL);
#line 942 "/home/jens/Source/shotwell/src/Dialogs.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 942 "/home/jens/Source/shotwell/src/Dialogs.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 942 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return G_PARAM_SPEC (spec);
#line 9496 "Dialogs.c"
}


gpointer value_get_multi_text_entry_dialog_mediator (const GValue* value) {
#line 942 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR), NULL);
#line 942 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return value->data[0].v_pointer;
#line 9505 "Dialogs.c"
}


void value_set_multi_text_entry_dialog_mediator (GValue* value, gpointer v_object) {
	MultiTextEntryDialogMediator* old;
#line 942 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR));
#line 942 "/home/jens/Source/shotwell/src/Dialogs.vala"
	old = value->data[0].v_pointer;
#line 942 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (v_object) {
#line 942 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, TYPE_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR));
#line 942 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 942 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = v_object;
#line 942 "/home/jens/Source/shotwell/src/Dialogs.vala"
		multi_text_entry_dialog_mediator_ref (value->data[0].v_pointer);
#line 9525 "Dialogs.c"
	} else {
#line 942 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = NULL;
#line 9529 "Dialogs.c"
	}
#line 942 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (old) {
#line 942 "/home/jens/Source/shotwell/src/Dialogs.vala"
		multi_text_entry_dialog_mediator_unref (old);
#line 9535 "Dialogs.c"
	}
}


void value_take_multi_text_entry_dialog_mediator (GValue* value, gpointer v_object) {
	MultiTextEntryDialogMediator* old;
#line 942 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR));
#line 942 "/home/jens/Source/shotwell/src/Dialogs.vala"
	old = value->data[0].v_pointer;
#line 942 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (v_object) {
#line 942 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, TYPE_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR));
#line 942 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 942 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = v_object;
#line 9554 "Dialogs.c"
	} else {
#line 942 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = NULL;
#line 9558 "Dialogs.c"
	}
#line 942 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (old) {
#line 942 "/home/jens/Source/shotwell/src/Dialogs.vala"
		multi_text_entry_dialog_mediator_unref (old);
#line 9564 "Dialogs.c"
	}
}


static void multi_text_entry_dialog_mediator_class_init (MultiTextEntryDialogMediatorClass * klass) {
#line 942 "/home/jens/Source/shotwell/src/Dialogs.vala"
	multi_text_entry_dialog_mediator_parent_class = g_type_class_peek_parent (klass);
#line 942 "/home/jens/Source/shotwell/src/Dialogs.vala"
	((MultiTextEntryDialogMediatorClass *) klass)->finalize = multi_text_entry_dialog_mediator_finalize;
#line 942 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_type_class_add_private (klass, sizeof (MultiTextEntryDialogMediatorPrivate));
#line 942 "/home/jens/Source/shotwell/src/Dialogs.vala"
	((MultiTextEntryDialogMediatorClass *) klass)->on_modify_validate = multi_text_entry_dialog_mediator_real_on_modify_validate;
#line 9578 "Dialogs.c"
}


static void multi_text_entry_dialog_mediator_instance_init (MultiTextEntryDialogMediator * self) {
#line 942 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv = MULTI_TEXT_ENTRY_DIALOG_MEDIATOR_GET_PRIVATE (self);
#line 942 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->ref_count = 1;
#line 9587 "Dialogs.c"
}


static void multi_text_entry_dialog_mediator_finalize (MultiTextEntryDialogMediator* obj) {
	MultiTextEntryDialogMediator * self;
#line 942 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR, MultiTextEntryDialogMediator);
#line 942 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_handlers_destroy (self);
#line 943 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->dialog);
#line 9599 "Dialogs.c"
}


GType multi_text_entry_dialog_mediator_get_type (void) {
	static volatile gsize multi_text_entry_dialog_mediator_type_id__volatile = 0;
	if (g_once_init_enter (&multi_text_entry_dialog_mediator_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { value_multi_text_entry_dialog_mediator_init, value_multi_text_entry_dialog_mediator_free_value, value_multi_text_entry_dialog_mediator_copy_value, value_multi_text_entry_dialog_mediator_peek_pointer, "p", value_multi_text_entry_dialog_mediator_collect_value, "p", value_multi_text_entry_dialog_mediator_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (MultiTextEntryDialogMediatorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) multi_text_entry_dialog_mediator_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (MultiTextEntryDialogMediator), 0, (GInstanceInitFunc) multi_text_entry_dialog_mediator_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType multi_text_entry_dialog_mediator_type_id;
		multi_text_entry_dialog_mediator_type_id = g_type_register_fundamental (g_type_fundamental_next (), "MultiTextEntryDialogMediator", &g_define_type_info, &g_define_type_fundamental_info, G_TYPE_FLAG_ABSTRACT);
		g_once_init_leave (&multi_text_entry_dialog_mediator_type_id__volatile, multi_text_entry_dialog_mediator_type_id);
	}
	return multi_text_entry_dialog_mediator_type_id__volatile;
}


gpointer multi_text_entry_dialog_mediator_ref (gpointer instance) {
	MultiTextEntryDialogMediator* self;
	self = instance;
#line 942 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_atomic_int_inc (&self->ref_count);
#line 942 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return instance;
#line 9624 "Dialogs.c"
}


void multi_text_entry_dialog_mediator_unref (gpointer instance) {
	MultiTextEntryDialogMediator* self;
	self = instance;
#line 942 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 942 "/home/jens/Source/shotwell/src/Dialogs.vala"
		MULTI_TEXT_ENTRY_DIALOG_MEDIATOR_GET_CLASS (self)->finalize (self);
#line 942 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 9637 "Dialogs.c"
	}
}


gchar* build_alert_body_text (const gchar* primary_text, const gchar* secondary_text, gboolean should_escape) {
	gchar* result = NULL;
	gboolean _tmp0_ = FALSE;
	const gchar* _tmp9_ = NULL;
	gchar* _tmp10_ = NULL;
	gchar* _tmp11_ = NULL;
	const gchar* _tmp12_ = NULL;
	gchar* _tmp13_ = NULL;
	gchar* _tmp14_ = NULL;
#line 967 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = should_escape;
#line 967 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp0_) {
#line 9655 "Dialogs.c"
		const gchar* _tmp1_ = NULL;
		gchar* _tmp2_ = NULL;
		gchar* _tmp3_ = NULL;
		const gchar* _tmp4_ = NULL;
		gchar* _tmp5_ = NULL;
		gchar* _tmp6_ = NULL;
		gchar* _tmp7_ = NULL;
		gchar* _tmp8_ = NULL;
#line 968 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp1_ = primary_text;
#line 968 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp2_ = guarded_markup_escape_text (_tmp1_);
#line 968 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp3_ = _tmp2_;
#line 968 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp4_ = secondary_text;
#line 968 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp5_ = guarded_markup_escape_text (_tmp4_);
#line 968 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp6_ = _tmp5_;
#line 968 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp7_ = g_strdup_printf ("<span weight=\"Bold\" size=\"larger\">%s</span>\n%s", _tmp3_, _tmp6_);
#line 968 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp8_ = _tmp7_;
#line 968 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp6_);
#line 968 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp3_);
#line 968 "/home/jens/Source/shotwell/src/Dialogs.vala"
		result = _tmp8_;
#line 968 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return result;
#line 9688 "Dialogs.c"
	}
#line 972 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = primary_text;
#line 972 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp10_ = guarded_markup_escape_text (_tmp9_);
#line 972 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp11_ = _tmp10_;
#line 972 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp12_ = secondary_text;
#line 972 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp13_ = g_strdup_printf ("<span weight=\"Bold\" size=\"larger\">%s</span>\n%s", _tmp11_, _tmp12_);
#line 972 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp14_ = _tmp13_;
#line 972 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp11_);
#line 972 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = _tmp14_;
#line 972 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 9708 "Dialogs.c"
}


static gboolean _entry_multi_completion_match_func_gtk_entry_completion_match_func (GtkEntryCompletion* completion, const gchar* key, GtkTreeIter* iter, gpointer self) {
	gboolean result;
	result = entry_multi_completion_match_func ((EntryMultiCompletion*) self, completion, key, iter);
#line 987 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 9717 "Dialogs.c"
}


EntryMultiCompletion* entry_multi_completion_construct (GType object_type, GeeCollection* completion_list, const gchar* delimiter) {
	EntryMultiCompletion * self = NULL;
	gboolean _tmp0_ = FALSE;
	const gchar* _tmp1_ = NULL;
	const gchar* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	GeeCollection* _tmp7_ = NULL;
	GtkListStore* _tmp8_ = NULL;
	GtkListStore* _tmp9_ = NULL;
#line 981 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (GEE_IS_COLLECTION (completion_list), NULL);
#line 981 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = (EntryMultiCompletion*) g_object_new (object_type, NULL);
#line 982 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = delimiter;
#line 982 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp1_ == NULL) {
#line 982 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = TRUE;
#line 9740 "Dialogs.c"
	} else {
		const gchar* _tmp2_ = NULL;
		gint _tmp3_ = 0;
		gint _tmp4_ = 0;
#line 982 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp2_ = delimiter;
#line 982 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp3_ = strlen (_tmp2_);
#line 982 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp4_ = _tmp3_;
#line 982 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = _tmp4_ == 1;
#line 9753 "Dialogs.c"
	}
#line 982 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_vala_assert (_tmp0_, "delimiter == null || delimiter.length == 1");
#line 983 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = delimiter;
#line 983 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = g_strdup (_tmp5_);
#line 983 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (self->priv->delimiter);
#line 983 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->delimiter = _tmp6_;
#line 985 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = completion_list;
#line 985 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = entry_multi_completion_create_completion_store (_tmp7_);
#line 985 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = _tmp8_;
#line 985 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_entry_completion_set_model (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_entry_completion_get_type (), GtkEntryCompletion), G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, GTK_TYPE_TREE_MODEL, GtkTreeModel));
#line 985 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp9_);
#line 986 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_entry_completion_set_text_column (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_entry_completion_get_type (), GtkEntryCompletion), 0);
#line 987 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_entry_completion_set_match_func (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_entry_completion_get_type (), GtkEntryCompletion), _entry_multi_completion_match_func_gtk_entry_completion_match_func, g_object_ref (self), g_object_unref);
#line 981 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return self;
#line 9781 "Dialogs.c"
}


EntryMultiCompletion* entry_multi_completion_new (GeeCollection* completion_list, const gchar* delimiter) {
#line 981 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return entry_multi_completion_construct (TYPE_ENTRY_MULTI_COMPLETION, completion_list, delimiter);
#line 9788 "Dialogs.c"
}


static GtkListStore* entry_multi_completion_create_completion_store (GeeCollection* completion_list) {
	GtkListStore* result = NULL;
	GtkListStore* completion_store = NULL;
	GtkListStore* _tmp0_ = NULL;
	GtkTreeIter store_iter = {0};
	GeeIterator* completion_iter = NULL;
	GeeCollection* _tmp1_ = NULL;
	GeeIterator* _tmp2_ = NULL;
#line 990 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (GEE_IS_COLLECTION (completion_list), NULL);
#line 991 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = gtk_list_store_new (1, G_TYPE_STRING, -1);
#line 991 "/home/jens/Source/shotwell/src/Dialogs.vala"
	completion_store = _tmp0_;
#line 993 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = completion_list;
#line 993 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, GEE_TYPE_ITERABLE, GeeIterable));
#line 993 "/home/jens/Source/shotwell/src/Dialogs.vala"
	completion_iter = _tmp2_;
#line 994 "/home/jens/Source/shotwell/src/Dialogs.vala"
	while (TRUE) {
#line 9814 "Dialogs.c"
		GeeIterator* _tmp3_ = NULL;
		gboolean _tmp4_ = FALSE;
		GtkListStore* _tmp5_ = NULL;
		GtkTreeIter _tmp6_ = {0};
		GtkListStore* _tmp7_ = NULL;
		GtkTreeIter _tmp8_ = {0};
		GeeIterator* _tmp9_ = NULL;
		gpointer _tmp10_ = NULL;
		gchar* _tmp11_ = NULL;
#line 994 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp3_ = completion_iter;
#line 994 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp4_ = gee_iterator_next (_tmp3_);
#line 994 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (!_tmp4_) {
#line 994 "/home/jens/Source/shotwell/src/Dialogs.vala"
			break;
#line 9832 "Dialogs.c"
		}
#line 995 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp5_ = completion_store;
#line 995 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_list_store_append (_tmp5_, &_tmp6_);
#line 995 "/home/jens/Source/shotwell/src/Dialogs.vala"
		store_iter = _tmp6_;
#line 996 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp7_ = completion_store;
#line 996 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp8_ = store_iter;
#line 996 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp9_ = completion_iter;
#line 996 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp10_ = gee_iterator_get (_tmp9_);
#line 996 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp11_ = (gchar*) _tmp10_;
#line 996 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_list_store_set (_tmp7_, &_tmp8_, 0, _tmp11_, -1, -1);
#line 996 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp11_);
#line 9854 "Dialogs.c"
	}
#line 999 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = completion_store;
#line 999 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (completion_iter);
#line 999 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 9862 "Dialogs.c"
}


static gchar* string_strip (const gchar* self) {
	gchar* result = NULL;
	gchar* _result_ = NULL;
	gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
#line 1207 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1208 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp0_ = g_strdup (self);
#line 1208 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_result_ = _tmp0_;
#line 1209 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp1_ = _result_;
#line 1209 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	g_strstrip (_tmp1_);
#line 1210 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	result = _result_;
#line 1210 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	return result;
#line 9885 "Dialogs.c"
}


static gboolean string_contains (const gchar* self, const gchar* needle) {
	gboolean result = FALSE;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 1376 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, FALSE);
#line 1376 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	g_return_val_if_fail (needle != NULL, FALSE);
#line 1377 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp0_ = needle;
#line 1377 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp1_ = strstr ((gchar*) self, (gchar*) _tmp0_);
#line 1377 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	result = _tmp1_ != NULL;
#line 1377 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	return result;
#line 9905 "Dialogs.c"
}


static gint string_last_index_of_char (const gchar* self, gunichar c, gint start_index) {
	gint result = 0;
	gchar* _result_ = NULL;
	gint _tmp0_ = 0;
	gunichar _tmp1_ = 0U;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
#line 1017 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, 0);
#line 1018 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp0_ = start_index;
#line 1018 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp1_ = c;
#line 1018 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp2_ = g_utf8_strrchr (((gchar*) self) + _tmp0_, (gssize) -1, _tmp1_);
#line 1018 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_result_ = _tmp2_;
#line 1020 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp3_ = _result_;
#line 1020 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	if (_tmp3_ != NULL) {
#line 9930 "Dialogs.c"
		gchar* _tmp4_ = NULL;
#line 1021 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp4_ = _result_;
#line 1021 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		result = (gint) (_tmp4_ - ((gchar*) self));
#line 1021 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		return result;
#line 9938 "Dialogs.c"
	} else {
#line 1023 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		result = -1;
#line 1023 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		return result;
#line 9944 "Dialogs.c"
	}
}


static gboolean entry_multi_completion_match_func (EntryMultiCompletion* self, GtkEntryCompletion* completion, const gchar* key, GtkTreeIter* iter) {
	gboolean result = FALSE;
	GtkTreeModel* model = NULL;
	GtkEntryCompletion* _tmp0_ = NULL;
	GtkTreeModel* _tmp1_ = NULL;
	GtkTreeModel* _tmp2_ = NULL;
	gchar* possible_match = NULL;
	GtkTreeModel* _tmp3_ = NULL;
	GtkTreeIter _tmp4_ = {0};
	const gchar* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
	gchar* _tmp8_ = NULL;
	gchar* normed_key = NULL;
	const gchar* _tmp9_ = NULL;
	gchar* _tmp10_ = NULL;
	const gchar* _tmp11_ = NULL;
#line 1002 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_ENTRY_MULTI_COMPLETION (self), FALSE);
#line 1002 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (GTK_IS_ENTRY_COMPLETION (completion), FALSE);
#line 1002 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (key != NULL, FALSE);
#line 1002 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (iter != NULL, FALSE);
#line 1003 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = completion;
#line 1003 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = gtk_entry_completion_get_model (_tmp0_);
#line 1003 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 1003 "/home/jens/Source/shotwell/src/Dialogs.vala"
	model = _tmp2_;
#line 1005 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = model;
#line 1005 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = *iter;
#line 1005 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_tree_model_get (_tmp3_, &_tmp4_, 0, &possible_match, -1);
#line 1011 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = possible_match;
#line 1011 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = g_utf8_casefold (_tmp5_, (gssize) -1);
#line 1011 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = _tmp6_;
#line 1011 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = g_utf8_normalize (_tmp7_, (gssize) -1, G_NORMALIZE_ALL_COMPOSE);
#line 1011 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (possible_match);
#line 1011 "/home/jens/Source/shotwell/src/Dialogs.vala"
	possible_match = _tmp8_;
#line 1011 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp7_);
#line 1012 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = key;
#line 1012 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp10_ = g_utf8_normalize (_tmp9_, (gssize) -1, G_NORMALIZE_ALL_COMPOSE);
#line 1012 "/home/jens/Source/shotwell/src/Dialogs.vala"
	normed_key = _tmp10_;
#line 1014 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp11_ = self->priv->delimiter;
#line 1014 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp11_ == NULL) {
#line 10012 "Dialogs.c"
		const gchar* _tmp12_ = NULL;
		const gchar* _tmp13_ = NULL;
		gchar* _tmp14_ = NULL;
		gchar* _tmp15_ = NULL;
		gboolean _tmp16_ = FALSE;
		gboolean _tmp17_ = FALSE;
#line 1015 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp12_ = possible_match;
#line 1015 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp13_ = normed_key;
#line 1015 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp14_ = string_strip (_tmp13_);
#line 1015 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp15_ = _tmp14_;
#line 1015 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp16_ = g_str_has_prefix (_tmp12_, _tmp15_);
#line 1015 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp17_ = _tmp16_;
#line 1015 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp15_);
#line 1015 "/home/jens/Source/shotwell/src/Dialogs.vala"
		result = _tmp17_;
#line 1015 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (normed_key);
#line 1015 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (possible_match);
#line 1015 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (model);
#line 1015 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return result;
#line 10043 "Dialogs.c"
	} else {
		const gchar* _tmp18_ = NULL;
		const gchar* _tmp19_ = NULL;
		gboolean _tmp20_ = FALSE;
		gchar* last_part = NULL;
		const gchar* _tmp31_ = NULL;
		gchar* _tmp32_ = NULL;
		gchar* _tmp33_ = NULL;
		const gchar* _tmp34_ = NULL;
		gchar* _tmp35_ = NULL;
		gchar* _tmp36_ = NULL;
		const gchar* _tmp37_ = NULL;
		gint _tmp38_ = 0;
		gint _tmp39_ = 0;
		const gchar* _tmp40_ = NULL;
		const gchar* _tmp41_ = NULL;
		gchar* _tmp42_ = NULL;
		gchar* _tmp43_ = NULL;
		gboolean _tmp44_ = FALSE;
		gboolean _tmp45_ = FALSE;
#line 1017 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp18_ = normed_key;
#line 1017 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp19_ = self->priv->delimiter;
#line 1017 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp20_ = string_contains (_tmp18_, _tmp19_);
#line 1017 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp20_) {
#line 10072 "Dialogs.c"
			gint offset = 0;
			const gchar* _tmp21_ = NULL;
			const gchar* _tmp22_ = NULL;
			const gchar* _tmp23_ = NULL;
			gchar _tmp24_ = '\0';
			gint _tmp25_ = 0;
			gint _tmp26_ = 0;
			gint position = 0;
			GtkWidget* _tmp27_ = NULL;
			gint _tmp28_ = 0;
			gint _tmp29_ = 0;
			gint _tmp30_ = 0;
#line 1019 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp21_ = normed_key;
#line 1019 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp22_ = normed_key;
#line 1019 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp23_ = self->priv->delimiter;
#line 1019 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp24_ = string_get (_tmp23_, (glong) 0);
#line 1019 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp25_ = string_last_index_of_char (_tmp22_, (gunichar) _tmp24_, 0);
#line 1019 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp26_ = g_utf8_strlen (_tmp21_, (gssize) _tmp25_);
#line 1019 "/home/jens/Source/shotwell/src/Dialogs.vala"
			offset = _tmp26_;
#line 1020 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp27_ = gtk_entry_completion_get_entry (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_entry_completion_get_type (), GtkEntryCompletion));
#line 1020 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp28_ = gtk_editable_get_position (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (_tmp27_, gtk_entry_get_type (), GtkEntry), GTK_TYPE_EDITABLE, GtkEditable));
#line 1020 "/home/jens/Source/shotwell/src/Dialogs.vala"
			position = _tmp28_;
#line 1021 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp29_ = position;
#line 1021 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp30_ = offset;
#line 1021 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (_tmp29_ <= _tmp30_) {
#line 1022 "/home/jens/Source/shotwell/src/Dialogs.vala"
				result = FALSE;
#line 1022 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (normed_key);
#line 1022 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (possible_match);
#line 1022 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_object_unref0 (model);
#line 1022 "/home/jens/Source/shotwell/src/Dialogs.vala"
				return result;
#line 10121 "Dialogs.c"
			}
		}
#line 1025 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp31_ = normed_key;
#line 1025 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp32_ = string_strip (_tmp31_);
#line 1025 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp33_ = _tmp32_;
#line 1025 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp34_ = self->priv->delimiter;
#line 1025 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp35_ = entry_multi_completion_get_last_part (_tmp33_, _tmp34_);
#line 1025 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp36_ = _tmp35_;
#line 1025 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp33_);
#line 1025 "/home/jens/Source/shotwell/src/Dialogs.vala"
		last_part = _tmp36_;
#line 1027 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp37_ = last_part;
#line 1027 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp38_ = strlen (_tmp37_);
#line 1027 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp39_ = _tmp38_;
#line 1027 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp39_ == 0) {
#line 1028 "/home/jens/Source/shotwell/src/Dialogs.vala"
			result = FALSE;
#line 1028 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (last_part);
#line 1028 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (normed_key);
#line 1028 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (possible_match);
#line 1028 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_object_unref0 (model);
#line 1028 "/home/jens/Source/shotwell/src/Dialogs.vala"
			return result;
#line 10160 "Dialogs.c"
		}
#line 1030 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp40_ = possible_match;
#line 1030 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp41_ = last_part;
#line 1030 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp42_ = string_strip (_tmp41_);
#line 1030 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp43_ = _tmp42_;
#line 1030 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp44_ = g_str_has_prefix (_tmp40_, _tmp43_);
#line 1030 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp45_ = _tmp44_;
#line 1030 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp43_);
#line 1030 "/home/jens/Source/shotwell/src/Dialogs.vala"
		result = _tmp45_;
#line 1030 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (last_part);
#line 1030 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (normed_key);
#line 1030 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (possible_match);
#line 1030 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (model);
#line 1030 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return result;
#line 10188 "Dialogs.c"
	}
#line 1002 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (normed_key);
#line 1002 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (possible_match);
#line 1002 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (model);
#line 10196 "Dialogs.c"
}


static glong string_strnlen (gchar* str, glong maxlen) {
	glong result = 0L;
	gchar* end = NULL;
	gchar* _tmp0_ = NULL;
	glong _tmp1_ = 0L;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
#line 1295 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp0_ = str;
#line 1295 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp1_ = maxlen;
#line 1295 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp2_ = memchr (_tmp0_, 0, (gsize) _tmp1_);
#line 1295 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	end = _tmp2_;
#line 1296 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp3_ = end;
#line 1296 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	if (_tmp3_ == NULL) {
#line 10219 "Dialogs.c"
		glong _tmp4_ = 0L;
#line 1297 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp4_ = maxlen;
#line 1297 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		result = _tmp4_;
#line 1297 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		return result;
#line 10227 "Dialogs.c"
	} else {
		gchar* _tmp5_ = NULL;
		gchar* _tmp6_ = NULL;
#line 1299 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp5_ = end;
#line 1299 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp6_ = str;
#line 1299 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		result = (glong) (_tmp5_ - _tmp6_);
#line 1299 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		return result;
#line 10239 "Dialogs.c"
	}
}


static gchar* string_substring (const gchar* self, glong offset, glong len) {
	gchar* result = NULL;
	glong string_length = 0L;
	gboolean _tmp0_ = FALSE;
	glong _tmp1_ = 0L;
	glong _tmp8_ = 0L;
	glong _tmp14_ = 0L;
	glong _tmp17_ = 0L;
	glong _tmp18_ = 0L;
	glong _tmp19_ = 0L;
	glong _tmp20_ = 0L;
	glong _tmp21_ = 0L;
	gchar* _tmp22_ = NULL;
#line 1306 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1308 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp1_ = offset;
#line 1308 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	if (_tmp1_ >= ((glong) 0)) {
#line 10263 "Dialogs.c"
		glong _tmp2_ = 0L;
#line 1308 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp2_ = len;
#line 1308 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp0_ = _tmp2_ >= ((glong) 0);
#line 10269 "Dialogs.c"
	} else {
#line 1308 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp0_ = FALSE;
#line 10273 "Dialogs.c"
	}
#line 1308 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	if (_tmp0_) {
#line 10277 "Dialogs.c"
		glong _tmp3_ = 0L;
		glong _tmp4_ = 0L;
		glong _tmp5_ = 0L;
#line 1310 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp3_ = offset;
#line 1310 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp4_ = len;
#line 1310 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp5_ = string_strnlen ((gchar*) self, _tmp3_ + _tmp4_);
#line 1310 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		string_length = _tmp5_;
#line 10289 "Dialogs.c"
	} else {
		gint _tmp6_ = 0;
		gint _tmp7_ = 0;
#line 1312 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp6_ = strlen (self);
#line 1312 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp7_ = _tmp6_;
#line 1312 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		string_length = (glong) _tmp7_;
#line 10299 "Dialogs.c"
	}
#line 1315 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp8_ = offset;
#line 1315 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	if (_tmp8_ < ((glong) 0)) {
#line 10305 "Dialogs.c"
		glong _tmp9_ = 0L;
		glong _tmp10_ = 0L;
		glong _tmp11_ = 0L;
#line 1316 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp9_ = string_length;
#line 1316 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp10_ = offset;
#line 1316 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		offset = _tmp9_ + _tmp10_;
#line 1317 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp11_ = offset;
#line 1317 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		g_return_val_if_fail (_tmp11_ >= ((glong) 0), NULL);
#line 10319 "Dialogs.c"
	} else {
		glong _tmp12_ = 0L;
		glong _tmp13_ = 0L;
#line 1319 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp12_ = offset;
#line 1319 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp13_ = string_length;
#line 1319 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		g_return_val_if_fail (_tmp12_ <= _tmp13_, NULL);
#line 10329 "Dialogs.c"
	}
#line 1321 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp14_ = len;
#line 1321 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	if (_tmp14_ < ((glong) 0)) {
#line 10335 "Dialogs.c"
		glong _tmp15_ = 0L;
		glong _tmp16_ = 0L;
#line 1322 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp15_ = string_length;
#line 1322 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp16_ = offset;
#line 1322 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		len = _tmp15_ - _tmp16_;
#line 10344 "Dialogs.c"
	}
#line 1324 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp17_ = offset;
#line 1324 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp18_ = len;
#line 1324 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp19_ = string_length;
#line 1324 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	g_return_val_if_fail ((_tmp17_ + _tmp18_) <= _tmp19_, NULL);
#line 1325 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp20_ = offset;
#line 1325 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp21_ = len;
#line 1325 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp22_ = g_strndup (((gchar*) self) + _tmp20_, (gsize) _tmp21_);
#line 1325 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	result = _tmp22_;
#line 1325 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	return result;
#line 10364 "Dialogs.c"
}


static gboolean entry_multi_completion_real_match_selected (GtkEntryCompletion* base, GtkTreeModel* model, GtkTreeIter* iter) {
	EntryMultiCompletion * self;
	gboolean result = FALSE;
	gchar* match = NULL;
	GtkTreeModel* _tmp0_ = NULL;
	GtkTreeIter _tmp1_ = {0};
	GtkEntry* entry = NULL;
	GtkWidget* _tmp2_ = NULL;
	GtkEntry* _tmp3_ = NULL;
	gchar* old_text = NULL;
	GtkEntry* _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	const gchar* _tmp7_ = NULL;
	gint _tmp8_ = 0;
	gint _tmp9_ = 0;
	const gchar* _tmp24_ = NULL;
	const gchar* _tmp25_ = NULL;
	gchar* new_text = NULL;
	const gchar* _tmp26_ = NULL;
	const gchar* _tmp27_ = NULL;
	gchar* _tmp28_ = NULL;
	gchar* _tmp29_ = NULL;
	const gchar* _tmp30_ = NULL;
	gchar* _tmp31_ = NULL;
	gchar* _tmp32_ = NULL;
	gchar* _tmp33_ = NULL;
	gchar* _tmp34_ = NULL;
	GtkEntry* _tmp35_ = NULL;
	GtkEntry* _tmp36_ = NULL;
	gint _tmp37_ = 0;
	gint _tmp38_ = 0;
#line 1034 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_ENTRY_MULTI_COMPLETION, EntryMultiCompletion);
#line 1034 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (GTK_IS_TREE_MODEL (model), FALSE);
#line 1034 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (iter != NULL, FALSE);
#line 1036 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = model;
#line 1036 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = *iter;
#line 1036 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_tree_model_get (_tmp0_, &_tmp1_, 0, &match, -1);
#line 1038 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = gtk_entry_completion_get_entry (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_entry_completion_get_type (), GtkEntryCompletion));
#line 1038 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, gtk_entry_get_type (), GtkEntry));
#line 1038 "/home/jens/Source/shotwell/src/Dialogs.vala"
	entry = _tmp3_;
#line 1040 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = entry;
#line 1040 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = gtk_entry_get_text (_tmp4_);
#line 1040 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = g_utf8_normalize (_tmp5_, (gssize) -1, G_NORMALIZE_ALL_COMPOSE);
#line 1040 "/home/jens/Source/shotwell/src/Dialogs.vala"
	old_text = _tmp6_;
#line 1041 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = old_text;
#line 1041 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = strlen (_tmp7_);
#line 1041 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = _tmp8_;
#line 1041 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp9_ > 0) {
#line 10434 "Dialogs.c"
		const gchar* _tmp10_ = NULL;
		const gchar* _tmp11_ = NULL;
		gboolean _tmp12_ = FALSE;
#line 1042 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp10_ = old_text;
#line 1042 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp11_ = self->priv->delimiter;
#line 1042 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp12_ = string_contains (_tmp10_, _tmp11_);
#line 1042 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp12_) {
#line 10446 "Dialogs.c"
			const gchar* _tmp13_ = NULL;
			const gchar* _tmp14_ = NULL;
			const gchar* _tmp15_ = NULL;
			const gchar* _tmp16_ = NULL;
			const gchar* _tmp17_ = NULL;
			gchar _tmp18_ = '\0';
			gint _tmp19_ = 0;
			gchar* _tmp20_ = NULL;
			gchar* _tmp21_ = NULL;
			gchar* _tmp22_ = NULL;
#line 1043 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp14_ = self->priv->delimiter;
#line 1043 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (g_strcmp0 (_tmp14_, " ") != 0) {
#line 1043 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp13_ = " ";
#line 10463 "Dialogs.c"
			} else {
#line 1043 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp13_ = "";
#line 10467 "Dialogs.c"
			}
#line 1043 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp15_ = old_text;
#line 1043 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp16_ = old_text;
#line 1043 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp17_ = self->priv->delimiter;
#line 1043 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp18_ = string_get (_tmp17_, (glong) 0);
#line 1043 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp19_ = string_last_index_of_char (_tmp16_, (gunichar) _tmp18_, 0);
#line 1043 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp20_ = string_substring (_tmp15_, (glong) 0, (glong) (_tmp19_ + 1));
#line 1043 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp21_ = _tmp20_;
#line 1043 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp22_ = g_strconcat (_tmp21_, _tmp13_, NULL);
#line 1043 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (old_text);
#line 1043 "/home/jens/Source/shotwell/src/Dialogs.vala"
			old_text = _tmp22_;
#line 1043 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (_tmp21_);
#line 10491 "Dialogs.c"
		} else {
			gchar* _tmp23_ = NULL;
#line 1045 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp23_ = g_strdup ("");
#line 1045 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (old_text);
#line 1045 "/home/jens/Source/shotwell/src/Dialogs.vala"
			old_text = _tmp23_;
#line 10500 "Dialogs.c"
		}
	}
#line 1048 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp25_ = self->priv->delimiter;
#line 1048 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (g_strcmp0 (_tmp25_, " ") != 0) {
#line 1048 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp24_ = " ";
#line 10509 "Dialogs.c"
	} else {
#line 1048 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp24_ = "";
#line 10513 "Dialogs.c"
	}
#line 1048 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp26_ = old_text;
#line 1048 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp27_ = match;
#line 1048 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp28_ = g_strconcat (_tmp26_, _tmp27_, NULL);
#line 1048 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp29_ = _tmp28_;
#line 1048 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp30_ = self->priv->delimiter;
#line 1048 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp31_ = g_strconcat (_tmp29_, _tmp30_, NULL);
#line 1048 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp32_ = _tmp31_;
#line 1048 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp33_ = g_strconcat (_tmp32_, _tmp24_, NULL);
#line 1048 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp34_ = _tmp33_;
#line 1048 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp32_);
#line 1048 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp29_);
#line 1048 "/home/jens/Source/shotwell/src/Dialogs.vala"
	new_text = _tmp34_;
#line 1049 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp35_ = entry;
#line 1049 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_entry_set_text (_tmp35_, new_text);
#line 1050 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp36_ = entry;
#line 1050 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp37_ = strlen (new_text);
#line 1050 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp38_ = _tmp37_;
#line 1050 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_editable_set_position (G_TYPE_CHECK_INSTANCE_CAST (_tmp36_, GTK_TYPE_EDITABLE, GtkEditable), (gint) _tmp38_);
#line 1052 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = TRUE;
#line 1052 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (new_text);
#line 1052 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (old_text);
#line 1052 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (entry);
#line 1052 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (match);
#line 1052 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 10563 "Dialogs.c"
}


static gchar* entry_multi_completion_get_last_part (const gchar* s, const gchar* delimiter) {
	gchar* result = NULL;
	gchar** split = NULL;
	const gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gchar** _tmp2_ = NULL;
	gchar** _tmp3_ = NULL;
	gint split_length1 = 0;
	gint _split_size_ = 0;
	gboolean _tmp4_ = FALSE;
	gchar** _tmp5_ = NULL;
	gint _tmp5__length1 = 0;
#line 1056 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (s != NULL, NULL);
#line 1056 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (delimiter != NULL, NULL);
#line 1057 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = s;
#line 1057 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = delimiter;
#line 1057 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = _tmp2_ = g_strsplit (_tmp0_, _tmp1_, 0);
#line 1057 "/home/jens/Source/shotwell/src/Dialogs.vala"
	split = _tmp3_;
#line 1057 "/home/jens/Source/shotwell/src/Dialogs.vala"
	split_length1 = _vala_array_length (_tmp2_);
#line 1057 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_split_size_ = split_length1;
#line 1059 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = split;
#line 1059 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5__length1 = split_length1;
#line 1059 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp5_ != NULL) {
#line 10601 "Dialogs.c"
		gchar** _tmp6_ = NULL;
		gint _tmp6__length1 = 0;
		const gchar* _tmp7_ = NULL;
#line 1059 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp6_ = split;
#line 1059 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp6__length1 = split_length1;
#line 1059 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp7_ = _tmp6_[0];
#line 1059 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp4_ = _tmp7_ != NULL;
#line 10613 "Dialogs.c"
	} else {
#line 1059 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp4_ = FALSE;
#line 10617 "Dialogs.c"
	}
#line 1059 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp4_) {
#line 10621 "Dialogs.c"
		gchar** _tmp8_ = NULL;
		gint _tmp8__length1 = 0;
		gchar** _tmp9_ = NULL;
		gint _tmp9__length1 = 0;
		const gchar* _tmp10_ = NULL;
		gchar* _tmp11_ = NULL;
#line 1060 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp8_ = split;
#line 1060 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp8__length1 = split_length1;
#line 1060 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp9_ = split;
#line 1060 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp9__length1 = split_length1;
#line 1060 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp10_ = _tmp8_[_tmp9__length1 - 1];
#line 1060 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp11_ = g_strdup (_tmp10_);
#line 1060 "/home/jens/Source/shotwell/src/Dialogs.vala"
		result = _tmp11_;
#line 1060 "/home/jens/Source/shotwell/src/Dialogs.vala"
		split = (_vala_array_free (split, split_length1, (GDestroyNotify) g_free), NULL);
#line 1060 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return result;
#line 10646 "Dialogs.c"
	} else {
		gchar* _tmp12_ = NULL;
#line 1062 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp12_ = g_strdup ("");
#line 1062 "/home/jens/Source/shotwell/src/Dialogs.vala"
		result = _tmp12_;
#line 1062 "/home/jens/Source/shotwell/src/Dialogs.vala"
		split = (_vala_array_free (split, split_length1, (GDestroyNotify) g_free), NULL);
#line 1062 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return result;
#line 10657 "Dialogs.c"
	}
#line 1056 "/home/jens/Source/shotwell/src/Dialogs.vala"
	split = (_vala_array_free (split, split_length1, (GDestroyNotify) g_free), NULL);
#line 10661 "Dialogs.c"
}


static void entry_multi_completion_class_init (EntryMultiCompletionClass * klass) {
#line 978 "/home/jens/Source/shotwell/src/Dialogs.vala"
	entry_multi_completion_parent_class = g_type_class_peek_parent (klass);
#line 978 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_type_class_add_private (klass, sizeof (EntryMultiCompletionPrivate));
#line 978 "/home/jens/Source/shotwell/src/Dialogs.vala"
	((GtkEntryCompletionClass *) klass)->match_selected = entry_multi_completion_real_match_selected;
#line 978 "/home/jens/Source/shotwell/src/Dialogs.vala"
	G_OBJECT_CLASS (klass)->finalize = entry_multi_completion_finalize;
#line 10674 "Dialogs.c"
}


static void entry_multi_completion_instance_init (EntryMultiCompletion * self) {
#line 978 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv = ENTRY_MULTI_COMPLETION_GET_PRIVATE (self);
#line 10681 "Dialogs.c"
}


static void entry_multi_completion_finalize (GObject* obj) {
	EntryMultiCompletion * self;
#line 978 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_ENTRY_MULTI_COMPLETION, EntryMultiCompletion);
#line 979 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (self->priv->delimiter);
#line 978 "/home/jens/Source/shotwell/src/Dialogs.vala"
	G_OBJECT_CLASS (entry_multi_completion_parent_class)->finalize (obj);
#line 10693 "Dialogs.c"
}


GType entry_multi_completion_get_type (void) {
	static volatile gsize entry_multi_completion_type_id__volatile = 0;
	if (g_once_init_enter (&entry_multi_completion_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (EntryMultiCompletionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) entry_multi_completion_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (EntryMultiCompletion), 0, (GInstanceInitFunc) entry_multi_completion_instance_init, NULL };
		GType entry_multi_completion_type_id;
		entry_multi_completion_type_id = g_type_register_static (gtk_entry_completion_get_type (), "EntryMultiCompletion", &g_define_type_info, 0);
		g_once_init_leave (&entry_multi_completion_type_id__volatile, entry_multi_completion_type_id);
	}
	return entry_multi_completion_type_id__volatile;
}


static void _set_background_dialog_on_checkbox_clicked_gtk_toggle_button_toggled (GtkToggleButton* _sender, gpointer self) {
#line 1086 "/home/jens/Source/shotwell/src/Dialogs.vala"
	set_background_dialog_on_checkbox_clicked ((SetBackgroundDialog*) self);
#line 10712 "Dialogs.c"
}


SetBackgroundDialog* set_background_dialog_construct (GType object_type, GtkBuilder* builder) {
	SetBackgroundDialog* self = NULL;
	GtkBuilder* _tmp0_ = NULL;
	GObject* _tmp1_ = NULL;
	GtkDialog* _tmp2_ = NULL;
	GtkDialog* _tmp3_ = NULL;
	GtkDialog* _tmp4_ = NULL;
	AppWindow* _tmp5_ = NULL;
	AppWindow* _tmp6_ = NULL;
	GdkWindow* _tmp7_ = NULL;
	GtkDialog* _tmp8_ = NULL;
	AppWindow* _tmp9_ = NULL;
	AppWindow* _tmp10_ = NULL;
	GtkDialog* _tmp11_ = NULL;
	GtkBuilder* _tmp12_ = NULL;
	GObject* _tmp13_ = NULL;
	GtkCheckButton* _tmp14_ = NULL;
	GtkCheckButton* _tmp15_ = NULL;
	gboolean _tmp16_ = FALSE;
	GtkCheckButton* _tmp17_ = NULL;
	GtkBuilder* _tmp18_ = NULL;
	GObject* _tmp19_ = NULL;
	GtkCheckButton* _tmp20_ = NULL;
	GtkCheckButton* _tmp21_ = NULL;
	gboolean _tmp22_ = FALSE;
	GtkCheckButton* _tmp23_ = NULL;
	GtkBuilder* _tmp24_ = NULL;
	GObject* _tmp25_ = NULL;
	GtkButton* _tmp26_ = NULL;
#line 1076 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (GTK_IS_BUILDER (builder), NULL);
#line 1076 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = (SetBackgroundDialog*) g_type_create_instance (object_type);
#line 1078 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = builder;
#line 1078 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = gtk_builder_get_object (_tmp0_, "dialog1");
#line 1078 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, gtk_dialog_get_type ()) ? ((GtkDialog*) _tmp1_) : NULL);
#line 1078 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->dialog);
#line 1078 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->dialog = _tmp2_;
#line 1079 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = self->dialog;
#line 1079 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_window_set_type_hint (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, gtk_window_get_type (), GtkWindow), GDK_WINDOW_TYPE_HINT_DIALOG);
#line 1080 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = self->dialog;
#line 1080 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = app_window_get_instance ();
#line 1080 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = _tmp5_;
#line 1080 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = gtk_widget_get_parent_window (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, gtk_widget_get_type (), GtkWidget));
#line 1080 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_set_parent_window (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, gtk_widget_get_type (), GtkWidget), _tmp7_);
#line 1080 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp6_);
#line 1081 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = self->dialog;
#line 1081 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = app_window_get_instance ();
#line 1081 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp10_ = _tmp9_;
#line 1081 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_window_set_transient_for (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, gtk_window_get_type (), GtkWindow), G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, gtk_window_get_type (), GtkWindow));
#line 1081 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp10_);
#line 1082 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp11_ = self->dialog;
#line 1082 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_dialog_set_default_response (_tmp11_, (gint) GTK_RESPONSE_OK);
#line 1084 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp12_ = builder;
#line 1084 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp13_ = gtk_builder_get_object (_tmp12_, "desktop_background_checkbox");
#line 1084 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp14_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp13_, gtk_check_button_get_type ()) ? ((GtkCheckButton*) _tmp13_) : NULL);
#line 1084 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->desktop_background_button);
#line 1084 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->desktop_background_button = _tmp14_;
#line 1085 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp15_ = self->desktop_background_button;
#line 1085 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp16_ = self->desktop;
#line 1085 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_toggle_button_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp15_, gtk_toggle_button_get_type (), GtkToggleButton), _tmp16_);
#line 1086 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp17_ = self->desktop_background_button;
#line 1086 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_connect (G_TYPE_CHECK_INSTANCE_CAST (_tmp17_, gtk_toggle_button_get_type (), GtkToggleButton), "toggled", (GCallback) _set_background_dialog_on_checkbox_clicked_gtk_toggle_button_toggled, self);
#line 1087 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp18_ = builder;
#line 1087 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp19_ = gtk_builder_get_object (_tmp18_, "screensaver_checkbox");
#line 1087 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp20_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp19_, gtk_check_button_get_type ()) ? ((GtkCheckButton*) _tmp19_) : NULL);
#line 1087 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->screensaver_button);
#line 1087 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->screensaver_button = _tmp20_;
#line 1088 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp21_ = self->screensaver_button;
#line 1088 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp22_ = self->screensaver;
#line 1088 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_toggle_button_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp21_, gtk_toggle_button_get_type (), GtkToggleButton), _tmp22_);
#line 1089 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp23_ = self->screensaver_button;
#line 1089 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_connect (G_TYPE_CHECK_INSTANCE_CAST (_tmp23_, gtk_toggle_button_get_type (), GtkToggleButton), "toggled", (GCallback) _set_background_dialog_on_checkbox_clicked_gtk_toggle_button_toggled, self);
#line 1091 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp24_ = builder;
#line 1091 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp25_ = gtk_builder_get_object (_tmp24_, "ok_button");
#line 1091 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp26_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp25_, gtk_button_get_type ()) ? ((GtkButton*) _tmp25_) : NULL);
#line 1091 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->ok_button);
#line 1091 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->ok_button = _tmp26_;
#line 1076 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return self;
#line 10841 "Dialogs.c"
}


void set_background_dialog_on_checkbox_clicked (SetBackgroundDialog* self) {
	GtkCheckButton* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_ = FALSE;
	GtkCheckButton* _tmp3_ = NULL;
	gboolean _tmp4_ = FALSE;
	gboolean _tmp5_ = FALSE;
	gboolean _tmp6_ = FALSE;
	gboolean _tmp7_ = FALSE;
#line 1094 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_SET_BACKGROUND_DIALOG (self));
#line 1095 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = self->desktop_background_button;
#line 1095 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = gtk_toggle_button_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_toggle_button_get_type (), GtkToggleButton));
#line 1095 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = _tmp1_;
#line 1095 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->desktop = _tmp2_;
#line 1096 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = self->screensaver_button;
#line 1096 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = gtk_toggle_button_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, gtk_toggle_button_get_type (), GtkToggleButton));
#line 1096 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = _tmp4_;
#line 1096 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->screensaver = _tmp5_;
#line 1098 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = self->desktop;
#line 1098 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (!_tmp7_) {
#line 10876 "Dialogs.c"
		gboolean _tmp8_ = FALSE;
#line 1098 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp8_ = self->screensaver;
#line 1098 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp6_ = !_tmp8_;
#line 10882 "Dialogs.c"
	} else {
#line 1098 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp6_ = FALSE;
#line 10886 "Dialogs.c"
	}
#line 1098 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp6_) {
#line 10890 "Dialogs.c"
		GtkButton* _tmp9_ = NULL;
#line 1099 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp9_ = self->ok_button;
#line 1099 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 10896 "Dialogs.c"
	} else {
		GtkButton* _tmp10_ = NULL;
#line 1101 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp10_ = self->ok_button;
#line 1101 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, gtk_widget_get_type (), GtkWidget), TRUE);
#line 10903 "Dialogs.c"
	}
}


gboolean set_background_dialog_execute_base (SetBackgroundDialog* self) {
	gboolean result = FALSE;
	GtkDialog* _tmp0_ = NULL;
	gboolean _result_ = FALSE;
	GtkDialog* _tmp1_ = NULL;
	gint _tmp2_ = 0;
	GtkDialog* _tmp3_ = NULL;
#line 1105 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_SET_BACKGROUND_DIALOG (self), FALSE);
#line 1106 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = self->dialog;
#line 1106 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_show_all (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_widget_get_type (), GtkWidget));
#line 1107 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = self->dialog;
#line 1107 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = gtk_dialog_run (_tmp1_);
#line 1107 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_result_ = _tmp2_ == ((gint) GTK_RESPONSE_OK);
#line 1108 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = self->dialog;
#line 1108 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, gtk_widget_get_type (), GtkWidget));
#line 1110 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = _result_;
#line 1110 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 10935 "Dialogs.c"
}


static void value_set_background_dialog_init (GValue* value) {
#line 1067 "/home/jens/Source/shotwell/src/Dialogs.vala"
	value->data[0].v_pointer = NULL;
#line 10942 "Dialogs.c"
}


static void value_set_background_dialog_free_value (GValue* value) {
#line 1067 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (value->data[0].v_pointer) {
#line 1067 "/home/jens/Source/shotwell/src/Dialogs.vala"
		set_background_dialog_unref (value->data[0].v_pointer);
#line 10951 "Dialogs.c"
	}
}


static void value_set_background_dialog_copy_value (const GValue* src_value, GValue* dest_value) {
#line 1067 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (src_value->data[0].v_pointer) {
#line 1067 "/home/jens/Source/shotwell/src/Dialogs.vala"
		dest_value->data[0].v_pointer = set_background_dialog_ref (src_value->data[0].v_pointer);
#line 10961 "Dialogs.c"
	} else {
#line 1067 "/home/jens/Source/shotwell/src/Dialogs.vala"
		dest_value->data[0].v_pointer = NULL;
#line 10965 "Dialogs.c"
	}
}


static gpointer value_set_background_dialog_peek_pointer (const GValue* value) {
#line 1067 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return value->data[0].v_pointer;
#line 10973 "Dialogs.c"
}


static gchar* value_set_background_dialog_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
#line 1067 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (collect_values[0].v_pointer) {
#line 10980 "Dialogs.c"
		SetBackgroundDialog* object;
		object = collect_values[0].v_pointer;
#line 1067 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (object->parent_instance.g_class == NULL) {
#line 1067 "/home/jens/Source/shotwell/src/Dialogs.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 10987 "Dialogs.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 1067 "/home/jens/Source/shotwell/src/Dialogs.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 10991 "Dialogs.c"
		}
#line 1067 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = set_background_dialog_ref (object);
#line 10995 "Dialogs.c"
	} else {
#line 1067 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = NULL;
#line 10999 "Dialogs.c"
	}
#line 1067 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return NULL;
#line 11003 "Dialogs.c"
}


static gchar* value_set_background_dialog_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	SetBackgroundDialog** object_p;
	object_p = collect_values[0].v_pointer;
#line 1067 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (!object_p) {
#line 1067 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 11014 "Dialogs.c"
	}
#line 1067 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (!value->data[0].v_pointer) {
#line 1067 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*object_p = NULL;
#line 11020 "Dialogs.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 1067 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*object_p = value->data[0].v_pointer;
#line 11024 "Dialogs.c"
	} else {
#line 1067 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*object_p = set_background_dialog_ref (value->data[0].v_pointer);
#line 11028 "Dialogs.c"
	}
#line 1067 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return NULL;
#line 11032 "Dialogs.c"
}


GParamSpec* param_spec_set_background_dialog (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
	ParamSpecSetBackgroundDialog* spec;
#line 1067 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (g_type_is_a (object_type, TYPE_SET_BACKGROUND_DIALOG), NULL);
#line 1067 "/home/jens/Source/shotwell/src/Dialogs.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 1067 "/home/jens/Source/shotwell/src/Dialogs.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 1067 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return G_PARAM_SPEC (spec);
#line 11046 "Dialogs.c"
}


gpointer value_get_set_background_dialog (const GValue* value) {
#line 1067 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_SET_BACKGROUND_DIALOG), NULL);
#line 1067 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return value->data[0].v_pointer;
#line 11055 "Dialogs.c"
}


void value_set_set_background_dialog (GValue* value, gpointer v_object) {
	SetBackgroundDialog* old;
#line 1067 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_SET_BACKGROUND_DIALOG));
#line 1067 "/home/jens/Source/shotwell/src/Dialogs.vala"
	old = value->data[0].v_pointer;
#line 1067 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (v_object) {
#line 1067 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, TYPE_SET_BACKGROUND_DIALOG));
#line 1067 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 1067 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = v_object;
#line 1067 "/home/jens/Source/shotwell/src/Dialogs.vala"
		set_background_dialog_ref (value->data[0].v_pointer);
#line 11075 "Dialogs.c"
	} else {
#line 1067 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = NULL;
#line 11079 "Dialogs.c"
	}
#line 1067 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (old) {
#line 1067 "/home/jens/Source/shotwell/src/Dialogs.vala"
		set_background_dialog_unref (old);
#line 11085 "Dialogs.c"
	}
}


void value_take_set_background_dialog (GValue* value, gpointer v_object) {
	SetBackgroundDialog* old;
#line 1067 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_SET_BACKGROUND_DIALOG));
#line 1067 "/home/jens/Source/shotwell/src/Dialogs.vala"
	old = value->data[0].v_pointer;
#line 1067 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (v_object) {
#line 1067 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, TYPE_SET_BACKGROUND_DIALOG));
#line 1067 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 1067 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = v_object;
#line 11104 "Dialogs.c"
	} else {
#line 1067 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = NULL;
#line 11108 "Dialogs.c"
	}
#line 1067 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (old) {
#line 1067 "/home/jens/Source/shotwell/src/Dialogs.vala"
		set_background_dialog_unref (old);
#line 11114 "Dialogs.c"
	}
}


static void set_background_dialog_class_init (SetBackgroundDialogClass * klass) {
#line 1067 "/home/jens/Source/shotwell/src/Dialogs.vala"
	set_background_dialog_parent_class = g_type_class_peek_parent (klass);
#line 1067 "/home/jens/Source/shotwell/src/Dialogs.vala"
	((SetBackgroundDialogClass *) klass)->finalize = set_background_dialog_finalize;
#line 11124 "Dialogs.c"
}


static void set_background_dialog_instance_init (SetBackgroundDialog * self) {
#line 1073 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->desktop = TRUE;
#line 1074 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->screensaver = FALSE;
#line 1067 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->ref_count = 1;
#line 11135 "Dialogs.c"
}


static void set_background_dialog_finalize (SetBackgroundDialog* obj) {
	SetBackgroundDialog * self;
#line 1067 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_SET_BACKGROUND_DIALOG, SetBackgroundDialog);
#line 1067 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_handlers_destroy (self);
#line 1068 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->dialog);
#line 1069 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->desktop_background_button);
#line 1070 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->screensaver_button);
#line 1071 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->ok_button);
#line 11153 "Dialogs.c"
}


GType set_background_dialog_get_type (void) {
	static volatile gsize set_background_dialog_type_id__volatile = 0;
	if (g_once_init_enter (&set_background_dialog_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { value_set_background_dialog_init, value_set_background_dialog_free_value, value_set_background_dialog_copy_value, value_set_background_dialog_peek_pointer, "p", value_set_background_dialog_collect_value, "p", value_set_background_dialog_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (SetBackgroundDialogClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) set_background_dialog_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SetBackgroundDialog), 0, (GInstanceInitFunc) set_background_dialog_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType set_background_dialog_type_id;
		set_background_dialog_type_id = g_type_register_fundamental (g_type_fundamental_next (), "SetBackgroundDialog", &g_define_type_info, &g_define_type_fundamental_info, G_TYPE_FLAG_ABSTRACT);
		g_once_init_leave (&set_background_dialog_type_id__volatile, set_background_dialog_type_id);
	}
	return set_background_dialog_type_id__volatile;
}


gpointer set_background_dialog_ref (gpointer instance) {
	SetBackgroundDialog* self;
	self = instance;
#line 1067 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_atomic_int_inc (&self->ref_count);
#line 1067 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return instance;
#line 11178 "Dialogs.c"
}


void set_background_dialog_unref (gpointer instance) {
	SetBackgroundDialog* self;
	self = instance;
#line 1067 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 1067 "/home/jens/Source/shotwell/src/Dialogs.vala"
		SET_BACKGROUND_DIALOG_GET_CLASS (self)->finalize (self);
#line 1067 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 11191 "Dialogs.c"
	}
}


SetBackgroundPhotoDialog* set_background_photo_dialog_construct (GType object_type) {
	SetBackgroundPhotoDialog* self = NULL;
	GtkBuilder* builder = NULL;
	GtkBuilder* _tmp0_ = NULL;
#line 1117 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = app_window_create_builder ("set_background_dialog.ui", self);
#line 1117 "/home/jens/Source/shotwell/src/Dialogs.vala"
	builder = _tmp0_;
#line 1118 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = (SetBackgroundPhotoDialog*) set_background_dialog_construct (object_type, builder);
#line 1116 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (builder);
#line 1116 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return self;
#line 11210 "Dialogs.c"
}


SetBackgroundPhotoDialog* set_background_photo_dialog_new (void) {
#line 1116 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return set_background_photo_dialog_construct (TYPE_SET_BACKGROUND_PHOTO_DIALOG);
#line 11217 "Dialogs.c"
}


gboolean set_background_photo_dialog_execute (SetBackgroundPhotoDialog* self, gboolean* desktop_background, gboolean* screensaver) {
	gboolean _vala_desktop_background = FALSE;
	gboolean _vala_screensaver = FALSE;
	gboolean result = FALSE;
	gboolean _result_ = FALSE;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_ = FALSE;
#line 1121 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_SET_BACKGROUND_PHOTO_DIALOG (self), FALSE);
#line 1122 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = set_background_dialog_execute_base (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_SET_BACKGROUND_DIALOG, SetBackgroundDialog));
#line 1122 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_result_ = _tmp0_;
#line 1124 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_SET_BACKGROUND_DIALOG, SetBackgroundDialog)->desktop;
#line 1124 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_vala_desktop_background = _tmp1_;
#line 1125 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_SET_BACKGROUND_DIALOG, SetBackgroundDialog)->screensaver;
#line 1125 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_vala_screensaver = _tmp2_;
#line 1127 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = _result_;
#line 1127 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (desktop_background) {
#line 1127 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*desktop_background = _vala_desktop_background;
#line 11249 "Dialogs.c"
	}
#line 1127 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (screensaver) {
#line 1127 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*screensaver = _vala_screensaver;
#line 11255 "Dialogs.c"
	}
#line 1127 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 11259 "Dialogs.c"
}


static void set_background_photo_dialog_class_init (SetBackgroundPhotoDialogClass * klass) {
#line 1114 "/home/jens/Source/shotwell/src/Dialogs.vala"
	set_background_photo_dialog_parent_class = g_type_class_peek_parent (klass);
#line 11266 "Dialogs.c"
}


static void set_background_photo_dialog_instance_init (SetBackgroundPhotoDialog * self) {
}


GType set_background_photo_dialog_get_type (void) {
	static volatile gsize set_background_photo_dialog_type_id__volatile = 0;
	if (g_once_init_enter (&set_background_photo_dialog_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SetBackgroundPhotoDialogClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) set_background_photo_dialog_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SetBackgroundPhotoDialog), 0, (GInstanceInitFunc) set_background_photo_dialog_instance_init, NULL };
		GType set_background_photo_dialog_type_id;
		set_background_photo_dialog_type_id = g_type_register_static (TYPE_SET_BACKGROUND_DIALOG, "SetBackgroundPhotoDialog", &g_define_type_info, 0);
		g_once_init_leave (&set_background_photo_dialog_type_id__volatile, set_background_photo_dialog_type_id);
	}
	return set_background_photo_dialog_type_id__volatile;
}


static void _set_background_slideshow_dialog_on_delay_scale_value_changed_gtk_range_value_changed (GtkRange* _sender, gpointer self) {
#line 1143 "/home/jens/Source/shotwell/src/Dialogs.vala"
	set_background_slideshow_dialog_on_delay_scale_value_changed ((SetBackgroundSlideshowDialog*) self);
#line 11289 "Dialogs.c"
}


SetBackgroundSlideshowDialog* set_background_slideshow_dialog_construct (GType object_type) {
	SetBackgroundSlideshowDialog* self = NULL;
	GtkBuilder* builder = NULL;
	GtkBuilder* _tmp0_ = NULL;
	GObject* _tmp1_ = NULL;
	GtkLabel* _tmp2_ = NULL;
	GObject* _tmp3_ = NULL;
	GtkScale* _tmp4_ = NULL;
	GtkScale* _tmp5_ = NULL;
	GtkScale* _tmp6_ = NULL;
	GtkAdjustment* _tmp7_ = NULL;
	GtkAdjustment* _tmp8_ = NULL;
#line 1137 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = app_window_create_builder ("set_background_slideshow_dialog.ui", self);
#line 1137 "/home/jens/Source/shotwell/src/Dialogs.vala"
	builder = _tmp0_;
#line 1138 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = (SetBackgroundSlideshowDialog*) set_background_dialog_construct (object_type, builder);
#line 1140 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = gtk_builder_get_object (builder, "delay_value_label");
#line 1140 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, gtk_label_get_type ()) ? ((GtkLabel*) _tmp1_) : NULL);
#line 1140 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->delay_value_label);
#line 1140 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->delay_value_label = _tmp2_;
#line 1142 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = gtk_builder_get_object (builder, "delay_scale");
#line 1142 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, gtk_scale_get_type ()) ? ((GtkScale*) _tmp3_) : NULL);
#line 1142 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->delay_scale);
#line 1142 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->delay_scale = _tmp4_;
#line 1143 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = self->priv->delay_scale;
#line 1143 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_connect (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, gtk_range_get_type (), GtkRange), "value-changed", (GCallback) _set_background_slideshow_dialog_on_delay_scale_value_changed_gtk_range_value_changed, self);
#line 1144 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = self->priv->delay_scale;
#line 1144 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = gtk_range_get_adjustment (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, gtk_range_get_type (), GtkRange));
#line 1144 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = _tmp7_;
#line 1144 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_adjustment_set_value (_tmp8_, (gdouble) 50);
#line 1136 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (builder);
#line 1136 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return self;
#line 11343 "Dialogs.c"
}


SetBackgroundSlideshowDialog* set_background_slideshow_dialog_new (void) {
#line 1136 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return set_background_slideshow_dialog_construct (TYPE_SET_BACKGROUND_SLIDESHOW_DIALOG);
#line 11350 "Dialogs.c"
}


static void set_background_slideshow_dialog_on_delay_scale_value_changed (SetBackgroundSlideshowDialog* self) {
	gdouble value = 0.0;
	GtkScale* _tmp0_ = NULL;
	GtkAdjustment* _tmp1_ = NULL;
	GtkAdjustment* _tmp2_ = NULL;
	gdouble _tmp3_ = 0.0;
	gdouble _tmp4_ = 0.0;
	gdouble _tmp5_ = 0.0;
	gdouble _tmp6_ = 0.0;
	gdouble _tmp7_ = 0.0;
	gchar* text = NULL;
	gint _tmp8_ = 0;
	GtkLabel* _tmp29_ = NULL;
	const gchar* _tmp30_ = NULL;
#line 1147 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_SET_BACKGROUND_SLIDESHOW_DIALOG (self));
#line 1148 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = self->priv->delay_scale;
#line 1148 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = gtk_range_get_adjustment (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_range_get_type (), GtkRange));
#line 1148 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = _tmp1_;
#line 1148 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = gtk_adjustment_get_value (_tmp2_);
#line 1148 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = _tmp3_;
#line 1148 "/home/jens/Source/shotwell/src/Dialogs.vala"
	value = _tmp4_;
#line 1153 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = value;
#line 1153 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = pow (_tmp5_, (gdouble) 5);
#line 1153 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = pow ((gdouble) 90, (gdouble) 5);
#line 1153 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->delay_value = (gint) (((((_tmp6_ / _tmp7_) * 60) * 60) * 24) + 5);
#line 1157 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = self->priv->delay_value;
#line 1157 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp8_ < 60) {
#line 11394 "Dialogs.c"
		gint _tmp9_ = 0;
		const gchar* _tmp10_ = NULL;
		gint _tmp11_ = 0;
		gchar* _tmp12_ = NULL;
#line 1158 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp9_ = self->priv->delay_value;
#line 1158 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp10_ = ngettext ("%d second", "%d seconds", (gulong) _tmp9_);
#line 1158 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp11_ = self->priv->delay_value;
#line 1158 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp12_ = g_strdup_printf (_tmp10_, _tmp11_);
#line 1158 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (text);
#line 1158 "/home/jens/Source/shotwell/src/Dialogs.vala"
		text = _tmp12_;
#line 11411 "Dialogs.c"
	} else {
		gint _tmp13_ = 0;
#line 1159 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp13_ = self->priv->delay_value;
#line 1159 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp13_ < (60 * 60)) {
#line 11418 "Dialogs.c"
			gint minutes = 0;
			gint _tmp14_ = 0;
			gint _tmp15_ = 0;
			const gchar* _tmp16_ = NULL;
			gint _tmp17_ = 0;
			gchar* _tmp18_ = NULL;
			gint _tmp19_ = 0;
#line 1160 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp14_ = self->priv->delay_value;
#line 1160 "/home/jens/Source/shotwell/src/Dialogs.vala"
			minutes = _tmp14_ / 60;
#line 1161 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp15_ = minutes;
#line 1161 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp16_ = ngettext ("%d minute", "%d minutes", (gulong) _tmp15_);
#line 1161 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp17_ = minutes;
#line 1161 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp18_ = g_strdup_printf (_tmp16_, _tmp17_);
#line 1161 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (text);
#line 1161 "/home/jens/Source/shotwell/src/Dialogs.vala"
			text = _tmp18_;
#line 1162 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp19_ = minutes;
#line 1162 "/home/jens/Source/shotwell/src/Dialogs.vala"
			self->priv->delay_value = _tmp19_ * 60;
#line 11446 "Dialogs.c"
		} else {
			gint _tmp20_ = 0;
#line 1163 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp20_ = self->priv->delay_value;
#line 1163 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (_tmp20_ < ((60 * 60) * 24)) {
#line 11453 "Dialogs.c"
				gint hours = 0;
				gint _tmp21_ = 0;
				gint _tmp22_ = 0;
				const gchar* _tmp23_ = NULL;
				gint _tmp24_ = 0;
				gchar* _tmp25_ = NULL;
				gint _tmp26_ = 0;
#line 1164 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp21_ = self->priv->delay_value;
#line 1164 "/home/jens/Source/shotwell/src/Dialogs.vala"
				hours = _tmp21_ / (60 * 60);
#line 1165 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp22_ = hours;
#line 1165 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp23_ = ngettext ("%d hour", "%d hours", (gulong) _tmp22_);
#line 1165 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp24_ = hours;
#line 1165 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp25_ = g_strdup_printf (_tmp23_, _tmp24_);
#line 1165 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (text);
#line 1165 "/home/jens/Source/shotwell/src/Dialogs.vala"
				text = _tmp25_;
#line 1166 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp26_ = hours;
#line 1166 "/home/jens/Source/shotwell/src/Dialogs.vala"
				self->priv->delay_value = _tmp26_ * (60 * 60);
#line 11481 "Dialogs.c"
			} else {
				const gchar* _tmp27_ = NULL;
				gchar* _tmp28_ = NULL;
#line 1168 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp27_ = _ ("1 day");
#line 1168 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp28_ = g_strdup (_tmp27_);
#line 1168 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (text);
#line 1168 "/home/jens/Source/shotwell/src/Dialogs.vala"
				text = _tmp28_;
#line 1169 "/home/jens/Source/shotwell/src/Dialogs.vala"
				self->priv->delay_value = (60 * 60) * 24;
#line 11495 "Dialogs.c"
			}
		}
	}
#line 1172 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp29_ = self->priv->delay_value_label;
#line 1172 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp30_ = text;
#line 1172 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_label_set_label (_tmp29_, _tmp30_);
#line 1147 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (text);
#line 11507 "Dialogs.c"
}


gboolean set_background_slideshow_dialog_execute (SetBackgroundSlideshowDialog* self, gint* delay_value, gboolean* desktop_background, gboolean* screensaver) {
	gint _vala_delay_value = 0;
	gboolean _vala_desktop_background = FALSE;
	gboolean _vala_screensaver = FALSE;
	gboolean result = FALSE;
	gboolean _result_ = FALSE;
	gboolean _tmp0_ = FALSE;
	gint _tmp1_ = 0;
	gboolean _tmp2_ = FALSE;
	gboolean _tmp3_ = FALSE;
#line 1175 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_SET_BACKGROUND_SLIDESHOW_DIALOG (self), FALSE);
#line 1176 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = set_background_dialog_execute_base (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_SET_BACKGROUND_DIALOG, SetBackgroundDialog));
#line 1176 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_result_ = _tmp0_;
#line 1178 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = self->priv->delay_value;
#line 1178 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_vala_delay_value = _tmp1_;
#line 1179 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_SET_BACKGROUND_DIALOG, SetBackgroundDialog)->desktop;
#line 1179 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_vala_desktop_background = _tmp2_;
#line 1180 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_SET_BACKGROUND_DIALOG, SetBackgroundDialog)->screensaver;
#line 1180 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_vala_screensaver = _tmp3_;
#line 1182 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = _result_;
#line 1182 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (delay_value) {
#line 1182 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*delay_value = _vala_delay_value;
#line 11545 "Dialogs.c"
	}
#line 1182 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (desktop_background) {
#line 1182 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*desktop_background = _vala_desktop_background;
#line 11551 "Dialogs.c"
	}
#line 1182 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (screensaver) {
#line 1182 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*screensaver = _vala_screensaver;
#line 11557 "Dialogs.c"
	}
#line 1182 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 11561 "Dialogs.c"
}


static void set_background_slideshow_dialog_class_init (SetBackgroundSlideshowDialogClass * klass) {
#line 1131 "/home/jens/Source/shotwell/src/Dialogs.vala"
	set_background_slideshow_dialog_parent_class = g_type_class_peek_parent (klass);
#line 1131 "/home/jens/Source/shotwell/src/Dialogs.vala"
	((SetBackgroundDialogClass *) klass)->finalize = set_background_slideshow_dialog_finalize;
#line 1131 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_type_class_add_private (klass, sizeof (SetBackgroundSlideshowDialogPrivate));
#line 11572 "Dialogs.c"
}


static void set_background_slideshow_dialog_instance_init (SetBackgroundSlideshowDialog * self) {
#line 1131 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv = SET_BACKGROUND_SLIDESHOW_DIALOG_GET_PRIVATE (self);
#line 1134 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->delay_value = 0;
#line 11581 "Dialogs.c"
}


static void set_background_slideshow_dialog_finalize (SetBackgroundDialog* obj) {
	SetBackgroundSlideshowDialog * self;
#line 1131 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_SET_BACKGROUND_SLIDESHOW_DIALOG, SetBackgroundSlideshowDialog);
#line 1132 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->delay_value_label);
#line 1133 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->delay_scale);
#line 1131 "/home/jens/Source/shotwell/src/Dialogs.vala"
	SET_BACKGROUND_DIALOG_CLASS (set_background_slideshow_dialog_parent_class)->finalize (obj);
#line 11595 "Dialogs.c"
}


GType set_background_slideshow_dialog_get_type (void) {
	static volatile gsize set_background_slideshow_dialog_type_id__volatile = 0;
	if (g_once_init_enter (&set_background_slideshow_dialog_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SetBackgroundSlideshowDialogClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) set_background_slideshow_dialog_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SetBackgroundSlideshowDialog), 0, (GInstanceInitFunc) set_background_slideshow_dialog_instance_init, NULL };
		GType set_background_slideshow_dialog_type_id;
		set_background_slideshow_dialog_type_id = g_type_register_static (TYPE_SET_BACKGROUND_DIALOG, "SetBackgroundSlideshowDialog", &g_define_type_info, 0);
		g_once_init_leave (&set_background_slideshow_dialog_type_id__volatile, set_background_slideshow_dialog_type_id);
	}
	return set_background_slideshow_dialog_type_id__volatile;
}


TextEntryDialog* text_entry_dialog_construct (GType object_type) {
	TextEntryDialog * self = NULL;
	gboolean use_header = FALSE;
	GtkSettings* _tmp0_ = NULL;
	gint _tmp1_ = 0;
	gboolean _tmp2_ = FALSE;
#line 1198 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = gtk_settings_get_default ();
#line 1198 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_get (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, G_TYPE_OBJECT, GObject), "gtk-dialogs-use-header", &use_header, NULL);
#line 1199 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = use_header;
#line 1199 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp2_) {
#line 1199 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp1_ = 1;
#line 11627 "Dialogs.c"
	} else {
#line 1199 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp1_ = 0;
#line 11631 "Dialogs.c"
	}
#line 1199 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = (TextEntryDialog*) g_object_new (object_type, "use-header-bar", _tmp1_, NULL);
#line 1196 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return self;
#line 11637 "Dialogs.c"
}


TextEntryDialog* text_entry_dialog_new (void) {
#line 1196 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return text_entry_dialog_construct (TYPE_TEXT_ENTRY_DIALOG);
#line 11644 "Dialogs.c"
}


void text_entry_dialog_set_builder (TextEntryDialog* self, GtkBuilder* builder) {
	GtkBuilder* _tmp0_ = NULL;
	GtkBuilder* _tmp1_ = NULL;
#line 1202 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_TEXT_ENTRY_DIALOG (self));
#line 1202 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (GTK_IS_BUILDER (builder));
#line 1203 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = builder;
#line 1203 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 1203 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->builder);
#line 1203 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->builder = _tmp1_;
#line 11663 "Dialogs.c"
}


static void _text_entry_dialog_on_entry_changed_gtk_editable_changed (GtkEditable* _sender, gpointer self) {
#line 1220 "/home/jens/Source/shotwell/src/Dialogs.vala"
	text_entry_dialog_on_entry_changed ((TextEntryDialog*) self);
#line 11670 "Dialogs.c"
}


void text_entry_dialog_setup (TextEntryDialog* self, TextEntryDialogOnModifyValidateType modify_validate, void* modify_validate_target, const gchar* title, const gchar* label, const gchar* initial_text, GeeCollection* completion_list, const gchar* completion_delimiter) {
	const gchar* _tmp0_ = NULL;
	AppWindow* _tmp1_ = NULL;
	AppWindow* _tmp2_ = NULL;
	GdkWindow* _tmp3_ = NULL;
	AppWindow* _tmp4_ = NULL;
	AppWindow* _tmp5_ = NULL;
	TextEntryDialogOnModifyValidateType _tmp6_ = NULL;
	void* _tmp6__target = NULL;
	GtkLabel* name_label = NULL;
	GtkBuilder* _tmp7_ = NULL;
	GObject* _tmp8_ = NULL;
	GtkLabel* _tmp9_ = NULL;
	GtkLabel* _tmp10_ = NULL;
	const gchar* _tmp11_ = NULL;
	GtkBuilder* _tmp12_ = NULL;
	GObject* _tmp13_ = NULL;
	GtkEntry* _tmp14_ = NULL;
	const gchar* _tmp15_ = NULL;
	const gchar* _tmp16_ = NULL;
	GtkEntry* _tmp18_ = NULL;
	GtkEntry* _tmp19_ = NULL;
	GtkEntry* _tmp20_ = NULL;
	GtkWidget* _tmp21_ = NULL;
	GtkButtonBox* _tmp22_ = NULL;
	GtkButtonBox* _tmp23_ = NULL;
	GtkWidget* _tmp24_ = NULL;
	GtkButton* _tmp25_ = NULL;
	GtkWidget* _tmp26_ = NULL;
	GtkButton* _tmp27_ = NULL;
	GeeCollection* _tmp28_ = NULL;
#line 1206 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_TEXT_ENTRY_DIALOG (self));
#line 1206 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (title != NULL);
#line 1206 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (label != NULL);
#line 1206 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail ((completion_list == NULL) || GEE_IS_COLLECTION (completion_list));
#line 1208 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = title;
#line 1208 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_window_set_title (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), _tmp0_);
#line 1209 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_window_set_resizable (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), TRUE);
#line 1210 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = app_window_get_instance ();
#line 1210 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = _tmp1_;
#line 1210 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = gtk_widget_get_parent_window (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, gtk_widget_get_type (), GtkWidget));
#line 1210 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_set_parent_window (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget), _tmp3_);
#line 1210 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp2_);
#line 1211 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = app_window_get_instance ();
#line 1211 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = _tmp4_;
#line 1211 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_window_set_transient_for (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, gtk_window_get_type (), GtkWindow));
#line 1211 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp5_);
#line 1212 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = modify_validate;
#line 1212 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6__target = modify_validate_target;
#line 1212 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->on_modify_validate = _tmp6_;
#line 1212 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->on_modify_validate_target = _tmp6__target;
#line 1214 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = self->priv->builder;
#line 1214 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = gtk_builder_get_object (_tmp7_, "label");
#line 1214 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp8_, gtk_label_get_type ()) ? ((GtkLabel*) _tmp8_) : NULL);
#line 1214 "/home/jens/Source/shotwell/src/Dialogs.vala"
	name_label = _tmp9_;
#line 1215 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp10_ = name_label;
#line 1215 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp11_ = label;
#line 1215 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_label_set_text (_tmp10_, _tmp11_);
#line 1217 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp12_ = self->priv->builder;
#line 1217 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp13_ = gtk_builder_get_object (_tmp12_, "entry");
#line 1217 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp14_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp13_, gtk_entry_get_type ()) ? ((GtkEntry*) _tmp13_) : NULL);
#line 1217 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->entry);
#line 1217 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->entry = _tmp14_;
#line 1218 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp16_ = initial_text;
#line 1218 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp16_ != NULL) {
#line 11773 "Dialogs.c"
		const gchar* _tmp17_ = NULL;
#line 1218 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp17_ = initial_text;
#line 1218 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp15_ = _tmp17_;
#line 11779 "Dialogs.c"
	} else {
#line 1218 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp15_ = "";
#line 11783 "Dialogs.c"
	}
#line 1218 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp18_ = self->priv->entry;
#line 1218 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_entry_set_text (_tmp18_, _tmp15_);
#line 1219 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp19_ = self->priv->entry;
#line 1219 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_grab_focus (G_TYPE_CHECK_INSTANCE_CAST (_tmp19_, gtk_widget_get_type (), GtkWidget));
#line 1220 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp20_ = self->priv->entry;
#line 1220 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp20_, GTK_TYPE_EDITABLE, GtkEditable), "changed", (GCallback) _text_entry_dialog_on_entry_changed_gtk_editable_changed, self, 0);
#line 1222 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp21_ = gtk_dialog_get_action_area (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog));
#line 1222 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp22_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp21_, gtk_button_box_get_type (), GtkButtonBox));
#line 1222 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->action_area_box);
#line 1222 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->action_area_box = _tmp22_;
#line 1223 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp23_ = self->priv->action_area_box;
#line 1223 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_button_box_set_layout (_tmp23_, GTK_BUTTONBOX_END);
#line 1225 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp24_ = gtk_dialog_add_button (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog), RESOURCES_CANCEL_LABEL, (gint) GTK_RESPONSE_CANCEL);
#line 1225 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp25_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp24_, gtk_button_get_type (), GtkButton));
#line 1225 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->button1);
#line 1225 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->button1 = _tmp25_;
#line 1226 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp26_ = gtk_dialog_add_button (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog), RESOURCES_SAVE_LABEL, (gint) GTK_RESPONSE_OK);
#line 1226 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp27_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp26_, gtk_button_get_type (), GtkButton));
#line 1226 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->button2);
#line 1226 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->button2 = _tmp27_;
#line 1227 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_dialog_set_default_response (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog), (gint) GTK_RESPONSE_OK);
#line 1229 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp28_ = completion_list;
#line 1229 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp28_ != NULL) {
#line 11831 "Dialogs.c"
		EntryMultiCompletion* completion = NULL;
		GeeCollection* _tmp29_ = NULL;
		const gchar* _tmp30_ = NULL;
		EntryMultiCompletion* _tmp31_ = NULL;
		GtkEntry* _tmp32_ = NULL;
		EntryMultiCompletion* _tmp33_ = NULL;
#line 1230 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp29_ = completion_list;
#line 1230 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp30_ = completion_delimiter;
#line 1230 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp31_ = entry_multi_completion_new (_tmp29_, _tmp30_);
#line 1230 "/home/jens/Source/shotwell/src/Dialogs.vala"
		completion = _tmp31_;
#line 1232 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp32_ = self->priv->entry;
#line 1232 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp33_ = completion;
#line 1232 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_entry_set_completion (_tmp32_, G_TYPE_CHECK_INSTANCE_CAST (_tmp33_, gtk_entry_completion_get_type (), GtkEntryCompletion));
#line 1229 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (completion);
#line 11854 "Dialogs.c"
	}
#line 1235 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_dialog_set_default_response (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog), (gint) GTK_RESPONSE_OK);
#line 1236 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_window_set_has_resize_grip (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), FALSE);
#line 1206 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (name_label);
#line 11862 "Dialogs.c"
}


gchar* text_entry_dialog_execute (TextEntryDialog* self) {
	gchar* result = NULL;
	gchar* text = NULL;
	TextEntryDialogOnModifyValidateType _tmp0_ = NULL;
	void* _tmp0__target = NULL;
	GtkEntry* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	gboolean _tmp3_ = FALSE;
	gint _tmp4_ = 0;
	GtkEntry* _tmp8_ = NULL;
	guint _tmp9_ = 0U;
#line 1239 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_TEXT_ENTRY_DIALOG (self), NULL);
#line 1240 "/home/jens/Source/shotwell/src/Dialogs.vala"
	text = NULL;
#line 1243 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = self->priv->on_modify_validate;
#line 1243 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0__target = self->priv->on_modify_validate_target;
#line 1243 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = self->priv->entry;
#line 1243 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = gtk_entry_get_text (_tmp1_);
#line 1243 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = _tmp0_ (_tmp2_, _tmp0__target);
#line 1243 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_dialog_set_response_sensitive (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog), (gint) GTK_RESPONSE_OK, _tmp3_);
#line 1245 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_show_all (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 1247 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog));
#line 1247 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp4_ == ((gint) GTK_RESPONSE_OK)) {
#line 11899 "Dialogs.c"
		GtkEntry* _tmp5_ = NULL;
		const gchar* _tmp6_ = NULL;
		gchar* _tmp7_ = NULL;
#line 1248 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp5_ = self->priv->entry;
#line 1248 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp6_ = gtk_entry_get_text (_tmp5_);
#line 1248 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp7_ = g_strdup (_tmp6_);
#line 1248 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (text);
#line 1248 "/home/jens/Source/shotwell/src/Dialogs.vala"
		text = _tmp7_;
#line 11913 "Dialogs.c"
	}
#line 1250 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = self->priv->entry;
#line 1250 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_parse_name ("changed", GTK_TYPE_EDITABLE, &_tmp9_, NULL, FALSE);
#line 1250 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_handlers_disconnect_matched (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, GTK_TYPE_EDITABLE, GtkEditable), G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp9_, 0, NULL, (GCallback) _text_entry_dialog_on_entry_changed_gtk_editable_changed, self);
#line 1251 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 1253 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = text;
#line 1253 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 11927 "Dialogs.c"
}


void text_entry_dialog_on_entry_changed (TextEntryDialog* self) {
	TextEntryDialogOnModifyValidateType _tmp0_ = NULL;
	void* _tmp0__target = NULL;
	GtkEntry* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	gboolean _tmp3_ = FALSE;
#line 1256 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_TEXT_ENTRY_DIALOG (self));
#line 1257 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = self->priv->on_modify_validate;
#line 1257 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0__target = self->priv->on_modify_validate_target;
#line 1257 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = self->priv->entry;
#line 1257 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = gtk_entry_get_text (_tmp1_);
#line 1257 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = _tmp0_ (_tmp2_, _tmp0__target);
#line 1257 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_dialog_set_response_sensitive (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog), (gint) GTK_RESPONSE_OK, _tmp3_);
#line 11951 "Dialogs.c"
}


static void text_entry_dialog_class_init (TextEntryDialogClass * klass) {
#line 1186 "/home/jens/Source/shotwell/src/Dialogs.vala"
	text_entry_dialog_parent_class = g_type_class_peek_parent (klass);
#line 1186 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_type_class_add_private (klass, sizeof (TextEntryDialogPrivate));
#line 1186 "/home/jens/Source/shotwell/src/Dialogs.vala"
	G_OBJECT_CLASS (klass)->finalize = text_entry_dialog_finalize;
#line 11962 "Dialogs.c"
}


static void text_entry_dialog_instance_init (TextEntryDialog * self) {
#line 1186 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv = TEXT_ENTRY_DIALOG_GET_PRIVATE (self);
#line 11969 "Dialogs.c"
}


static void text_entry_dialog_finalize (GObject* obj) {
	TextEntryDialog * self;
#line 1186 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_TEXT_ENTRY_DIALOG, TextEntryDialog);
#line 1190 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->entry);
#line 1191 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->builder);
#line 1192 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->button1);
#line 1193 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->button2);
#line 1194 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->action_area_box);
#line 1186 "/home/jens/Source/shotwell/src/Dialogs.vala"
	G_OBJECT_CLASS (text_entry_dialog_parent_class)->finalize (obj);
#line 11989 "Dialogs.c"
}


GType text_entry_dialog_get_type (void) {
	static volatile gsize text_entry_dialog_type_id__volatile = 0;
	if (g_once_init_enter (&text_entry_dialog_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (TextEntryDialogClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) text_entry_dialog_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TextEntryDialog), 0, (GInstanceInitFunc) text_entry_dialog_instance_init, NULL };
		GType text_entry_dialog_type_id;
		text_entry_dialog_type_id = g_type_register_static (gtk_dialog_get_type (), "TextEntryDialog", &g_define_type_info, 0);
		g_once_init_leave (&text_entry_dialog_type_id__volatile, text_entry_dialog_type_id);
	}
	return text_entry_dialog_type_id__volatile;
}


MultiTextEntryDialog* multi_text_entry_dialog_construct (GType object_type) {
	MultiTextEntryDialog * self = NULL;
	gboolean use_header = FALSE;
	GtkSettings* _tmp0_ = NULL;
	gint _tmp1_ = 0;
	gboolean _tmp2_ = FALSE;
#line 1273 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = gtk_settings_get_default ();
#line 1273 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_get (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, G_TYPE_OBJECT, GObject), "gtk-dialogs-use-header", &use_header, NULL);
#line 1274 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = use_header;
#line 1274 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp2_) {
#line 1274 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp1_ = 1;
#line 12021 "Dialogs.c"
	} else {
#line 1274 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp1_ = 0;
#line 12025 "Dialogs.c"
	}
#line 1274 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = (MultiTextEntryDialog*) g_object_new (object_type, "use-header-bar", _tmp1_, NULL);
#line 1271 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return self;
#line 12031 "Dialogs.c"
}


MultiTextEntryDialog* multi_text_entry_dialog_new (void) {
#line 1271 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return multi_text_entry_dialog_construct (TYPE_MULTI_TEXT_ENTRY_DIALOG);
#line 12038 "Dialogs.c"
}


void multi_text_entry_dialog_set_builder (MultiTextEntryDialog* self, GtkBuilder* builder) {
	GtkBuilder* _tmp0_ = NULL;
	GtkBuilder* _tmp1_ = NULL;
#line 1277 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_MULTI_TEXT_ENTRY_DIALOG (self));
#line 1277 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (GTK_IS_BUILDER (builder));
#line 1278 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = builder;
#line 1278 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 1278 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->builder);
#line 1278 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->builder = _tmp1_;
#line 12057 "Dialogs.c"
}


void multi_text_entry_dialog_setup (MultiTextEntryDialog* self, MultiTextEntryDialogOnModifyValidateType modify_validate, void* modify_validate_target, const gchar* title, const gchar* label, const gchar* initial_text) {
	const gchar* _tmp0_ = NULL;
	AppWindow* _tmp1_ = NULL;
	AppWindow* _tmp2_ = NULL;
	GdkWindow* _tmp3_ = NULL;
	AppWindow* _tmp4_ = NULL;
	AppWindow* _tmp5_ = NULL;
	MultiTextEntryDialogOnModifyValidateType _tmp6_ = NULL;
	void* _tmp6__target = NULL;
	GtkBuilder* _tmp7_ = NULL;
	GObject* _tmp8_ = NULL;
	GtkTextView* _tmp9_ = NULL;
	GtkTextView* _tmp10_ = NULL;
	GtkTextView* _tmp11_ = NULL;
	GtkTextBuffer* _tmp12_ = NULL;
	GtkTextBuffer* _tmp13_ = NULL;
	const gchar* _tmp14_ = NULL;
	const gchar* _tmp15_ = NULL;
	GtkTextView* _tmp17_ = NULL;
	GtkTextBuffer* _tmp18_ = NULL;
	GtkTextBuffer* _tmp19_ = NULL;
	GtkTextView* _tmp20_ = NULL;
	GtkWidget* _tmp21_ = NULL;
	GtkButtonBox* _tmp22_ = NULL;
	GtkButtonBox* _tmp23_ = NULL;
	GtkWidget* _tmp24_ = NULL;
	GtkButton* _tmp25_ = NULL;
	GtkWidget* _tmp26_ = NULL;
	GtkButton* _tmp27_ = NULL;
#line 1281 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_MULTI_TEXT_ENTRY_DIALOG (self));
#line 1281 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (title != NULL);
#line 1281 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (label != NULL);
#line 1282 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = title;
#line 1282 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_window_set_title (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), _tmp0_);
#line 1283 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_window_set_resizable (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), TRUE);
#line 1284 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_window_set_default_size (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), 500, 300);
#line 1285 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = app_window_get_instance ();
#line 1285 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = _tmp1_;
#line 1285 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = gtk_widget_get_parent_window (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, gtk_widget_get_type (), GtkWidget));
#line 1285 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_set_parent_window (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget), _tmp3_);
#line 1285 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp2_);
#line 1286 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = app_window_get_instance ();
#line 1286 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = _tmp4_;
#line 1286 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_window_set_transient_for (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, gtk_window_get_type (), GtkWindow));
#line 1286 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp5_);
#line 1287 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = modify_validate;
#line 1287 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6__target = modify_validate_target;
#line 1287 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->on_modify_validate = _tmp6_;
#line 1287 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->on_modify_validate_target = _tmp6__target;
#line 1289 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = self->priv->builder;
#line 1289 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = gtk_builder_get_object (_tmp7_, "textview1");
#line 1289 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp8_, gtk_text_view_get_type ()) ? ((GtkTextView*) _tmp8_) : NULL);
#line 1289 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->entry);
#line 1289 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->entry = _tmp9_;
#line 1290 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp10_ = self->priv->entry;
#line 1290 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_text_view_set_wrap_mode (_tmp10_, GTK_WRAP_WORD);
#line 1291 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp11_ = self->priv->entry;
#line 1291 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp12_ = gtk_text_buffer_new (NULL);
#line 1291 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp13_ = _tmp12_;
#line 1291 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_text_view_set_buffer (_tmp11_, _tmp13_);
#line 1291 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp13_);
#line 1292 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp15_ = initial_text;
#line 1292 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp15_ != NULL) {
#line 12158 "Dialogs.c"
		const gchar* _tmp16_ = NULL;
#line 1292 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp16_ = initial_text;
#line 1292 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp14_ = _tmp16_;
#line 12164 "Dialogs.c"
	} else {
#line 1292 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp14_ = "";
#line 12168 "Dialogs.c"
	}
#line 1292 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp17_ = self->priv->entry;
#line 1292 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp18_ = gtk_text_view_get_buffer (_tmp17_);
#line 1292 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp19_ = _tmp18_;
#line 1292 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_set (_tmp19_, "text", _tmp14_, NULL);
#line 1294 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp20_ = self->priv->entry;
#line 1294 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_grab_focus (G_TYPE_CHECK_INSTANCE_CAST (_tmp20_, gtk_widget_get_type (), GtkWidget));
#line 1296 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp21_ = gtk_dialog_get_action_area (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog));
#line 1296 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp22_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp21_, gtk_button_box_get_type (), GtkButtonBox));
#line 1296 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->action_area_box);
#line 1296 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->action_area_box = _tmp22_;
#line 1297 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp23_ = self->priv->action_area_box;
#line 1297 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_button_box_set_layout (_tmp23_, GTK_BUTTONBOX_END);
#line 1299 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp24_ = gtk_dialog_add_button (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog), RESOURCES_CANCEL_LABEL, (gint) GTK_RESPONSE_CANCEL);
#line 1299 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp25_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp24_, gtk_button_get_type (), GtkButton));
#line 1299 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->button1);
#line 1299 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->button1 = _tmp25_;
#line 1300 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp26_ = gtk_dialog_add_button (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog), RESOURCES_SAVE_LABEL, (gint) GTK_RESPONSE_OK);
#line 1300 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp27_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp26_, gtk_button_get_type (), GtkButton));
#line 1300 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->button2);
#line 1300 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->button2 = _tmp27_;
#line 1301 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_dialog_set_default_response (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog), (gint) GTK_RESPONSE_OK);
#line 1303 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_window_set_has_resize_grip (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), TRUE);
#line 12214 "Dialogs.c"
}


gchar* multi_text_entry_dialog_execute (MultiTextEntryDialog* self) {
	gchar* result = NULL;
	gchar* text = NULL;
	gint _tmp0_ = 0;
#line 1306 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_MULTI_TEXT_ENTRY_DIALOG (self), NULL);
#line 1307 "/home/jens/Source/shotwell/src/Dialogs.vala"
	text = NULL;
#line 1309 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_show_all (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 1311 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog));
#line 1311 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp0_ == ((gint) GTK_RESPONSE_OK)) {
#line 12232 "Dialogs.c"
		GtkTextView* _tmp1_ = NULL;
		GtkTextBuffer* _tmp2_ = NULL;
		GtkTextBuffer* _tmp3_ = NULL;
		gchar* _tmp4_ = NULL;
		gchar* _tmp5_ = NULL;
#line 1312 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp1_ = self->priv->entry;
#line 1312 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp2_ = gtk_text_view_get_buffer (_tmp1_);
#line 1312 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp3_ = _tmp2_;
#line 1312 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_object_get (_tmp3_, "text", &_tmp4_, NULL);
#line 1312 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp5_ = _tmp4_;
#line 1312 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (text);
#line 1312 "/home/jens/Source/shotwell/src/Dialogs.vala"
		text = _tmp5_;
#line 12252 "Dialogs.c"
	}
#line 1314 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 1316 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = text;
#line 1316 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 12260 "Dialogs.c"
}


static void multi_text_entry_dialog_class_init (MultiTextEntryDialogClass * klass) {
#line 1261 "/home/jens/Source/shotwell/src/Dialogs.vala"
	multi_text_entry_dialog_parent_class = g_type_class_peek_parent (klass);
#line 1261 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_type_class_add_private (klass, sizeof (MultiTextEntryDialogPrivate));
#line 1261 "/home/jens/Source/shotwell/src/Dialogs.vala"
	G_OBJECT_CLASS (klass)->finalize = multi_text_entry_dialog_finalize;
#line 12271 "Dialogs.c"
}


static void multi_text_entry_dialog_instance_init (MultiTextEntryDialog * self) {
#line 1261 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv = MULTI_TEXT_ENTRY_DIALOG_GET_PRIVATE (self);
#line 12278 "Dialogs.c"
}


static void multi_text_entry_dialog_finalize (GObject* obj) {
	MultiTextEntryDialog * self;
#line 1261 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_MULTI_TEXT_ENTRY_DIALOG, MultiTextEntryDialog);
#line 1265 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->entry);
#line 1266 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->builder);
#line 1267 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->button1);
#line 1268 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->button2);
#line 1269 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->action_area_box);
#line 1261 "/home/jens/Source/shotwell/src/Dialogs.vala"
	G_OBJECT_CLASS (multi_text_entry_dialog_parent_class)->finalize (obj);
#line 12298 "Dialogs.c"
}


GType multi_text_entry_dialog_get_type (void) {
	static volatile gsize multi_text_entry_dialog_type_id__volatile = 0;
	if (g_once_init_enter (&multi_text_entry_dialog_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (MultiTextEntryDialogClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) multi_text_entry_dialog_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (MultiTextEntryDialog), 0, (GInstanceInitFunc) multi_text_entry_dialog_instance_init, NULL };
		GType multi_text_entry_dialog_type_id;
		multi_text_entry_dialog_type_id = g_type_register_static (gtk_dialog_get_type (), "MultiTextEntryDialog", &g_define_type_info, 0);
		g_once_init_leave (&multi_text_entry_dialog_type_id__volatile, multi_text_entry_dialog_type_id);
	}
	return multi_text_entry_dialog_type_id__volatile;
}


EventRenameDialog* event_rename_dialog_construct (GType object_type, const gchar* event_name) {
	EventRenameDialog* self = NULL;
	const gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
#line 1322 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = _ ("Rename Event");
#line 1322 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = _ ("Name:");
#line 1322 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = event_name;
#line 1322 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = (EventRenameDialog*) text_entry_dialog_mediator_construct (object_type, _tmp0_, _tmp1_, _tmp2_, NULL, NULL);
#line 1321 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return self;
#line 12329 "Dialogs.c"
}


EventRenameDialog* event_rename_dialog_new (const gchar* event_name) {
#line 1321 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return event_rename_dialog_construct (TYPE_EVENT_RENAME_DIALOG, event_name);
#line 12336 "Dialogs.c"
}


static gchar* event_rename_dialog_real_execute (EventRenameDialog* self) {
	gchar* result = NULL;
	gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
#line 1326 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = _text_entry_dialog_mediator_execute (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_TEXT_ENTRY_DIALOG_MEDIATOR, TextEntryDialogMediator));
#line 1326 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = _tmp0_;
#line 1326 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = event_prep_event_name (_tmp1_);
#line 1326 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = _tmp2_;
#line 1326 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp1_);
#line 1326 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = _tmp3_;
#line 1326 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 12360 "Dialogs.c"
}


gchar* event_rename_dialog_execute (EventRenameDialog* self) {
#line 1325 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_EVENT_RENAME_DIALOG (self), NULL);
#line 1325 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return EVENT_RENAME_DIALOG_GET_CLASS (self)->execute (self);
#line 12369 "Dialogs.c"
}


static void event_rename_dialog_class_init (EventRenameDialogClass * klass) {
#line 1320 "/home/jens/Source/shotwell/src/Dialogs.vala"
	event_rename_dialog_parent_class = g_type_class_peek_parent (klass);
#line 1320 "/home/jens/Source/shotwell/src/Dialogs.vala"
	((EventRenameDialogClass *) klass)->execute = event_rename_dialog_real_execute;
#line 12378 "Dialogs.c"
}


static void event_rename_dialog_instance_init (EventRenameDialog * self) {
}


GType event_rename_dialog_get_type (void) {
	static volatile gsize event_rename_dialog_type_id__volatile = 0;
	if (g_once_init_enter (&event_rename_dialog_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (EventRenameDialogClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) event_rename_dialog_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (EventRenameDialog), 0, (GInstanceInitFunc) event_rename_dialog_instance_init, NULL };
		GType event_rename_dialog_type_id;
		event_rename_dialog_type_id = g_type_register_static (TYPE_TEXT_ENTRY_DIALOG_MEDIATOR, "EventRenameDialog", &g_define_type_info, 0);
		g_once_init_leave (&event_rename_dialog_type_id__volatile, event_rename_dialog_type_id);
	}
	return event_rename_dialog_type_id__volatile;
}


EditTitleDialog* edit_title_dialog_construct (GType object_type, const gchar* photo_title) {
	EditTitleDialog* self = NULL;
	const gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
#line 1333 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = C_ ("Dialog Title", "Edit Title");
#line 1333 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = _ ("Title:");
#line 1333 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = photo_title;
#line 1333 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = (EditTitleDialog*) text_entry_dialog_mediator_construct (object_type, _tmp0_, _tmp1_, _tmp2_, NULL, NULL);
#line 1331 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return self;
#line 12413 "Dialogs.c"
}


EditTitleDialog* edit_title_dialog_new (const gchar* photo_title) {
#line 1331 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return edit_title_dialog_construct (TYPE_EDIT_TITLE_DIALOG, photo_title);
#line 12420 "Dialogs.c"
}


static gchar* edit_title_dialog_real_execute (EditTitleDialog* self) {
	gchar* result = NULL;
	gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
#line 1338 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = _text_entry_dialog_mediator_execute (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_TEXT_ENTRY_DIALOG_MEDIATOR, TextEntryDialogMediator));
#line 1338 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = _tmp0_;
#line 1338 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = media_source_prep_title (_tmp1_);
#line 1338 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = _tmp2_;
#line 1338 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp1_);
#line 1338 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = _tmp3_;
#line 1338 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 12444 "Dialogs.c"
}


gchar* edit_title_dialog_execute (EditTitleDialog* self) {
#line 1337 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_EDIT_TITLE_DIALOG (self), NULL);
#line 1337 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return EDIT_TITLE_DIALOG_GET_CLASS (self)->execute (self);
#line 12453 "Dialogs.c"
}


static gboolean edit_title_dialog_real_on_modify_validate (TextEntryDialogMediator* base, const gchar* text) {
	EditTitleDialog * self;
	gboolean result = FALSE;
#line 1341 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_EDIT_TITLE_DIALOG, EditTitleDialog);
#line 1341 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (text != NULL, FALSE);
#line 1342 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = TRUE;
#line 1342 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 12468 "Dialogs.c"
}


static void edit_title_dialog_class_init (EditTitleDialogClass * klass) {
#line 1330 "/home/jens/Source/shotwell/src/Dialogs.vala"
	edit_title_dialog_parent_class = g_type_class_peek_parent (klass);
#line 1330 "/home/jens/Source/shotwell/src/Dialogs.vala"
	((EditTitleDialogClass *) klass)->execute = edit_title_dialog_real_execute;
#line 1330 "/home/jens/Source/shotwell/src/Dialogs.vala"
	((TextEntryDialogMediatorClass *) klass)->on_modify_validate = edit_title_dialog_real_on_modify_validate;
#line 12479 "Dialogs.c"
}


static void edit_title_dialog_instance_init (EditTitleDialog * self) {
}


GType edit_title_dialog_get_type (void) {
	static volatile gsize edit_title_dialog_type_id__volatile = 0;
	if (g_once_init_enter (&edit_title_dialog_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (EditTitleDialogClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) edit_title_dialog_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (EditTitleDialog), 0, (GInstanceInitFunc) edit_title_dialog_instance_init, NULL };
		GType edit_title_dialog_type_id;
		edit_title_dialog_type_id = g_type_register_static (TYPE_TEXT_ENTRY_DIALOG_MEDIATOR, "EditTitleDialog", &g_define_type_info, 0);
		g_once_init_leave (&edit_title_dialog_type_id__volatile, edit_title_dialog_type_id);
	}
	return edit_title_dialog_type_id__volatile;
}


EditCommentDialog* edit_comment_dialog_construct (GType object_type, const gchar* comment, gboolean is_event) {
	EditCommentDialog* self = NULL;
	const gchar* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	gchar* title_tmp = NULL;
	gchar* _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
	const gchar* _tmp6_ = NULL;
#line 1348 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = is_event;
#line 1348 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp1_) {
#line 12511 "Dialogs.c"
		const gchar* _tmp2_ = NULL;
#line 1350 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp2_ = _ ("Edit Event Comment");
#line 1350 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = _tmp2_;
#line 12517 "Dialogs.c"
	} else {
		const gchar* _tmp3_ = NULL;
#line 1351 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp3_ = _ ("Edit Photo/Video Comment");
#line 1351 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = _tmp3_;
#line 12524 "Dialogs.c"
	}
#line 1348 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = g_strdup (_tmp0_);
#line 1348 "/home/jens/Source/shotwell/src/Dialogs.vala"
	title_tmp = _tmp4_;
#line 1352 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = _ ("Comment:");
#line 1352 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = comment;
#line 1352 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = (EditCommentDialog*) multi_text_entry_dialog_mediator_construct (object_type, title_tmp, _tmp5_, _tmp6_);
#line 1347 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (title_tmp);
#line 1347 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return self;
#line 12540 "Dialogs.c"
}


EditCommentDialog* edit_comment_dialog_new (const gchar* comment, gboolean is_event) {
#line 1347 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return edit_comment_dialog_construct (TYPE_EDIT_COMMENT_DIALOG, comment, is_event);
#line 12547 "Dialogs.c"
}


static gchar* edit_comment_dialog_real_execute (EditCommentDialog* self) {
	gchar* result = NULL;
	gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
#line 1356 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = _multi_text_entry_dialog_mediator_execute (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR, MultiTextEntryDialogMediator));
#line 1356 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = _tmp0_;
#line 1356 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = media_source_prep_comment (_tmp1_);
#line 1356 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = _tmp2_;
#line 1356 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp1_);
#line 1356 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = _tmp3_;
#line 1356 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 12571 "Dialogs.c"
}


gchar* edit_comment_dialog_execute (EditCommentDialog* self) {
#line 1355 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_EDIT_COMMENT_DIALOG (self), NULL);
#line 1355 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return EDIT_COMMENT_DIALOG_GET_CLASS (self)->execute (self);
#line 12580 "Dialogs.c"
}


static gboolean edit_comment_dialog_real_on_modify_validate (MultiTextEntryDialogMediator* base, const gchar* text) {
	EditCommentDialog * self;
	gboolean result = FALSE;
#line 1359 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_EDIT_COMMENT_DIALOG, EditCommentDialog);
#line 1359 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (text != NULL, FALSE);
#line 1360 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = TRUE;
#line 1360 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 12595 "Dialogs.c"
}


static void edit_comment_dialog_class_init (EditCommentDialogClass * klass) {
#line 1346 "/home/jens/Source/shotwell/src/Dialogs.vala"
	edit_comment_dialog_parent_class = g_type_class_peek_parent (klass);
#line 1346 "/home/jens/Source/shotwell/src/Dialogs.vala"
	((EditCommentDialogClass *) klass)->execute = edit_comment_dialog_real_execute;
#line 1346 "/home/jens/Source/shotwell/src/Dialogs.vala"
	((MultiTextEntryDialogMediatorClass *) klass)->on_modify_validate = edit_comment_dialog_real_on_modify_validate;
#line 12606 "Dialogs.c"
}


static void edit_comment_dialog_instance_init (EditCommentDialog * self) {
}


GType edit_comment_dialog_get_type (void) {
	static volatile gsize edit_comment_dialog_type_id__volatile = 0;
	if (g_once_init_enter (&edit_comment_dialog_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (EditCommentDialogClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) edit_comment_dialog_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (EditCommentDialog), 0, (GInstanceInitFunc) edit_comment_dialog_instance_init, NULL };
		GType edit_comment_dialog_type_id;
		edit_comment_dialog_type_id = g_type_register_static (TYPE_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR, "EditCommentDialog", &g_define_type_info, 0);
		g_once_init_leave (&edit_comment_dialog_type_id__volatile, edit_comment_dialog_type_id);
	}
	return edit_comment_dialog_type_id__volatile;
}


GtkResponseType remove_from_library_dialog (GtkWindow* owner, const gchar* title, const gchar* user_message, gint count) {
	GtkResponseType result = 0;
	gchar* trash_action = NULL;
	gint _tmp0_ = 0;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	GtkMessageDialog* dialog = NULL;
	GtkWindow* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	GtkMessageDialog* _tmp5_ = NULL;
	const gchar* _tmp6_ = NULL;
	const gchar* _tmp7_ = NULL;
	const gchar* _tmp8_ = NULL;
	gchar* _tmp9_ = NULL;
	gchar* _tmp10_ = NULL;
	GtkResponseType _result_ = 0;
	gint _tmp11_ = 0;
#line 1366 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (GTK_IS_WINDOW (owner), 0);
#line 1366 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (title != NULL, 0);
#line 1366 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (user_message != NULL, 0);
#line 1368 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = count;
#line 1368 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = ngettext ("Remove and _Trash File", "Remove and _Trash Files", (gulong) _tmp0_);
#line 1368 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = g_strdup (_tmp1_);
#line 1368 "/home/jens/Source/shotwell/src/Dialogs.vala"
	trash_action = _tmp2_;
#line 1370 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = owner;
#line 1370 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = user_message;
#line 1370 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = (GtkMessageDialog*) gtk_message_dialog_new (_tmp3_, GTK_DIALOG_MODAL, GTK_MESSAGE_WARNING, GTK_BUTTONS_CANCEL, "%s", _tmp4_);
#line 1370 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp5_);
#line 1370 "/home/jens/Source/shotwell/src/Dialogs.vala"
	dialog = _tmp5_;
#line 1372 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = _ ("_Remove From Library");
#line 1372 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_dialog_add_button (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_dialog_get_type (), GtkDialog), _tmp6_, (gint) GTK_RESPONSE_NO);
#line 1373 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_dialog_add_button (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_dialog_get_type (), GtkDialog), trash_action, (gint) GTK_RESPONSE_YES);
#line 1378 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = title;
#line 1378 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = user_message;
#line 1378 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = build_alert_body_text (_tmp7_, _tmp8_, TRUE);
#line 1378 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp10_ = _tmp9_;
#line 1378 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_message_dialog_set_markup (dialog, _tmp10_);
#line 1378 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp10_);
#line 1380 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp11_ = gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_dialog_get_type (), GtkDialog));
#line 1380 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_result_ = (GtkResponseType) _tmp11_;
#line 1382 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_widget_get_type (), GtkWidget));
#line 1384 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = _result_;
#line 1384 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (dialog);
#line 1384 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (trash_action);
#line 1384 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 12699 "Dialogs.c"
}


GtkResponseType remove_from_filesystem_dialog (GtkWindow* owner, const gchar* title, const gchar* user_message) {
	GtkResponseType result = 0;
	GtkMessageDialog* dialog = NULL;
	GtkWindow* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	GtkMessageDialog* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
	const gchar* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
	gchar* _tmp8_ = NULL;
	GtkResponseType _result_ = 0;
	gint _tmp9_ = 0;
#line 1388 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (GTK_IS_WINDOW (owner), 0);
#line 1388 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (title != NULL, 0);
#line 1388 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (user_message != NULL, 0);
#line 1390 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = owner;
#line 1390 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = user_message;
#line 1390 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = (GtkMessageDialog*) gtk_message_dialog_new (_tmp0_, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_NONE, "%s", _tmp1_);
#line 1390 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp2_);
#line 1390 "/home/jens/Source/shotwell/src/Dialogs.vala"
	dialog = _tmp2_;
#line 1392 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = _ ("_Keep");
#line 1392 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_dialog_add_button (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_dialog_get_type (), GtkDialog), _tmp3_, (gint) GTK_RESPONSE_NO);
#line 1393 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = _ ("_Delete");
#line 1393 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_dialog_add_button (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_dialog_get_type (), GtkDialog), _tmp4_, (gint) GTK_RESPONSE_YES);
#line 1394 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_dialog_set_default_response (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_dialog_get_type (), GtkDialog), (gint) GTK_RESPONSE_NO);
#line 1396 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = title;
#line 1396 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = user_message;
#line 1396 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = build_alert_body_text (_tmp5_, _tmp6_, TRUE);
#line 1396 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = _tmp7_;
#line 1396 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_message_dialog_set_markup (dialog, _tmp8_);
#line 1396 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp8_);
#line 1398 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_dialog_get_type (), GtkDialog));
#line 1398 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_result_ = (GtkResponseType) _tmp9_;
#line 1400 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_widget_get_type (), GtkWidget));
#line 1402 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = _result_;
#line 1402 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (dialog);
#line 1402 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 12767 "Dialogs.c"
}


gboolean revert_editable_dialog (GtkWindow* owner, GeeCollection* photos) {
	gboolean result = FALSE;
	gint count = 0;
	gint _tmp9_ = 0;
	const gchar* _tmp10_ = NULL;
	gint _tmp11_ = 0;
	gchar* headline = NULL;
	gchar* _tmp14_ = NULL;
	gchar* msg = NULL;
	gint _tmp15_ = 0;
	const gchar* _tmp16_ = NULL;
	gint _tmp17_ = 0;
	gchar* _tmp18_ = NULL;
	const gchar* _tmp19_ = NULL;
	gint _tmp20_ = 0;
	gchar* action = NULL;
	gchar* _tmp23_ = NULL;
	GtkMessageDialog* dialog = NULL;
	GtkWindow* _tmp24_ = NULL;
	const gchar* _tmp25_ = NULL;
	GtkMessageDialog* _tmp26_ = NULL;
	GtkMessageDialog* _tmp27_ = NULL;
	const gchar* _tmp28_ = NULL;
	GtkMessageDialog* _tmp29_ = NULL;
	const gchar* _tmp30_ = NULL;
	GtkMessageDialog* _tmp31_ = NULL;
	const gchar* _tmp32_ = NULL;
	const gchar* _tmp33_ = NULL;
	gchar* _tmp34_ = NULL;
	gchar* _tmp35_ = NULL;
	GtkResponseType _result_ = 0;
	GtkMessageDialog* _tmp36_ = NULL;
	gint _tmp37_ = 0;
	GtkMessageDialog* _tmp38_ = NULL;
	GtkResponseType _tmp39_ = 0;
#line 1405 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (GTK_IS_WINDOW (owner), FALSE);
#line 1405 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (GEE_IS_COLLECTION (photos), FALSE);
#line 1406 "/home/jens/Source/shotwell/src/Dialogs.vala"
	count = 0;
#line 12812 "Dialogs.c"
	{
		GeeIterator* _photo_it = NULL;
		GeeCollection* _tmp0_ = NULL;
		GeeIterator* _tmp1_ = NULL;
#line 1407 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = photos;
#line 1407 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp1_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, GEE_TYPE_ITERABLE, GeeIterable));
#line 1407 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_photo_it = _tmp1_;
#line 1407 "/home/jens/Source/shotwell/src/Dialogs.vala"
		while (TRUE) {
#line 12825 "Dialogs.c"
			GeeIterator* _tmp2_ = NULL;
			gboolean _tmp3_ = FALSE;
			Photo* photo = NULL;
			GeeIterator* _tmp4_ = NULL;
			gpointer _tmp5_ = NULL;
			Photo* _tmp6_ = NULL;
			gboolean _tmp7_ = FALSE;
#line 1407 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp2_ = _photo_it;
#line 1407 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp3_ = gee_iterator_next (_tmp2_);
#line 1407 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (!_tmp3_) {
#line 1407 "/home/jens/Source/shotwell/src/Dialogs.vala"
				break;
#line 12841 "Dialogs.c"
			}
#line 1407 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp4_ = _photo_it;
#line 1407 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp5_ = gee_iterator_get (_tmp4_);
#line 1407 "/home/jens/Source/shotwell/src/Dialogs.vala"
			photo = (Photo*) _tmp5_;
#line 1408 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp6_ = photo;
#line 1408 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp7_ = photo_has_editable (_tmp6_);
#line 1408 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (_tmp7_) {
#line 12855 "Dialogs.c"
				gint _tmp8_ = 0;
#line 1409 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp8_ = count;
#line 1409 "/home/jens/Source/shotwell/src/Dialogs.vala"
				count = _tmp8_ + 1;
#line 12861 "Dialogs.c"
			}
#line 1407 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_object_unref0 (photo);
#line 12865 "Dialogs.c"
		}
#line 1407 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (_photo_it);
#line 12869 "Dialogs.c"
	}
#line 1412 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = count;
#line 1412 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp9_ == 0) {
#line 1413 "/home/jens/Source/shotwell/src/Dialogs.vala"
		result = FALSE;
#line 1413 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return result;
#line 12879 "Dialogs.c"
	}
#line 1415 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp11_ = count;
#line 1415 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp11_ == 1) {
#line 12885 "Dialogs.c"
		const gchar* _tmp12_ = NULL;
#line 1415 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp12_ = _ ("Revert External Edit?");
#line 1415 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp10_ = _tmp12_;
#line 12891 "Dialogs.c"
	} else {
		const gchar* _tmp13_ = NULL;
#line 1415 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp13_ = _ ("Revert External Edits?");
#line 1415 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp10_ = _tmp13_;
#line 12898 "Dialogs.c"
	}
#line 1415 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp14_ = g_strdup (_tmp10_);
#line 1415 "/home/jens/Source/shotwell/src/Dialogs.vala"
	headline = _tmp14_;
#line 1416 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp15_ = count;
#line 1416 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp16_ = ngettext ("This will destroy all changes made to the external file.  Continue?", "This will destroy all changes made to %d external files.  Continue?", (gulong) _tmp15_);
#line 1416 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp17_ = count;
#line 1416 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp18_ = g_strdup_printf (_tmp16_, _tmp17_);
#line 1416 "/home/jens/Source/shotwell/src/Dialogs.vala"
	msg = _tmp18_;
#line 1421 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp20_ = count;
#line 1421 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp20_ == 1) {
#line 12918 "Dialogs.c"
		const gchar* _tmp21_ = NULL;
#line 1421 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp21_ = _ ("Re_vert External Edit");
#line 1421 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp19_ = _tmp21_;
#line 12924 "Dialogs.c"
	} else {
		const gchar* _tmp22_ = NULL;
#line 1421 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp22_ = _ ("Re_vert External Edits");
#line 1421 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp19_ = _tmp22_;
#line 12931 "Dialogs.c"
	}
#line 1421 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp23_ = g_strdup (_tmp19_);
#line 1421 "/home/jens/Source/shotwell/src/Dialogs.vala"
	action = _tmp23_;
#line 1423 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp24_ = owner;
#line 1423 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp25_ = msg;
#line 1423 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp26_ = (GtkMessageDialog*) gtk_message_dialog_new (_tmp24_, GTK_DIALOG_MODAL, GTK_MESSAGE_WARNING, GTK_BUTTONS_NONE, "%s", _tmp25_);
#line 1423 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp26_);
#line 1423 "/home/jens/Source/shotwell/src/Dialogs.vala"
	dialog = _tmp26_;
#line 1425 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp27_ = dialog;
#line 1425 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp28_ = _ ("_Cancel");
#line 1425 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_dialog_add_button (G_TYPE_CHECK_INSTANCE_CAST (_tmp27_, gtk_dialog_get_type (), GtkDialog), _tmp28_, (gint) GTK_RESPONSE_CANCEL);
#line 1426 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp29_ = dialog;
#line 1426 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp30_ = action;
#line 1426 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_dialog_add_button (G_TYPE_CHECK_INSTANCE_CAST (_tmp29_, gtk_dialog_get_type (), GtkDialog), _tmp30_, (gint) GTK_RESPONSE_YES);
#line 1428 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp31_ = dialog;
#line 1428 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp32_ = headline;
#line 1428 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp33_ = msg;
#line 1428 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp34_ = build_alert_body_text (_tmp32_, _tmp33_, TRUE);
#line 1428 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp35_ = _tmp34_;
#line 1428 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_message_dialog_set_markup (_tmp31_, _tmp35_);
#line 1428 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp35_);
#line 1430 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp36_ = dialog;
#line 1430 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp37_ = gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (_tmp36_, gtk_dialog_get_type (), GtkDialog));
#line 1430 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_result_ = (GtkResponseType) _tmp37_;
#line 1432 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp38_ = dialog;
#line 1432 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (_tmp38_, gtk_widget_get_type (), GtkWidget));
#line 1434 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp39_ = _result_;
#line 1434 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = _tmp39_ == GTK_RESPONSE_YES;
#line 1434 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (dialog);
#line 1434 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (action);
#line 1434 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (msg);
#line 1434 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (headline);
#line 1434 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 12997 "Dialogs.c"
}


gboolean remove_offline_dialog (GtkWindow* owner, gint count) {
	gboolean result = FALSE;
	gint _tmp0_ = 0;
	gchar* msg = NULL;
	gint _tmp1_ = 0;
	const gchar* _tmp2_ = NULL;
	gint _tmp3_ = 0;
	gchar* _tmp4_ = NULL;
	GtkMessageDialog* dialog = NULL;
	GtkWindow* _tmp5_ = NULL;
	const gchar* _tmp6_ = NULL;
	GtkMessageDialog* _tmp7_ = NULL;
	GtkMessageDialog* _tmp8_ = NULL;
	const gchar* _tmp9_ = NULL;
	GtkMessageDialog* _tmp10_ = NULL;
	const gchar* _tmp11_ = NULL;
	const gchar* _tmp12_ = NULL;
	gint _tmp13_ = 0;
	GtkMessageDialog* _tmp16_ = NULL;
	GtkResponseType _result_ = 0;
	GtkMessageDialog* _tmp17_ = NULL;
	gint _tmp18_ = 0;
	GtkMessageDialog* _tmp19_ = NULL;
	GtkResponseType _tmp20_ = 0;
#line 1437 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (GTK_IS_WINDOW (owner), FALSE);
#line 1438 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = count;
#line 1438 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp0_ == 0) {
#line 1439 "/home/jens/Source/shotwell/src/Dialogs.vala"
		result = FALSE;
#line 1439 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return result;
#line 13035 "Dialogs.c"
	}
#line 1441 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = count;
#line 1441 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = ngettext ("This will remove the photo from the library.  Continue?", "This will remove %d photos from the library.  Continue?", (gulong) _tmp1_);
#line 1441 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = count;
#line 1441 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = g_strdup_printf (_tmp2_, _tmp3_);
#line 1441 "/home/jens/Source/shotwell/src/Dialogs.vala"
	msg = _tmp4_;
#line 1446 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = owner;
#line 1446 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = msg;
#line 1446 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = (GtkMessageDialog*) gtk_message_dialog_new (_tmp5_, GTK_DIALOG_MODAL, GTK_MESSAGE_WARNING, GTK_BUTTONS_NONE, "%s", _tmp6_);
#line 1446 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp7_);
#line 1446 "/home/jens/Source/shotwell/src/Dialogs.vala"
	dialog = _tmp7_;
#line 1448 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = dialog;
#line 1448 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = _ ("_Cancel");
#line 1448 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_dialog_add_button (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, gtk_dialog_get_type (), GtkDialog), _tmp9_, (gint) GTK_RESPONSE_CANCEL);
#line 1449 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp10_ = dialog;
#line 1449 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp11_ = _ ("_Remove");
#line 1449 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_dialog_add_button (G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, gtk_dialog_get_type (), GtkDialog), _tmp11_, (gint) GTK_RESPONSE_OK);
#line 1450 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp13_ = count;
#line 1450 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp13_ == 1) {
#line 13073 "Dialogs.c"
		const gchar* _tmp14_ = NULL;
#line 1450 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp14_ = _ ("Remove Photo From Library");
#line 1450 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp12_ = _tmp14_;
#line 13079 "Dialogs.c"
	} else {
		const gchar* _tmp15_ = NULL;
#line 1450 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp15_ = _ ("Remove Photos From Library");
#line 1450 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp12_ = _tmp15_;
#line 13086 "Dialogs.c"
	}
#line 1450 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp16_ = dialog;
#line 1450 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_window_set_title (G_TYPE_CHECK_INSTANCE_CAST (_tmp16_, gtk_window_get_type (), GtkWindow), _tmp12_);
#line 1452 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp17_ = dialog;
#line 1452 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp18_ = gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (_tmp17_, gtk_dialog_get_type (), GtkDialog));
#line 1452 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_result_ = (GtkResponseType) _tmp18_;
#line 1454 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp19_ = dialog;
#line 1454 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (_tmp19_, gtk_widget_get_type (), GtkWidget));
#line 1456 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp20_ = _result_;
#line 1456 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = _tmp20_ == GTK_RESPONSE_OK;
#line 1456 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (dialog);
#line 1456 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (msg);
#line 1456 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 13112 "Dialogs.c"
}


static void _progress_dialog_on_cancel_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 1489 "/home/jens/Source/shotwell/src/Dialogs.vala"
	progress_dialog_on_cancel ((ProgressDialog*) self);
#line 13119 "Dialogs.c"
}


static gboolean _progress_dialog_on_window_closed_gtk_widget_delete_event (GtkWidget* _sender, GdkEventAny* event, gpointer self) {
	gboolean result;
	result = progress_dialog_on_window_closed ((ProgressDialog*) self);
#line 1490 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 13128 "Dialogs.c"
}


ProgressDialog* progress_dialog_construct (GType object_type, GtkWindow* owner, const gchar* text, GCancellable* cancellable) {
	ProgressDialog * self = NULL;
	GCancellable* _tmp0_ = NULL;
	GCancellable* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	GtkWindow* _tmp3_ = NULL;
	GtkProgressBar* _tmp5_ = NULL;
	GtkProgressBar* _tmp6_ = NULL;
	GtkBox* vbox_bar = NULL;
	GtkBox* _tmp7_ = NULL;
	GtkBox* _tmp8_ = NULL;
	GtkProgressBar* _tmp9_ = NULL;
	GCancellable* _tmp10_ = NULL;
	GtkBox* hbox = NULL;
	GtkBox* _tmp13_ = NULL;
	GtkBox* _tmp14_ = NULL;
	GtkBox* _tmp15_ = NULL;
	GtkButton* _tmp16_ = NULL;
	GtkLabel* primary_text_label = NULL;
	GtkLabel* _tmp19_ = NULL;
	const gchar* _tmp20_ = NULL;
	gchar* _tmp21_ = NULL;
	gchar* _tmp22_ = NULL;
	GtkBox* vbox = NULL;
	GtkBox* _tmp23_ = NULL;
	GtkBox* _tmp24_ = NULL;
	GtkAlignment* alignment = NULL;
	GtkAlignment* _tmp25_ = NULL;
	gulong _tmp26_ = 0UL;
#line 1471 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail ((owner == NULL) || GTK_IS_WINDOW (owner), NULL);
#line 1471 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (text != NULL, NULL);
#line 1471 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail ((cancellable == NULL) || G_IS_CANCELLABLE (cancellable), NULL);
#line 1471 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = (ProgressDialog*) g_object_new (object_type, NULL);
#line 1472 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = cancellable;
#line 1472 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 1472 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->cancellable);
#line 1472 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->cancellable = _tmp1_;
#line 1474 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = text;
#line 1474 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_window_set_title (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), _tmp2_);
#line 1475 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_window_set_resizable (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), FALSE);
#line 1476 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = owner;
#line 1476 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp3_ != NULL) {
#line 13187 "Dialogs.c"
		GtkWindow* _tmp4_ = NULL;
#line 1477 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp4_ = owner;
#line 1477 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_window_set_transient_for (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), _tmp4_);
#line 13193 "Dialogs.c"
	}
#line 1478 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_window_set_modal (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), TRUE);
#line 1479 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_window_set_type_hint (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), GDK_WINDOW_TYPE_HINT_DIALOG);
#line 1481 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = self->priv->progress_bar;
#line 1481 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_set_size_request (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, gtk_widget_get_type (), GtkWidget), 300, -1);
#line 1482 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = self->priv->progress_bar;
#line 1482 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_progress_bar_set_show_text (_tmp6_, TRUE);
#line 1484 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
#line 1484 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp7_);
#line 1484 "/home/jens/Source/shotwell/src/Dialogs.vala"
	vbox_bar = _tmp7_;
#line 1485 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = vbox_bar;
#line 1485 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = self->priv->progress_bar;
#line 1485 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_box_pack_start (_tmp8_, G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, gtk_widget_get_type (), GtkWidget), TRUE, FALSE, (guint) 0);
#line 1487 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp10_ = cancellable;
#line 1487 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp10_ != NULL) {
#line 13223 "Dialogs.c"
		GtkButton* _tmp11_ = NULL;
		GtkButton* _tmp12_ = NULL;
#line 1488 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp11_ = (GtkButton*) gtk_button_new_with_mnemonic (RESOURCES_CANCEL_LABEL);
#line 1488 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_object_ref_sink (_tmp11_);
#line 1488 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (self->priv->cancel_button);
#line 1488 "/home/jens/Source/shotwell/src/Dialogs.vala"
		self->priv->cancel_button = _tmp11_;
#line 1489 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp12_ = self->priv->cancel_button;
#line 1489 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_signal_connect_object (_tmp12_, "clicked", (GCallback) _progress_dialog_on_cancel_gtk_button_clicked, self, 0);
#line 1490 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget), "delete-event", (GCallback) _progress_dialog_on_window_closed_gtk_widget_delete_event, self, 0);
#line 13240 "Dialogs.c"
	}
#line 1493 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp13_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 8);
#line 1493 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp13_);
#line 1493 "/home/jens/Source/shotwell/src/Dialogs.vala"
	hbox = _tmp13_;
#line 1494 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp14_ = hbox;
#line 1494 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp15_ = vbox_bar;
#line 1494 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_box_pack_start (_tmp14_, G_TYPE_CHECK_INSTANCE_CAST (_tmp15_, gtk_widget_get_type (), GtkWidget), TRUE, FALSE, (guint) 0);
#line 1495 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp16_ = self->priv->cancel_button;
#line 1495 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp16_ != NULL) {
#line 13258 "Dialogs.c"
		GtkBox* _tmp17_ = NULL;
		GtkButton* _tmp18_ = NULL;
#line 1496 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp17_ = hbox;
#line 1496 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp18_ = self->priv->cancel_button;
#line 1496 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_box_pack_end (_tmp17_, G_TYPE_CHECK_INSTANCE_CAST (_tmp18_, gtk_widget_get_type (), GtkWidget), FALSE, FALSE, (guint) 0);
#line 13267 "Dialogs.c"
	}
#line 1498 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp19_ = (GtkLabel*) gtk_label_new ("");
#line 1498 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp19_);
#line 1498 "/home/jens/Source/shotwell/src/Dialogs.vala"
	primary_text_label = _tmp19_;
#line 1499 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp20_ = text;
#line 1499 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp21_ = g_strdup_printf ("<span weight=\"bold\">%s</span>", _tmp20_);
#line 1499 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp22_ = _tmp21_;
#line 1499 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_label_set_markup (primary_text_label, _tmp22_);
#line 1499 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp22_);
#line 1500 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_misc_set_alignment (G_TYPE_CHECK_INSTANCE_CAST (primary_text_label, gtk_misc_get_type (), GtkMisc), (gfloat) 0, 0.5f);
#line 1502 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp23_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 12);
#line 1502 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp23_);
#line 1502 "/home/jens/Source/shotwell/src/Dialogs.vala"
	vbox = _tmp23_;
#line 1503 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_box_pack_start (vbox, G_TYPE_CHECK_INSTANCE_CAST (primary_text_label, gtk_widget_get_type (), GtkWidget), FALSE, FALSE, (guint) 0);
#line 1504 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp24_ = hbox;
#line 1504 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_box_pack_start (vbox, G_TYPE_CHECK_INSTANCE_CAST (_tmp24_, gtk_widget_get_type (), GtkWidget), TRUE, FALSE, (guint) 0);
#line 1506 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp25_ = (GtkAlignment*) gtk_alignment_new (0.5f, 0.5f, 1.0f, 1.0f);
#line 1506 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp25_);
#line 1506 "/home/jens/Source/shotwell/src/Dialogs.vala"
	alignment = _tmp25_;
#line 1507 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_alignment_set_padding (alignment, (guint) 12, (guint) 12, (guint) 12, (guint) 12);
#line 1508 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_container_add (G_TYPE_CHECK_INSTANCE_CAST (alignment, gtk_container_get_type (), GtkContainer), G_TYPE_CHECK_INSTANCE_CAST (vbox, gtk_widget_get_type (), GtkWidget));
#line 1510 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_container_add (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_container_get_type (), GtkContainer), G_TYPE_CHECK_INSTANCE_CAST (alignment, gtk_widget_get_type (), GtkWidget));
#line 1512 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp26_ = now_ms ();
#line 1512 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->time_started = _tmp26_;
#line 1471 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (alignment);
#line 1471 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (vbox);
#line 1471 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (primary_text_label);
#line 1471 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (hbox);
#line 1471 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (vbox_bar);
#line 1471 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return self;
#line 13327 "Dialogs.c"
}


ProgressDialog* progress_dialog_new (GtkWindow* owner, const gchar* text, GCancellable* cancellable) {
#line 1471 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return progress_dialog_construct (TYPE_PROGRESS_DIALOG, owner, text, cancellable);
#line 13334 "Dialogs.c"
}


static void progress_dialog_real_realize (GtkWidget* base) {
	ProgressDialog * self;
	GCancellable* _tmp0_ = NULL;
#line 1515 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_PROGRESS_DIALOG, ProgressDialog);
#line 1516 "/home/jens/Source/shotwell/src/Dialogs.vala"
	GTK_WIDGET_CLASS (progress_dialog_parent_class)->realize (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), gtk_widget_get_type (), GtkWidget));
#line 1519 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = self->priv->cancellable;
#line 1519 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp0_ == NULL) {
#line 13349 "Dialogs.c"
		GdkWindow* _tmp1_ = NULL;
#line 1520 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp1_ = gtk_widget_get_window (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 1520 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gdk_window_set_functions (_tmp1_, GDK_FUNC_MOVE);
#line 13355 "Dialogs.c"
	}
}


void progress_dialog_update_display_every (ProgressDialog* self, gint update_every) {
	gint _tmp0_ = 0;
	gint _tmp1_ = 0;
#line 1523 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_PROGRESS_DIALOG (self));
#line 1524 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = update_every;
#line 1524 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_vala_assert (_tmp0_ >= 1, "update_every >= 1");
#line 1526 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = update_every;
#line 1526 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->update_every = _tmp1_;
#line 13373 "Dialogs.c"
}


void progress_dialog_set_minimum_on_screen_time_msec (ProgressDialog* self, gint minimum_on_screen_time_msec) {
	gint _tmp0_ = 0;
#line 1529 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_PROGRESS_DIALOG (self));
#line 1530 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = minimum_on_screen_time_msec;
#line 1530 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->minimum_on_screen_time_msec = _tmp0_;
#line 13385 "Dialogs.c"
}


void progress_dialog_set_fraction (ProgressDialog* self, gint current, gint total) {
	gint _tmp0_ = 0;
	gint _tmp1_ = 0;
#line 1533 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_PROGRESS_DIALOG (self));
#line 1534 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = current;
#line 1534 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = total;
#line 1534 "/home/jens/Source/shotwell/src/Dialogs.vala"
	progress_dialog_set_percentage (self, ((gdouble) _tmp0_) / ((gdouble) _tmp1_));
#line 13400 "Dialogs.c"
}


void progress_dialog_set_percentage (ProgressDialog* self, gdouble pct) {
	gdouble _tmp0_ = 0.0;
	gdouble _tmp1_ = 0.0;
	gdouble _tmp2_ = 0.0;
	GtkProgressBar* _tmp3_ = NULL;
	gdouble _tmp4_ = 0.0;
	GtkProgressBar* _tmp5_ = NULL;
	const gchar* _tmp6_ = NULL;
	gdouble _tmp7_ = 0.0;
	gchar* _tmp8_ = NULL;
	gchar* _tmp9_ = NULL;
#line 1537 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_PROGRESS_DIALOG (self));
#line 1538 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = pct;
#line 1538 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = CLAMP (_tmp0_, 0.0, 1.0);
#line 1538 "/home/jens/Source/shotwell/src/Dialogs.vala"
	pct = _tmp1_;
#line 1540 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = pct;
#line 1540 "/home/jens/Source/shotwell/src/Dialogs.vala"
	progress_dialog_maybe_show_all (self, _tmp2_);
#line 1542 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = self->priv->progress_bar;
#line 1542 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = pct;
#line 1542 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_progress_bar_set_fraction (_tmp3_, _tmp4_);
#line 1543 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = self->priv->progress_bar;
#line 1543 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = _ ("%d%%");
#line 1543 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = pct;
#line 1543 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = g_strdup_printf (_tmp6_, (gint) (_tmp7_ * 100.0));
#line 1543 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = _tmp8_;
#line 1543 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_progress_bar_set_text (_tmp5_, _tmp9_);
#line 1543 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp9_);
#line 13447 "Dialogs.c"
}


void progress_dialog_set_status (ProgressDialog* self, const gchar* text) {
	GtkProgressBar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
#line 1551 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_PROGRESS_DIALOG (self));
#line 1551 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (text != NULL);
#line 1552 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = self->priv->progress_bar;
#line 1552 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = text;
#line 1552 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_progress_bar_set_text (_tmp0_, _tmp1_);
#line 1558 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_show_all (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 13466 "Dialogs.c"
}


gboolean progress_dialog_monitor (ProgressDialog* self, guint64 count, guint64 total, gboolean do_event_loop) {
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
	guint64 _tmp1_ = 0ULL;
	gboolean _tmp8_ = FALSE;
	GCancellable* _tmp9_ = NULL;
	gboolean keep_going = FALSE;
	gboolean _tmp12_ = FALSE;
#line 1562 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_PROGRESS_DIALOG (self), FALSE);
#line 1563 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = self->priv->last_count;
#line 1563 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp1_ == G_MAXUINT64) {
#line 1563 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = TRUE;
#line 13486 "Dialogs.c"
	} else {
		guint64 _tmp2_ = 0ULL;
		guint64 _tmp3_ = 0ULL;
		gint _tmp4_ = 0;
#line 1563 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp2_ = count;
#line 1563 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp3_ = self->priv->last_count;
#line 1563 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp4_ = self->priv->update_every;
#line 1563 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = (_tmp2_ - _tmp3_) >= ((guint64) _tmp4_);
#line 13499 "Dialogs.c"
	}
#line 1563 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp0_) {
#line 13503 "Dialogs.c"
		guint64 _tmp5_ = 0ULL;
		guint64 _tmp6_ = 0ULL;
		guint64 _tmp7_ = 0ULL;
#line 1564 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp5_ = count;
#line 1564 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp6_ = total;
#line 1564 "/home/jens/Source/shotwell/src/Dialogs.vala"
		progress_dialog_set_percentage (self, ((gdouble) _tmp5_) / ((gdouble) _tmp6_));
#line 1565 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp7_ = count;
#line 1565 "/home/jens/Source/shotwell/src/Dialogs.vala"
		self->priv->last_count = _tmp7_;
#line 13517 "Dialogs.c"
	}
#line 1568 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = self->priv->cancellable;
#line 1568 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp9_ != NULL) {
#line 13523 "Dialogs.c"
		GCancellable* _tmp10_ = NULL;
		gboolean _tmp11_ = FALSE;
#line 1568 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp10_ = self->priv->cancellable;
#line 1568 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp11_ = g_cancellable_is_cancelled (_tmp10_);
#line 1568 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp8_ = !_tmp11_;
#line 13532 "Dialogs.c"
	} else {
#line 1568 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp8_ = TRUE;
#line 13536 "Dialogs.c"
	}
#line 1568 "/home/jens/Source/shotwell/src/Dialogs.vala"
	keep_going = _tmp8_;
#line 1576 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp12_ = do_event_loop;
#line 1576 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp12_) {
#line 1577 "/home/jens/Source/shotwell/src/Dialogs.vala"
		spin_event_loop ();
#line 13546 "Dialogs.c"
	}
#line 1579 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = keep_going;
#line 1579 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 13552 "Dialogs.c"
}


void progress_dialog_close (ProgressDialog* self) {
#line 1582 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_PROGRESS_DIALOG (self));
#line 1587 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_hide (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 1588 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 13563 "Dialogs.c"
}


static gboolean progress_dialog_on_window_closed (ProgressDialog* self) {
	gboolean result = FALSE;
#line 1591 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_PROGRESS_DIALOG (self), FALSE);
#line 1592 "/home/jens/Source/shotwell/src/Dialogs.vala"
	progress_dialog_on_cancel (self);
#line 1593 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = FALSE;
#line 1593 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 13577 "Dialogs.c"
}


static void progress_dialog_on_cancel (ProgressDialog* self) {
	GCancellable* _tmp0_ = NULL;
	GtkButton* _tmp2_ = NULL;
#line 1597 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_PROGRESS_DIALOG (self));
#line 1598 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = self->priv->cancellable;
#line 1598 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp0_ != NULL) {
#line 13590 "Dialogs.c"
		GCancellable* _tmp1_ = NULL;
#line 1599 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp1_ = self->priv->cancellable;
#line 1599 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_cancellable_cancel (_tmp1_);
#line 13596 "Dialogs.c"
	}
#line 1601 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = self->priv->cancel_button;
#line 1601 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 13602 "Dialogs.c"
}


static void progress_dialog_maybe_show_all (ProgressDialog* self, gdouble pct) {
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_ = FALSE;
#line 1604 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_PROGRESS_DIALOG (self));
#line 1607 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = gtk_widget_get_visible (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 1607 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = _tmp1_;
#line 1607 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (!_tmp2_) {
#line 13618 "Dialogs.c"
		gulong _tmp3_ = 0UL;
		gulong _tmp4_ = 0UL;
		gint _tmp5_ = 0;
#line 1607 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp3_ = now_ms ();
#line 1607 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp4_ = self->priv->time_started;
#line 1607 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp5_ = self->priv->minimum_on_screen_time_msec;
#line 1607 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = (_tmp3_ - _tmp4_) > ((gulong) _tmp5_);
#line 13630 "Dialogs.c"
	} else {
#line 1607 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = FALSE;
#line 13634 "Dialogs.c"
	}
#line 1607 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp0_) {
#line 13638 "Dialogs.c"
		gdouble pps = 0.0;
		gdouble _tmp6_ = 0.0;
		gint _tmp7_ = 0;
		gdouble ttc = 0.0;
		gdouble _tmp8_ = 0.0;
		gdouble _tmp9_ = 0.0;
		gint _tmp10_ = 0;
#line 1609 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp6_ = pct;
#line 1609 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp7_ = self->priv->minimum_on_screen_time_msec;
#line 1609 "/home/jens/Source/shotwell/src/Dialogs.vala"
		pps = (_tmp6_ * 100.0) / _tmp7_;
#line 1611 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp8_ = pps;
#line 1611 "/home/jens/Source/shotwell/src/Dialogs.vala"
		ttc = 100.0 / _tmp8_;
#line 1614 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp9_ = ttc;
#line 1614 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp10_ = self->priv->minimum_on_screen_time_msec;
#line 1614 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp9_ > ((gdouble) _tmp10_)) {
#line 1619 "/home/jens/Source/shotwell/src/Dialogs.vala"
			gtk_widget_show_all (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 1620 "/home/jens/Source/shotwell/src/Dialogs.vala"
			spin_event_loop ();
#line 13666 "Dialogs.c"
		}
	}
}


static void progress_dialog_class_init (ProgressDialogClass * klass) {
#line 1459 "/home/jens/Source/shotwell/src/Dialogs.vala"
	progress_dialog_parent_class = g_type_class_peek_parent (klass);
#line 1459 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_type_class_add_private (klass, sizeof (ProgressDialogPrivate));
#line 1459 "/home/jens/Source/shotwell/src/Dialogs.vala"
	((GtkWidgetClass *) klass)->realize = progress_dialog_real_realize;
#line 1459 "/home/jens/Source/shotwell/src/Dialogs.vala"
	G_OBJECT_CLASS (klass)->finalize = progress_dialog_finalize;
#line 13681 "Dialogs.c"
}


static void progress_dialog_instance_init (ProgressDialog * self) {
	GtkProgressBar* _tmp0_ = NULL;
#line 1459 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv = PROGRESS_DIALOG_GET_PRIVATE (self);
#line 1460 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = (GtkProgressBar*) gtk_progress_bar_new ();
#line 1460 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp0_);
#line 1460 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->progress_bar = _tmp0_;
#line 1461 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->cancel_button = NULL;
#line 1463 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->last_count = G_MAXUINT64;
#line 1464 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->update_every = 1;
#line 1465 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->minimum_on_screen_time_msec = 500;
#line 13703 "Dialogs.c"
}


static void progress_dialog_finalize (GObject* obj) {
	ProgressDialog * self;
#line 1459 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_PROGRESS_DIALOG, ProgressDialog);
#line 1460 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->progress_bar);
#line 1461 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->cancel_button);
#line 1462 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->cancellable);
#line 1459 "/home/jens/Source/shotwell/src/Dialogs.vala"
	G_OBJECT_CLASS (progress_dialog_parent_class)->finalize (obj);
#line 13719 "Dialogs.c"
}


GType progress_dialog_get_type (void) {
	static volatile gsize progress_dialog_type_id__volatile = 0;
	if (g_once_init_enter (&progress_dialog_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (ProgressDialogClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) progress_dialog_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ProgressDialog), 0, (GInstanceInitFunc) progress_dialog_instance_init, NULL };
		GType progress_dialog_type_id;
		progress_dialog_type_id = g_type_register_static (gtk_window_get_type (), "ProgressDialog", &g_define_type_info, 0);
		g_once_init_leave (&progress_dialog_type_id__volatile, progress_dialog_type_id);
	}
	return progress_dialog_type_id__volatile;
}


static GType adjust_date_time_dialog_time_system_get_type (void) {
	static volatile gsize adjust_date_time_dialog_time_system_type_id__volatile = 0;
	if (g_once_init_enter (&adjust_date_time_dialog_time_system_type_id__volatile)) {
		static const GEnumValue values[] = {{ADJUST_DATE_TIME_DIALOG_TIME_SYSTEM_AM, "ADJUST_DATE_TIME_DIALOG_TIME_SYSTEM_AM", "am"}, {ADJUST_DATE_TIME_DIALOG_TIME_SYSTEM_PM, "ADJUST_DATE_TIME_DIALOG_TIME_SYSTEM_PM", "pm"}, {ADJUST_DATE_TIME_DIALOG_TIME_SYSTEM_24HR, "ADJUST_DATE_TIME_DIALOG_TIME_SYSTEM_24HR", "24hr"}, {0, NULL, NULL}};
		GType adjust_date_time_dialog_time_system_type_id;
		adjust_date_time_dialog_time_system_type_id = g_enum_register_static ("AdjustDateTimeDialogTimeSystem", values);
		g_once_init_leave (&adjust_date_time_dialog_time_system_type_id__volatile, adjust_date_time_dialog_time_system_type_id);
	}
	return adjust_date_time_dialog_time_system_type_id__volatile;
}


static void _adjust_date_time_dialog_on_time_changed_gtk_calendar_day_selected (GtkCalendar* _sender, gpointer self) {
#line 1672 "/home/jens/Source/shotwell/src/Dialogs.vala"
	adjust_date_time_dialog_on_time_changed ((AdjustDateTimeDialog*) self);
#line 13750 "Dialogs.c"
}


static void _adjust_date_time_dialog_on_time_changed_gtk_calendar_month_changed (GtkCalendar* _sender, gpointer self) {
#line 1673 "/home/jens/Source/shotwell/src/Dialogs.vala"
	adjust_date_time_dialog_on_time_changed ((AdjustDateTimeDialog*) self);
#line 13757 "Dialogs.c"
}


static void _adjust_date_time_dialog_on_time_changed_gtk_calendar_next_year (GtkCalendar* _sender, gpointer self) {
#line 1674 "/home/jens/Source/shotwell/src/Dialogs.vala"
	adjust_date_time_dialog_on_time_changed ((AdjustDateTimeDialog*) self);
#line 13764 "Dialogs.c"
}


static void _adjust_date_time_dialog_on_time_changed_gtk_calendar_prev_year (GtkCalendar* _sender, gpointer self) {
#line 1675 "/home/jens/Source/shotwell/src/Dialogs.vala"
	adjust_date_time_dialog_on_time_changed ((AdjustDateTimeDialog*) self);
#line 13771 "Dialogs.c"
}


static gboolean _adjust_date_time_dialog_on_spin_button_output_gtk_spin_button_output (GtkSpinButton* _sender, gpointer self) {
	gboolean result;
	result = adjust_date_time_dialog_on_spin_button_output ((AdjustDateTimeDialog*) self, _sender);
#line 1682 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 13780 "Dialogs.c"
}


static void _adjust_date_time_dialog_on_time_system_changed_gtk_combo_box_changed (GtkComboBox* _sender, gpointer self) {
#line 1700 "/home/jens/Source/shotwell/src/Dialogs.vala"
	adjust_date_time_dialog_on_time_system_changed ((AdjustDateTimeDialog*) self);
#line 13787 "Dialogs.c"
}


static void _adjust_date_time_dialog_on_time_changed_gtk_toggle_button_toggled (GtkToggleButton* _sender, gpointer self) {
#line 1722 "/home/jens/Source/shotwell/src/Dialogs.vala"
	adjust_date_time_dialog_on_time_changed ((AdjustDateTimeDialog*) self);
#line 13794 "Dialogs.c"
}


static void g_time_local (time_t time, struct tm* result) {
	struct tm _result_ = {0};
	struct tm _tmp0_ = {0};
#line 2701 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	localtime_r (&time, &_tmp0_);
#line 2701 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_result_ = _tmp0_;
#line 2702 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	*result = _result_;
#line 2702 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	return;
#line 13809 "Dialogs.c"
}


AdjustDateTimeDialog* adjust_date_time_dialog_construct (GType object_type, Dateable* source, gint photo_count, gboolean display_options, gboolean contains_video, gboolean only_video) {
	AdjustDateTimeDialog * self = NULL;
	Dateable* _tmp0_ = NULL;
	gboolean use_header = FALSE;
	GtkSettings* _tmp1_ = NULL;
	gint _tmp2_ = 0;
	gboolean _tmp3_ = FALSE;
	AppWindow* _tmp4_ = NULL;
	AppWindow* _tmp5_ = NULL;
	GtkCalendar* _tmp6_ = NULL;
	GtkCalendar* _tmp7_ = NULL;
	GtkCalendar* _tmp8_ = NULL;
	GtkCalendar* _tmp9_ = NULL;
	GtkCalendar* _tmp10_ = NULL;
	ConfigFacade* _tmp11_ = NULL;
	ConfigFacade* _tmp12_ = NULL;
	gboolean _tmp13_ = FALSE;
	gboolean _tmp14_ = FALSE;
	GtkSpinButton* _tmp17_ = NULL;
	GtkSpinButton* _tmp18_ = NULL;
	GtkSpinButton* _tmp19_ = NULL;
	GtkSpinButton* _tmp20_ = NULL;
	GtkSpinButton* _tmp21_ = NULL;
	GtkSpinButton* _tmp22_ = NULL;
	GtkSpinButton* _tmp23_ = NULL;
	GtkSpinButton* _tmp24_ = NULL;
	GtkSpinButton* _tmp25_ = NULL;
	GtkSpinButton* _tmp26_ = NULL;
	GtkSpinButton* _tmp27_ = NULL;
	GtkComboBoxText* _tmp28_ = NULL;
	GtkComboBoxText* _tmp29_ = NULL;
	const gchar* _tmp30_ = NULL;
	GtkComboBoxText* _tmp31_ = NULL;
	const gchar* _tmp32_ = NULL;
	GtkComboBoxText* _tmp33_ = NULL;
	const gchar* _tmp34_ = NULL;
	GtkComboBoxText* _tmp35_ = NULL;
	GtkBox* clock = NULL;
	GtkBox* _tmp36_ = NULL;
	GtkBox* _tmp37_ = NULL;
	GtkSpinButton* _tmp38_ = NULL;
	GtkBox* _tmp39_ = NULL;
	GtkLabel* _tmp40_ = NULL;
	GtkLabel* _tmp41_ = NULL;
	GtkBox* _tmp42_ = NULL;
	GtkSpinButton* _tmp43_ = NULL;
	GtkBox* _tmp44_ = NULL;
	GtkLabel* _tmp45_ = NULL;
	GtkLabel* _tmp46_ = NULL;
	GtkBox* _tmp47_ = NULL;
	GtkSpinButton* _tmp48_ = NULL;
	GtkBox* _tmp49_ = NULL;
	GtkComboBoxText* _tmp50_ = NULL;
	const gchar* _tmp51_ = NULL;
	GtkRadioButton* _tmp52_ = NULL;
	GtkRadioButton* _tmp53_ = NULL;
	ConfigFacade* _tmp54_ = NULL;
	ConfigFacade* _tmp55_ = NULL;
	gboolean _tmp56_ = FALSE;
	gboolean _tmp57_ = FALSE;
	gboolean _tmp58_ = FALSE;
	GtkRadioButton* _tmp60_ = NULL;
	GtkRadioButton* _tmp61_ = NULL;
	GSList* _tmp62_ = NULL;
	const gchar* _tmp63_ = NULL;
	GtkRadioButton* _tmp64_ = NULL;
	GtkRadioButton* _tmp65_ = NULL;
	ConfigFacade* _tmp66_ = NULL;
	ConfigFacade* _tmp67_ = NULL;
	gboolean _tmp68_ = FALSE;
	gboolean _tmp69_ = FALSE;
	gboolean _tmp70_ = FALSE;
	GtkRadioButton* _tmp72_ = NULL;
	GtkRadioButton* _tmp73_ = NULL;
	gboolean _tmp74_ = FALSE;
	gboolean _tmp85_ = FALSE;
	ConfigFacade* _tmp86_ = NULL;
	ConfigFacade* _tmp87_ = NULL;
	gboolean _tmp88_ = FALSE;
	gboolean _tmp89_ = FALSE;
	GtkCheckButton* _tmp91_ = NULL;
	gboolean _tmp92_ = FALSE;
	gboolean _tmp93_ = FALSE;
	GtkCheckButton* _tmp100_ = NULL;
	GtkBox* time_content = NULL;
	GtkBox* _tmp101_ = NULL;
	GtkBox* _tmp102_ = NULL;
	GtkCalendar* _tmp103_ = NULL;
	GtkBox* _tmp104_ = NULL;
	GtkBox* _tmp105_ = NULL;
	gboolean _tmp106_ = FALSE;
	GdkPixbuf* preview = NULL;
	GtkBox* image_content = NULL;
	GtkBox* _tmp120_ = NULL;
	GtkBox* _tmp121_ = NULL;
	GtkBox* _tmp122_ = NULL;
	GtkImage* _tmp123_ = NULL;
	GdkPixbuf* _tmp124_ = NULL;
	GtkImage* image = NULL;
	GtkImage* _tmp128_ = NULL;
	GtkLabel* _tmp129_ = NULL;
	GtkBox* _tmp130_ = NULL;
	GtkImage* _tmp131_ = NULL;
	GtkBox* _tmp132_ = NULL;
	GtkLabel* _tmp133_ = NULL;
	GtkBox* hbox = NULL;
	GtkBox* _tmp134_ = NULL;
	GtkBox* _tmp135_ = NULL;
	GtkBox* _tmp136_ = NULL;
	GtkBox* _tmp137_ = NULL;
	GtkBox* _tmp138_ = NULL;
	GtkBox* _tmp139_ = NULL;
	GtkAlignment* hbox_alignment = NULL;
	GtkAlignment* _tmp140_ = NULL;
	GtkAlignment* _tmp141_ = NULL;
	GtkBox* _tmp142_ = NULL;
	GtkBox* _tmp143_ = NULL;
	GtkAlignment* _tmp144_ = NULL;
	GtkLabel* _tmp145_ = NULL;
	GtkLabel* _tmp146_ = NULL;
	GtkLabel* _tmp147_ = NULL;
	GtkBox* _tmp148_ = NULL;
	GtkLabel* _tmp149_ = NULL;
	Dateable* _tmp150_ = NULL;
	time_t _tmp151_ = 0;
	time_t _tmp152_ = 0;
	time_t _tmp154_ = 0;
	struct tm _tmp155_ = {0};
	ConfigFacade* _tmp156_ = NULL;
	ConfigFacade* _tmp157_ = NULL;
	gboolean _tmp158_ = FALSE;
	GError * _inner_error_ = NULL;
#line 1655 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_DATEABLE (source), NULL);
#line 1657 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = source;
#line 1657 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_vala_assert (_tmp0_ != NULL, "source != null");
#line 1660 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = gtk_settings_get_default ();
#line 1660 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_get (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, G_TYPE_OBJECT, GObject), "gtk-dialogs-use-header", &use_header, NULL);
#line 1661 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = use_header;
#line 1661 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp3_) {
#line 1661 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp2_ = 1;
#line 13961 "Dialogs.c"
	} else {
#line 1661 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp2_ = 0;
#line 13965 "Dialogs.c"
	}
#line 1661 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = (AdjustDateTimeDialog*) g_object_new (object_type, "use-header-bar", _tmp2_, NULL);
#line 1663 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_window_set_modal (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), TRUE);
#line 1664 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_window_set_resizable (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), FALSE);
#line 1665 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = app_window_get_instance ();
#line 1665 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = _tmp4_;
#line 1665 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_window_set_transient_for (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, gtk_window_get_type (), GtkWindow));
#line 1665 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp5_);
#line 1667 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_dialog_add_buttons (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog), RESOURCES_CANCEL_LABEL, GTK_RESPONSE_CANCEL, RESOURCES_OK_LABEL, GTK_RESPONSE_OK, NULL);
#line 1669 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_window_set_title (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), RESOURCES_ADJUST_DATE_TIME_LABEL);
#line 1671 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = (GtkCalendar*) gtk_calendar_new ();
#line 1671 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp6_);
#line 1671 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->calendar);
#line 1671 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->calendar = _tmp6_;
#line 1672 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = self->priv->calendar;
#line 1672 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_connect_object (_tmp7_, "day-selected", (GCallback) _adjust_date_time_dialog_on_time_changed_gtk_calendar_day_selected, self, 0);
#line 1673 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = self->priv->calendar;
#line 1673 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_connect_object (_tmp8_, "month-changed", (GCallback) _adjust_date_time_dialog_on_time_changed_gtk_calendar_month_changed, self, 0);
#line 1674 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = self->priv->calendar;
#line 1674 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_connect_object (_tmp9_, "next-year", (GCallback) _adjust_date_time_dialog_on_time_changed_gtk_calendar_next_year, self, 0);
#line 1675 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp10_ = self->priv->calendar;
#line 1675 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_connect_object (_tmp10_, "prev-year", (GCallback) _adjust_date_time_dialog_on_time_changed_gtk_calendar_prev_year, self, 0);
#line 1677 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp11_ = config_facade_get_instance ();
#line 1677 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp12_ = _tmp11_;
#line 1677 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp13_ = configuration_facade_get_use_24_hour_time (G_TYPE_CHECK_INSTANCE_CAST (_tmp12_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade));
#line 1677 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp14_ = _tmp13_;
#line 1677 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp12_);
#line 1677 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp14_) {
#line 14021 "Dialogs.c"
		GtkSpinButton* _tmp15_ = NULL;
#line 1678 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp15_ = (GtkSpinButton*) gtk_spin_button_new_with_range ((gdouble) 0, (gdouble) 23, (gdouble) 1);
#line 1678 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_object_ref_sink (_tmp15_);
#line 1678 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (self->priv->hour);
#line 1678 "/home/jens/Source/shotwell/src/Dialogs.vala"
		self->priv->hour = _tmp15_;
#line 14031 "Dialogs.c"
	} else {
		GtkSpinButton* _tmp16_ = NULL;
#line 1680 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp16_ = (GtkSpinButton*) gtk_spin_button_new_with_range ((gdouble) 1, (gdouble) 12, (gdouble) 1);
#line 1680 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_object_ref_sink (_tmp16_);
#line 1680 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (self->priv->hour);
#line 1680 "/home/jens/Source/shotwell/src/Dialogs.vala"
		self->priv->hour = _tmp16_;
#line 14042 "Dialogs.c"
	}
#line 1682 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp17_ = self->priv->hour;
#line 1682 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_connect_object (_tmp17_, "output", (GCallback) _adjust_date_time_dialog_on_spin_button_output_gtk_spin_button_output, self, 0);
#line 1683 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp18_ = self->priv->hour;
#line 1683 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_entry_set_width_chars (G_TYPE_CHECK_INSTANCE_CAST (_tmp18_, gtk_entry_get_type (), GtkEntry), 2);
#line 1684 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp19_ = self->priv->hour;
#line 1684 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_entry_set_max_width_chars (G_TYPE_CHECK_INSTANCE_CAST (_tmp19_, gtk_entry_get_type (), GtkEntry), 2);
#line 1686 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp20_ = (GtkSpinButton*) gtk_spin_button_new_with_range ((gdouble) 0, (gdouble) 59, (gdouble) 1);
#line 1686 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp20_);
#line 1686 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->minute);
#line 1686 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->minute = _tmp20_;
#line 1687 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp21_ = self->priv->minute;
#line 1687 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_entry_set_width_chars (G_TYPE_CHECK_INSTANCE_CAST (_tmp21_, gtk_entry_get_type (), GtkEntry), 2);
#line 1688 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp22_ = self->priv->minute;
#line 1688 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_entry_set_max_width_chars (G_TYPE_CHECK_INSTANCE_CAST (_tmp22_, gtk_entry_get_type (), GtkEntry), 2);
#line 1689 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp23_ = self->priv->minute;
#line 1689 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_connect_object (_tmp23_, "output", (GCallback) _adjust_date_time_dialog_on_spin_button_output_gtk_spin_button_output, self, 0);
#line 1691 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp24_ = (GtkSpinButton*) gtk_spin_button_new_with_range ((gdouble) 0, (gdouble) 59, (gdouble) 1);
#line 1691 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp24_);
#line 1691 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->second);
#line 1691 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->second = _tmp24_;
#line 1692 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp25_ = self->priv->second;
#line 1692 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_entry_set_width_chars (G_TYPE_CHECK_INSTANCE_CAST (_tmp25_, gtk_entry_get_type (), GtkEntry), 2);
#line 1693 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp26_ = self->priv->second;
#line 1693 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_entry_set_max_width_chars (G_TYPE_CHECK_INSTANCE_CAST (_tmp26_, gtk_entry_get_type (), GtkEntry), 2);
#line 1694 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp27_ = self->priv->second;
#line 1694 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_connect_object (_tmp27_, "output", (GCallback) _adjust_date_time_dialog_on_spin_button_output_gtk_spin_button_output, self, 0);
#line 1696 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp28_ = (GtkComboBoxText*) gtk_combo_box_text_new ();
#line 1696 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp28_);
#line 1696 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->system);
#line 1696 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->system = _tmp28_;
#line 1697 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp29_ = self->priv->system;
#line 1697 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp30_ = _ ("AM");
#line 1697 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_combo_box_text_append_text (_tmp29_, _tmp30_);
#line 1698 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp31_ = self->priv->system;
#line 1698 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp32_ = _ ("PM");
#line 1698 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_combo_box_text_append_text (_tmp31_, _tmp32_);
#line 1699 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp33_ = self->priv->system;
#line 1699 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp34_ = _ ("24 Hr");
#line 1699 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_combo_box_text_append_text (_tmp33_, _tmp34_);
#line 1700 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp35_ = self->priv->system;
#line 1700 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp35_, gtk_combo_box_get_type (), GtkComboBox), "changed", (GCallback) _adjust_date_time_dialog_on_time_system_changed_gtk_combo_box_changed, self, 0);
#line 1702 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp36_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 3);
#line 1702 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp36_);
#line 1702 "/home/jens/Source/shotwell/src/Dialogs.vala"
	clock = _tmp36_;
#line 1704 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp37_ = clock;
#line 1704 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp38_ = self->priv->hour;
#line 1704 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_box_pack_start (_tmp37_, G_TYPE_CHECK_INSTANCE_CAST (_tmp38_, gtk_widget_get_type (), GtkWidget), FALSE, FALSE, (guint) 0);
#line 1705 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp39_ = clock;
#line 1705 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp40_ = (GtkLabel*) gtk_label_new (":");
#line 1705 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp40_);
#line 1705 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp41_ = _tmp40_;
#line 1705 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_box_pack_start (_tmp39_, G_TYPE_CHECK_INSTANCE_CAST (_tmp41_, gtk_widget_get_type (), GtkWidget), FALSE, FALSE, (guint) 0);
#line 1705 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp41_);
#line 1706 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp42_ = clock;
#line 1706 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp43_ = self->priv->minute;
#line 1706 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_box_pack_start (_tmp42_, G_TYPE_CHECK_INSTANCE_CAST (_tmp43_, gtk_widget_get_type (), GtkWidget), FALSE, FALSE, (guint) 0);
#line 1707 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp44_ = clock;
#line 1707 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp45_ = (GtkLabel*) gtk_label_new (":");
#line 1707 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp45_);
#line 1707 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp46_ = _tmp45_;
#line 1707 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_box_pack_start (_tmp44_, G_TYPE_CHECK_INSTANCE_CAST (_tmp46_, gtk_widget_get_type (), GtkWidget), FALSE, FALSE, (guint) 0);
#line 1707 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp46_);
#line 1708 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp47_ = clock;
#line 1708 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp48_ = self->priv->second;
#line 1708 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_box_pack_start (_tmp47_, G_TYPE_CHECK_INSTANCE_CAST (_tmp48_, gtk_widget_get_type (), GtkWidget), FALSE, FALSE, (guint) 0);
#line 1709 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp49_ = clock;
#line 1709 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp50_ = self->priv->system;
#line 1709 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_box_pack_start (_tmp49_, G_TYPE_CHECK_INSTANCE_CAST (_tmp50_, gtk_widget_get_type (), GtkWidget), FALSE, FALSE, (guint) 0);
#line 1711 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_dialog_set_default_response (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog), (gint) GTK_RESPONSE_OK);
#line 1713 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp51_ = _ ("_Shift photos/videos by the same amount");
#line 1713 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp52_ = (GtkRadioButton*) gtk_radio_button_new_with_mnemonic (NULL, _tmp51_);
#line 1713 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp52_);
#line 1713 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->relativity_radio_button);
#line 1713 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->relativity_radio_button = _tmp52_;
#line 1715 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp53_ = self->priv->relativity_radio_button;
#line 1715 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp54_ = config_facade_get_instance ();
#line 1715 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp55_ = _tmp54_;
#line 1715 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp56_ = configuration_facade_get_keep_relativity (G_TYPE_CHECK_INSTANCE_CAST (_tmp55_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade));
#line 1715 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_toggle_button_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp53_, gtk_toggle_button_get_type (), GtkToggleButton), _tmp56_);
#line 1715 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp55_);
#line 1716 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp58_ = display_options;
#line 1716 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp58_) {
#line 14208 "Dialogs.c"
		gint _tmp59_ = 0;
#line 1716 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp59_ = photo_count;
#line 1716 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp57_ = _tmp59_ > 1;
#line 14214 "Dialogs.c"
	} else {
#line 1716 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp57_ = FALSE;
#line 14218 "Dialogs.c"
	}
#line 1716 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp60_ = self->priv->relativity_radio_button;
#line 1716 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp60_, gtk_widget_get_type (), GtkWidget), _tmp57_);
#line 1718 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp61_ = self->priv->relativity_radio_button;
#line 1718 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp62_ = gtk_radio_button_get_group (_tmp61_);
#line 1718 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp63_ = _ ("Set _all photos/videos to this time");
#line 1718 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp64_ = (GtkRadioButton*) gtk_radio_button_new_with_mnemonic (_tmp62_, _tmp63_);
#line 1718 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp64_);
#line 1718 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->batch_radio_button);
#line 1718 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->batch_radio_button = _tmp64_;
#line 1720 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp65_ = self->priv->batch_radio_button;
#line 1720 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp66_ = config_facade_get_instance ();
#line 1720 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp67_ = _tmp66_;
#line 1720 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp68_ = configuration_facade_get_keep_relativity (G_TYPE_CHECK_INSTANCE_CAST (_tmp67_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade));
#line 1720 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_toggle_button_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp65_, gtk_toggle_button_get_type (), GtkToggleButton), !_tmp68_);
#line 1720 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp67_);
#line 1721 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp70_ = display_options;
#line 1721 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp70_) {
#line 14254 "Dialogs.c"
		gint _tmp71_ = 0;
#line 1721 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp71_ = photo_count;
#line 1721 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp69_ = _tmp71_ > 1;
#line 14260 "Dialogs.c"
	} else {
#line 1721 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp69_ = FALSE;
#line 14264 "Dialogs.c"
	}
#line 1721 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp72_ = self->priv->batch_radio_button;
#line 1721 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp72_, gtk_widget_get_type (), GtkWidget), _tmp69_);
#line 1722 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp73_ = self->priv->batch_radio_button;
#line 1722 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp73_, gtk_toggle_button_get_type (), GtkToggleButton), "toggled", (GCallback) _adjust_date_time_dialog_on_time_changed_gtk_toggle_button_toggled, self, 0);
#line 1724 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp74_ = contains_video;
#line 1724 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp74_) {
#line 14278 "Dialogs.c"
		const gchar* _tmp75_ = NULL;
		gint _tmp76_ = 0;
		GtkCheckButton* _tmp79_ = NULL;
#line 1725 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp76_ = photo_count;
#line 1725 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp76_ == 1) {
#line 14286 "Dialogs.c"
			const gchar* _tmp77_ = NULL;
#line 1726 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp77_ = _ ("_Modify original photo file");
#line 1726 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp75_ = _tmp77_;
#line 14292 "Dialogs.c"
		} else {
			const gchar* _tmp78_ = NULL;
#line 1726 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp78_ = _ ("_Modify original photo files");
#line 1726 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp75_ = _tmp78_;
#line 14299 "Dialogs.c"
		}
#line 1725 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp79_ = (GtkCheckButton*) gtk_check_button_new_with_mnemonic (_tmp75_);
#line 1725 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_object_ref_sink (_tmp79_);
#line 1725 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (self->priv->modify_originals_check_button);
#line 1725 "/home/jens/Source/shotwell/src/Dialogs.vala"
		self->priv->modify_originals_check_button = _tmp79_;
#line 14309 "Dialogs.c"
	} else {
		const gchar* _tmp80_ = NULL;
		gint _tmp81_ = 0;
		GtkCheckButton* _tmp84_ = NULL;
#line 1728 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp81_ = photo_count;
#line 1728 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp81_ == 1) {
#line 14318 "Dialogs.c"
			const gchar* _tmp82_ = NULL;
#line 1729 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp82_ = _ ("_Modify original file");
#line 1729 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp80_ = _tmp82_;
#line 14324 "Dialogs.c"
		} else {
			const gchar* _tmp83_ = NULL;
#line 1729 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp83_ = _ ("_Modify original files");
#line 1729 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp80_ = _tmp83_;
#line 14331 "Dialogs.c"
		}
#line 1728 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp84_ = (GtkCheckButton*) gtk_check_button_new_with_mnemonic (_tmp80_);
#line 1728 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_object_ref_sink (_tmp84_);
#line 1728 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (self->priv->modify_originals_check_button);
#line 1728 "/home/jens/Source/shotwell/src/Dialogs.vala"
		self->priv->modify_originals_check_button = _tmp84_;
#line 14341 "Dialogs.c"
	}
#line 1732 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp86_ = config_facade_get_instance ();
#line 1732 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp87_ = _tmp86_;
#line 1732 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp88_ = configuration_facade_get_commit_metadata_to_masters (G_TYPE_CHECK_INSTANCE_CAST (_tmp87_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade));
#line 1732 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp89_ = _tmp88_;
#line 1732 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp87_);
#line 1732 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp89_) {
#line 14355 "Dialogs.c"
		gboolean _tmp90_ = FALSE;
#line 1733 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp90_ = display_options;
#line 1733 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp85_ = _tmp90_;
#line 14361 "Dialogs.c"
	} else {
#line 1732 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp85_ = FALSE;
#line 14365 "Dialogs.c"
	}
#line 1732 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp91_ = self->priv->modify_originals_check_button;
#line 1732 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_toggle_button_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp91_, gtk_toggle_button_get_type (), GtkToggleButton), _tmp85_);
#line 1734 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp93_ = only_video;
#line 1734 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (!_tmp93_) {
#line 14375 "Dialogs.c"
		gboolean _tmp94_ = FALSE;
		ConfigFacade* _tmp95_ = NULL;
		ConfigFacade* _tmp96_ = NULL;
		gboolean _tmp97_ = FALSE;
		gboolean _tmp98_ = FALSE;
#line 1735 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp95_ = config_facade_get_instance ();
#line 1735 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp96_ = _tmp95_;
#line 1735 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp97_ = configuration_facade_get_commit_metadata_to_masters (G_TYPE_CHECK_INSTANCE_CAST (_tmp96_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade));
#line 1735 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp98_ = !_tmp97_;
#line 1735 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (_tmp96_);
#line 1735 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp98_) {
#line 14393 "Dialogs.c"
			gboolean _tmp99_ = FALSE;
#line 1735 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp99_ = display_options;
#line 1735 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp94_ = _tmp99_;
#line 14399 "Dialogs.c"
		} else {
#line 1735 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp94_ = FALSE;
#line 14403 "Dialogs.c"
		}
#line 1735 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp92_ = _tmp94_;
#line 14407 "Dialogs.c"
	} else {
#line 1734 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp92_ = FALSE;
#line 14411 "Dialogs.c"
	}
#line 1734 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp100_ = self->priv->modify_originals_check_button;
#line 1734 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp100_, gtk_widget_get_type (), GtkWidget), _tmp92_);
#line 1737 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp101_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 5);
#line 1737 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp101_);
#line 1737 "/home/jens/Source/shotwell/src/Dialogs.vala"
	time_content = _tmp101_;
#line 1739 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp102_ = time_content;
#line 1739 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp103_ = self->priv->calendar;
#line 1739 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_box_pack_start (_tmp102_, G_TYPE_CHECK_INSTANCE_CAST (_tmp103_, gtk_widget_get_type (), GtkWidget), TRUE, FALSE, (guint) 0);
#line 1740 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp104_ = time_content;
#line 1740 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp105_ = clock;
#line 1740 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_box_pack_start (_tmp104_, G_TYPE_CHECK_INSTANCE_CAST (_tmp105_, gtk_widget_get_type (), GtkWidget), TRUE, FALSE, (guint) 0);
#line 1742 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp106_ = display_options;
#line 1742 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp106_) {
#line 14439 "Dialogs.c"
		GtkBox* _tmp107_ = NULL;
		GtkRadioButton* _tmp108_ = NULL;
		GtkBox* _tmp109_ = NULL;
		GtkRadioButton* _tmp110_ = NULL;
		GtkBox* _tmp111_ = NULL;
		GtkCheckButton* _tmp112_ = NULL;
#line 1743 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp107_ = time_content;
#line 1743 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp108_ = self->priv->relativity_radio_button;
#line 1743 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_box_pack_start (_tmp107_, G_TYPE_CHECK_INSTANCE_CAST (_tmp108_, gtk_widget_get_type (), GtkWidget), TRUE, FALSE, (guint) 0);
#line 1744 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp109_ = time_content;
#line 1744 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp110_ = self->priv->batch_radio_button;
#line 1744 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_box_pack_start (_tmp109_, G_TYPE_CHECK_INSTANCE_CAST (_tmp110_, gtk_widget_get_type (), GtkWidget), TRUE, FALSE, (guint) 0);
#line 1745 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp111_ = time_content;
#line 1745 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp112_ = self->priv->modify_originals_check_button;
#line 1745 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_box_pack_start (_tmp111_, G_TYPE_CHECK_INSTANCE_CAST (_tmp112_, gtk_widget_get_type (), GtkWidget), TRUE, FALSE, (guint) 0);
#line 14464 "Dialogs.c"
	}
#line 1748 "/home/jens/Source/shotwell/src/Dialogs.vala"
	preview = NULL;
#line 14468 "Dialogs.c"
	{
		GdkPixbuf* _tmp113_ = NULL;
		Dateable* _tmp114_ = NULL;
		GdkPixbuf* _tmp115_ = NULL;
		GdkPixbuf* _tmp116_ = NULL;
#line 1752 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp114_ = source;
#line 1752 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp115_ = thumbnail_source_get_thumbnail (G_TYPE_CHECK_INSTANCE_CAST (_tmp114_, TYPE_THUMBNAIL_SOURCE, ThumbnailSource), ADJUST_DATE_TIME_DIALOG_CALENDAR_THUMBNAIL_SCALE, &_inner_error_);
#line 1752 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp113_ = _tmp115_;
#line 1752 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 14482 "Dialogs.c"
			goto __catch412_g_error;
		}
#line 1752 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp116_ = _tmp113_;
#line 1752 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp113_ = NULL;
#line 1752 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (preview);
#line 1752 "/home/jens/Source/shotwell/src/Dialogs.vala"
		preview = _tmp116_;
#line 1749 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (_tmp113_);
#line 14495 "Dialogs.c"
	}
	goto __finally412;
	__catch412_g_error:
	{
		GError* err = NULL;
		Dateable* _tmp117_ = NULL;
		gchar* _tmp118_ = NULL;
		gchar* _tmp119_ = NULL;
#line 1749 "/home/jens/Source/shotwell/src/Dialogs.vala"
		err = _inner_error_;
#line 1749 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_inner_error_ = NULL;
#line 1754 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp117_ = source;
#line 1754 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp118_ = data_object_to_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp117_, TYPE_DATA_OBJECT, DataObject));
#line 1754 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp119_ = _tmp118_;
#line 1754 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_warning ("Dialogs.vala:1754: Unable to fetch preview for %s", _tmp119_);
#line 1754 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp119_);
#line 1749 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_error_free0 (err);
#line 14520 "Dialogs.c"
	}
	__finally412:
#line 1749 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1749 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (preview);
#line 1749 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (time_content);
#line 1749 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (clock);
#line 1749 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1749 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_clear_error (&_inner_error_);
#line 1749 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return NULL;
#line 14537 "Dialogs.c"
	}
#line 1757 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp120_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
#line 1757 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp120_);
#line 1757 "/home/jens/Source/shotwell/src/Dialogs.vala"
	image_content = _tmp120_;
#line 1758 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp121_ = image_content;
#line 1758 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_set_valign (G_TYPE_CHECK_INSTANCE_CAST (_tmp121_, gtk_widget_get_type (), GtkWidget), GTK_ALIGN_START);
#line 1759 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp122_ = image_content;
#line 1759 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_box_set_homogeneous (_tmp122_, TRUE);
#line 1760 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp124_ = preview;
#line 1760 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp124_ != NULL) {
#line 14557 "Dialogs.c"
		GdkPixbuf* _tmp125_ = NULL;
		GtkImage* _tmp126_ = NULL;
#line 1760 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp125_ = preview;
#line 1760 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp126_ = (GtkImage*) gtk_image_new_from_pixbuf (_tmp125_);
#line 1760 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_object_ref_sink (_tmp126_);
#line 1760 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (_tmp123_);
#line 1760 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp123_ = _tmp126_;
#line 14570 "Dialogs.c"
	} else {
		GtkImage* _tmp127_ = NULL;
#line 1760 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp127_ = (GtkImage*) gtk_image_new ();
#line 1760 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_object_ref_sink (_tmp127_);
#line 1760 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (_tmp123_);
#line 1760 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp123_ = _tmp127_;
#line 14581 "Dialogs.c"
	}
#line 1760 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp128_ = _g_object_ref0 (_tmp123_);
#line 1760 "/home/jens/Source/shotwell/src/Dialogs.vala"
	image = _tmp128_;
#line 1761 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp129_ = (GtkLabel*) gtk_label_new (NULL);
#line 1761 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp129_);
#line 1761 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->original_time_label);
#line 1761 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->original_time_label = _tmp129_;
#line 1762 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp130_ = image_content;
#line 1762 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp131_ = image;
#line 1762 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_box_pack_start (_tmp130_, G_TYPE_CHECK_INSTANCE_CAST (_tmp131_, gtk_widget_get_type (), GtkWidget), TRUE, FALSE, (guint) 0);
#line 1763 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp132_ = image_content;
#line 1763 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp133_ = self->priv->original_time_label;
#line 1763 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_box_pack_start (_tmp132_, G_TYPE_CHECK_INSTANCE_CAST (_tmp133_, gtk_widget_get_type (), GtkWidget), TRUE, FALSE, (guint) 0);
#line 1765 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp134_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 10);
#line 1765 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp134_);
#line 1765 "/home/jens/Source/shotwell/src/Dialogs.vala"
	hbox = _tmp134_;
#line 1766 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp135_ = hbox;
#line 1766 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_container_set_border_width (G_TYPE_CHECK_INSTANCE_CAST (_tmp135_, gtk_container_get_type (), GtkContainer), (guint) 3);
#line 1767 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp136_ = hbox;
#line 1767 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp137_ = image_content;
#line 1767 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_box_pack_start (_tmp136_, G_TYPE_CHECK_INSTANCE_CAST (_tmp137_, gtk_widget_get_type (), GtkWidget), TRUE, FALSE, (guint) 0);
#line 1768 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp138_ = hbox;
#line 1768 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp139_ = time_content;
#line 1768 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_box_pack_start (_tmp138_, G_TYPE_CHECK_INSTANCE_CAST (_tmp139_, gtk_widget_get_type (), GtkWidget), TRUE, FALSE, (guint) 0);
#line 1770 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp140_ = (GtkAlignment*) gtk_alignment_new (0.5f, 0.5f, (gfloat) 0, (gfloat) 0);
#line 1770 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp140_);
#line 1770 "/home/jens/Source/shotwell/src/Dialogs.vala"
	hbox_alignment = _tmp140_;
#line 1771 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp141_ = hbox_alignment;
#line 1771 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp142_ = hbox;
#line 1771 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_container_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp141_, gtk_container_get_type (), GtkContainer), G_TYPE_CHECK_INSTANCE_CAST (_tmp142_, gtk_widget_get_type (), GtkWidget));
#line 1773 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp143_ = (GtkBox*) gtk_dialog_get_content_area (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog));
#line 1773 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp144_ = hbox_alignment;
#line 1773 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_box_pack_start (G_TYPE_CHECK_INSTANCE_CAST (_tmp143_, gtk_box_get_type (), GtkBox), G_TYPE_CHECK_INSTANCE_CAST (_tmp144_, gtk_widget_get_type (), GtkWidget), TRUE, FALSE, (guint) 0);
#line 1775 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp145_ = (GtkLabel*) gtk_label_new ("");
#line 1775 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp145_);
#line 1775 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->notification);
#line 1775 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->notification = _tmp145_;
#line 1776 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp146_ = self->priv->notification;
#line 1776 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_label_set_line_wrap (_tmp146_, TRUE);
#line 1777 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp147_ = self->priv->notification;
#line 1777 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_label_set_justify (_tmp147_, GTK_JUSTIFY_CENTER);
#line 1779 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp148_ = (GtkBox*) gtk_dialog_get_content_area (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog));
#line 1779 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp149_ = self->priv->notification;
#line 1779 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_box_pack_start (G_TYPE_CHECK_INSTANCE_CAST (_tmp148_, gtk_box_get_type (), GtkBox), G_TYPE_CHECK_INSTANCE_CAST (_tmp149_, gtk_widget_get_type (), GtkWidget), TRUE, TRUE, (guint) 0);
#line 1781 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp150_ = source;
#line 1781 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp151_ = dateable_get_exposure_time (_tmp150_);
#line 1781 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->original_time = _tmp151_;
#line 1783 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp152_ = self->priv->original_time;
#line 1783 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp152_ == ((time_t) 0)) {
#line 14679 "Dialogs.c"
		time_t _tmp153_ = 0;
#line 1784 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp153_ = time (NULL);
#line 1784 "/home/jens/Source/shotwell/src/Dialogs.vala"
		self->priv->original_time = _tmp153_;
#line 1785 "/home/jens/Source/shotwell/src/Dialogs.vala"
		self->priv->no_original_time = TRUE;
#line 14687 "Dialogs.c"
	}
#line 1788 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp154_ = self->priv->original_time;
#line 1788 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_time_local (_tmp154_, &_tmp155_);
#line 1788 "/home/jens/Source/shotwell/src/Dialogs.vala"
	adjust_date_time_dialog_set_time (self, &_tmp155_);
#line 1789 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp156_ = config_facade_get_instance ();
#line 1789 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp157_ = _tmp156_;
#line 1789 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp158_ = configuration_facade_get_use_24_hour_time (G_TYPE_CHECK_INSTANCE_CAST (_tmp157_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade));
#line 1789 "/home/jens/Source/shotwell/src/Dialogs.vala"
	adjust_date_time_dialog_set_original_time_label (self, _tmp158_);
#line 1789 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp157_);
#line 1655 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (hbox_alignment);
#line 1655 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (hbox);
#line 1655 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (image);
#line 1655 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp123_);
#line 1655 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (image_content);
#line 1655 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (preview);
#line 1655 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (time_content);
#line 1655 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (clock);
#line 1655 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return self;
#line 14723 "Dialogs.c"
}


AdjustDateTimeDialog* adjust_date_time_dialog_new (Dateable* source, gint photo_count, gboolean display_options, gboolean contains_video, gboolean only_video) {
#line 1655 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return adjust_date_time_dialog_construct (TYPE_ADJUST_DATE_TIME_DIALOG, source, photo_count, display_options, contains_video, only_video);
#line 14730 "Dialogs.c"
}


static void adjust_date_time_dialog_set_time (AdjustDateTimeDialog* self, struct tm* time) {
	GtkCalendar* _tmp0_ = NULL;
	struct tm _tmp1_ = {0};
	gint _tmp2_ = 0;
	struct tm _tmp3_ = {0};
	gint _tmp4_ = 0;
	GtkCalendar* _tmp5_ = NULL;
	struct tm _tmp6_ = {0};
	gint _tmp7_ = 0;
	ConfigFacade* _tmp8_ = NULL;
	ConfigFacade* _tmp9_ = NULL;
	gboolean _tmp10_ = FALSE;
	gboolean _tmp11_ = FALSE;
	GtkSpinButton* _tmp26_ = NULL;
	struct tm _tmp27_ = {0};
	gint _tmp28_ = 0;
	GtkSpinButton* _tmp29_ = NULL;
	struct tm _tmp30_ = {0};
	gint _tmp31_ = 0;
	GtkComboBoxText* _tmp32_ = NULL;
	gint _tmp33_ = 0;
#line 1792 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_ADJUST_DATE_TIME_DIALOG (self));
#line 1792 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (time != NULL);
#line 1793 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = self->priv->calendar;
#line 1793 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = *time;
#line 1793 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = _tmp1_.tm_mon;
#line 1793 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = *time;
#line 1793 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = _tmp3_.tm_year;
#line 1793 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_calendar_select_month (_tmp0_, (guint) _tmp2_, (guint) (_tmp4_ + ADJUST_DATE_TIME_DIALOG_YEAR_OFFSET));
#line 1794 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = self->priv->calendar;
#line 1794 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = *time;
#line 1794 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = _tmp6_.tm_mday;
#line 1794 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_calendar_select_day (_tmp5_, (guint) _tmp7_);
#line 1796 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = config_facade_get_instance ();
#line 1796 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = _tmp8_;
#line 1796 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp10_ = configuration_facade_get_use_24_hour_time (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade));
#line 1796 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp11_ = _tmp10_;
#line 1796 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp9_);
#line 1796 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp11_) {
#line 14791 "Dialogs.c"
		GtkComboBoxText* _tmp12_ = NULL;
		GtkSpinButton* _tmp13_ = NULL;
		struct tm _tmp14_ = {0};
		gint _tmp15_ = 0;
#line 1797 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp12_ = self->priv->system;
#line 1797 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_combo_box_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp12_, gtk_combo_box_get_type (), GtkComboBox), (gint) ADJUST_DATE_TIME_DIALOG_TIME_SYSTEM_24HR);
#line 1798 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp13_ = self->priv->hour;
#line 1798 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp14_ = *time;
#line 1798 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp15_ = _tmp14_.tm_hour;
#line 1798 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_spin_button_set_value (_tmp13_, (gdouble) _tmp15_);
#line 14808 "Dialogs.c"
	} else {
		gint AMPM_hour = 0;
		struct tm _tmp16_ = {0};
		gint _tmp17_ = 0;
		gint _tmp18_ = 0;
		gint _tmp19_ = 0;
		GtkSpinButton* _tmp21_ = NULL;
		AdjustDateTimeDialogTimeSystem _tmp22_ = 0;
		struct tm _tmp23_ = {0};
		gint _tmp24_ = 0;
		GtkComboBoxText* _tmp25_ = NULL;
#line 1800 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp16_ = *time;
#line 1800 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp17_ = _tmp16_.tm_hour;
#line 1800 "/home/jens/Source/shotwell/src/Dialogs.vala"
		AMPM_hour = _tmp17_ % 12;
#line 1801 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp19_ = AMPM_hour;
#line 1801 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp19_ == 0) {
#line 1801 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp18_ = 12;
#line 14832 "Dialogs.c"
		} else {
			gint _tmp20_ = 0;
#line 1801 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp20_ = AMPM_hour;
#line 1801 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp18_ = _tmp20_;
#line 14839 "Dialogs.c"
		}
#line 1801 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp21_ = self->priv->hour;
#line 1801 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_spin_button_set_value (_tmp21_, (gdouble) _tmp18_);
#line 1802 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp23_ = *time;
#line 1802 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp24_ = _tmp23_.tm_hour;
#line 1802 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp24_ >= 12) {
#line 1802 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp22_ = ADJUST_DATE_TIME_DIALOG_TIME_SYSTEM_PM;
#line 14853 "Dialogs.c"
		} else {
#line 1802 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp22_ = ADJUST_DATE_TIME_DIALOG_TIME_SYSTEM_AM;
#line 14857 "Dialogs.c"
		}
#line 1802 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp25_ = self->priv->system;
#line 1802 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_combo_box_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp25_, gtk_combo_box_get_type (), GtkComboBox), (gint) _tmp22_);
#line 14863 "Dialogs.c"
	}
#line 1805 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp26_ = self->priv->minute;
#line 1805 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp27_ = *time;
#line 1805 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp28_ = _tmp27_.tm_min;
#line 1805 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_spin_button_set_value (_tmp26_, (gdouble) _tmp28_);
#line 1806 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp29_ = self->priv->second;
#line 1806 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp30_ = *time;
#line 1806 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp31_ = _tmp30_.tm_sec;
#line 1806 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_spin_button_set_value (_tmp29_, (gdouble) _tmp31_);
#line 1808 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp32_ = self->priv->system;
#line 1808 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp33_ = gtk_combo_box_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp32_, gtk_combo_box_get_type (), GtkComboBox));
#line 1808 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->previous_time_system = (AdjustDateTimeDialogTimeSystem) _tmp33_;
#line 14887 "Dialogs.c"
}


static gchar* g_time_format (struct tm *self, const gchar* format) {
	gchar* result = NULL;
	gchar* buffer = NULL;
	gchar* _tmp0_ = NULL;
	gint buffer_length1 = 0;
	gint _buffer_size_ = 0;
	gchar* _tmp1_ = NULL;
	gint _tmp1__length1 = 0;
	const gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gint _tmp3__length1 = 0;
	gchar* _tmp4_ = NULL;
#line 2709 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	g_return_val_if_fail (format != NULL, NULL);
#line 2710 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp0_ = g_new0 (gchar, 64);
#line 2710 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	buffer = _tmp0_;
#line 2710 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	buffer_length1 = 64;
#line 2710 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_buffer_size_ = buffer_length1;
#line 2711 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp1_ = buffer;
#line 2711 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp1__length1 = buffer_length1;
#line 2711 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp2_ = format;
#line 2711 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	strftime (_tmp1_, _tmp1__length1, _tmp2_, &(*self));
#line 2712 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp3_ = buffer;
#line 2712 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp3__length1 = buffer_length1;
#line 2712 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp4_ = g_strdup ((const gchar*) _tmp3_);
#line 2712 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	result = _tmp4_;
#line 2712 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	buffer = (g_free (buffer), NULL);
#line 2712 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	return result;
#line 14933 "Dialogs.c"
}


static void adjust_date_time_dialog_set_original_time_label (AdjustDateTimeDialog* self, gboolean use_24_hr_format) {
	gboolean _tmp0_ = FALSE;
	const gchar* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	GtkLabel* _tmp5_ = NULL;
	const gchar* _tmp6_ = NULL;
	time_t _tmp7_ = 0;
	struct tm _tmp8_ = {0};
	gchar* _tmp9_ = NULL;
	gchar* _tmp10_ = NULL;
	gchar* _tmp11_ = NULL;
	gchar* _tmp12_ = NULL;
#line 1811 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_ADJUST_DATE_TIME_DIALOG (self));
#line 1812 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = self->priv->no_original_time;
#line 1812 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp0_) {
#line 1813 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return;
#line 14957 "Dialogs.c"
	}
#line 1816 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = use_24_hr_format;
#line 1816 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp2_) {
#line 14963 "Dialogs.c"
		const gchar* _tmp3_ = NULL;
#line 1816 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp3_ = _ ("%m/%d/%Y, %H:%M:%S");
#line 1816 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp1_ = _tmp3_;
#line 14969 "Dialogs.c"
	} else {
		const gchar* _tmp4_ = NULL;
#line 1817 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp4_ = _ ("%m/%d/%Y, %I:%M:%S %p");
#line 1817 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp1_ = _tmp4_;
#line 14976 "Dialogs.c"
	}
#line 1815 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = self->priv->original_time_label;
#line 1815 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = _ ("Original: ");
#line 1815 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = self->priv->original_time;
#line 1815 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_time_local (_tmp7_, &_tmp8_);
#line 1815 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = g_time_format (&_tmp8_, _tmp1_);
#line 1815 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp10_ = _tmp9_;
#line 1815 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp11_ = g_strconcat (_tmp6_, _tmp10_, NULL);
#line 1815 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp12_ = _tmp11_;
#line 1815 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_label_set_text (_tmp5_, _tmp12_);
#line 1815 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp12_);
#line 1815 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp10_);
#line 15000 "Dialogs.c"
}


static time_t adjust_date_time_dialog_get_time (AdjustDateTimeDialog* self) {
	time_t result = 0;
	struct tm time = {0};
	GtkSpinButton* _tmp0_ = NULL;
	gdouble _tmp1_ = 0.0;
	GtkSpinButton* _tmp2_ = NULL;
	gdouble _tmp3_ = 0.0;
	gint hour = 0;
	GtkSpinButton* _tmp4_ = NULL;
	gdouble _tmp5_ = 0.0;
	gint _tmp6_ = 0;
	gboolean _tmp7_ = FALSE;
	gint _tmp8_ = 0;
	gint _tmp12_ = 0;
	GtkComboBoxText* _tmp13_ = NULL;
	gint _tmp14_ = 0;
	gint _tmp15_ = 0;
	guint year = 0U;
	guint month = 0U;
	guint day = 0U;
	GtkCalendar* _tmp16_ = NULL;
	guint _tmp17_ = 0U;
	guint _tmp18_ = 0U;
	guint _tmp19_ = 0U;
	time_t _tmp20_ = 0;
#line 1820 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_ADJUST_DATE_TIME_DIALOG (self), 0);
#line 1821 "/home/jens/Source/shotwell/src/Dialogs.vala"
	memset (&time, 0, sizeof (struct tm));
#line 1823 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = self->priv->second;
#line 1823 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = gtk_spin_button_get_value (_tmp0_);
#line 1823 "/home/jens/Source/shotwell/src/Dialogs.vala"
	time.tm_sec = (gint) _tmp1_;
#line 1824 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = self->priv->minute;
#line 1824 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = gtk_spin_button_get_value (_tmp2_);
#line 1824 "/home/jens/Source/shotwell/src/Dialogs.vala"
	time.tm_min = (gint) _tmp3_;
#line 1827 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = self->priv->hour;
#line 1827 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = gtk_spin_button_get_value (_tmp4_);
#line 1827 "/home/jens/Source/shotwell/src/Dialogs.vala"
	hour = (gint) _tmp5_;
#line 1828 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = hour;
#line 1828 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp8_ == 12) {
#line 15055 "Dialogs.c"
		GtkComboBoxText* _tmp9_ = NULL;
		gint _tmp10_ = 0;
#line 1828 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp9_ = self->priv->system;
#line 1828 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp10_ = gtk_combo_box_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, gtk_combo_box_get_type (), GtkComboBox));
#line 1828 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp7_ = _tmp10_ != ((gint) ADJUST_DATE_TIME_DIALOG_TIME_SYSTEM_24HR);
#line 15064 "Dialogs.c"
	} else {
#line 1828 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp7_ = FALSE;
#line 15068 "Dialogs.c"
	}
#line 1828 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp7_) {
#line 1828 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp6_ = 0;
#line 15074 "Dialogs.c"
	} else {
		gint _tmp11_ = 0;
#line 1828 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp11_ = hour;
#line 1828 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp6_ = _tmp11_;
#line 15081 "Dialogs.c"
	}
#line 1828 "/home/jens/Source/shotwell/src/Dialogs.vala"
	time.tm_hour = _tmp6_;
#line 1829 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp13_ = self->priv->system;
#line 1829 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp14_ = gtk_combo_box_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp13_, gtk_combo_box_get_type (), GtkComboBox));
#line 1829 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp14_ == ((gint) ADJUST_DATE_TIME_DIALOG_TIME_SYSTEM_PM)) {
#line 1829 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp12_ = 12;
#line 15093 "Dialogs.c"
	} else {
#line 1829 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp12_ = 0;
#line 15097 "Dialogs.c"
	}
#line 1829 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp15_ = time.tm_hour;
#line 1829 "/home/jens/Source/shotwell/src/Dialogs.vala"
	time.tm_hour = _tmp15_ + _tmp12_;
#line 1832 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp16_ = self->priv->calendar;
#line 1832 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_calendar_get_date (_tmp16_, &_tmp17_, &_tmp18_, &_tmp19_);
#line 1832 "/home/jens/Source/shotwell/src/Dialogs.vala"
	year = _tmp17_;
#line 1832 "/home/jens/Source/shotwell/src/Dialogs.vala"
	month = _tmp18_;
#line 1832 "/home/jens/Source/shotwell/src/Dialogs.vala"
	day = _tmp19_;
#line 1833 "/home/jens/Source/shotwell/src/Dialogs.vala"
	time.tm_year = ((gint) year) - ADJUST_DATE_TIME_DIALOG_YEAR_OFFSET;
#line 1834 "/home/jens/Source/shotwell/src/Dialogs.vala"
	time.tm_mon = (gint) month;
#line 1835 "/home/jens/Source/shotwell/src/Dialogs.vala"
	time.tm_mday = (gint) day;
#line 1837 "/home/jens/Source/shotwell/src/Dialogs.vala"
	time.tm_isdst = -1;
#line 1839 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp20_ = mktime (&time);
#line 1839 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = _tmp20_;
#line 1839 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 15127 "Dialogs.c"
}


gboolean adjust_date_time_dialog_execute (AdjustDateTimeDialog* self, gint64* time_shift, gboolean* keep_relativity, gboolean* modify_originals) {
	gint64 _vala_time_shift = 0LL;
	gboolean _vala_keep_relativity = FALSE;
	gboolean _vala_modify_originals = FALSE;
	gboolean result = FALSE;
	gboolean response = FALSE;
	gint _tmp0_ = 0;
#line 1842 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_ADJUST_DATE_TIME_DIALOG (self), FALSE);
#line 1844 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_show_all (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 1846 "/home/jens/Source/shotwell/src/Dialogs.vala"
	response = FALSE;
#line 1848 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog));
#line 1848 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp0_ == ((gint) GTK_RESPONSE_OK)) {
#line 15148 "Dialogs.c"
		gboolean _tmp1_ = FALSE;
		GtkRadioButton* _tmp5_ = NULL;
		gboolean _tmp6_ = FALSE;
		GtkRadioButton* _tmp7_ = NULL;
		gboolean _tmp8_ = FALSE;
		gboolean _tmp9_ = FALSE;
		GtkCheckButton* _tmp13_ = NULL;
		gboolean _tmp14_ = FALSE;
		GtkCheckButton* _tmp15_ = NULL;
		gboolean _tmp16_ = FALSE;
		gboolean _tmp17_ = FALSE;
#line 1849 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp1_ = self->priv->no_original_time;
#line 1849 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp1_) {
#line 15164 "Dialogs.c"
			time_t _tmp2_ = 0;
#line 1850 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp2_ = adjust_date_time_dialog_get_time (self);
#line 1850 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_vala_time_shift = (gint64) _tmp2_;
#line 15170 "Dialogs.c"
		} else {
			time_t _tmp3_ = 0;
			time_t _tmp4_ = 0;
#line 1852 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp3_ = adjust_date_time_dialog_get_time (self);
#line 1852 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp4_ = self->priv->original_time;
#line 1852 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_vala_time_shift = (gint64) (_tmp3_ - _tmp4_);
#line 15180 "Dialogs.c"
		}
#line 1854 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp5_ = self->priv->relativity_radio_button;
#line 1854 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp6_ = gtk_toggle_button_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, gtk_toggle_button_get_type (), GtkToggleButton));
#line 1854 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_vala_keep_relativity = _tmp6_;
#line 1856 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp7_ = self->priv->relativity_radio_button;
#line 1856 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp8_ = gtk_widget_get_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, gtk_widget_get_type (), GtkWidget));
#line 1856 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp9_ = _tmp8_;
#line 1856 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp9_) {
#line 15196 "Dialogs.c"
			ConfigFacade* _tmp10_ = NULL;
			ConfigFacade* _tmp11_ = NULL;
			gboolean _tmp12_ = FALSE;
#line 1857 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp10_ = config_facade_get_instance ();
#line 1857 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp11_ = _tmp10_;
#line 1857 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp12_ = _vala_keep_relativity;
#line 1857 "/home/jens/Source/shotwell/src/Dialogs.vala"
			configuration_facade_set_keep_relativity (G_TYPE_CHECK_INSTANCE_CAST (_tmp11_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade), _tmp12_);
#line 1857 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_object_unref0 (_tmp11_);
#line 15210 "Dialogs.c"
		}
#line 1859 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp13_ = self->priv->modify_originals_check_button;
#line 1859 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp14_ = gtk_toggle_button_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp13_, gtk_toggle_button_get_type (), GtkToggleButton));
#line 1859 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_vala_modify_originals = _tmp14_;
#line 1861 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp15_ = self->priv->modify_originals_check_button;
#line 1861 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp16_ = gtk_widget_get_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp15_, gtk_widget_get_type (), GtkWidget));
#line 1861 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp17_ = _tmp16_;
#line 1861 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp17_) {
#line 15226 "Dialogs.c"
			ConfigFacade* _tmp18_ = NULL;
			ConfigFacade* _tmp19_ = NULL;
			gboolean _tmp20_ = FALSE;
#line 1862 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp18_ = config_facade_get_instance ();
#line 1862 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp19_ = _tmp18_;
#line 1862 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp20_ = _vala_modify_originals;
#line 1862 "/home/jens/Source/shotwell/src/Dialogs.vala"
			configuration_facade_set_modify_originals (G_TYPE_CHECK_INSTANCE_CAST (_tmp19_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade), _tmp20_);
#line 1862 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_object_unref0 (_tmp19_);
#line 15240 "Dialogs.c"
		}
#line 1864 "/home/jens/Source/shotwell/src/Dialogs.vala"
		response = TRUE;
#line 15244 "Dialogs.c"
	} else {
#line 1866 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_vala_time_shift = (gint64) 0;
#line 1867 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_vala_keep_relativity = TRUE;
#line 1868 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_vala_modify_originals = FALSE;
#line 15252 "Dialogs.c"
	}
#line 1871 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 1873 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = response;
#line 1873 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (time_shift) {
#line 1873 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*time_shift = _vala_time_shift;
#line 15262 "Dialogs.c"
	}
#line 1873 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (keep_relativity) {
#line 1873 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*keep_relativity = _vala_keep_relativity;
#line 15268 "Dialogs.c"
	}
#line 1873 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (modify_originals) {
#line 1873 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*modify_originals = _vala_modify_originals;
#line 15274 "Dialogs.c"
	}
#line 1873 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 15278 "Dialogs.c"
}


static gboolean adjust_date_time_dialog_on_spin_button_output (AdjustDateTimeDialog* self, GtkSpinButton* button) {
	gboolean result = FALSE;
	GtkSpinButton* _tmp0_ = NULL;
	GtkSpinButton* _tmp1_ = NULL;
	gdouble _tmp2_ = 0.0;
	gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
#line 1876 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_ADJUST_DATE_TIME_DIALOG (self), FALSE);
#line 1876 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (GTK_IS_SPIN_BUTTON (button), FALSE);
#line 1877 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = button;
#line 1877 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = button;
#line 1877 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = gtk_spin_button_get_value (_tmp1_);
#line 1877 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = g_strdup_printf ("%02d", (gint) _tmp2_);
#line 1877 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = _tmp3_;
#line 1877 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_entry_set_text (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_entry_get_type (), GtkEntry), _tmp4_);
#line 1877 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp4_);
#line 1879 "/home/jens/Source/shotwell/src/Dialogs.vala"
	adjust_date_time_dialog_on_time_changed (self);
#line 1881 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = TRUE;
#line 1881 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 15313 "Dialogs.c"
}


static void adjust_date_time_dialog_on_time_changed (AdjustDateTimeDialog* self) {
	gint64 time_shift = 0LL;
	time_t _tmp0_ = 0;
	time_t _tmp1_ = 0;
	GtkComboBoxText* _tmp2_ = NULL;
	gint _tmp3_ = 0;
	gboolean _tmp4_ = FALSE;
	gboolean _tmp5_ = FALSE;
	gint64 _tmp6_ = 0LL;
#line 1884 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_ADJUST_DATE_TIME_DIALOG (self));
#line 1885 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = adjust_date_time_dialog_get_time (self);
#line 1885 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = self->priv->original_time;
#line 1885 "/home/jens/Source/shotwell/src/Dialogs.vala"
	time_shift = ((gint64) _tmp0_) - ((gint64) _tmp1_);
#line 1887 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = self->priv->system;
#line 1887 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = gtk_combo_box_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, gtk_combo_box_get_type (), GtkComboBox));
#line 1887 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->previous_time_system = (AdjustDateTimeDialogTimeSystem) _tmp3_;
#line 1889 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = time_shift;
#line 1889 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp6_ == ((gint64) 0)) {
#line 1889 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp5_ = TRUE;
#line 15346 "Dialogs.c"
	} else {
		gboolean _tmp7_ = FALSE;
#line 1889 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp7_ = self->priv->no_original_time;
#line 1889 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp5_ = _tmp7_;
#line 15353 "Dialogs.c"
	}
#line 1889 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp5_) {
#line 1889 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp4_ = TRUE;
#line 15359 "Dialogs.c"
	} else {
		gboolean _tmp8_ = FALSE;
		GtkRadioButton* _tmp9_ = NULL;
		gboolean _tmp10_ = FALSE;
#line 1889 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp9_ = self->priv->batch_radio_button;
#line 1889 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp10_ = gtk_toggle_button_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, gtk_toggle_button_get_type (), GtkToggleButton));
#line 1889 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp10_) {
#line 15370 "Dialogs.c"
			GtkRadioButton* _tmp11_ = NULL;
			gboolean _tmp12_ = FALSE;
			gboolean _tmp13_ = FALSE;
#line 1890 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp11_ = self->priv->batch_radio_button;
#line 1890 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp12_ = gtk_widget_get_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp11_, gtk_widget_get_type (), GtkWidget));
#line 1890 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp13_ = _tmp12_;
#line 1890 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp8_ = _tmp13_;
#line 15382 "Dialogs.c"
		} else {
#line 1889 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp8_ = FALSE;
#line 15386 "Dialogs.c"
		}
#line 1889 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp4_ = _tmp8_;
#line 15390 "Dialogs.c"
	}
#line 1889 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp4_) {
#line 15394 "Dialogs.c"
		GtkLabel* _tmp14_ = NULL;
#line 1891 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp14_ = self->priv->notification;
#line 1891 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_widget_hide (G_TYPE_CHECK_INSTANCE_CAST (_tmp14_, gtk_widget_get_type (), GtkWidget));
#line 15400 "Dialogs.c"
	} else {
		gboolean forward = FALSE;
		gint64 _tmp15_ = 0LL;
		gint days = 0;
		gint hours = 0;
		gint minutes = 0;
		gint seconds = 0;
		gint64 _tmp16_ = 0LL;
		gint64 _tmp17_ = 0LL;
		gint64 _tmp18_ = 0LL;
		gint64 _tmp19_ = 0LL;
		gint64 _tmp20_ = 0LL;
		gint64 _tmp21_ = 0LL;
		gint64 _tmp22_ = 0LL;
		gint64 _tmp23_ = 0LL;
		const gchar* _tmp24_ = NULL;
		gboolean _tmp25_ = FALSE;
		gchar* shift_status = NULL;
		gchar* _tmp28_ = NULL;
		GtkLabel* _tmp29_ = NULL;
		const gchar* _tmp30_ = NULL;
		gint _tmp31_ = 0;
		gint _tmp32_ = 0;
		const gchar* _tmp33_ = NULL;
		gint _tmp34_ = 0;
		gint _tmp35_ = 0;
		const gchar* _tmp36_ = NULL;
		gint _tmp37_ = 0;
		gint _tmp38_ = 0;
		const gchar* _tmp39_ = NULL;
		gint _tmp40_ = 0;
		gint _tmp41_ = 0;
		const gchar* _tmp42_ = NULL;
		gchar* _tmp43_ = NULL;
		gchar* _tmp44_ = NULL;
		GtkLabel* _tmp45_ = NULL;
#line 1893 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp15_ = time_shift;
#line 1893 "/home/jens/Source/shotwell/src/Dialogs.vala"
		forward = _tmp15_ > ((gint64) 0);
#line 1896 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp16_ = time_shift;
#line 1896 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp17_ = llabs (_tmp16_);
#line 1896 "/home/jens/Source/shotwell/src/Dialogs.vala"
		time_shift = _tmp17_;
#line 1898 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp18_ = time_shift;
#line 1898 "/home/jens/Source/shotwell/src/Dialogs.vala"
		days = (gint) (_tmp18_ / ADJUST_DATE_TIME_DIALOG_SECONDS_IN_DAY);
#line 1899 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp19_ = time_shift;
#line 1899 "/home/jens/Source/shotwell/src/Dialogs.vala"
		time_shift = _tmp19_ % ADJUST_DATE_TIME_DIALOG_SECONDS_IN_DAY;
#line 1900 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp20_ = time_shift;
#line 1900 "/home/jens/Source/shotwell/src/Dialogs.vala"
		hours = (gint) (_tmp20_ / ADJUST_DATE_TIME_DIALOG_SECONDS_IN_HOUR);
#line 1901 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp21_ = time_shift;
#line 1901 "/home/jens/Source/shotwell/src/Dialogs.vala"
		time_shift = _tmp21_ % ADJUST_DATE_TIME_DIALOG_SECONDS_IN_HOUR;
#line 1902 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp22_ = time_shift;
#line 1902 "/home/jens/Source/shotwell/src/Dialogs.vala"
		minutes = (gint) (_tmp22_ / ADJUST_DATE_TIME_DIALOG_SECONDS_IN_MINUTE);
#line 1903 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp23_ = time_shift;
#line 1903 "/home/jens/Source/shotwell/src/Dialogs.vala"
		seconds = (gint) (_tmp23_ % ADJUST_DATE_TIME_DIALOG_SECONDS_IN_MINUTE);
#line 1905 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp25_ = forward;
#line 1905 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp25_) {
#line 15475 "Dialogs.c"
			const gchar* _tmp26_ = NULL;
#line 1906 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp26_ = _ ("Exposure time will be shifted forward by\n" \
"%d %s, %d %s, %d %s, and %d %s.");
#line 1906 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp24_ = _tmp26_;
#line 15481 "Dialogs.c"
		} else {
			const gchar* _tmp27_ = NULL;
#line 1907 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp27_ = _ ("Exposure time will be shifted backward by\n" \
"%d %s, %d %s, %d %s, and %d %s.");
#line 1907 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp24_ = _tmp27_;
#line 15488 "Dialogs.c"
		}
#line 1905 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp28_ = g_strdup (_tmp24_);
#line 1905 "/home/jens/Source/shotwell/src/Dialogs.vala"
		shift_status = _tmp28_;
#line 1909 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp29_ = self->priv->notification;
#line 1909 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp30_ = shift_status;
#line 1909 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp31_ = days;
#line 1909 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp32_ = days;
#line 1909 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp33_ = ngettext ("day", "days", (gulong) _tmp32_);
#line 1909 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp34_ = hours;
#line 1909 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp35_ = hours;
#line 1909 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp36_ = ngettext ("hour", "hours", (gulong) _tmp35_);
#line 1909 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp37_ = minutes;
#line 1909 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp38_ = minutes;
#line 1909 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp39_ = ngettext ("minute", "minutes", (gulong) _tmp38_);
#line 1909 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp40_ = seconds;
#line 1909 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp41_ = seconds;
#line 1909 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp42_ = ngettext ("second", "seconds", (gulong) _tmp41_);
#line 1909 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp43_ = g_strdup_printf (_tmp30_, _tmp31_, _tmp33_, _tmp34_, _tmp36_, _tmp37_, _tmp39_, _tmp40_, _tmp42_);
#line 1909 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp44_ = _tmp43_;
#line 1909 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_label_set_text (_tmp29_, _tmp44_);
#line 1909 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp44_);
#line 1914 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp45_ = self->priv->notification;
#line 1914 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_widget_show (G_TYPE_CHECK_INSTANCE_CAST (_tmp45_, gtk_widget_get_type (), GtkWidget));
#line 1889 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (shift_status);
#line 15536 "Dialogs.c"
	}
}


static void adjust_date_time_dialog_on_time_system_changed (AdjustDateTimeDialog* self) {
	AdjustDateTimeDialogTimeSystem _tmp0_ = 0;
	GtkComboBoxText* _tmp1_ = NULL;
	gint _tmp2_ = 0;
	ConfigFacade* _tmp3_ = NULL;
	ConfigFacade* _tmp4_ = NULL;
	GtkComboBoxText* _tmp5_ = NULL;
	gint _tmp6_ = 0;
	GtkComboBoxText* _tmp7_ = NULL;
	gint _tmp8_ = 0;
#line 1918 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_ADJUST_DATE_TIME_DIALOG (self));
#line 1919 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = self->priv->previous_time_system;
#line 1919 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = self->priv->system;
#line 1919 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = gtk_combo_box_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, gtk_combo_box_get_type (), GtkComboBox));
#line 1919 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp0_ == _tmp2_) {
#line 1920 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return;
#line 15563 "Dialogs.c"
	}
#line 1922 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = config_facade_get_instance ();
#line 1922 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = _tmp3_;
#line 1922 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = self->priv->system;
#line 1922 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = gtk_combo_box_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, gtk_combo_box_get_type (), GtkComboBox));
#line 1922 "/home/jens/Source/shotwell/src/Dialogs.vala"
	configuration_facade_set_use_24_hour_time (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade), _tmp6_ == ((gint) ADJUST_DATE_TIME_DIALOG_TIME_SYSTEM_24HR));
#line 1922 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp4_);
#line 1924 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = self->priv->system;
#line 1924 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = gtk_combo_box_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, gtk_combo_box_get_type (), GtkComboBox));
#line 1924 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp8_ == ((gint) ADJUST_DATE_TIME_DIALOG_TIME_SYSTEM_24HR)) {
#line 15583 "Dialogs.c"
		gint _tmp9_ = 0;
		GtkSpinButton* _tmp10_ = NULL;
		gdouble _tmp11_ = 0.0;
		gint time = 0;
		gint _tmp14_ = 0;
		AdjustDateTimeDialogTimeSystem _tmp15_ = 0;
		gint _tmp16_ = 0;
		GtkSpinButton* _tmp17_ = NULL;
		GtkSpinButton* _tmp18_ = NULL;
		gint _tmp19_ = 0;
#line 1925 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp10_ = self->priv->hour;
#line 1925 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp11_ = gtk_spin_button_get_value (_tmp10_);
#line 1925 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp11_ == 12.0) {
#line 1925 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp9_ = 0;
#line 15602 "Dialogs.c"
		} else {
			GtkSpinButton* _tmp12_ = NULL;
			gdouble _tmp13_ = 0.0;
#line 1925 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp12_ = self->priv->hour;
#line 1925 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp13_ = gtk_spin_button_get_value (_tmp12_);
#line 1925 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp9_ = (gint) _tmp13_;
#line 15612 "Dialogs.c"
		}
#line 1925 "/home/jens/Source/shotwell/src/Dialogs.vala"
		time = _tmp9_;
#line 1926 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp15_ = self->priv->previous_time_system;
#line 1926 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp15_ == ADJUST_DATE_TIME_DIALOG_TIME_SYSTEM_PM) {
#line 1926 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp14_ = 12;
#line 15622 "Dialogs.c"
		} else {
#line 1926 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp14_ = 0;
#line 15626 "Dialogs.c"
		}
#line 1926 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp16_ = time;
#line 1926 "/home/jens/Source/shotwell/src/Dialogs.vala"
		time = _tmp16_ + _tmp14_;
#line 1928 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp17_ = self->priv->hour;
#line 1928 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_spin_button_set_range (_tmp17_, (gdouble) 0, (gdouble) 23);
#line 1929 "/home/jens/Source/shotwell/src/Dialogs.vala"
		adjust_date_time_dialog_set_original_time_label (self, TRUE);
#line 1931 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp18_ = self->priv->hour;
#line 1931 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp19_ = time;
#line 1931 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_spin_button_set_value (_tmp18_, (gdouble) _tmp19_);
#line 15644 "Dialogs.c"
	} else {
		gint AMPM_hour = 0;
		GtkSpinButton* _tmp20_ = NULL;
		gdouble _tmp21_ = 0.0;
		GtkSpinButton* _tmp22_ = NULL;
		gint _tmp23_ = 0;
		gint _tmp24_ = 0;
		GtkSpinButton* _tmp26_ = NULL;
#line 1933 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp20_ = self->priv->hour;
#line 1933 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp21_ = gtk_spin_button_get_value (_tmp20_);
#line 1933 "/home/jens/Source/shotwell/src/Dialogs.vala"
		AMPM_hour = ((gint) _tmp21_) % 12;
#line 1935 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp22_ = self->priv->hour;
#line 1935 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_spin_button_set_range (_tmp22_, (gdouble) 1, (gdouble) 12);
#line 1936 "/home/jens/Source/shotwell/src/Dialogs.vala"
		adjust_date_time_dialog_set_original_time_label (self, FALSE);
#line 1938 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp24_ = AMPM_hour;
#line 1938 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp24_ == 0) {
#line 1938 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp23_ = 12;
#line 15671 "Dialogs.c"
		} else {
			gint _tmp25_ = 0;
#line 1938 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp25_ = AMPM_hour;
#line 1938 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp23_ = _tmp25_;
#line 15678 "Dialogs.c"
		}
#line 1938 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp26_ = self->priv->hour;
#line 1938 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_spin_button_set_value (_tmp26_, (gdouble) _tmp23_);
#line 15684 "Dialogs.c"
	}
#line 1941 "/home/jens/Source/shotwell/src/Dialogs.vala"
	adjust_date_time_dialog_on_time_changed (self);
#line 15688 "Dialogs.c"
}


static void adjust_date_time_dialog_class_init (AdjustDateTimeDialogClass * klass) {
#line 1626 "/home/jens/Source/shotwell/src/Dialogs.vala"
	adjust_date_time_dialog_parent_class = g_type_class_peek_parent (klass);
#line 1626 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_type_class_add_private (klass, sizeof (AdjustDateTimeDialogPrivate));
#line 1626 "/home/jens/Source/shotwell/src/Dialogs.vala"
	G_OBJECT_CLASS (klass)->finalize = adjust_date_time_dialog_finalize;
#line 15699 "Dialogs.c"
}


static void adjust_date_time_dialog_instance_init (AdjustDateTimeDialog * self) {
#line 1626 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv = ADJUST_DATE_TIME_DIALOG_GET_PRIVATE (self);
#line 1631 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->no_original_time = FALSE;
#line 15708 "Dialogs.c"
}


static void adjust_date_time_dialog_finalize (GObject* obj) {
	AdjustDateTimeDialog * self;
#line 1626 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_ADJUST_DATE_TIME_DIALOG, AdjustDateTimeDialog);
#line 1636 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->original_time_label);
#line 1637 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->calendar);
#line 1638 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->hour);
#line 1639 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->minute);
#line 1640 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->second);
#line 1641 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->system);
#line 1642 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->relativity_radio_button);
#line 1643 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->batch_radio_button);
#line 1644 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->modify_originals_check_button);
#line 1645 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->notification);
#line 1626 "/home/jens/Source/shotwell/src/Dialogs.vala"
	G_OBJECT_CLASS (adjust_date_time_dialog_parent_class)->finalize (obj);
#line 15738 "Dialogs.c"
}


GType adjust_date_time_dialog_get_type (void) {
	static volatile gsize adjust_date_time_dialog_type_id__volatile = 0;
	if (g_once_init_enter (&adjust_date_time_dialog_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (AdjustDateTimeDialogClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) adjust_date_time_dialog_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (AdjustDateTimeDialog), 0, (GInstanceInitFunc) adjust_date_time_dialog_instance_init, NULL };
		GType adjust_date_time_dialog_type_id;
		adjust_date_time_dialog_type_id = g_type_register_static (gtk_dialog_get_type (), "AdjustDateTimeDialog", &g_define_type_info, 0);
		g_once_init_leave (&adjust_date_time_dialog_type_id__volatile, adjust_date_time_dialog_type_id);
	}
	return adjust_date_time_dialog_type_id__volatile;
}


void multiple_object_error_dialog (GeeArrayList* objects, const gchar* message, const gchar* title) {
	gchar* dialog_message = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	gint remainder = 0;
	GeeArrayList* _tmp20_ = NULL;
	gint _tmp21_ = 0;
	gint _tmp22_ = 0;
	gint _tmp23_ = 0;
	GtkMessageDialog* dialog = NULL;
	AppWindow* _tmp31_ = NULL;
	AppWindow* _tmp32_ = NULL;
	const gchar* _tmp33_ = NULL;
	GtkMessageDialog* _tmp34_ = NULL;
	GtkMessageDialog* _tmp35_ = NULL;
	const gchar* _tmp36_ = NULL;
#line 1946 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (GEE_IS_ARRAY_LIST (objects));
#line 1946 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (message != NULL);
#line 1946 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (title != NULL);
#line 1948 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = message;
#line 1948 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = g_strconcat (_tmp0_, "\n", NULL);
#line 1948 "/home/jens/Source/shotwell/src/Dialogs.vala"
	dialog_message = _tmp1_;
#line 15782 "Dialogs.c"
	{
		gint i = 0;
#line 1951 "/home/jens/Source/shotwell/src/Dialogs.vala"
		i = 0;
#line 15787 "Dialogs.c"
		{
			gboolean _tmp2_ = FALSE;
#line 1951 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp2_ = TRUE;
#line 1951 "/home/jens/Source/shotwell/src/Dialogs.vala"
			while (TRUE) {
#line 15794 "Dialogs.c"
				gboolean _tmp4_ = FALSE;
				gint _tmp5_ = 0;
				const gchar* _tmp10_ = NULL;
				GeeArrayList* _tmp11_ = NULL;
				gint _tmp12_ = 0;
				gpointer _tmp13_ = NULL;
				DataObject* _tmp14_ = NULL;
				gchar* _tmp15_ = NULL;
				gchar* _tmp16_ = NULL;
				gchar* _tmp17_ = NULL;
				gchar* _tmp18_ = NULL;
				gchar* _tmp19_ = NULL;
#line 1951 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (!_tmp2_) {
#line 15809 "Dialogs.c"
					gint _tmp3_ = 0;
#line 1951 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp3_ = i;
#line 1951 "/home/jens/Source/shotwell/src/Dialogs.vala"
					i = _tmp3_ + 1;
#line 15815 "Dialogs.c"
				}
#line 1951 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp2_ = FALSE;
#line 1951 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp5_ = i;
#line 1951 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (_tmp5_ < MAX_OBJECTS_DISPLAYED) {
#line 15823 "Dialogs.c"
					GeeArrayList* _tmp6_ = NULL;
					gint _tmp7_ = 0;
					gint _tmp8_ = 0;
					gint _tmp9_ = 0;
#line 1951 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp6_ = objects;
#line 1951 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp7_ = gee_abstract_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, GEE_TYPE_COLLECTION, GeeCollection));
#line 1951 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp8_ = _tmp7_;
#line 1951 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp9_ = i;
#line 1951 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp4_ = _tmp8_ > _tmp9_;
#line 15838 "Dialogs.c"
				} else {
#line 1951 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp4_ = FALSE;
#line 15842 "Dialogs.c"
				}
#line 1951 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (!_tmp4_) {
#line 1951 "/home/jens/Source/shotwell/src/Dialogs.vala"
					break;
#line 15848 "Dialogs.c"
				}
#line 1952 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp10_ = dialog_message;
#line 1952 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp11_ = objects;
#line 1952 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp12_ = i;
#line 1952 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp13_ = gee_abstract_list_get (G_TYPE_CHECK_INSTANCE_CAST (_tmp11_, GEE_TYPE_ABSTRACT_LIST, GeeAbstractList), _tmp12_);
#line 1952 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp14_ = (DataObject*) _tmp13_;
#line 1952 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp15_ = data_object_to_string (_tmp14_);
#line 1952 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp16_ = _tmp15_;
#line 1952 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp17_ = g_strconcat ("\n", _tmp16_, NULL);
#line 1952 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp18_ = _tmp17_;
#line 1952 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp19_ = g_strconcat (_tmp10_, _tmp18_, NULL);
#line 1952 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (dialog_message);
#line 1952 "/home/jens/Source/shotwell/src/Dialogs.vala"
				dialog_message = _tmp19_;
#line 1952 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp18_);
#line 1952 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp16_);
#line 1952 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_object_unref0 (_tmp14_);
#line 15880 "Dialogs.c"
			}
		}
	}
#line 1954 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp20_ = objects;
#line 1954 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp21_ = gee_abstract_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp20_, GEE_TYPE_COLLECTION, GeeCollection));
#line 1954 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp22_ = _tmp21_;
#line 1954 "/home/jens/Source/shotwell/src/Dialogs.vala"
	remainder = _tmp22_ - MAX_OBJECTS_DISPLAYED;
#line 1955 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp23_ = remainder;
#line 1955 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp23_ > 0) {
#line 15896 "Dialogs.c"
		const gchar* _tmp24_ = NULL;
		gint _tmp25_ = 0;
		const gchar* _tmp26_ = NULL;
		gint _tmp27_ = 0;
		gchar* _tmp28_ = NULL;
		gchar* _tmp29_ = NULL;
		gchar* _tmp30_ = NULL;
#line 1956 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp24_ = dialog_message;
#line 1956 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp25_ = remainder;
#line 1956 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp26_ = ngettext ("\n\nAnd %d other.", "\n\nAnd %d others.", (gulong) _tmp25_);
#line 1956 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp27_ = remainder;
#line 1956 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp28_ = g_strdup_printf (_tmp26_, _tmp27_);
#line 1956 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp29_ = _tmp28_;
#line 1956 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp30_ = g_strconcat (_tmp24_, _tmp29_, NULL);
#line 1956 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (dialog_message);
#line 1956 "/home/jens/Source/shotwell/src/Dialogs.vala"
		dialog_message = _tmp30_;
#line 1956 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp29_);
#line 15924 "Dialogs.c"
	}
#line 1960 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp31_ = app_window_get_instance ();
#line 1960 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp32_ = _tmp31_;
#line 1960 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp33_ = dialog_message;
#line 1960 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp34_ = (GtkMessageDialog*) gtk_message_dialog_new (G_TYPE_CHECK_INSTANCE_CAST (_tmp32_, gtk_window_get_type (), GtkWindow), GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, "%s", _tmp33_);
#line 1960 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp34_);
#line 1960 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp35_ = _tmp34_;
#line 1960 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp32_);
#line 1960 "/home/jens/Source/shotwell/src/Dialogs.vala"
	dialog = _tmp35_;
#line 1963 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp36_ = title;
#line 1963 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_window_set_title (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_window_get_type (), GtkWindow), _tmp36_);
#line 1965 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_dialog_get_type (), GtkDialog));
#line 1966 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_widget_get_type (), GtkWidget));
#line 1946 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (dialog);
#line 1946 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (dialog_message);
#line 15954 "Dialogs.c"
}


TagsDialog* tags_dialog_construct (GType object_type, const gchar* title, const gchar* label, const gchar* initial_text) {
	TagsDialog* self = NULL;
	const gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	HierarchicalTagIndex* _tmp3_ = NULL;
	HierarchicalTagIndex* _tmp4_ = NULL;
	GeeCollection* _tmp5_ = NULL;
	GeeCollection* _tmp6_ = NULL;
#line 1970 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (title != NULL, NULL);
#line 1970 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (label != NULL, NULL);
#line 1971 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = title;
#line 1971 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = label;
#line 1971 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = initial_text;
#line 1971 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = hierarchical_tag_index_get_global_index ();
#line 1971 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = _tmp3_;
#line 1971 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = hierarchical_tag_index_get_all_tags (_tmp4_);
#line 1971 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = _tmp5_;
#line 1971 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = (TagsDialog*) text_entry_dialog_mediator_construct (object_type, _tmp0_, _tmp1_, _tmp2_, _tmp6_, ",");
#line 1971 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp6_);
#line 1971 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_hierarchical_tag_index_unref0 (_tmp4_);
#line 1970 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return self;
#line 15993 "Dialogs.c"
}


static void tags_dialog_class_init (TagsDialogClass * klass) {
#line 1969 "/home/jens/Source/shotwell/src/Dialogs.vala"
	tags_dialog_parent_class = g_type_class_peek_parent (klass);
#line 16000 "Dialogs.c"
}


static void tags_dialog_instance_init (TagsDialog * self) {
}


GType tags_dialog_get_type (void) {
	static volatile gsize tags_dialog_type_id__volatile = 0;
	if (g_once_init_enter (&tags_dialog_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (TagsDialogClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tags_dialog_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TagsDialog), 0, (GInstanceInitFunc) tags_dialog_instance_init, NULL };
		GType tags_dialog_type_id;
		tags_dialog_type_id = g_type_register_static (TYPE_TEXT_ENTRY_DIALOG_MEDIATOR, "TagsDialog", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
		g_once_init_leave (&tags_dialog_type_id__volatile, tags_dialog_type_id);
	}
	return tags_dialog_type_id__volatile;
}


AddTagsDialog* add_tags_dialog_construct (GType object_type) {
	AddTagsDialog* self = NULL;
	gchar* title = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
#line 1978 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = g_dpgettext2 (NULL, "Dialog Title", RESOURCES_ADD_TAGS_TITLE);
#line 1978 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 1978 "/home/jens/Source/shotwell/src/Dialogs.vala"
	title = _tmp1_;
#line 1980 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = _ ("Tags (separated by commas):");
#line 1980 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = (AddTagsDialog*) tags_dialog_construct (object_type, title, _tmp2_, NULL);
#line 1977 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (title);
#line 1977 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return self;
#line 16040 "Dialogs.c"
}


AddTagsDialog* add_tags_dialog_new (void) {
#line 1977 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return add_tags_dialog_construct (TYPE_ADD_TAGS_DIALOG);
#line 16047 "Dialogs.c"
}


gchar** add_tags_dialog_execute (AddTagsDialog* self, int* result_length1) {
	gchar** result = NULL;
	gchar* text = NULL;
	gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	const gchar* _tmp3_ = NULL;
	gchar** _tmp4_ = NULL;
	gchar** _tmp5_ = NULL;
	gchar** _tmp6_ = NULL;
	gint _tmp6__length1 = 0;
	gint _tmp7_ = 0;
	gchar** _tmp8_ = NULL;
	gchar** _tmp9_ = NULL;
	gint _tmp9__length1 = 0;
	gchar** _tmp10_ = NULL;
	gint _tmp10__length1 = 0;
#line 1983 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_ADD_TAGS_DIALOG (self), NULL);
#line 1984 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = _text_entry_dialog_mediator_execute (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_TEXT_ENTRY_DIALOG_MEDIATOR, TextEntryDialogMediator));
#line 1984 "/home/jens/Source/shotwell/src/Dialogs.vala"
	text = _tmp0_;
#line 1985 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = text;
#line 1985 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp1_ == NULL) {
#line 16077 "Dialogs.c"
		gchar** _tmp2_ = NULL;
		gint _tmp2__length1 = 0;
#line 1986 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp2_ = NULL;
#line 1986 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp2__length1 = 0;
#line 1986 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (result_length1) {
#line 1986 "/home/jens/Source/shotwell/src/Dialogs.vala"
			*result_length1 = _tmp2__length1;
#line 16088 "Dialogs.c"
		}
#line 1986 "/home/jens/Source/shotwell/src/Dialogs.vala"
		result = _tmp2_;
#line 1986 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (text);
#line 1986 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return result;
#line 16096 "Dialogs.c"
	}
#line 1990 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = text;
#line 1990 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = _tmp4_ = g_strsplit (_tmp3_, ",", 0);
#line 1990 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = _tmp5_;
#line 1990 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6__length1 = _vala_array_length (_tmp4_);
#line 1990 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = tag_prep_tag_names (_tmp6_, _vala_array_length (_tmp4_), &_tmp7_);
#line 1990 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = _tmp8_;
#line 1990 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9__length1 = _tmp7_;
#line 1990 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = (_vala_array_free (_tmp6_, _tmp6__length1, (GDestroyNotify) g_free), NULL);
#line 1990 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp10_ = _tmp9_;
#line 1990 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp10__length1 = _tmp9__length1;
#line 1990 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (result_length1) {
#line 1990 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*result_length1 = _tmp10__length1;
#line 16122 "Dialogs.c"
	}
#line 1990 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = _tmp10_;
#line 1990 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (text);
#line 1990 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 16130 "Dialogs.c"
}


static gboolean add_tags_dialog_real_on_modify_validate (TextEntryDialogMediator* base, const gchar* text) {
	AddTagsDialog * self;
	gboolean result = FALSE;
	const gchar* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	gchar** names = NULL;
	const gchar* _tmp2_ = NULL;
	gchar** _tmp3_ = NULL;
	gchar** _tmp4_ = NULL;
	gchar** _tmp5_ = NULL;
	gint _tmp5__length1 = 0;
	gint _tmp6_ = 0;
	gchar** _tmp7_ = NULL;
	gchar** _tmp8_ = NULL;
	gint _tmp8__length1 = 0;
	gint names_length1 = 0;
	gint _names_size_ = 0;
	gchar** _tmp9_ = NULL;
	gint _tmp9__length1 = 0;
#line 1993 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_ADD_TAGS_DIALOG, AddTagsDialog);
#line 1993 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (text != NULL, FALSE);
#line 1994 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = text;
#line 1994 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = string_contains (_tmp0_, TAG_PATH_SEPARATOR_STRING);
#line 1994 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp1_) {
#line 1995 "/home/jens/Source/shotwell/src/Dialogs.vala"
		result = FALSE;
#line 1995 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return result;
#line 16167 "Dialogs.c"
	}
#line 1999 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = text;
#line 1999 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = _tmp3_ = g_strsplit (_tmp2_, ",", 0);
#line 1999 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = _tmp4_;
#line 1999 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5__length1 = _vala_array_length (_tmp3_);
#line 1999 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = tag_prep_tag_names (_tmp5_, _vala_array_length (_tmp3_), &_tmp6_);
#line 1999 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = _tmp7_;
#line 1999 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8__length1 = _tmp6_;
#line 1999 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = (_vala_array_free (_tmp5_, _tmp5__length1, (GDestroyNotify) g_free), NULL);
#line 1999 "/home/jens/Source/shotwell/src/Dialogs.vala"
	names = _tmp8_;
#line 1999 "/home/jens/Source/shotwell/src/Dialogs.vala"
	names_length1 = _tmp8__length1;
#line 1999 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_names_size_ = names_length1;
#line 2001 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = names;
#line 2001 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9__length1 = names_length1;
#line 2001 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = _tmp9__length1 > 0;
#line 2001 "/home/jens/Source/shotwell/src/Dialogs.vala"
	names = (_vala_array_free (names, names_length1, (GDestroyNotify) g_free), NULL);
#line 2001 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 16201 "Dialogs.c"
}


static void add_tags_dialog_class_init (AddTagsDialogClass * klass) {
#line 1976 "/home/jens/Source/shotwell/src/Dialogs.vala"
	add_tags_dialog_parent_class = g_type_class_peek_parent (klass);
#line 1976 "/home/jens/Source/shotwell/src/Dialogs.vala"
	((TextEntryDialogMediatorClass *) klass)->on_modify_validate = add_tags_dialog_real_on_modify_validate;
#line 16210 "Dialogs.c"
}


static void add_tags_dialog_instance_init (AddTagsDialog * self) {
}


GType add_tags_dialog_get_type (void) {
	static volatile gsize add_tags_dialog_type_id__volatile = 0;
	if (g_once_init_enter (&add_tags_dialog_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (AddTagsDialogClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) add_tags_dialog_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (AddTagsDialog), 0, (GInstanceInitFunc) add_tags_dialog_instance_init, NULL };
		GType add_tags_dialog_type_id;
		add_tags_dialog_type_id = g_type_register_static (TYPE_TAGS_DIALOG, "AddTagsDialog", &g_define_type_info, 0);
		g_once_init_leave (&add_tags_dialog_type_id__volatile, add_tags_dialog_type_id);
	}
	return add_tags_dialog_type_id__volatile;
}


ModifyTagsDialog* modify_tags_dialog_construct (GType object_type, MediaSource* source) {
	ModifyTagsDialog* self = NULL;
	const gchar* _tmp0_ = NULL;
	MediaSource* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
#line 2006 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_MEDIA_SOURCE (source), NULL);
#line 2007 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = _ ("Tags (separated by commas):");
#line 2007 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = source;
#line 2007 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = modify_tags_dialog_get_initial_text (_tmp1_);
#line 2007 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = _tmp2_;
#line 2007 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = (ModifyTagsDialog*) tags_dialog_construct (object_type, RESOURCES_MODIFY_TAGS_LABEL, _tmp0_, _tmp3_);
#line 2007 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp3_);
#line 2006 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return self;
#line 16252 "Dialogs.c"
}


ModifyTagsDialog* modify_tags_dialog_new (MediaSource* source) {
#line 2006 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return modify_tags_dialog_construct (TYPE_MODIFY_TAGS_DIALOG, source);
#line 16259 "Dialogs.c"
}


static gchar* modify_tags_dialog_get_initial_text (MediaSource* source) {
	gchar* result = NULL;
	GeeCollection* source_tags = NULL;
	TagSourceCollection* _tmp0_ = NULL;
	MediaSource* _tmp1_ = NULL;
	GeeList* _tmp2_ = NULL;
	GeeCollection* _tmp3_ = NULL;
	GeeCollection* terminal_tags = NULL;
	GeeCollection* _tmp4_ = NULL;
	GeeCollection* _tmp5_ = NULL;
	GeeSortedSet* tag_basenames = NULL;
	GeeTreeSet* _tmp6_ = NULL;
	gchar* text = NULL;
#line 2011 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_MEDIA_SOURCE (source), NULL);
#line 2012 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = tag_global;
#line 2012 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = source;
#line 2012 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = tag_source_collection_fetch_for_source (_tmp0_, _tmp1_);
#line 2012 "/home/jens/Source/shotwell/src/Dialogs.vala"
	source_tags = G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, GEE_TYPE_COLLECTION, GeeCollection);
#line 2013 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = source_tags;
#line 2013 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp3_ == NULL) {
#line 2014 "/home/jens/Source/shotwell/src/Dialogs.vala"
		result = NULL;
#line 2014 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (source_tags);
#line 2014 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return result;
#line 16296 "Dialogs.c"
	}
#line 2016 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = source_tags;
#line 2016 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = tag_get_terminal_tags (_tmp4_);
#line 2016 "/home/jens/Source/shotwell/src/Dialogs.vala"
	terminal_tags = _tmp5_;
#line 2018 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = gee_tree_set_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL);
#line 2018 "/home/jens/Source/shotwell/src/Dialogs.vala"
	tag_basenames = G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, GEE_TYPE_SORTED_SET, GeeSortedSet);
#line 16308 "Dialogs.c"
	{
		GeeIterator* _tag_it = NULL;
		GeeCollection* _tmp7_ = NULL;
		GeeIterator* _tmp8_ = NULL;
#line 2019 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp7_ = terminal_tags;
#line 2019 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp8_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, GEE_TYPE_ITERABLE, GeeIterable));
#line 2019 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tag_it = _tmp8_;
#line 2019 "/home/jens/Source/shotwell/src/Dialogs.vala"
		while (TRUE) {
#line 16321 "Dialogs.c"
			GeeIterator* _tmp9_ = NULL;
			gboolean _tmp10_ = FALSE;
			Tag* tag = NULL;
			GeeIterator* _tmp11_ = NULL;
			gpointer _tmp12_ = NULL;
			GeeSortedSet* _tmp13_ = NULL;
			Tag* _tmp14_ = NULL;
			gchar* _tmp15_ = NULL;
			gchar* _tmp16_ = NULL;
			gchar* _tmp17_ = NULL;
			gchar* _tmp18_ = NULL;
#line 2019 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp9_ = _tag_it;
#line 2019 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp10_ = gee_iterator_next (_tmp9_);
#line 2019 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (!_tmp10_) {
#line 2019 "/home/jens/Source/shotwell/src/Dialogs.vala"
				break;
#line 16341 "Dialogs.c"
			}
#line 2019 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp11_ = _tag_it;
#line 2019 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp12_ = gee_iterator_get (_tmp11_);
#line 2019 "/home/jens/Source/shotwell/src/Dialogs.vala"
			tag = (Tag*) _tmp12_;
#line 2020 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp13_ = tag_basenames;
#line 2020 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp14_ = tag;
#line 2020 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp15_ = tag_get_path (_tmp14_);
#line 2020 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp16_ = _tmp15_;
#line 2020 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp17_ = hierarchical_tag_utilities_get_basename (_tmp16_);
#line 2020 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp18_ = _tmp17_;
#line 2020 "/home/jens/Source/shotwell/src/Dialogs.vala"
			gee_collection_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp13_, GEE_TYPE_COLLECTION, GeeCollection), _tmp18_);
#line 2020 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (_tmp18_);
#line 2020 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (_tmp16_);
#line 2019 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_object_unref0 (tag);
#line 16369 "Dialogs.c"
		}
#line 2019 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (_tag_it);
#line 16373 "Dialogs.c"
	}
#line 2022 "/home/jens/Source/shotwell/src/Dialogs.vala"
	text = NULL;
#line 16377 "Dialogs.c"
	{
		GeeIterator* _name_it = NULL;
		GeeSortedSet* _tmp19_ = NULL;
		GeeIterator* _tmp20_ = NULL;
#line 2023 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp19_ = tag_basenames;
#line 2023 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp20_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp19_, GEE_TYPE_ITERABLE, GeeIterable));
#line 2023 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_name_it = _tmp20_;
#line 2023 "/home/jens/Source/shotwell/src/Dialogs.vala"
		while (TRUE) {
#line 16390 "Dialogs.c"
			GeeIterator* _tmp21_ = NULL;
			gboolean _tmp22_ = FALSE;
			gchar* name = NULL;
			GeeIterator* _tmp23_ = NULL;
			gpointer _tmp24_ = NULL;
			const gchar* _tmp25_ = NULL;
			const gchar* _tmp29_ = NULL;
			const gchar* _tmp30_ = NULL;
			gchar* _tmp31_ = NULL;
#line 2023 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp21_ = _name_it;
#line 2023 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp22_ = gee_iterator_next (_tmp21_);
#line 2023 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (!_tmp22_) {
#line 2023 "/home/jens/Source/shotwell/src/Dialogs.vala"
				break;
#line 16408 "Dialogs.c"
			}
#line 2023 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp23_ = _name_it;
#line 2023 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp24_ = gee_iterator_get (_tmp23_);
#line 2023 "/home/jens/Source/shotwell/src/Dialogs.vala"
			name = (gchar*) _tmp24_;
#line 2024 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp25_ = text;
#line 2024 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (_tmp25_ == NULL) {
#line 16420 "Dialogs.c"
				gchar* _tmp26_ = NULL;
#line 2025 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp26_ = g_strdup ("");
#line 2025 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (text);
#line 2025 "/home/jens/Source/shotwell/src/Dialogs.vala"
				text = _tmp26_;
#line 16428 "Dialogs.c"
			} else {
				const gchar* _tmp27_ = NULL;
				gchar* _tmp28_ = NULL;
#line 2027 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp27_ = text;
#line 2027 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp28_ = g_strconcat (_tmp27_, ", ", NULL);
#line 2027 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (text);
#line 2027 "/home/jens/Source/shotwell/src/Dialogs.vala"
				text = _tmp28_;
#line 16440 "Dialogs.c"
			}
#line 2029 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp29_ = text;
#line 2029 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp30_ = name;
#line 2029 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp31_ = g_strconcat (_tmp29_, _tmp30_, NULL);
#line 2029 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (text);
#line 2029 "/home/jens/Source/shotwell/src/Dialogs.vala"
			text = _tmp31_;
#line 2023 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (name);
#line 16454 "Dialogs.c"
		}
#line 2023 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (_name_it);
#line 16458 "Dialogs.c"
	}
#line 2032 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = text;
#line 2032 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (tag_basenames);
#line 2032 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (terminal_tags);
#line 2032 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (source_tags);
#line 2032 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 16470 "Dialogs.c"
}


GeeArrayList* modify_tags_dialog_execute (ModifyTagsDialog* self) {
	GeeArrayList* result = NULL;
	gchar* text = NULL;
	gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	GeeArrayList* new_tags = NULL;
	GeeArrayList* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	gboolean _tmp4_ = FALSE;
	gchar** tag_names = NULL;
	const gchar* _tmp5_ = NULL;
	gchar** _tmp6_ = NULL;
	gchar** _tmp7_ = NULL;
	gchar** _tmp8_ = NULL;
	gint _tmp8__length1 = 0;
	gint _tmp9_ = 0;
	gchar** _tmp10_ = NULL;
	gchar** _tmp11_ = NULL;
	gint _tmp11__length1 = 0;
	gint tag_names_length1 = 0;
	gint _tag_names_size_ = 0;
	HierarchicalTagIndex* _tmp12_ = NULL;
	HierarchicalTagIndex* _tmp13_ = NULL;
	gchar** _tmp14_ = NULL;
	gint _tmp14__length1 = 0;
	gint _tmp15_ = 0;
	gchar** _tmp16_ = NULL;
	gchar** _tmp17_ = NULL;
	gint _tmp17__length1 = 0;
#line 2035 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_MODIFY_TAGS_DIALOG (self), NULL);
#line 2036 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = _text_entry_dialog_mediator_execute (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_TEXT_ENTRY_DIALOG_MEDIATOR, TextEntryDialogMediator));
#line 2036 "/home/jens/Source/shotwell/src/Dialogs.vala"
	text = _tmp0_;
#line 2037 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = text;
#line 2037 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp1_ == NULL) {
#line 2038 "/home/jens/Source/shotwell/src/Dialogs.vala"
		result = NULL;
#line 2038 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (text);
#line 2038 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return result;
#line 16519 "Dialogs.c"
	}
#line 2040 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = gee_array_list_new (TYPE_TAG, (GBoxedCopyFunc) g_object_ref, g_object_unref, NULL, NULL, NULL);
#line 2040 "/home/jens/Source/shotwell/src/Dialogs.vala"
	new_tags = _tmp2_;
#line 2043 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = text;
#line 2043 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = is_string_empty (_tmp3_);
#line 2043 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp4_) {
#line 2044 "/home/jens/Source/shotwell/src/Dialogs.vala"
		result = new_tags;
#line 2044 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (text);
#line 2044 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return result;
#line 16537 "Dialogs.c"
	}
#line 2047 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = text;
#line 2047 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = _tmp6_ = g_strsplit (_tmp5_, ",", 0);
#line 2047 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = _tmp7_;
#line 2047 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8__length1 = _vala_array_length (_tmp6_);
#line 2047 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp10_ = tag_prep_tag_names (_tmp8_, _vala_array_length (_tmp6_), &_tmp9_);
#line 2047 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp11_ = _tmp10_;
#line 2047 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp11__length1 = _tmp9_;
#line 2047 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = (_vala_array_free (_tmp8_, _tmp8__length1, (GDestroyNotify) g_free), NULL);
#line 2047 "/home/jens/Source/shotwell/src/Dialogs.vala"
	tag_names = _tmp11_;
#line 2047 "/home/jens/Source/shotwell/src/Dialogs.vala"
	tag_names_length1 = _tmp11__length1;
#line 2047 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tag_names_size_ = tag_names_length1;
#line 2049 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp12_ = hierarchical_tag_index_get_global_index ();
#line 2049 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp13_ = _tmp12_;
#line 2049 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp14_ = tag_names;
#line 2049 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp14__length1 = tag_names_length1;
#line 2049 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp16_ = hierarchical_tag_index_get_paths_for_names_array (_tmp13_, _tmp14_, _tmp14__length1, &_tmp15_);
#line 2049 "/home/jens/Source/shotwell/src/Dialogs.vala"
	tag_names = (_vala_array_free (tag_names, tag_names_length1, (GDestroyNotify) g_free), NULL);
#line 2049 "/home/jens/Source/shotwell/src/Dialogs.vala"
	tag_names = _tmp16_;
#line 2049 "/home/jens/Source/shotwell/src/Dialogs.vala"
	tag_names_length1 = _tmp15_;
#line 2049 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tag_names_size_ = tag_names_length1;
#line 2049 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_hierarchical_tag_index_unref0 (_tmp13_);
#line 2051 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp17_ = tag_names;
#line 2051 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp17__length1 = tag_names_length1;
#line 16585 "Dialogs.c"
	{
		gchar** name_collection = NULL;
		gint name_collection_length1 = 0;
		gint _name_collection_size_ = 0;
		gint name_it = 0;
#line 2051 "/home/jens/Source/shotwell/src/Dialogs.vala"
		name_collection = _tmp17_;
#line 2051 "/home/jens/Source/shotwell/src/Dialogs.vala"
		name_collection_length1 = _tmp17__length1;
#line 2051 "/home/jens/Source/shotwell/src/Dialogs.vala"
		for (name_it = 0; name_it < _tmp17__length1; name_it = name_it + 1) {
#line 16597 "Dialogs.c"
			gchar* _tmp18_ = NULL;
			gchar* name = NULL;
#line 2051 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp18_ = g_strdup (name_collection[name_it]);
#line 2051 "/home/jens/Source/shotwell/src/Dialogs.vala"
			name = _tmp18_;
#line 16604 "Dialogs.c"
			{
				GeeArrayList* _tmp19_ = NULL;
				const gchar* _tmp20_ = NULL;
				Tag* _tmp21_ = NULL;
				Tag* _tmp22_ = NULL;
#line 2052 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp19_ = new_tags;
#line 2052 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp20_ = name;
#line 2052 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp21_ = tag_for_path (_tmp20_);
#line 2052 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp22_ = _tmp21_;
#line 2052 "/home/jens/Source/shotwell/src/Dialogs.vala"
				gee_abstract_collection_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp19_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection), _tmp22_);
#line 2052 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_object_unref0 (_tmp22_);
#line 2051 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (name);
#line 16624 "Dialogs.c"
			}
		}
	}
#line 2054 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = new_tags;
#line 2054 "/home/jens/Source/shotwell/src/Dialogs.vala"
	tag_names = (_vala_array_free (tag_names, tag_names_length1, (GDestroyNotify) g_free), NULL);
#line 2054 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (text);
#line 2054 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 16636 "Dialogs.c"
}


static gboolean modify_tags_dialog_real_on_modify_validate (TextEntryDialogMediator* base, const gchar* text) {
	ModifyTagsDialog * self;
	gboolean result = FALSE;
	const gchar* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
#line 2057 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_MODIFY_TAGS_DIALOG, ModifyTagsDialog);
#line 2057 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (text != NULL, FALSE);
#line 2058 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = text;
#line 2058 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = string_contains (_tmp0_, TAG_PATH_SEPARATOR_STRING);
#line 2058 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = !_tmp1_;
#line 2058 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 16657 "Dialogs.c"
}


static void modify_tags_dialog_class_init (ModifyTagsDialogClass * klass) {
#line 2005 "/home/jens/Source/shotwell/src/Dialogs.vala"
	modify_tags_dialog_parent_class = g_type_class_peek_parent (klass);
#line 2005 "/home/jens/Source/shotwell/src/Dialogs.vala"
	((TextEntryDialogMediatorClass *) klass)->on_modify_validate = modify_tags_dialog_real_on_modify_validate;
#line 16666 "Dialogs.c"
}


static void modify_tags_dialog_instance_init (ModifyTagsDialog * self) {
}


GType modify_tags_dialog_get_type (void) {
	static volatile gsize modify_tags_dialog_type_id__volatile = 0;
	if (g_once_init_enter (&modify_tags_dialog_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (ModifyTagsDialogClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) modify_tags_dialog_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ModifyTagsDialog), 0, (GInstanceInitFunc) modify_tags_dialog_instance_init, NULL };
		GType modify_tags_dialog_type_id;
		modify_tags_dialog_type_id = g_type_register_static (TYPE_TAGS_DIALOG, "ModifyTagsDialog", &g_define_type_info, 0);
		g_once_init_leave (&modify_tags_dialog_type_id__volatile, modify_tags_dialog_type_id);
	}
	return modify_tags_dialog_type_id__volatile;
}


gchar* welcome_service_entry_get_service_name (WelcomeServiceEntry* self) {
#line 2064 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_WELCOME_SERVICE_ENTRY (self), NULL);
#line 2064 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return WELCOME_SERVICE_ENTRY_GET_INTERFACE (self)->get_service_name (self);
#line 16691 "Dialogs.c"
}


void welcome_service_entry_execute (WelcomeServiceEntry* self) {
#line 2066 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_WELCOME_SERVICE_ENTRY (self));
#line 2066 "/home/jens/Source/shotwell/src/Dialogs.vala"
	WELCOME_SERVICE_ENTRY_GET_INTERFACE (self)->execute (self);
#line 16700 "Dialogs.c"
}


static void welcome_service_entry_base_init (WelcomeServiceEntryIface * iface) {
#line 2063 "/home/jens/Source/shotwell/src/Dialogs.vala"
	static gboolean initialized = FALSE;
#line 2063 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (!initialized) {
#line 2063 "/home/jens/Source/shotwell/src/Dialogs.vala"
		initialized = TRUE;
#line 16711 "Dialogs.c"
	}
}


GType welcome_service_entry_get_type (void) {
	static volatile gsize welcome_service_entry_type_id__volatile = 0;
	if (g_once_init_enter (&welcome_service_entry_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (WelcomeServiceEntryIface), (GBaseInitFunc) welcome_service_entry_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
		GType welcome_service_entry_type_id;
		welcome_service_entry_type_id = g_type_register_static (G_TYPE_INTERFACE, "WelcomeServiceEntry", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (welcome_service_entry_type_id, G_TYPE_OBJECT);
		g_once_init_leave (&welcome_service_entry_type_id__volatile, welcome_service_entry_type_id);
	}
	return welcome_service_entry_type_id__volatile;
}


WelcomeDialog* welcome_dialog_construct (GType object_type, GtkWindow* owner) {
	WelcomeDialog * self = NULL;
	SpitDataImportsWelcomeImportMetaHost* _tmp0_ = NULL;
	gboolean show_system_pictures_import = FALSE;
	gboolean _tmp1_ = FALSE;
	GtkWidget* ok_button = NULL;
	GtkWidget* _tmp2_ = NULL;
	GtkWidget* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	GtkWindow* _tmp5_ = NULL;
	GtkLabel* primary_text = NULL;
	GtkLabel* _tmp6_ = NULL;
	GtkLabel* _tmp7_ = NULL;
	const gchar* _tmp8_ = NULL;
	gchar* _tmp9_ = NULL;
	gchar* _tmp10_ = NULL;
	GtkLabel* _tmp11_ = NULL;
	GtkLabel* _tmp12_ = NULL;
	GtkLabel* _tmp13_ = NULL;
	const gchar* _tmp14_ = NULL;
	gchar* _tmp15_ = NULL;
	gchar* _tmp16_ = NULL;
	GtkLabel* _tmp17_ = NULL;
	GtkImage* image = NULL;
	GtkImage* _tmp18_ = NULL;
	GtkBox* header_text = NULL;
	GtkBox* _tmp19_ = NULL;
	GtkBox* _tmp20_ = NULL;
	GtkLabel* _tmp21_ = NULL;
	GtkBox* _tmp22_ = NULL;
	GtkLabel* _tmp23_ = NULL;
	GtkBox* header_content = NULL;
	GtkBox* _tmp24_ = NULL;
	GtkBox* _tmp25_ = NULL;
	GtkImage* _tmp26_ = NULL;
	GtkBox* _tmp27_ = NULL;
	GtkBox* _tmp28_ = NULL;
	GtkLabel* instructions = NULL;
	GtkLabel* _tmp29_ = NULL;
	gchar* indent_prefix = NULL;
	gchar* _tmp30_ = NULL;
	const gchar* _tmp31_ = NULL;
	GtkTextDirection _tmp32_ = 0;
	gchar* arrow_glyph = NULL;
	gchar* _tmp33_ = NULL;
	GtkLabel* _tmp34_ = NULL;
	const gchar* _tmp35_ = NULL;
	gchar* _tmp36_ = NULL;
	gchar* _tmp37_ = NULL;
	const gchar* _tmp38_ = NULL;
	gchar* _tmp39_ = NULL;
	gchar* _tmp40_ = NULL;
	gchar* _tmp41_ = NULL;
	gchar* _tmp42_ = NULL;
	const gchar* _tmp43_ = NULL;
	gchar* _tmp44_ = NULL;
	gchar* _tmp45_ = NULL;
	gchar* _tmp46_ = NULL;
	gchar* _tmp47_ = NULL;
	const gchar* _tmp48_ = NULL;
	const gchar* _tmp49_ = NULL;
	gchar* _tmp50_ = NULL;
	gchar* _tmp51_ = NULL;
	const gchar* _tmp52_ = NULL;
	const gchar* _tmp53_ = NULL;
	gchar* _tmp54_ = NULL;
	gchar* _tmp55_ = NULL;
	GtkLabel* _tmp56_ = NULL;
	GtkBox* _tmp57_ = NULL;
	GtkBox* _tmp58_ = NULL;
	GtkBox* _tmp59_ = NULL;
	GtkBox* _tmp60_ = NULL;
	gboolean _tmp61_ = FALSE;
	const gchar* _tmp73_ = NULL;
	GtkLabel* _tmp74_ = NULL;
	GtkLabel* _tmp75_ = NULL;
	GtkLabel* _tmp76_ = NULL;
	GtkBox* content = NULL;
	GtkBox* _tmp77_ = NULL;
	GtkBox* _tmp78_ = NULL;
	GtkBox* _tmp79_ = NULL;
	GtkBox* _tmp80_ = NULL;
	GtkLabel* _tmp81_ = NULL;
	const gchar* _tmp82_ = NULL;
	GtkCheckButton* _tmp83_ = NULL;
	GtkCheckButton* _tmp84_ = NULL;
	GtkCheckButton* _tmp85_ = NULL;
	GtkAlignment* alignment = NULL;
	GtkAlignment* _tmp86_ = NULL;
	GtkBox* _tmp87_ = NULL;
	GtkWidget* _tmp88_ = NULL;
	SpitDataImportsWelcomeImportMetaHost* _tmp89_ = NULL;
#line 2083 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (GTK_IS_WINDOW (owner), NULL);
#line 2083 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = (WelcomeDialog*) g_object_new (object_type, NULL);
#line 2084 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = spit_data_imports_welcome_import_meta_host_new (self);
#line 2084 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->import_meta_host);
#line 2084 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->import_meta_host = _tmp0_;
#line 2085 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = welcome_dialog_is_system_pictures_import_possible ();
#line 2085 "/home/jens/Source/shotwell/src/Dialogs.vala"
	show_system_pictures_import = _tmp1_;
#line 2086 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = gtk_dialog_add_button (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog), RESOURCES_OK_LABEL, (gint) GTK_RESPONSE_OK);
#line 2086 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 2086 "/home/jens/Source/shotwell/src/Dialogs.vala"
	ok_button = _tmp3_;
#line 2087 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = _ ("Welcome!");
#line 2087 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_window_set_title (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), _tmp4_);
#line 2088 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_window_set_resizable (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), FALSE);
#line 2089 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_window_set_type_hint (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), GDK_WINDOW_TYPE_HINT_DIALOG);
#line 2090 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = owner;
#line 2090 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_window_set_transient_for (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), _tmp5_);
#line 2092 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = (GtkLabel*) gtk_label_new ("");
#line 2092 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp6_);
#line 2092 "/home/jens/Source/shotwell/src/Dialogs.vala"
	primary_text = _tmp6_;
#line 2093 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = primary_text;
#line 2093 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = _ ("Welcome to Shotwell!");
#line 2093 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = g_strdup_printf ("<span size=\"large\" weight=\"bold\">%s</span>", _tmp8_);
#line 2093 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp10_ = _tmp9_;
#line 2093 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_label_set_markup (_tmp7_, _tmp10_);
#line 2093 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp10_);
#line 2095 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp11_ = primary_text;
#line 2095 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_misc_set_alignment (G_TYPE_CHECK_INSTANCE_CAST (_tmp11_, gtk_misc_get_type (), GtkMisc), (gfloat) 0, 0.5f);
#line 2096 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp12_ = (GtkLabel*) gtk_label_new ("");
#line 2096 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp12_);
#line 2096 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->secondary_text);
#line 2096 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->secondary_text = _tmp12_;
#line 2097 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp13_ = self->priv->secondary_text;
#line 2097 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp14_ = _ ("To get started, import photos in any of these ways:");
#line 2097 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp15_ = g_strdup_printf ("<span weight=\"normal\">%s</span>", _tmp14_);
#line 2097 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp16_ = _tmp15_;
#line 2097 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_label_set_markup (_tmp13_, _tmp16_);
#line 2097 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp16_);
#line 2099 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp17_ = self->priv->secondary_text;
#line 2099 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_misc_set_alignment (G_TYPE_CHECK_INSTANCE_CAST (_tmp17_, gtk_misc_get_type (), GtkMisc), (gfloat) 0, 0.5f);
#line 2100 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp18_ = (GtkImage*) gtk_image_new_from_icon_name ("shotwell", GTK_ICON_SIZE_DIALOG);
#line 2100 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp18_);
#line 2100 "/home/jens/Source/shotwell/src/Dialogs.vala"
	image = _tmp18_;
#line 2102 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp19_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
#line 2102 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp19_);
#line 2102 "/home/jens/Source/shotwell/src/Dialogs.vala"
	header_text = _tmp19_;
#line 2103 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp20_ = header_text;
#line 2103 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp21_ = primary_text;
#line 2103 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_box_pack_start (_tmp20_, G_TYPE_CHECK_INSTANCE_CAST (_tmp21_, gtk_widget_get_type (), GtkWidget), FALSE, FALSE, (guint) 5);
#line 2104 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp22_ = header_text;
#line 2104 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp23_ = self->priv->secondary_text;
#line 2104 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_box_pack_start (_tmp22_, G_TYPE_CHECK_INSTANCE_CAST (_tmp23_, gtk_widget_get_type (), GtkWidget), FALSE, FALSE, (guint) 0);
#line 2106 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp24_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 12);
#line 2106 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp24_);
#line 2106 "/home/jens/Source/shotwell/src/Dialogs.vala"
	header_content = _tmp24_;
#line 2107 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp25_ = header_content;
#line 2107 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp26_ = image;
#line 2107 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_box_pack_start (_tmp25_, G_TYPE_CHECK_INSTANCE_CAST (_tmp26_, gtk_widget_get_type (), GtkWidget), FALSE, FALSE, (guint) 0);
#line 2108 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp27_ = header_content;
#line 2108 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp28_ = header_text;
#line 2108 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_box_pack_start (_tmp27_, G_TYPE_CHECK_INSTANCE_CAST (_tmp28_, gtk_widget_get_type (), GtkWidget), FALSE, FALSE, (guint) 0);
#line 2110 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp29_ = (GtkLabel*) gtk_label_new ("");
#line 2110 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp29_);
#line 2110 "/home/jens/Source/shotwell/src/Dialogs.vala"
	instructions = _tmp29_;
#line 2111 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp30_ = g_strdup ("   ");
#line 2111 "/home/jens/Source/shotwell/src/Dialogs.vala"
	indent_prefix = _tmp30_;
#line 2113 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp32_ = gtk_widget_get_direction (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 2113 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp32_ == GTK_TEXT_DIR_RTL) {
#line 2113 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp31_ = "◂";
#line 16957 "Dialogs.c"
	} else {
#line 2113 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp31_ = "▸";
#line 16961 "Dialogs.c"
	}
#line 2113 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp33_ = g_strdup (_tmp31_);
#line 2113 "/home/jens/Source/shotwell/src/Dialogs.vala"
	arrow_glyph = _tmp33_;
#line 2115 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp34_ = instructions;
#line 2115 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp35_ = indent_prefix;
#line 2115 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp36_ = g_strconcat (_tmp35_, "&#8226; %s\n", NULL);
#line 2115 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp37_ = _tmp36_;
#line 2115 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp38_ = indent_prefix;
#line 2115 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp39_ = g_strconcat (_tmp38_, "&#8226; %s\n", NULL);
#line 2115 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp40_ = _tmp39_;
#line 2115 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp41_ = g_strconcat (_tmp37_, _tmp40_, NULL);
#line 2115 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp42_ = _tmp41_;
#line 2115 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp43_ = indent_prefix;
#line 2115 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp44_ = g_strconcat (_tmp43_, "&#8226; %s", NULL);
#line 2115 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp45_ = _tmp44_;
#line 2115 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp46_ = g_strconcat (_tmp42_, _tmp45_, NULL);
#line 2115 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp47_ = _tmp46_;
#line 2115 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp48_ = _ ("Choose <span weight=\"bold\">File %s Import From Folder</span>");
#line 2115 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp49_ = arrow_glyph;
#line 2115 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp50_ = g_strdup_printf (_tmp48_, _tmp49_);
#line 2115 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp51_ = _tmp50_;
#line 2115 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp52_ = _ ("Drag and drop photos onto the Shotwell window");
#line 2115 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp53_ = _ ("Connect a camera to your computer and import");
#line 2115 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp54_ = g_strdup_printf (_tmp47_, _tmp51_, _tmp52_, _tmp53_);
#line 2115 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp55_ = _tmp54_;
#line 2115 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_label_set_markup (_tmp34_, _tmp55_);
#line 2115 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp55_);
#line 2115 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp51_);
#line 2115 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp47_);
#line 2115 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp45_);
#line 2115 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp42_);
#line 2115 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp40_);
#line 2115 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp37_);
#line 2120 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp56_ = instructions;
#line 2120 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_misc_set_alignment (G_TYPE_CHECK_INSTANCE_CAST (_tmp56_, gtk_misc_get_type (), GtkMisc), (gfloat) 0, 0.5f);
#line 2122 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp57_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 2);
#line 2122 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp57_);
#line 2122 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->import_action_checkbox_packer);
#line 2122 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->import_action_checkbox_packer = _tmp57_;
#line 2124 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp58_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 2);
#line 2124 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp58_);
#line 2124 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->external_import_action_checkbox_packer);
#line 2124 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->external_import_action_checkbox_packer = _tmp58_;
#line 2125 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp59_ = self->priv->import_action_checkbox_packer;
#line 2125 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp60_ = self->priv->external_import_action_checkbox_packer;
#line 2125 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_container_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp59_, gtk_container_get_type (), GtkContainer), G_TYPE_CHECK_INSTANCE_CAST (_tmp60_, gtk_widget_get_type (), GtkWidget));
#line 2127 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp61_ = show_system_pictures_import;
#line 2127 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp61_) {
#line 17057 "Dialogs.c"
		const gchar* _tmp62_ = NULL;
		GFile* _tmp63_ = NULL;
		GFile* _tmp64_ = NULL;
		gchar* _tmp65_ = NULL;
		gchar* _tmp66_ = NULL;
		gchar* _tmp67_ = NULL;
		gchar* _tmp68_ = NULL;
		GtkCheckButton* _tmp69_ = NULL;
		GtkBox* _tmp70_ = NULL;
		GtkCheckButton* _tmp71_ = NULL;
		GtkCheckButton* _tmp72_ = NULL;
#line 2128 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp62_ = _ ("_Import photos from your %s folder");
#line 2128 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp63_ = app_dirs_get_import_dir ();
#line 2128 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp64_ = _tmp63_;
#line 2128 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp65_ = get_display_pathname (_tmp64_);
#line 2128 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp66_ = _tmp65_;
#line 2128 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp67_ = g_strdup_printf (_tmp62_, _tmp66_);
#line 2128 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp68_ = _tmp67_;
#line 2128 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp69_ = (GtkCheckButton*) gtk_check_button_new_with_mnemonic (_tmp68_);
#line 2128 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_object_ref_sink (_tmp69_);
#line 2128 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (self->priv->system_pictures_import_check);
#line 2128 "/home/jens/Source/shotwell/src/Dialogs.vala"
		self->priv->system_pictures_import_check = _tmp69_;
#line 2128 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp68_);
#line 2128 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp66_);
#line 2128 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (_tmp64_);
#line 2131 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp70_ = self->priv->import_action_checkbox_packer;
#line 2131 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp71_ = self->priv->system_pictures_import_check;
#line 2131 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_container_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp70_, gtk_container_get_type (), GtkContainer), G_TYPE_CHECK_INSTANCE_CAST (_tmp71_, gtk_widget_get_type (), GtkWidget));
#line 2132 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp72_ = self->priv->system_pictures_import_check;
#line 2132 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_toggle_button_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp72_, gtk_toggle_button_get_type (), GtkToggleButton), TRUE);
#line 17107 "Dialogs.c"
	}
#line 2135 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp73_ = _ ("You can also import photos in any of these ways:");
#line 2135 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp74_ = (GtkLabel*) gtk_label_new (_tmp73_);
#line 2135 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp74_);
#line 2135 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->instruction_header);
#line 2135 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->instruction_header = _tmp74_;
#line 2137 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp75_ = self->priv->instruction_header;
#line 2137 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_misc_set_alignment (G_TYPE_CHECK_INSTANCE_CAST (_tmp75_, gtk_misc_get_type (), GtkMisc), 0.0f, 0.5f);
#line 2138 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp76_ = self->priv->instruction_header;
#line 2138 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_set_margin_top (G_TYPE_CHECK_INSTANCE_CAST (_tmp76_, gtk_widget_get_type (), GtkWidget), 20);
#line 2140 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp77_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 16);
#line 2140 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp77_);
#line 2140 "/home/jens/Source/shotwell/src/Dialogs.vala"
	content = _tmp77_;
#line 2141 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp78_ = header_content;
#line 2141 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_box_pack_start (content, G_TYPE_CHECK_INSTANCE_CAST (_tmp78_, gtk_widget_get_type (), GtkWidget), TRUE, TRUE, (guint) 0);
#line 2142 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp79_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 2);
#line 2142 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp79_);
#line 2142 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->import_content);
#line 2142 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->import_content = _tmp79_;
#line 2143 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp80_ = self->priv->import_content;
#line 2143 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_container_add (G_TYPE_CHECK_INSTANCE_CAST (content, gtk_container_get_type (), GtkContainer), G_TYPE_CHECK_INSTANCE_CAST (_tmp80_, gtk_widget_get_type (), GtkWidget));
#line 2144 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp81_ = instructions;
#line 2144 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_box_pack_start (content, G_TYPE_CHECK_INSTANCE_CAST (_tmp81_, gtk_widget_get_type (), GtkWidget), FALSE, FALSE, (guint) 0);
#line 2146 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp82_ = _ ("_Don't show this message again");
#line 2146 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp83_ = (GtkCheckButton*) gtk_check_button_new_with_mnemonic (_tmp82_);
#line 2146 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp83_);
#line 2146 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->hide_button);
#line 2146 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->hide_button = _tmp83_;
#line 2147 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp84_ = self->priv->hide_button;
#line 2147 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_toggle_button_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp84_, gtk_toggle_button_get_type (), GtkToggleButton), TRUE);
#line 2148 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp85_ = self->priv->hide_button;
#line 2148 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_box_pack_start (content, G_TYPE_CHECK_INSTANCE_CAST (_tmp85_, gtk_widget_get_type (), GtkWidget), FALSE, FALSE, (guint) 6);
#line 2150 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp86_ = (GtkAlignment*) gtk_alignment_new ((gfloat) 0, (gfloat) 0, (gfloat) 0, (gfloat) 0);
#line 2150 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp86_);
#line 2150 "/home/jens/Source/shotwell/src/Dialogs.vala"
	alignment = _tmp86_;
#line 2151 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_alignment_set_padding (alignment, (guint) 12, (guint) 0, (guint) 12, (guint) 12);
#line 2152 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_container_add (G_TYPE_CHECK_INSTANCE_CAST (alignment, gtk_container_get_type (), GtkContainer), G_TYPE_CHECK_INSTANCE_CAST (content, gtk_widget_get_type (), GtkWidget));
#line 2154 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp87_ = (GtkBox*) gtk_dialog_get_content_area (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog));
#line 2154 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_box_pack_start (G_TYPE_CHECK_INSTANCE_CAST (_tmp87_, gtk_box_get_type (), GtkBox), G_TYPE_CHECK_INSTANCE_CAST (alignment, gtk_widget_get_type (), GtkWidget), FALSE, FALSE, (guint) 0);
#line 2156 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_window_set_has_resize_grip (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), FALSE);
#line 2158 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp88_ = ok_button;
#line 2158 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_grab_focus (_tmp88_);
#line 2160 "/home/jens/Source/shotwell/src/Dialogs.vala"
	welcome_dialog_install_import_content (self);
#line 2162 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp89_ = self->priv->import_meta_host;
#line 2162 "/home/jens/Source/shotwell/src/Dialogs.vala"
	spit_data_imports_welcome_import_meta_host_start (_tmp89_);
#line 2083 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (alignment);
#line 2083 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (content);
#line 2083 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (arrow_glyph);
#line 2083 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (indent_prefix);
#line 2083 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (instructions);
#line 2083 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (header_content);
#line 2083 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (header_text);
#line 2083 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (image);
#line 2083 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (primary_text);
#line 2083 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (ok_button);
#line 2083 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return self;
#line 17219 "Dialogs.c"
}


WelcomeDialog* welcome_dialog_new (GtkWindow* owner) {
#line 2083 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return welcome_dialog_construct (TYPE_WELCOME_DIALOG, owner);
#line 17226 "Dialogs.c"
}


static void welcome_dialog_install_import_content (WelcomeDialog* self) {
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	GtkCheckButton** _tmp2_ = NULL;
	gint _tmp2__length1 = 0;
#line 2165 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_WELCOME_DIALOG (self));
#line 2167 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = self->priv->external_import_checks;
#line 2167 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2__length1 = self->priv->external_import_checks_length1;
#line 2167 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp2__length1 > 0) {
#line 2167 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp1_ = TRUE;
#line 17245 "Dialogs.c"
	} else {
		GtkCheckButton* _tmp3_ = NULL;
#line 2167 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp3_ = self->priv->system_pictures_import_check;
#line 2167 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp1_ = _tmp3_ != NULL;
#line 17252 "Dialogs.c"
	}
#line 2167 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp1_) {
#line 17256 "Dialogs.c"
		gboolean _tmp4_ = FALSE;
#line 2168 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp4_ = self->priv->import_content_already_installed;
#line 2168 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = _tmp4_ == FALSE;
#line 17262 "Dialogs.c"
	} else {
#line 2167 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = FALSE;
#line 17266 "Dialogs.c"
	}
#line 2166 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp0_) {
#line 17270 "Dialogs.c"
		GtkLabel* _tmp5_ = NULL;
		GtkBox* _tmp6_ = NULL;
		GtkBox* _tmp7_ = NULL;
		GtkBox* _tmp8_ = NULL;
		GtkLabel* _tmp9_ = NULL;
#line 2170 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp5_ = self->priv->secondary_text;
#line 2170 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_label_set_markup (_tmp5_, "");
#line 2171 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp6_ = self->priv->import_content;
#line 2171 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp7_ = self->priv->import_action_checkbox_packer;
#line 2171 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_container_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, gtk_container_get_type (), GtkContainer), G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, gtk_widget_get_type (), GtkWidget));
#line 2172 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp8_ = self->priv->import_content;
#line 2172 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp9_ = self->priv->instruction_header;
#line 2172 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_container_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, gtk_container_get_type (), GtkContainer), G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, gtk_widget_get_type (), GtkWidget));
#line 2173 "/home/jens/Source/shotwell/src/Dialogs.vala"
		self->priv->import_content_already_installed = TRUE;
#line 17294 "Dialogs.c"
	}
}


static void _vala_array_add275 (WelcomeServiceEntry*** array, int* length, int* size, WelcomeServiceEntry* value) {
#line 2179 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if ((*length) == (*size)) {
#line 2179 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 2179 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*array = g_renew (WelcomeServiceEntry*, *array, (*size) + 1);
#line 17306 "Dialogs.c"
	}
#line 2179 "/home/jens/Source/shotwell/src/Dialogs.vala"
	(*array)[(*length)++] = value;
#line 2179 "/home/jens/Source/shotwell/src/Dialogs.vala"
	(*array)[*length] = NULL;
#line 17312 "Dialogs.c"
}


static void _vala_array_add276 (GtkCheckButton*** array, int* length, int* size, GtkCheckButton* value) {
#line 2182 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if ((*length) == (*size)) {
#line 2182 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 2182 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*array = g_renew (GtkCheckButton*, *array, (*size) + 1);
#line 17323 "Dialogs.c"
	}
#line 2182 "/home/jens/Source/shotwell/src/Dialogs.vala"
	(*array)[(*length)++] = value;
#line 2182 "/home/jens/Source/shotwell/src/Dialogs.vala"
	(*array)[*length] = NULL;
#line 17329 "Dialogs.c"
}


void welcome_dialog_install_service_entry (WelcomeDialog* self, WelcomeServiceEntry* entry) {
	WelcomeServiceEntry* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	WelcomeServiceEntry** _tmp5_ = NULL;
	gint _tmp5__length1 = 0;
	WelcomeServiceEntry* _tmp6_ = NULL;
	WelcomeServiceEntry* _tmp7_ = NULL;
	GtkCheckButton* entry_check = NULL;
	const gchar* _tmp8_ = NULL;
	WelcomeServiceEntry* _tmp9_ = NULL;
	gchar* _tmp10_ = NULL;
	gchar* _tmp11_ = NULL;
	gchar* _tmp12_ = NULL;
	gchar* _tmp13_ = NULL;
	GtkCheckButton* _tmp14_ = NULL;
	GtkCheckButton* _tmp15_ = NULL;
	GtkCheckButton** _tmp16_ = NULL;
	gint _tmp16__length1 = 0;
	GtkCheckButton* _tmp17_ = NULL;
	GtkBox* _tmp18_ = NULL;
#line 2177 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_WELCOME_DIALOG (self));
#line 2177 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_WELCOME_SERVICE_ENTRY (entry));
#line 2178 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = entry;
#line 2178 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = welcome_service_entry_get_service_name (_tmp0_);
#line 2178 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = _tmp1_;
#line 2178 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = g_strdup_printf ("WelcomeDialog: Installing service entry for %s", _tmp2_);
#line 2178 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = _tmp3_;
#line 2178 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_debug ("Dialogs.vala:2178: %s", _tmp4_);
#line 2178 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp4_);
#line 2178 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp2_);
#line 2179 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = self->priv->external_import_entries;
#line 2179 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5__length1 = self->priv->external_import_entries_length1;
#line 2179 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = entry;
#line 2179 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = _g_object_ref0 (_tmp6_);
#line 2179 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_vala_array_add275 (&self->priv->external_import_entries, &self->priv->external_import_entries_length1, &self->priv->_external_import_entries_size_, _tmp7_);
#line 2180 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = _ ("Import photos from your %s library");
#line 2180 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = entry;
#line 2180 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp10_ = welcome_service_entry_get_service_name (_tmp9_);
#line 2180 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp11_ = _tmp10_;
#line 2180 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp12_ = g_strdup_printf (_tmp8_, _tmp11_);
#line 2180 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp13_ = _tmp12_;
#line 2180 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp14_ = (GtkCheckButton*) gtk_check_button_new_with_label (_tmp13_);
#line 2180 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp14_);
#line 2180 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp15_ = _tmp14_;
#line 2180 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp13_);
#line 2180 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp11_);
#line 2180 "/home/jens/Source/shotwell/src/Dialogs.vala"
	entry_check = _tmp15_;
#line 2182 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp16_ = self->priv->external_import_checks;
#line 2182 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp16__length1 = self->priv->external_import_checks_length1;
#line 2182 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp17_ = _g_object_ref0 (entry_check);
#line 2182 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_vala_array_add276 (&self->priv->external_import_checks, &self->priv->external_import_checks_length1, &self->priv->_external_import_checks_size_, _tmp17_);
#line 2183 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_toggle_button_set_active (G_TYPE_CHECK_INSTANCE_CAST (entry_check, gtk_toggle_button_get_type (), GtkToggleButton), TRUE);
#line 2184 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp18_ = self->priv->external_import_action_checkbox_packer;
#line 2184 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_container_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp18_, gtk_container_get_type (), GtkContainer), G_TYPE_CHECK_INSTANCE_CAST (entry_check, gtk_widget_get_type (), GtkWidget));
#line 2185 "/home/jens/Source/shotwell/src/Dialogs.vala"
	welcome_dialog_install_import_content (self);
#line 2177 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (entry_check);
#line 17428 "Dialogs.c"
}


/**
     * Connected to the 'response' signal.  This is part of a workaround
     * for the fact that run()-ning this dialog can interfere with displaying
     * images from a camera; please see #4997 for details.
     */
static void welcome_dialog_on_dismiss (WelcomeDialog* self, gint resp) {
	gint _tmp0_ = 0;
#line 2193 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_WELCOME_DIALOG (self));
#line 2194 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = resp;
#line 2194 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp0_ == ((gint) GTK_RESPONSE_OK)) {
#line 2195 "/home/jens/Source/shotwell/src/Dialogs.vala"
		self->priv->ok_clicked = TRUE;
#line 17447 "Dialogs.c"
	}
#line 2197 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_hide (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 2198 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_main_quit ();
#line 17453 "Dialogs.c"
}


static void _welcome_dialog_on_dismiss_gtk_dialog_response (GtkDialog* _sender, gint response_id, gpointer self) {
#line 2204 "/home/jens/Source/shotwell/src/Dialogs.vala"
	welcome_dialog_on_dismiss ((WelcomeDialog*) self, response_id);
#line 17460 "Dialogs.c"
}


static void _vala_array_add277 (WelcomeServiceEntry*** array, int* length, int* size, WelcomeServiceEntry* value) {
#line 2227 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if ((*length) == (*size)) {
#line 2227 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 2227 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*array = g_renew (WelcomeServiceEntry*, *array, (*size) + 1);
#line 17471 "Dialogs.c"
	}
#line 2227 "/home/jens/Source/shotwell/src/Dialogs.vala"
	(*array)[(*length)++] = value;
#line 2227 "/home/jens/Source/shotwell/src/Dialogs.vala"
	(*array)[*length] = NULL;
#line 17477 "Dialogs.c"
}


static WelcomeServiceEntry** _vala_array_dup30 (WelcomeServiceEntry** self, int length) {
	WelcomeServiceEntry** result;
	int i;
#line 2229 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = g_new0 (WelcomeServiceEntry*, length + 1);
#line 2229 "/home/jens/Source/shotwell/src/Dialogs.vala"
	for (i = 0; i < length; i++) {
#line 17488 "Dialogs.c"
		WelcomeServiceEntry* _tmp0_ = NULL;
#line 2229 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = _g_object_ref0 (self[i]);
#line 2229 "/home/jens/Source/shotwell/src/Dialogs.vala"
		result[i] = _tmp0_;
#line 17494 "Dialogs.c"
	}
#line 2229 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 17498 "Dialogs.c"
}


gboolean welcome_dialog_execute (WelcomeDialog* self, WelcomeServiceEntry*** selected_import_entries, int* selected_import_entries_length1, gboolean* do_system_pictures_import) {
	WelcomeServiceEntry** _vala_selected_import_entries = NULL;
	int _vala_selected_import_entries_length1 = 0;
	gboolean _vala_do_system_pictures_import = FALSE;
	gboolean result = FALSE;
	guint _tmp0_ = 0U;
	gboolean ok = FALSE;
	gboolean _tmp1_ = FALSE;
	gboolean show_dialog = FALSE;
	gboolean _tmp2_ = FALSE;
	WelcomeServiceEntry** _result_ = NULL;
	WelcomeServiceEntry** _tmp5_ = NULL;
	gint _result__length1 = 0;
	gint __result__size_ = 0;
	WelcomeServiceEntry** _tmp19_ = NULL;
	gint _tmp19__length1 = 0;
	WelcomeServiceEntry** _tmp20_ = NULL;
	gint _tmp20__length1 = 0;
	gboolean _tmp21_ = FALSE;
	GtkCheckButton* _tmp22_ = NULL;
#line 2201 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_WELCOME_DIALOG (self), FALSE);
#line 2204 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog), "response", (GCallback) _welcome_dialog_on_dismiss_gtk_dialog_response, self, 0);
#line 2205 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_show_all (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 2206 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_show (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 2211 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_main ();
#line 2215 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_parse_name ("response", gtk_dialog_get_type (), &_tmp0_, NULL, FALSE);
#line 2215 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_handlers_disconnect_matched (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog), G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp0_, 0, NULL, (GCallback) _welcome_dialog_on_dismiss_gtk_dialog_response, self);
#line 2217 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = self->priv->ok_clicked;
#line 2217 "/home/jens/Source/shotwell/src/Dialogs.vala"
	ok = _tmp1_;
#line 2218 "/home/jens/Source/shotwell/src/Dialogs.vala"
	show_dialog = TRUE;
#line 2220 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = ok;
#line 2220 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp2_) {
#line 17546 "Dialogs.c"
		GtkCheckButton* _tmp3_ = NULL;
		gboolean _tmp4_ = FALSE;
#line 2221 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp3_ = self->priv->hide_button;
#line 2221 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp4_ = gtk_toggle_button_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, gtk_toggle_button_get_type (), GtkToggleButton));
#line 2221 "/home/jens/Source/shotwell/src/Dialogs.vala"
		show_dialog = !_tmp4_;
#line 17555 "Dialogs.c"
	}
#line 2224 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = g_new0 (WelcomeServiceEntry*, 0 + 1);
#line 2224 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_result_ = _tmp5_;
#line 2224 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_result__length1 = 0;
#line 2224 "/home/jens/Source/shotwell/src/Dialogs.vala"
	__result__size_ = _result__length1;
#line 17565 "Dialogs.c"
	{
		gint i = 0;
#line 2225 "/home/jens/Source/shotwell/src/Dialogs.vala"
		i = 0;
#line 17570 "Dialogs.c"
		{
			gboolean _tmp6_ = FALSE;
#line 2225 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp6_ = TRUE;
#line 2225 "/home/jens/Source/shotwell/src/Dialogs.vala"
			while (TRUE) {
#line 17577 "Dialogs.c"
				gint _tmp8_ = 0;
				WelcomeServiceEntry** _tmp9_ = NULL;
				gint _tmp9__length1 = 0;
				GtkCheckButton** _tmp10_ = NULL;
				gint _tmp10__length1 = 0;
				gint _tmp11_ = 0;
				GtkCheckButton* _tmp12_ = NULL;
				gboolean _tmp13_ = FALSE;
#line 2225 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (!_tmp6_) {
#line 17588 "Dialogs.c"
					gint _tmp7_ = 0;
#line 2225 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp7_ = i;
#line 2225 "/home/jens/Source/shotwell/src/Dialogs.vala"
					i = _tmp7_ + 1;
#line 17594 "Dialogs.c"
				}
#line 2225 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp6_ = FALSE;
#line 2225 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp8_ = i;
#line 2225 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp9_ = self->priv->external_import_entries;
#line 2225 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp9__length1 = self->priv->external_import_entries_length1;
#line 2225 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (!(_tmp8_ < _tmp9__length1)) {
#line 2225 "/home/jens/Source/shotwell/src/Dialogs.vala"
					break;
#line 17608 "Dialogs.c"
				}
#line 2226 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp10_ = self->priv->external_import_checks;
#line 2226 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp10__length1 = self->priv->external_import_checks_length1;
#line 2226 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp11_ = i;
#line 2226 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp12_ = _tmp10_[_tmp11_];
#line 2226 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp13_ = gtk_toggle_button_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp12_, gtk_toggle_button_get_type (), GtkToggleButton));
#line 2226 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (_tmp13_ == TRUE) {
#line 17622 "Dialogs.c"
					WelcomeServiceEntry** _tmp14_ = NULL;
					gint _tmp14__length1 = 0;
					WelcomeServiceEntry** _tmp15_ = NULL;
					gint _tmp15__length1 = 0;
					gint _tmp16_ = 0;
					WelcomeServiceEntry* _tmp17_ = NULL;
					WelcomeServiceEntry* _tmp18_ = NULL;
#line 2227 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp14_ = _result_;
#line 2227 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp14__length1 = _result__length1;
#line 2227 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp15_ = self->priv->external_import_entries;
#line 2227 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp15__length1 = self->priv->external_import_entries_length1;
#line 2227 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp16_ = i;
#line 2227 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp17_ = _tmp15_[_tmp16_];
#line 2227 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp18_ = _g_object_ref0 (_tmp17_);
#line 2227 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_vala_array_add277 (&_result_, &_result__length1, &__result__size_, _tmp18_);
#line 17646 "Dialogs.c"
				}
			}
		}
	}
#line 2229 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp19_ = _result_;
#line 2229 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp19__length1 = _result__length1;
#line 2229 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp20_ = (_tmp19_ != NULL) ? _vala_array_dup30 (_tmp19_, _tmp19__length1) : ((gpointer) _tmp19_);
#line 2229 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp20__length1 = _tmp19__length1;
#line 2229 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_vala_selected_import_entries = (_vala_array_free (_vala_selected_import_entries, _vala_selected_import_entries_length1, (GDestroyNotify) g_object_unref), NULL);
#line 2229 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_vala_selected_import_entries = _tmp20_;
#line 2229 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_vala_selected_import_entries_length1 = _tmp20__length1;
#line 2231 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp22_ = self->priv->system_pictures_import_check;
#line 2231 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp22_ != NULL) {
#line 17669 "Dialogs.c"
		GtkCheckButton* _tmp23_ = NULL;
		gboolean _tmp24_ = FALSE;
#line 2231 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp23_ = self->priv->system_pictures_import_check;
#line 2231 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp24_ = gtk_toggle_button_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp23_, gtk_toggle_button_get_type (), GtkToggleButton));
#line 2231 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp21_ = _tmp24_;
#line 17678 "Dialogs.c"
	} else {
#line 2231 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp21_ = FALSE;
#line 17682 "Dialogs.c"
	}
#line 2230 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_vala_do_system_pictures_import = _tmp21_;
#line 2233 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 2235 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = show_dialog;
#line 2235 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_result_ = (_vala_array_free (_result_, _result__length1, (GDestroyNotify) g_object_unref), NULL);
#line 2235 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (selected_import_entries) {
#line 2235 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*selected_import_entries = _vala_selected_import_entries;
#line 17696 "Dialogs.c"
	} else {
#line 2235 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_vala_selected_import_entries = (_vala_array_free (_vala_selected_import_entries, _vala_selected_import_entries_length1, (GDestroyNotify) g_object_unref), NULL);
#line 17700 "Dialogs.c"
	}
#line 2235 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (selected_import_entries_length1) {
#line 2235 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*selected_import_entries_length1 = _vala_selected_import_entries_length1;
#line 17706 "Dialogs.c"
	}
#line 2235 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (do_system_pictures_import) {
#line 2235 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*do_system_pictures_import = _vala_do_system_pictures_import;
#line 17712 "Dialogs.c"
	}
#line 2235 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 17716 "Dialogs.c"
}


static gboolean welcome_dialog_is_system_pictures_import_possible (void) {
	gboolean result = FALSE;
	GFile* system_pictures = NULL;
	GFile* _tmp0_ = NULL;
	GFile* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	GFile* _tmp3_ = NULL;
	GFileType _tmp4_ = 0;
	GError * _inner_error_ = NULL;
#line 2239 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = app_dirs_get_import_dir ();
#line 2239 "/home/jens/Source/shotwell/src/Dialogs.vala"
	system_pictures = _tmp0_;
#line 2240 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = system_pictures;
#line 2240 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = g_file_query_exists (_tmp1_, NULL);
#line 2240 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (!_tmp2_) {
#line 2241 "/home/jens/Source/shotwell/src/Dialogs.vala"
		result = FALSE;
#line 2241 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (system_pictures);
#line 2241 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return result;
#line 17745 "Dialogs.c"
	}
#line 2243 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = system_pictures;
#line 2243 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = g_file_query_file_type (_tmp3_, G_FILE_QUERY_INFO_NONE, NULL);
#line 2243 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (!(_tmp4_ == G_FILE_TYPE_DIRECTORY)) {
#line 2244 "/home/jens/Source/shotwell/src/Dialogs.vala"
		result = FALSE;
#line 2244 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (system_pictures);
#line 2244 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return result;
#line 17759 "Dialogs.c"
	}
	{
		GFileEnumerator* syspics_child_enum = NULL;
		GFile* _tmp5_ = NULL;
		GFileEnumerator* _tmp6_ = NULL;
		GFileInfo* _tmp7_ = NULL;
		GFileEnumerator* _tmp8_ = NULL;
		GFileInfo* _tmp9_ = NULL;
		GFileInfo* _tmp10_ = NULL;
		GFileInfo* _tmp11_ = NULL;
		gboolean _tmp12_ = FALSE;
#line 2247 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp5_ = system_pictures;
#line 2247 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp6_ = g_file_enumerate_children (_tmp5_, "standard::*", G_FILE_QUERY_INFO_NONE, NULL, &_inner_error_);
#line 2247 "/home/jens/Source/shotwell/src/Dialogs.vala"
		syspics_child_enum = _tmp6_;
#line 2247 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 17779 "Dialogs.c"
			goto __catch413_g_error;
		}
#line 2249 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp8_ = syspics_child_enum;
#line 2249 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp9_ = g_file_enumerator_next_file (_tmp8_, NULL, &_inner_error_);
#line 2249 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp7_ = _tmp9_;
#line 2249 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2249 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_object_unref0 (syspics_child_enum);
#line 17792 "Dialogs.c"
			goto __catch413_g_error;
		}
#line 2249 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp10_ = _tmp7_;
#line 2249 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp7_ = NULL;
#line 2249 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp11_ = _tmp10_;
#line 2249 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp12_ = _tmp11_ != NULL;
#line 2249 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (_tmp11_);
#line 2249 "/home/jens/Source/shotwell/src/Dialogs.vala"
		result = _tmp12_;
#line 2249 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (_tmp7_);
#line 2249 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (syspics_child_enum);
#line 2249 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (system_pictures);
#line 2249 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return result;
#line 17815 "Dialogs.c"
	}
	goto __finally413;
	__catch413_g_error:
	{
		GError* e = NULL;
#line 2246 "/home/jens/Source/shotwell/src/Dialogs.vala"
		e = _inner_error_;
#line 2246 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_inner_error_ = NULL;
#line 2251 "/home/jens/Source/shotwell/src/Dialogs.vala"
		result = FALSE;
#line 2251 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_error_free0 (e);
#line 2251 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (system_pictures);
#line 2251 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return result;
#line 17833 "Dialogs.c"
	}
	__finally413:
#line 2246 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (system_pictures);
#line 2246 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 2246 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_clear_error (&_inner_error_);
#line 2246 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return FALSE;
#line 17844 "Dialogs.c"
}


static void welcome_dialog_class_init (WelcomeDialogClass * klass) {
#line 2069 "/home/jens/Source/shotwell/src/Dialogs.vala"
	welcome_dialog_parent_class = g_type_class_peek_parent (klass);
#line 2069 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_type_class_add_private (klass, sizeof (WelcomeDialogPrivate));
#line 2069 "/home/jens/Source/shotwell/src/Dialogs.vala"
	G_OBJECT_CLASS (klass)->finalize = welcome_dialog_finalize;
#line 17855 "Dialogs.c"
}


static void welcome_dialog_instance_init (WelcomeDialog * self) {
	GtkCheckButton** _tmp0_ = NULL;
	WelcomeServiceEntry** _tmp1_ = NULL;
#line 2069 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv = WELCOME_DIALOG_GET_PRIVATE (self);
#line 2071 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->system_pictures_import_check = NULL;
#line 2072 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = g_new0 (GtkCheckButton*, 0 + 1);
#line 2072 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->external_import_checks = _tmp0_;
#line 2072 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->external_import_checks_length1 = 0;
#line 2072 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->_external_import_checks_size_ = self->priv->external_import_checks_length1;
#line 2073 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = g_new0 (WelcomeServiceEntry*, 0 + 1);
#line 2073 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->external_import_entries = _tmp1_;
#line 2073 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->external_import_entries_length1 = 0;
#line 2073 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->_external_import_entries_size_ = self->priv->external_import_entries_length1;
#line 2080 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->import_content_already_installed = FALSE;
#line 2081 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->ok_clicked = FALSE;
#line 17886 "Dialogs.c"
}


static void welcome_dialog_finalize (GObject* obj) {
	WelcomeDialog * self;
#line 2069 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_WELCOME_DIALOG, WelcomeDialog);
#line 2070 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->hide_button);
#line 2071 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->system_pictures_import_check);
#line 2072 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->external_import_checks = (_vala_array_free (self->priv->external_import_checks, self->priv->external_import_checks_length1, (GDestroyNotify) g_object_unref), NULL);
#line 2073 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->external_import_entries = (_vala_array_free (self->priv->external_import_entries, self->priv->external_import_entries_length1, (GDestroyNotify) g_object_unref), NULL);
#line 2074 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->secondary_text);
#line 2075 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->instruction_header);
#line 2076 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->import_content);
#line 2077 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->import_action_checkbox_packer);
#line 2078 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->external_import_action_checkbox_packer);
#line 2079 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->import_meta_host);
#line 2069 "/home/jens/Source/shotwell/src/Dialogs.vala"
	G_OBJECT_CLASS (welcome_dialog_parent_class)->finalize (obj);
#line 17916 "Dialogs.c"
}


GType welcome_dialog_get_type (void) {
	static volatile gsize welcome_dialog_type_id__volatile = 0;
	if (g_once_init_enter (&welcome_dialog_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (WelcomeDialogClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) welcome_dialog_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (WelcomeDialog), 0, (GInstanceInitFunc) welcome_dialog_instance_init, NULL };
		GType welcome_dialog_type_id;
		welcome_dialog_type_id = g_type_register_static (gtk_dialog_get_type (), "WelcomeDialog", &g_define_type_info, 0);
		g_once_init_leave (&welcome_dialog_type_id__volatile, welcome_dialog_type_id);
	}
	return welcome_dialog_type_id__volatile;
}


static gboolean _preferences_dialog_on_delete_gtk_widget_delete_event (GtkWidget* _sender, GdkEventAny* event, gpointer self) {
	gboolean result;
	result = preferences_dialog_on_delete ((PreferencesDialog*) self);
#line 2300 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 17937 "Dialogs.c"
}


static void _preferences_dialog_on_close_gtk_dialog_response (GtkDialog* _sender, gint response_id, gpointer self) {
#line 2301 "/home/jens/Source/shotwell/src/Dialogs.vala"
	preferences_dialog_on_close ((PreferencesDialog*) self);
#line 17944 "Dialogs.c"
}


static void _preferences_dialog_on_value_changed_gtk_adjustment_value_changed (GtkAdjustment* _sender, gpointer self) {
#line 2307 "/home/jens/Source/shotwell/src/Dialogs.vala"
	preferences_dialog_on_value_changed ((PreferencesDialog*) self);
#line 17951 "Dialogs.c"
}


static gboolean _preferences_dialog_on_bg_color_reset_gtk_widget_button_press_event (GtkWidget* _sender, GdkEventButton* event, gpointer self) {
	gboolean result;
	result = preferences_dialog_on_bg_color_reset ((PreferencesDialog*) self, event);
#line 2310 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 17960 "Dialogs.c"
}


static gboolean _preferences_dialog_on_local_pattern_help_gtk_label_activate_link (GtkLabel* _sender, const gchar* uri, gpointer self) {
	gboolean result;
	result = preferences_dialog_on_local_pattern_help ((PreferencesDialog*) self, uri);
#line 2333 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 17969 "Dialogs.c"
}


static void _preferences_dialog_on_dir_pattern_combo_changed_gtk_combo_box_changed (GtkComboBox* _sender, gpointer self) {
#line 2349 "/home/jens/Source/shotwell/src/Dialogs.vala"
	preferences_dialog_on_dir_pattern_combo_changed ((PreferencesDialog*) self);
#line 17976 "Dialogs.c"
}


static void _preferences_dialog_on_dir_pattern_entry_changed_gtk_editable_changed (GtkEditable* _sender, gpointer self) {
#line 2350 "/home/jens/Source/shotwell/src/Dialogs.vala"
	preferences_dialog_on_dir_pattern_entry_changed ((PreferencesDialog*) self);
#line 17983 "Dialogs.c"
}


static void _preferences_dialog_on_lowercase_toggled_gtk_toggle_button_toggled (GtkToggleButton* _sender, gpointer self) {
#line 2355 "/home/jens/Source/shotwell/src/Dialogs.vala"
	preferences_dialog_on_lowercase_toggled ((PreferencesDialog*) self);
#line 17990 "Dialogs.c"
}


static void _preferences_dialog_on_photo_editor_changed_gtk_combo_box_changed (GtkComboBox* _sender, gpointer self) {
#line 2362 "/home/jens/Source/shotwell/src/Dialogs.vala"
	preferences_dialog_on_photo_editor_changed ((PreferencesDialog*) self);
#line 17997 "Dialogs.c"
}


static void _preferences_dialog_on_raw_editor_changed_gtk_combo_box_changed (GtkComboBox* _sender, gpointer self) {
#line 2363 "/home/jens/Source/shotwell/src/Dialogs.vala"
	preferences_dialog_on_raw_editor_changed ((PreferencesDialog*) self);
#line 18004 "Dialogs.c"
}


static void _preferences_dialog_on_default_raw_developer_changed_gtk_combo_box_changed (GtkComboBox* _sender, gpointer self) {
#line 2375 "/home/jens/Source/shotwell/src/Dialogs.vala"
	preferences_dialog_on_default_raw_developer_changed ((PreferencesDialog*) self);
#line 18011 "Dialogs.c"
}


static gboolean _preferences_dialog_map_event_gtk_widget_map_event (GtkWidget* _sender, GdkEventAny* event, gpointer self) {
	gboolean result;
	result = preferences_dialog_map_event ((PreferencesDialog*) self);
#line 2377 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 18020 "Dialogs.c"
}


static PreferencesDialog* preferences_dialog_construct (GType object_type) {
	PreferencesDialog* self = NULL;
	GtkBuilder* _tmp0_ = NULL;
	GtkBuilder* _tmp1_ = NULL;
	GObject* _tmp2_ = NULL;
	GtkDialog* _tmp3_ = NULL;
	gboolean use_header = FALSE;
	GtkSettings* _tmp4_ = NULL;
	gboolean _tmp5_ = FALSE;
	GtkDialog* _tmp8_ = NULL;
	AppWindow* _tmp9_ = NULL;
	AppWindow* _tmp10_ = NULL;
	GdkWindow* _tmp11_ = NULL;
	GtkDialog* _tmp12_ = NULL;
	AppWindow* _tmp13_ = NULL;
	AppWindow* _tmp14_ = NULL;
	GtkDialog* _tmp15_ = NULL;
	GtkDialog* _tmp16_ = NULL;
	GtkDialog* _tmp17_ = NULL;
	GtkBuilder* _tmp18_ = NULL;
	GObject* _tmp19_ = NULL;
	GtkAdjustment* _tmp20_ = NULL;
	GtkAdjustment* _tmp21_ = NULL;
	GtkAdjustment* _tmp22_ = NULL;
	gdouble _tmp23_ = 0.0;
	ConfigFacade* _tmp24_ = NULL;
	ConfigFacade* _tmp25_ = NULL;
	GdkRGBA _tmp26_ = {0};
	gdouble _tmp27_ = 0.0;
	GtkAdjustment* _tmp28_ = NULL;
	GtkBuilder* _tmp29_ = NULL;
	GObject* _tmp30_ = NULL;
	GtkScale* _tmp31_ = NULL;
	GtkScale* _tmp32_ = NULL;
	GtkBuilder* _tmp33_ = NULL;
	GObject* _tmp34_ = NULL;
	GtkFileChooserButton* _tmp35_ = NULL;
	GtkBuilder* _tmp36_ = NULL;
	GObject* _tmp37_ = NULL;
	GtkComboBox* _tmp38_ = NULL;
	GtkBuilder* _tmp39_ = NULL;
	GObject* _tmp40_ = NULL;
	GtkComboBox* _tmp41_ = NULL;
	GtkLabel* pattern_help = NULL;
	GtkBuilder* _tmp42_ = NULL;
	GObject* _tmp43_ = NULL;
	GtkLabel* _tmp44_ = NULL;
	gchar* help_path = NULL;
	gchar* _tmp45_ = NULL;
	const gchar* _tmp46_ = NULL;
	GtkComboBoxText* _tmp60_ = NULL;
	GtkAlignment* dir_choser_align = NULL;
	GtkBuilder* _tmp61_ = NULL;
	GObject* _tmp62_ = NULL;
	GtkAlignment* _tmp63_ = NULL;
	GtkComboBoxText* _tmp64_ = NULL;
	GtkBuilder* _tmp65_ = NULL;
	GObject* _tmp66_ = NULL;
	GtkEntry* _tmp67_ = NULL;
	GtkBuilder* _tmp68_ = NULL;
	GObject* _tmp69_ = NULL;
	GtkLabel* _tmp70_ = NULL;
	const gchar* _tmp71_ = NULL;
	gchar* _tmp72_ = NULL;
	gchar* _tmp73_ = NULL;
	const gchar* _tmp74_ = NULL;
	gchar* _tmp75_ = NULL;
	gchar* _tmp76_ = NULL;
	const gchar* _tmp77_ = NULL;
	gchar* _tmp78_ = NULL;
	gchar* _tmp79_ = NULL;
	const gchar* _tmp80_ = NULL;
	const gchar* _tmp81_ = NULL;
	GtkComboBoxText* _tmp82_ = NULL;
	GtkEntry* _tmp83_ = NULL;
	GtkBuilder* _tmp84_ = NULL;
	GObject* _tmp85_ = NULL;
	GtkComboBoxText* _tmp86_ = NULL;
	GtkBuilder* _tmp87_ = NULL;
	GObject* _tmp88_ = NULL;
	GtkCheckButton* _tmp89_ = NULL;
	GtkCheckButton* _tmp90_ = NULL;
	GtkBin* plugin_manifest_container = NULL;
	GtkBuilder* _tmp91_ = NULL;
	GObject* _tmp92_ = NULL;
	GtkBin* _tmp93_ = NULL;
	PluginsManifestWidgetMediator* _tmp94_ = NULL;
	GtkWidget* _tmp95_ = NULL;
	GtkWidget* _tmp96_ = NULL;
	GtkComboBox* _tmp97_ = NULL;
	GtkComboBox* _tmp98_ = NULL;
	GtkCheckButton* auto_import_button = NULL;
	GtkBuilder* _tmp99_ = NULL;
	GObject* _tmp100_ = NULL;
	GtkCheckButton* _tmp101_ = NULL;
	ConfigFacade* _tmp102_ = NULL;
	ConfigFacade* _tmp103_ = NULL;
	gboolean _tmp104_ = FALSE;
	GtkCheckButton* commit_metadata_button = NULL;
	GtkBuilder* _tmp105_ = NULL;
	GObject* _tmp106_ = NULL;
	GtkCheckButton* _tmp107_ = NULL;
	ConfigFacade* _tmp108_ = NULL;
	ConfigFacade* _tmp109_ = NULL;
	gboolean _tmp110_ = FALSE;
	GtkBuilder* _tmp111_ = NULL;
	GObject* _tmp112_ = NULL;
	GtkComboBoxText* _tmp113_ = NULL;
	GtkComboBoxText* _tmp114_ = NULL;
	gchar* _tmp115_ = NULL;
	gchar* _tmp116_ = NULL;
	GtkComboBoxText* _tmp117_ = NULL;
	gchar* _tmp118_ = NULL;
	gchar* _tmp119_ = NULL;
	ConfigFacade* _tmp120_ = NULL;
	ConfigFacade* _tmp121_ = NULL;
	RawDeveloper _tmp122_ = 0;
	GtkComboBoxText* _tmp123_ = NULL;
	GtkDialog* _tmp124_ = NULL;
#line 2288 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = (PreferencesDialog*) g_type_create_instance (object_type);
#line 2289 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = app_window_create_builder ("shotwell.ui", NULL);
#line 2289 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->builder);
#line 2289 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->builder = _tmp0_;
#line 2291 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = self->priv->builder;
#line 2291 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = gtk_builder_get_object (_tmp1_, "preferences_dialog");
#line 2291 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp2_, gtk_dialog_get_type ()) ? ((GtkDialog*) _tmp2_) : NULL);
#line 2291 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->dialog);
#line 2291 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->dialog = _tmp3_;
#line 2293 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = gtk_settings_get_default ();
#line 2293 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_get (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, G_TYPE_OBJECT, GObject), "gtk-dialogs-use-header", &use_header, NULL);
#line 2294 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = use_header;
#line 2294 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (!_tmp5_) {
#line 18169 "Dialogs.c"
		GtkWidget* null_titlebar = NULL;
		GtkDialog* _tmp6_ = NULL;
		GtkWidget* _tmp7_ = NULL;
#line 2295 "/home/jens/Source/shotwell/src/Dialogs.vala"
		null_titlebar = NULL;
#line 2296 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp6_ = self->priv->dialog;
#line 2296 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp7_ = null_titlebar;
#line 2296 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_window_set_titlebar (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, gtk_window_get_type (), GtkWindow), _tmp7_);
#line 2294 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (null_titlebar);
#line 18183 "Dialogs.c"
	}
#line 2298 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = self->priv->dialog;
#line 2298 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = app_window_get_instance ();
#line 2298 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp10_ = _tmp9_;
#line 2298 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp11_ = gtk_widget_get_parent_window (G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, gtk_widget_get_type (), GtkWidget));
#line 2298 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_set_parent_window (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, gtk_widget_get_type (), GtkWidget), _tmp11_);
#line 2298 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp10_);
#line 2299 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp12_ = self->priv->dialog;
#line 2299 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp13_ = app_window_get_instance ();
#line 2299 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp14_ = _tmp13_;
#line 2299 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_window_set_transient_for (G_TYPE_CHECK_INSTANCE_CAST (_tmp12_, gtk_window_get_type (), GtkWindow), G_TYPE_CHECK_INSTANCE_CAST (_tmp14_, gtk_window_get_type (), GtkWindow));
#line 2299 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp14_);
#line 2300 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp15_ = self->priv->dialog;
#line 2300 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_connect (G_TYPE_CHECK_INSTANCE_CAST (_tmp15_, gtk_widget_get_type (), GtkWidget), "delete-event", (GCallback) _preferences_dialog_on_delete_gtk_widget_delete_event, self);
#line 2301 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp16_ = self->priv->dialog;
#line 2301 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_connect (_tmp16_, "response", (GCallback) _preferences_dialog_on_close_gtk_dialog_response, self);
#line 2302 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp17_ = self->priv->dialog;
#line 2302 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_window_set_has_resize_grip (G_TYPE_CHECK_INSTANCE_CAST (_tmp17_, gtk_window_get_type (), GtkWindow), FALSE);
#line 2304 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp18_ = self->priv->builder;
#line 2304 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp19_ = gtk_builder_get_object (_tmp18_, "bg_color_adjustment");
#line 2304 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp20_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp19_, gtk_adjustment_get_type ()) ? ((GtkAdjustment*) _tmp19_) : NULL);
#line 2304 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->bg_color_adjustment);
#line 2304 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->bg_color_adjustment = _tmp20_;
#line 2305 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp21_ = self->priv->bg_color_adjustment;
#line 2305 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp22_ = self->priv->bg_color_adjustment;
#line 2305 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp23_ = gtk_adjustment_get_upper (_tmp22_);
#line 2305 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp24_ = config_facade_get_instance ();
#line 2305 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp25_ = _tmp24_;
#line 2305 "/home/jens/Source/shotwell/src/Dialogs.vala"
	config_facade_get_bg_color (_tmp25_, &_tmp26_);
#line 2305 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp27_ = _tmp26_.red;
#line 2305 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_adjustment_set_value (_tmp21_, _tmp23_ - (_tmp27_ * 65535.0));
#line 2305 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp25_);
#line 2307 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp28_ = self->priv->bg_color_adjustment;
#line 2307 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_connect (_tmp28_, "value-changed", (GCallback) _preferences_dialog_on_value_changed_gtk_adjustment_value_changed, self);
#line 2309 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp29_ = self->priv->builder;
#line 2309 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp30_ = gtk_builder_get_object (_tmp29_, "bg_color_slider");
#line 2309 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp31_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp30_, gtk_scale_get_type ()) ? ((GtkScale*) _tmp30_) : NULL);
#line 2309 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->bg_color_slider);
#line 2309 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->bg_color_slider = _tmp31_;
#line 2310 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp32_ = self->priv->bg_color_slider;
#line 2310 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_connect (G_TYPE_CHECK_INSTANCE_CAST (_tmp32_, gtk_widget_get_type (), GtkWidget), "button-press-event", (GCallback) _preferences_dialog_on_bg_color_reset_gtk_widget_button_press_event, self);
#line 2312 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp33_ = self->priv->builder;
#line 2312 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp34_ = gtk_builder_get_object (_tmp33_, "library_dir_button");
#line 2312 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp35_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp34_, gtk_file_chooser_button_get_type ()) ? ((GtkFileChooserButton*) _tmp34_) : NULL);
#line 2312 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->library_dir_button);
#line 2312 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->library_dir_button = _tmp35_;
#line 2314 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp36_ = self->priv->builder;
#line 2314 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp37_ = gtk_builder_get_object (_tmp36_, "external_photo_editor_combo");
#line 2314 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp38_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp37_, gtk_combo_box_get_type ()) ? ((GtkComboBox*) _tmp37_) : NULL);
#line 2314 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->photo_editor_combo);
#line 2314 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->photo_editor_combo = _tmp38_;
#line 2315 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp39_ = self->priv->builder;
#line 2315 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp40_ = gtk_builder_get_object (_tmp39_, "external_raw_editor_combo");
#line 2315 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp41_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp40_, gtk_combo_box_get_type ()) ? ((GtkComboBox*) _tmp40_) : NULL);
#line 2315 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->raw_editor_combo);
#line 2315 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->raw_editor_combo = _tmp41_;
#line 2317 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp42_ = self->priv->builder;
#line 2317 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp43_ = gtk_builder_get_object (_tmp42_, "pattern_help");
#line 2317 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp44_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp43_, gtk_label_get_type ()) ? ((GtkLabel*) _tmp43_) : NULL);
#line 2317 "/home/jens/Source/shotwell/src/Dialogs.vala"
	pattern_help = _tmp44_;
#line 2324 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp45_ = resources_get_help_path ();
#line 2324 "/home/jens/Source/shotwell/src/Dialogs.vala"
	help_path = _tmp45_;
#line 2326 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp46_ = help_path;
#line 2326 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp46_ == NULL) {
#line 18311 "Dialogs.c"
		GtkLabel* _tmp47_ = NULL;
		const gchar* _tmp48_ = NULL;
		gchar* _tmp49_ = NULL;
		gchar* _tmp50_ = NULL;
		gchar* _tmp51_ = NULL;
		gchar* _tmp52_ = NULL;
#line 2328 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp47_ = pattern_help;
#line 2328 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp48_ = _ ("(Help)");
#line 2328 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp49_ = g_strconcat ("<a href=\"" RESOURCES_DIR_PATTERN_URI_SYSWIDE "\">", _tmp48_, NULL);
#line 2328 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp50_ = _tmp49_;
#line 2328 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp51_ = g_strconcat (_tmp50_, "</a>", NULL);
#line 2328 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp52_ = _tmp51_;
#line 2328 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_label_set_markup (_tmp47_, _tmp52_);
#line 2328 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp52_);
#line 2328 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp50_);
#line 18336 "Dialogs.c"
	} else {
		GtkLabel* _tmp53_ = NULL;
		const gchar* _tmp54_ = NULL;
		gchar* _tmp55_ = NULL;
		gchar* _tmp56_ = NULL;
		gchar* _tmp57_ = NULL;
		gchar* _tmp58_ = NULL;
		GtkLabel* _tmp59_ = NULL;
#line 2332 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp53_ = pattern_help;
#line 2332 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp54_ = _ ("(Help)");
#line 2332 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp55_ = g_strconcat ("<a href=\"dummy:\">", _tmp54_, NULL);
#line 2332 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp56_ = _tmp55_;
#line 2332 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp57_ = g_strconcat (_tmp56_, "</a>", NULL);
#line 2332 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp58_ = _tmp57_;
#line 2332 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_label_set_markup (_tmp53_, _tmp58_);
#line 2332 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp58_);
#line 2332 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp56_);
#line 2333 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp59_ = pattern_help;
#line 2333 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_signal_connect (_tmp59_, "activate-link", (GCallback) _preferences_dialog_on_local_pattern_help_gtk_label_activate_link, self);
#line 18367 "Dialogs.c"
	}
#line 2336 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp60_ = (GtkComboBoxText*) gtk_combo_box_text_new ();
#line 2336 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp60_);
#line 2336 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->dir_pattern_combo);
#line 2336 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->dir_pattern_combo = _tmp60_;
#line 2337 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp61_ = self->priv->builder;
#line 2337 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp62_ = gtk_builder_get_object (_tmp61_, "dir choser");
#line 2337 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp63_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp62_, gtk_alignment_get_type ()) ? ((GtkAlignment*) _tmp62_) : NULL);
#line 2337 "/home/jens/Source/shotwell/src/Dialogs.vala"
	dir_choser_align = _tmp63_;
#line 2338 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp64_ = self->priv->dir_pattern_combo;
#line 2338 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_container_add (G_TYPE_CHECK_INSTANCE_CAST (dir_choser_align, gtk_container_get_type (), GtkContainer), G_TYPE_CHECK_INSTANCE_CAST (_tmp64_, gtk_widget_get_type (), GtkWidget));
#line 2339 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp65_ = self->priv->builder;
#line 2339 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp66_ = gtk_builder_get_object (_tmp65_, "dir_pattern_entry");
#line 2339 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp67_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp66_, gtk_entry_get_type ()) ? ((GtkEntry*) _tmp66_) : NULL);
#line 2339 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->dir_pattern_entry);
#line 2339 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->dir_pattern_entry = _tmp67_;
#line 2340 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp68_ = self->priv->builder;
#line 2340 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp69_ = gtk_builder_get_object (_tmp68_, "dynamic example");
#line 2340 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp70_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp69_, gtk_label_get_type ()) ? ((GtkLabel*) _tmp69_) : NULL);
#line 2340 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->dir_pattern_example);
#line 2340 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->dir_pattern_example = _tmp70_;
#line 2341 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp71_ = _ ("Year%sMonth%sDay");
#line 2341 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp72_ = g_strdup_printf (_tmp71_, G_DIR_SEPARATOR_S, G_DIR_SEPARATOR_S);
#line 2341 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp73_ = _tmp72_;
#line 2341 "/home/jens/Source/shotwell/src/Dialogs.vala"
	preferences_dialog_add_to_dir_formats (self, _tmp73_, "%Y" G_DIR_SEPARATOR_S "%m" G_DIR_SEPARATOR_S "%d");
#line 2341 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp73_);
#line 2343 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp74_ = _ ("Year%sMonth");
#line 2343 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp75_ = g_strdup_printf (_tmp74_, G_DIR_SEPARATOR_S);
#line 2343 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp76_ = _tmp75_;
#line 2343 "/home/jens/Source/shotwell/src/Dialogs.vala"
	preferences_dialog_add_to_dir_formats (self, _tmp76_, "%Y" G_DIR_SEPARATOR_S "%m");
#line 2343 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp76_);
#line 2345 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp77_ = _ ("Year%sMonth-Day");
#line 2345 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp78_ = g_strdup_printf (_tmp77_, G_DIR_SEPARATOR_S);
#line 2345 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp79_ = _tmp78_;
#line 2345 "/home/jens/Source/shotwell/src/Dialogs.vala"
	preferences_dialog_add_to_dir_formats (self, _tmp79_, "%Y" G_DIR_SEPARATOR_S "%m-%d");
#line 2345 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp79_);
#line 2347 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp80_ = _ ("Year-Month-Day");
#line 2347 "/home/jens/Source/shotwell/src/Dialogs.vala"
	preferences_dialog_add_to_dir_formats (self, _tmp80_, "%Y-%m-%d");
#line 2348 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp81_ = _ ("Custom");
#line 2348 "/home/jens/Source/shotwell/src/Dialogs.vala"
	preferences_dialog_add_to_dir_formats (self, _tmp81_, NULL);
#line 2349 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp82_ = self->priv->dir_pattern_combo;
#line 2349 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_connect (G_TYPE_CHECK_INSTANCE_CAST (_tmp82_, gtk_combo_box_get_type (), GtkComboBox), "changed", (GCallback) _preferences_dialog_on_dir_pattern_combo_changed_gtk_combo_box_changed, self);
#line 2350 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp83_ = self->priv->dir_pattern_entry;
#line 2350 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_connect (G_TYPE_CHECK_INSTANCE_CAST (_tmp83_, GTK_TYPE_EDITABLE, GtkEditable), "changed", (GCallback) _preferences_dialog_on_dir_pattern_entry_changed_gtk_editable_changed, self);
#line 2352 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp84_ = self->priv->builder;
#line 2352 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp85_ = gtk_builder_get_object (_tmp84_, "dir_structure_label");
#line 2352 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp86_ = self->priv->dir_pattern_combo;
#line 2352 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_label_set_mnemonic_widget (G_TYPE_CHECK_INSTANCE_TYPE (_tmp85_, gtk_label_get_type ()) ? ((GtkLabel*) _tmp85_) : NULL, G_TYPE_CHECK_INSTANCE_CAST (_tmp86_, gtk_widget_get_type (), GtkWidget));
#line 2354 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp87_ = self->priv->builder;
#line 2354 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp88_ = gtk_builder_get_object (_tmp87_, "lowercase");
#line 2354 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp89_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp88_, gtk_check_button_get_type ()) ? ((GtkCheckButton*) _tmp88_) : NULL);
#line 2354 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->lowercase);
#line 2354 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->lowercase = _tmp89_;
#line 2355 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp90_ = self->priv->lowercase;
#line 2355 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_connect (G_TYPE_CHECK_INSTANCE_CAST (_tmp90_, gtk_toggle_button_get_type (), GtkToggleButton), "toggled", (GCallback) _preferences_dialog_on_lowercase_toggled_gtk_toggle_button_toggled, self);
#line 2357 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp91_ = self->priv->builder;
#line 2357 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp92_ = gtk_builder_get_object (_tmp91_, "plugin-manifest-bin");
#line 2357 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp93_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp92_, gtk_bin_get_type ()) ? ((GtkBin*) _tmp92_) : NULL);
#line 2357 "/home/jens/Source/shotwell/src/Dialogs.vala"
	plugin_manifest_container = _tmp93_;
#line 2358 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp94_ = self->priv->plugins_mediator;
#line 2358 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp95_ = plugins_manifest_widget_mediator_get_widget (_tmp94_);
#line 2358 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp96_ = _tmp95_;
#line 2358 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_container_add (G_TYPE_CHECK_INSTANCE_CAST (plugin_manifest_container, gtk_container_get_type (), GtkContainer), _tmp96_);
#line 2360 "/home/jens/Source/shotwell/src/Dialogs.vala"
	preferences_dialog_populate_preference_options (self);
#line 2362 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp97_ = self->priv->photo_editor_combo;
#line 2362 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_connect (_tmp97_, "changed", (GCallback) _preferences_dialog_on_photo_editor_changed_gtk_combo_box_changed, self);
#line 2363 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp98_ = self->priv->raw_editor_combo;
#line 2363 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_connect (_tmp98_, "changed", (GCallback) _preferences_dialog_on_raw_editor_changed_gtk_combo_box_changed, self);
#line 2365 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp99_ = self->priv->builder;
#line 2365 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp100_ = gtk_builder_get_object (_tmp99_, "autoimport");
#line 2365 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp101_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp100_, gtk_check_button_get_type ()) ? ((GtkCheckButton*) _tmp100_) : NULL);
#line 2365 "/home/jens/Source/shotwell/src/Dialogs.vala"
	auto_import_button = _tmp101_;
#line 2366 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp102_ = config_facade_get_instance ();
#line 2366 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp103_ = _tmp102_;
#line 2366 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp104_ = configuration_facade_get_auto_import_from_library (G_TYPE_CHECK_INSTANCE_CAST (_tmp103_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade));
#line 2366 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_toggle_button_set_active (G_TYPE_CHECK_INSTANCE_CAST (auto_import_button, gtk_toggle_button_get_type (), GtkToggleButton), _tmp104_);
#line 2366 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp103_);
#line 2368 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp105_ = self->priv->builder;
#line 2368 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp106_ = gtk_builder_get_object (_tmp105_, "write_metadata");
#line 2368 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp107_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp106_, gtk_check_button_get_type ()) ? ((GtkCheckButton*) _tmp106_) : NULL);
#line 2368 "/home/jens/Source/shotwell/src/Dialogs.vala"
	commit_metadata_button = _tmp107_;
#line 2369 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp108_ = config_facade_get_instance ();
#line 2369 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp109_ = _tmp108_;
#line 2369 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp110_ = configuration_facade_get_commit_metadata_to_masters (G_TYPE_CHECK_INSTANCE_CAST (_tmp109_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade));
#line 2369 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_toggle_button_set_active (G_TYPE_CHECK_INSTANCE_CAST (commit_metadata_button, gtk_toggle_button_get_type (), GtkToggleButton), _tmp110_);
#line 2369 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp109_);
#line 2371 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp111_ = self->priv->builder;
#line 2371 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp112_ = gtk_builder_get_object (_tmp111_, "default_raw_developer");
#line 2371 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp113_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp112_, gtk_combo_box_text_get_type ()) ? ((GtkComboBoxText*) _tmp112_) : NULL);
#line 2371 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->default_raw_developer_combo);
#line 2371 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->default_raw_developer_combo = _tmp113_;
#line 2372 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp114_ = self->priv->default_raw_developer_combo;
#line 2372 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp115_ = raw_developer_get_label (RAW_DEVELOPER_CAMERA);
#line 2372 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp116_ = _tmp115_;
#line 2372 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_combo_box_text_append_text (_tmp114_, _tmp116_);
#line 2372 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp116_);
#line 2373 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp117_ = self->priv->default_raw_developer_combo;
#line 2373 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp118_ = raw_developer_get_label (RAW_DEVELOPER_SHOTWELL);
#line 2373 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp119_ = _tmp118_;
#line 2373 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_combo_box_text_append_text (_tmp117_, _tmp119_);
#line 2373 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp119_);
#line 2374 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp120_ = config_facade_get_instance ();
#line 2374 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp121_ = _tmp120_;
#line 2374 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp122_ = configuration_facade_get_default_raw_developer (G_TYPE_CHECK_INSTANCE_CAST (_tmp121_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade));
#line 2374 "/home/jens/Source/shotwell/src/Dialogs.vala"
	preferences_dialog_set_raw_developer_combo (self, _tmp122_);
#line 2374 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp121_);
#line 2375 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp123_ = self->priv->default_raw_developer_combo;
#line 2375 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_connect (G_TYPE_CHECK_INSTANCE_CAST (_tmp123_, gtk_combo_box_get_type (), GtkComboBox), "changed", (GCallback) _preferences_dialog_on_default_raw_developer_changed_gtk_combo_box_changed, self);
#line 2377 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp124_ = self->priv->dialog;
#line 2377 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_connect (G_TYPE_CHECK_INSTANCE_CAST (_tmp124_, gtk_widget_get_type (), GtkWidget), "map-event", (GCallback) _preferences_dialog_map_event_gtk_widget_map_event, self);
#line 2288 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (commit_metadata_button);
#line 2288 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (auto_import_button);
#line 2288 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (plugin_manifest_container);
#line 2288 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (dir_choser_align);
#line 2288 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (help_path);
#line 2288 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (pattern_help);
#line 2288 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return self;
#line 18601 "Dialogs.c"
}


static PreferencesDialog* preferences_dialog_new (void) {
#line 2288 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return preferences_dialog_construct (TYPE_PREFERENCES_DIALOG);
#line 18608 "Dialogs.c"
}


void preferences_dialog_populate_preference_options (PreferencesDialog* self) {
	GtkComboBox* _tmp0_ = NULL;
	gint _tmp1_ = 0;
	gchar** _tmp2_ = NULL;
	gchar** _tmp3_ = NULL;
	gint _tmp3__length1 = 0;
	ConfigFacade* _tmp4_ = NULL;
	ConfigFacade* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
	SortedList* _tmp8_ = NULL;
	GtkComboBox* _tmp9_ = NULL;
	gint _tmp10_ = 0;
	gchar** _tmp11_ = NULL;
	gchar** _tmp12_ = NULL;
	gint _tmp12__length1 = 0;
	ConfigFacade* _tmp13_ = NULL;
	ConfigFacade* _tmp14_ = NULL;
	gchar* _tmp15_ = NULL;
	gchar* _tmp16_ = NULL;
	SortedList* _tmp17_ = NULL;
	GtkComboBoxText* _tmp18_ = NULL;
	GtkEntry* _tmp19_ = NULL;
	GtkCheckButton* _tmp20_ = NULL;
	ConfigFacade* _tmp21_ = NULL;
	ConfigFacade* _tmp22_ = NULL;
	gboolean _tmp23_ = FALSE;
#line 2380 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_PREFERENCES_DIALOG (self));
#line 2381 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = self->priv->photo_editor_combo;
#line 2381 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = photo_file_format_get_editable_mime_types (&_tmp1_);
#line 2381 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = _tmp2_;
#line 2381 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3__length1 = _tmp1_;
#line 2381 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = config_facade_get_instance ();
#line 2381 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = _tmp4_;
#line 2381 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = configuration_facade_get_external_photo_app (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade));
#line 2381 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = _tmp6_;
#line 2381 "/home/jens/Source/shotwell/src/Dialogs.vala"
	preferences_dialog_populate_app_combo_box (self, _tmp0_, _tmp3_, _tmp1_, _tmp7_, &_tmp8_);
#line 2381 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->external_photo_apps);
#line 2381 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->external_photo_apps = _tmp8_;
#line 2381 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp7_);
#line 2381 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp5_);
#line 2381 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = (_vala_array_free (_tmp3_, _tmp3__length1, (GDestroyNotify) g_free), NULL);
#line 2384 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = self->priv->raw_editor_combo;
#line 2384 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp11_ = photo_file_format_get_mime_types (PHOTO_FILE_FORMAT_RAW, &_tmp10_);
#line 2384 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp12_ = _tmp11_;
#line 2384 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp12__length1 = _tmp10_;
#line 2384 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp13_ = config_facade_get_instance ();
#line 2384 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp14_ = _tmp13_;
#line 2384 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp15_ = configuration_facade_get_external_raw_app (G_TYPE_CHECK_INSTANCE_CAST (_tmp14_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade));
#line 2384 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp16_ = _tmp15_;
#line 2384 "/home/jens/Source/shotwell/src/Dialogs.vala"
	preferences_dialog_populate_app_combo_box (self, _tmp9_, _tmp12_, _tmp10_, _tmp16_, &_tmp17_);
#line 2384 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->external_raw_apps);
#line 2384 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->external_raw_apps = _tmp17_;
#line 2384 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp16_);
#line 2384 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp14_);
#line 2384 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp12_ = (_vala_array_free (_tmp12_, _tmp12__length1, (GDestroyNotify) g_free), NULL);
#line 2387 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp18_ = self->priv->dir_pattern_combo;
#line 2387 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp19_ = self->priv->dir_pattern_entry;
#line 2387 "/home/jens/Source/shotwell/src/Dialogs.vala"
	preferences_dialog_setup_dir_pattern (self, G_TYPE_CHECK_INSTANCE_CAST (_tmp18_, gtk_combo_box_get_type (), GtkComboBox), _tmp19_);
#line 2389 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp20_ = self->priv->lowercase;
#line 2389 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp21_ = config_facade_get_instance ();
#line 2389 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp22_ = _tmp21_;
#line 2389 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp23_ = configuration_facade_get_use_lowercase_filenames (G_TYPE_CHECK_INSTANCE_CAST (_tmp22_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade));
#line 2389 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_toggle_button_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp20_, gtk_toggle_button_get_type (), GtkToggleButton), _tmp23_);
#line 2389 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp22_);
#line 18715 "Dialogs.c"
}


static gboolean preferences_dialog_on_local_pattern_help (PreferencesDialog* self, const gchar* ignore) {
	gboolean result = FALSE;
	GError * _inner_error_ = NULL;
#line 2394 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_PREFERENCES_DIALOG (self), FALSE);
#line 2394 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (ignore != NULL, FALSE);
#line 18726 "Dialogs.c"
	{
		AppWindow* _tmp0_ = NULL;
		AppWindow* _tmp1_ = NULL;
		GdkScreen* _tmp2_ = NULL;
#line 2396 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = app_window_get_instance ();
#line 2396 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp1_ = _tmp0_;
#line 2396 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp2_ = gtk_window_get_screen (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, gtk_window_get_type (), GtkWindow));
#line 2396 "/home/jens/Source/shotwell/src/Dialogs.vala"
		resources_launch_help (_tmp2_, "other-files.page", &_inner_error_);
#line 2396 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (_tmp1_);
#line 2396 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 18743 "Dialogs.c"
			goto __catch414_g_error;
		}
	}
	goto __finally414;
	__catch414_g_error:
	{
		GError* e = NULL;
		GError* _tmp3_ = NULL;
		const gchar* _tmp4_ = NULL;
#line 2395 "/home/jens/Source/shotwell/src/Dialogs.vala"
		e = _inner_error_;
#line 2395 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_inner_error_ = NULL;
#line 2398 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp3_ = e;
#line 2398 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp4_ = _tmp3_->message;
#line 2398 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_message ("Dialogs.vala:2398: Unable to launch help: %s", _tmp4_);
#line 2395 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_error_free0 (e);
#line 18765 "Dialogs.c"
	}
	__finally414:
#line 2395 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2395 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 2395 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_clear_error (&_inner_error_);
#line 2395 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return FALSE;
#line 18776 "Dialogs.c"
	}
#line 2400 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = TRUE;
#line 2400 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 18782 "Dialogs.c"
}


static void preferences_dialog_populate_app_combo_box (PreferencesDialog* self, GtkComboBox* combo_box, gchar** mime_types, int mime_types_length1, const gchar* current_app_executable, SortedList** external_apps) {
	SortedList* _vala_external_apps = NULL;
	gchar** _tmp0_ = NULL;
	gint _tmp0__length1 = 0;
	gchar** _tmp1_ = NULL;
	gint _tmp1__length1 = 0;
	SortedList* _tmp2_ = NULL;
	SortedList* _tmp3_ = NULL;
	gint _tmp4_ = 0;
	gint _tmp5_ = 0;
	GtkCellRendererPixbuf* pixbuf_renderer = NULL;
	GtkCellRendererPixbuf* _tmp6_ = NULL;
	GtkCellRendererText* text_renderer = NULL;
	GtkCellRendererText* _tmp7_ = NULL;
	GtkComboBox* _tmp8_ = NULL;
	GtkComboBox* _tmp9_ = NULL;
	GtkCellRendererPixbuf* _tmp10_ = NULL;
	GtkComboBox* _tmp11_ = NULL;
	GtkCellRendererText* _tmp12_ = NULL;
	GtkComboBox* _tmp13_ = NULL;
	GtkCellRendererPixbuf* _tmp14_ = NULL;
	GtkComboBox* _tmp15_ = NULL;
	GtkCellRendererText* _tmp16_ = NULL;
	GtkListStore* combo_store = NULL;
	GtkListStore* _tmp17_ = NULL;
	GtkTreeIter iter = {0};
	gint current_app = 0;
	GtkComboBox* _tmp67_ = NULL;
	GtkListStore* _tmp68_ = NULL;
	gint _tmp69_ = 0;
	GError * _inner_error_ = NULL;
#line 2403 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_PREFERENCES_DIALOG (self));
#line 2403 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (GTK_IS_COMBO_BOX (combo_box));
#line 2403 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (current_app_executable != NULL);
#line 2406 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = mime_types;
#line 2406 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0__length1 = mime_types_length1;
#line 2406 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_vala_assert (_tmp0__length1 != 0, "mime_types.length != 0");
#line 2407 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = mime_types;
#line 2407 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1__length1 = mime_types_length1;
#line 2407 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = desktop_integration_get_apps_for_mime_types (_tmp1_, _tmp1__length1);
#line 2407 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_vala_external_apps);
#line 2407 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_vala_external_apps = _tmp2_;
#line 2409 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = _vala_external_apps;
#line 2409 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, GEE_TYPE_COLLECTION, GeeCollection));
#line 2409 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = _tmp4_;
#line 2409 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp5_ == 0) {
#line 2410 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (external_apps) {
#line 2410 "/home/jens/Source/shotwell/src/Dialogs.vala"
			*external_apps = _vala_external_apps;
#line 18851 "Dialogs.c"
		} else {
#line 2410 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_object_unref0 (_vala_external_apps);
#line 18855 "Dialogs.c"
		}
#line 2410 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return;
#line 18859 "Dialogs.c"
	}
#line 2413 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = (GtkCellRendererPixbuf*) gtk_cell_renderer_pixbuf_new ();
#line 2413 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp6_);
#line 2413 "/home/jens/Source/shotwell/src/Dialogs.vala"
	pixbuf_renderer = _tmp6_;
#line 2414 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = (GtkCellRendererText*) gtk_cell_renderer_text_new ();
#line 2414 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp7_);
#line 2414 "/home/jens/Source/shotwell/src/Dialogs.vala"
	text_renderer = _tmp7_;
#line 2415 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = combo_box;
#line 2415 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_cell_layout_clear (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, GTK_TYPE_CELL_LAYOUT, GtkCellLayout));
#line 2416 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = combo_box;
#line 2416 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp10_ = pixbuf_renderer;
#line 2416 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_cell_layout_pack_start (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, GTK_TYPE_CELL_LAYOUT, GtkCellLayout), G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, gtk_cell_renderer_get_type (), GtkCellRenderer), FALSE);
#line 2417 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp11_ = combo_box;
#line 2417 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp12_ = text_renderer;
#line 2417 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_cell_layout_pack_start (G_TYPE_CHECK_INSTANCE_CAST (_tmp11_, GTK_TYPE_CELL_LAYOUT, GtkCellLayout), G_TYPE_CHECK_INSTANCE_CAST (_tmp12_, gtk_cell_renderer_get_type (), GtkCellRenderer), FALSE);
#line 2418 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp13_ = combo_box;
#line 2418 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp14_ = pixbuf_renderer;
#line 2418 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_cell_layout_add_attribute (G_TYPE_CHECK_INSTANCE_CAST (_tmp13_, GTK_TYPE_CELL_LAYOUT, GtkCellLayout), G_TYPE_CHECK_INSTANCE_CAST (_tmp14_, gtk_cell_renderer_get_type (), GtkCellRenderer), "pixbuf", 0);
#line 2419 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp15_ = combo_box;
#line 2419 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp16_ = text_renderer;
#line 2419 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_cell_layout_add_attribute (G_TYPE_CHECK_INSTANCE_CAST (_tmp15_, GTK_TYPE_CELL_LAYOUT, GtkCellLayout), G_TYPE_CHECK_INSTANCE_CAST (_tmp16_, gtk_cell_renderer_get_type (), GtkCellRenderer), "text", 1);
#line 2422 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp17_ = gtk_list_store_new (2, GDK_TYPE_PIXBUF, G_TYPE_STRING, -1);
#line 2422 "/home/jens/Source/shotwell/src/Dialogs.vala"
	combo_store = _tmp17_;
#line 2425 "/home/jens/Source/shotwell/src/Dialogs.vala"
	current_app = -1;
#line 18907 "Dialogs.c"
	{
		GeeIterator* _app_it = NULL;
		SortedList* _tmp18_ = NULL;
		GeeIterator* _tmp19_ = NULL;
#line 2427 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp18_ = _vala_external_apps;
#line 2427 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp19_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp18_, GEE_TYPE_ITERABLE, GeeIterable));
#line 2427 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_app_it = _tmp19_;
#line 2427 "/home/jens/Source/shotwell/src/Dialogs.vala"
		while (TRUE) {
#line 18920 "Dialogs.c"
			GeeIterator* _tmp20_ = NULL;
			gboolean _tmp21_ = FALSE;
			GAppInfo* app = NULL;
			GeeIterator* _tmp22_ = NULL;
			gpointer _tmp23_ = NULL;
			GtkListStore* _tmp24_ = NULL;
			GtkTreeIter _tmp25_ = {0};
			GIcon* app_icon = NULL;
			GAppInfo* _tmp26_ = NULL;
			GIcon* _tmp27_ = NULL;
			GIcon* _tmp28_ = NULL;
			GtkListStore* _tmp56_ = NULL;
			GtkTreeIter _tmp57_ = {0};
			GAppInfo* _tmp58_ = NULL;
			const gchar* _tmp59_ = NULL;
			GValue _tmp60_ = {0};
			GAppInfo* _tmp61_ = NULL;
			const gchar* _tmp62_ = NULL;
			const gchar* _tmp63_ = NULL;
#line 2427 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp20_ = _app_it;
#line 2427 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp21_ = gee_iterator_next (_tmp20_);
#line 2427 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (!_tmp21_) {
#line 2427 "/home/jens/Source/shotwell/src/Dialogs.vala"
				break;
#line 18948 "Dialogs.c"
			}
#line 2427 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp22_ = _app_it;
#line 2427 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp23_ = gee_iterator_get (_tmp22_);
#line 2427 "/home/jens/Source/shotwell/src/Dialogs.vala"
			app = (GAppInfo*) _tmp23_;
#line 2428 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp24_ = combo_store;
#line 2428 "/home/jens/Source/shotwell/src/Dialogs.vala"
			gtk_list_store_append (_tmp24_, &_tmp25_);
#line 2428 "/home/jens/Source/shotwell/src/Dialogs.vala"
			iter = _tmp25_;
#line 2430 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp26_ = app;
#line 2430 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp27_ = g_app_info_get_icon (_tmp26_);
#line 2430 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp28_ = _g_object_ref0 (_tmp27_);
#line 2430 "/home/jens/Source/shotwell/src/Dialogs.vala"
			app_icon = _tmp28_;
#line 18970 "Dialogs.c"
			{
				GIcon* _tmp29_ = NULL;
#line 2432 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp29_ = app_icon;
#line 2432 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp29_, g_file_icon_get_type ())) {
#line 18977 "Dialogs.c"
					GdkPixbuf* _tmp30_ = NULL;
					GIcon* _tmp31_ = NULL;
					GFile* _tmp32_ = NULL;
					gchar* _tmp33_ = NULL;
					gchar* _tmp34_ = NULL;
					GdkPixbuf* _tmp35_ = NULL;
					GdkPixbuf* _tmp36_ = NULL;
					GtkListStore* _tmp37_ = NULL;
					GtkTreeIter _tmp38_ = {0};
					GdkPixbuf* _tmp39_ = NULL;
					GValue _tmp40_ = {0};
#line 2433 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp31_ = app_icon;
#line 2433 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp32_ = g_file_icon_get_file (G_TYPE_CHECK_INSTANCE_CAST (_tmp31_, g_file_icon_get_type (), GFileIcon));
#line 2433 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp33_ = g_file_get_path (_tmp32_);
#line 2433 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp34_ = _tmp33_;
#line 2433 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp35_ = gdk_pixbuf_new_from_file (_tmp34_, &_inner_error_);
#line 2433 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp36_ = _tmp35_;
#line 2433 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_g_free0 (_tmp34_);
#line 2433 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp30_ = _tmp36_;
#line 2433 "/home/jens/Source/shotwell/src/Dialogs.vala"
					if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 19007 "Dialogs.c"
						goto __catch415_g_error;
					}
#line 2433 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp37_ = combo_store;
#line 2433 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp38_ = iter;
#line 2433 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp39_ = scale_pixbuf (_tmp30_, RESOURCES_DEFAULT_ICON_SCALE, GDK_INTERP_BILINEAR, FALSE);
#line 2433 "/home/jens/Source/shotwell/src/Dialogs.vala"
					g_value_init (&_tmp40_, GDK_TYPE_PIXBUF);
#line 2433 "/home/jens/Source/shotwell/src/Dialogs.vala"
					g_value_take_object (&_tmp40_, _tmp39_);
#line 2433 "/home/jens/Source/shotwell/src/Dialogs.vala"
					gtk_list_store_set_value (_tmp37_, &_tmp38_, 0, &_tmp40_);
#line 2433 "/home/jens/Source/shotwell/src/Dialogs.vala"
					G_IS_VALUE (&_tmp40_) ? (g_value_unset (&_tmp40_), NULL) : NULL;
#line 2432 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_g_object_unref0 (_tmp30_);
#line 19026 "Dialogs.c"
				} else {
					GIcon* _tmp41_ = NULL;
#line 2436 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp41_ = app_icon;
#line 2436 "/home/jens/Source/shotwell/src/Dialogs.vala"
					if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp41_, g_themed_icon_get_type ())) {
#line 19033 "Dialogs.c"
						GdkPixbuf* icon_pixbuf = NULL;
						GtkIconTheme* _tmp42_ = NULL;
						GIcon* _tmp43_ = NULL;
						gchar** _tmp44_ = NULL;
						gchar** _tmp45_ = NULL;
						const gchar* _tmp46_ = NULL;
						GdkPixbuf* _tmp47_ = NULL;
						GtkListStore* _tmp48_ = NULL;
						GtkTreeIter _tmp49_ = {0};
						GdkPixbuf* _tmp50_ = NULL;
						GValue _tmp51_ = {0};
#line 2437 "/home/jens/Source/shotwell/src/Dialogs.vala"
						_tmp42_ = gtk_icon_theme_get_default ();
#line 2437 "/home/jens/Source/shotwell/src/Dialogs.vala"
						_tmp43_ = app_icon;
#line 2437 "/home/jens/Source/shotwell/src/Dialogs.vala"
						_tmp45_ = _tmp44_ = g_themed_icon_get_names (G_TYPE_CHECK_INSTANCE_CAST (_tmp43_, g_themed_icon_get_type (), GThemedIcon));
#line 2437 "/home/jens/Source/shotwell/src/Dialogs.vala"
						_tmp46_ = _tmp45_[0];
#line 2437 "/home/jens/Source/shotwell/src/Dialogs.vala"
						_tmp47_ = gtk_icon_theme_load_icon (_tmp42_, _tmp46_, RESOURCES_DEFAULT_ICON_SCALE, GTK_ICON_LOOKUP_FORCE_SIZE, &_inner_error_);
#line 2437 "/home/jens/Source/shotwell/src/Dialogs.vala"
						icon_pixbuf = _tmp47_;
#line 2437 "/home/jens/Source/shotwell/src/Dialogs.vala"
						if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 19059 "Dialogs.c"
							goto __catch415_g_error;
						}
#line 2441 "/home/jens/Source/shotwell/src/Dialogs.vala"
						_tmp48_ = combo_store;
#line 2441 "/home/jens/Source/shotwell/src/Dialogs.vala"
						_tmp49_ = iter;
#line 2441 "/home/jens/Source/shotwell/src/Dialogs.vala"
						_tmp50_ = icon_pixbuf;
#line 2441 "/home/jens/Source/shotwell/src/Dialogs.vala"
						g_value_init (&_tmp51_, GDK_TYPE_PIXBUF);
#line 2441 "/home/jens/Source/shotwell/src/Dialogs.vala"
						g_value_set_object (&_tmp51_, _tmp50_);
#line 2441 "/home/jens/Source/shotwell/src/Dialogs.vala"
						gtk_list_store_set_value (_tmp48_, &_tmp49_, 0, &_tmp51_);
#line 2441 "/home/jens/Source/shotwell/src/Dialogs.vala"
						G_IS_VALUE (&_tmp51_) ? (g_value_unset (&_tmp51_), NULL) : NULL;
#line 2436 "/home/jens/Source/shotwell/src/Dialogs.vala"
						_g_object_unref0 (icon_pixbuf);
#line 19078 "Dialogs.c"
					}
				}
			}
			goto __finally415;
			__catch415_g_error:
			{
				GError* _error_ = NULL;
				GError* _tmp52_ = NULL;
				const gchar* _tmp53_ = NULL;
				gchar* _tmp54_ = NULL;
				gchar* _tmp55_ = NULL;
#line 2431 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_error_ = _inner_error_;
#line 2431 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_inner_error_ = NULL;
#line 2444 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp52_ = _error_;
#line 2444 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp53_ = _tmp52_->message;
#line 2444 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp54_ = g_strconcat ("Error loading icon pixbuf: ", _tmp53_, NULL);
#line 2444 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp55_ = _tmp54_;
#line 2444 "/home/jens/Source/shotwell/src/Dialogs.vala"
				g_warning ("Dialogs.vala:2444: %s", _tmp55_);
#line 2444 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp55_);
#line 2431 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_error_free0 (_error_);
#line 19108 "Dialogs.c"
			}
			__finally415:
#line 2431 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2431 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_object_unref0 (app_icon);
#line 2431 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_object_unref0 (app);
#line 2431 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_object_unref0 (_app_it);
#line 2431 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_object_unref0 (combo_store);
#line 2431 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_object_unref0 (text_renderer);
#line 2431 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_object_unref0 (pixbuf_renderer);
#line 2431 "/home/jens/Source/shotwell/src/Dialogs.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 2431 "/home/jens/Source/shotwell/src/Dialogs.vala"
				g_clear_error (&_inner_error_);
#line 2431 "/home/jens/Source/shotwell/src/Dialogs.vala"
				return;
#line 19131 "Dialogs.c"
			}
#line 2447 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp56_ = combo_store;
#line 2447 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp57_ = iter;
#line 2447 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp58_ = app;
#line 2447 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp59_ = g_app_info_get_name (_tmp58_);
#line 2447 "/home/jens/Source/shotwell/src/Dialogs.vala"
			g_value_init (&_tmp60_, G_TYPE_STRING);
#line 2447 "/home/jens/Source/shotwell/src/Dialogs.vala"
			g_value_set_string (&_tmp60_, _tmp59_);
#line 2447 "/home/jens/Source/shotwell/src/Dialogs.vala"
			gtk_list_store_set_value (_tmp56_, &_tmp57_, 1, &_tmp60_);
#line 2447 "/home/jens/Source/shotwell/src/Dialogs.vala"
			G_IS_VALUE (&_tmp60_) ? (g_value_unset (&_tmp60_), NULL) : NULL;
#line 2449 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp61_ = app;
#line 2449 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp62_ = g_app_info_get_commandline (_tmp61_);
#line 2449 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp63_ = current_app_executable;
#line 2449 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (g_strcmp0 (_tmp62_, _tmp63_) == 0) {
#line 19157 "Dialogs.c"
				SortedList* _tmp64_ = NULL;
				GAppInfo* _tmp65_ = NULL;
				gint _tmp66_ = 0;
#line 2450 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp64_ = _vala_external_apps;
#line 2450 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp65_ = app;
#line 2450 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp66_ = sorted_list_index_of (_tmp64_, _tmp65_);
#line 2450 "/home/jens/Source/shotwell/src/Dialogs.vala"
				current_app = _tmp66_;
#line 19169 "Dialogs.c"
			}
#line 2427 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_object_unref0 (app_icon);
#line 2427 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_object_unref0 (app);
#line 19175 "Dialogs.c"
		}
#line 2427 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (_app_it);
#line 19179 "Dialogs.c"
	}
#line 2455 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp67_ = combo_box;
#line 2455 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp68_ = combo_store;
#line 2455 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_combo_box_set_model (_tmp67_, G_TYPE_CHECK_INSTANCE_CAST (_tmp68_, GTK_TYPE_TREE_MODEL, GtkTreeModel));
#line 2457 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp69_ = current_app;
#line 2457 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp69_ != -1) {
#line 19191 "Dialogs.c"
		GtkComboBox* _tmp70_ = NULL;
		gint _tmp71_ = 0;
#line 2458 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp70_ = combo_box;
#line 2458 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp71_ = current_app;
#line 2458 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_combo_box_set_active (_tmp70_, _tmp71_);
#line 19200 "Dialogs.c"
	}
#line 2403 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (combo_store);
#line 2403 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (text_renderer);
#line 2403 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (pixbuf_renderer);
#line 2403 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (external_apps) {
#line 2403 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*external_apps = _vala_external_apps;
#line 19212 "Dialogs.c"
	} else {
#line 2403 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (_vala_external_apps);
#line 19216 "Dialogs.c"
	}
}


static void preferences_dialog_setup_dir_pattern (PreferencesDialog* self, GtkComboBox* combo_box, GtkEntry* entry) {
	gchar* pattern = NULL;
	ConfigFacade* _tmp0_ = NULL;
	ConfigFacade* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gboolean found = FALSE;
	const gchar* _tmp4_ = NULL;
	gboolean _tmp32_ = FALSE;
#line 2461 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_PREFERENCES_DIALOG (self));
#line 2461 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (GTK_IS_COMBO_BOX (combo_box));
#line 2461 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (GTK_IS_ENTRY (entry));
#line 2462 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = config_facade_get_instance ();
#line 2462 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = _tmp0_;
#line 2462 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = configuration_facade_get_directory_pattern (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade));
#line 2462 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = _tmp2_;
#line 2462 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp1_);
#line 2462 "/home/jens/Source/shotwell/src/Dialogs.vala"
	pattern = _tmp3_;
#line 2463 "/home/jens/Source/shotwell/src/Dialogs.vala"
	found = FALSE;
#line 2464 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = pattern;
#line 2464 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (NULL != _tmp4_) {
#line 19254 "Dialogs.c"
		gint i = 0;
#line 2466 "/home/jens/Source/shotwell/src/Dialogs.vala"
		i = 0;
#line 19258 "Dialogs.c"
		{
			GeeArrayList* _pf_list = NULL;
			GeeArrayList* _tmp5_ = NULL;
			GeeArrayList* _tmp6_ = NULL;
			gint _pf_size = 0;
			GeeArrayList* _tmp7_ = NULL;
			gint _tmp8_ = 0;
			gint _tmp9_ = 0;
			gint _pf_index = 0;
#line 2467 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp5_ = self->priv->path_formats;
#line 2467 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp6_ = _g_object_ref0 (_tmp5_);
#line 2467 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_pf_list = _tmp6_;
#line 2467 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp7_ = _pf_list;
#line 2467 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp8_ = gee_abstract_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, GEE_TYPE_COLLECTION, GeeCollection));
#line 2467 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp9_ = _tmp8_;
#line 2467 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_pf_size = _tmp9_;
#line 2467 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_pf_index = -1;
#line 2467 "/home/jens/Source/shotwell/src/Dialogs.vala"
			while (TRUE) {
#line 19286 "Dialogs.c"
				gint _tmp10_ = 0;
				gint _tmp11_ = 0;
				gint _tmp12_ = 0;
				PreferencesDialogPathFormat* pf = NULL;
				GeeArrayList* _tmp13_ = NULL;
				gint _tmp14_ = 0;
				gpointer _tmp15_ = NULL;
				PreferencesDialogPathFormat* _tmp16_ = NULL;
				const gchar* _tmp17_ = NULL;
				const gchar* _tmp18_ = NULL;
				gint _tmp21_ = 0;
#line 2467 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp10_ = _pf_index;
#line 2467 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_pf_index = _tmp10_ + 1;
#line 2467 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp11_ = _pf_index;
#line 2467 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp12_ = _pf_size;
#line 2467 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (!(_tmp11_ < _tmp12_)) {
#line 2467 "/home/jens/Source/shotwell/src/Dialogs.vala"
					break;
#line 19310 "Dialogs.c"
				}
#line 2467 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp13_ = _pf_list;
#line 2467 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp14_ = _pf_index;
#line 2467 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp15_ = gee_abstract_list_get (G_TYPE_CHECK_INSTANCE_CAST (_tmp13_, GEE_TYPE_ABSTRACT_LIST, GeeAbstractList), _tmp14_);
#line 2467 "/home/jens/Source/shotwell/src/Dialogs.vala"
				pf = (PreferencesDialogPathFormat*) _tmp15_;
#line 2468 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp16_ = pf;
#line 2468 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp17_ = _tmp16_->pattern;
#line 2468 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp18_ = pattern;
#line 2468 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (g_strcmp0 (_tmp17_, _tmp18_) == 0) {
#line 19328 "Dialogs.c"
					GtkComboBox* _tmp19_ = NULL;
					gint _tmp20_ = 0;
#line 2469 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp19_ = combo_box;
#line 2469 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp20_ = i;
#line 2469 "/home/jens/Source/shotwell/src/Dialogs.vala"
					gtk_combo_box_set_active (_tmp19_, _tmp20_);
#line 2470 "/home/jens/Source/shotwell/src/Dialogs.vala"
					found = TRUE;
#line 2471 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_preferences_dialog_path_format_unref0 (pf);
#line 2471 "/home/jens/Source/shotwell/src/Dialogs.vala"
					break;
#line 19343 "Dialogs.c"
				}
#line 2473 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp21_ = i;
#line 2473 "/home/jens/Source/shotwell/src/Dialogs.vala"
				i = _tmp21_ + 1;
#line 2467 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_preferences_dialog_path_format_unref0 (pf);
#line 19351 "Dialogs.c"
			}
#line 2467 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_object_unref0 (_pf_list);
#line 19355 "Dialogs.c"
		}
	} else {
		gchar* s = NULL;
		ConfigFacade* _tmp22_ = NULL;
		ConfigFacade* _tmp23_ = NULL;
		gchar* _tmp24_ = NULL;
		gchar* _tmp25_ = NULL;
		const gchar* _tmp26_ = NULL;
		gboolean _tmp27_ = FALSE;
#line 2477 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp22_ = config_facade_get_instance ();
#line 2477 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp23_ = _tmp22_;
#line 2477 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp24_ = configuration_facade_get_directory_pattern_custom (G_TYPE_CHECK_INSTANCE_CAST (_tmp23_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade));
#line 2477 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp25_ = _tmp24_;
#line 2477 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (_tmp23_);
#line 2477 "/home/jens/Source/shotwell/src/Dialogs.vala"
		s = _tmp25_;
#line 2478 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp26_ = s;
#line 2478 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp27_ = is_string_empty (_tmp26_);
#line 2478 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (!_tmp27_) {
#line 19383 "Dialogs.c"
			GtkComboBox* _tmp28_ = NULL;
			GeeArrayList* _tmp29_ = NULL;
			gint _tmp30_ = 0;
			gint _tmp31_ = 0;
#line 2479 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp28_ = combo_box;
#line 2479 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp29_ = self->priv->path_formats;
#line 2479 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp30_ = gee_abstract_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp29_, GEE_TYPE_COLLECTION, GeeCollection));
#line 2479 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp31_ = _tmp30_;
#line 2479 "/home/jens/Source/shotwell/src/Dialogs.vala"
			gtk_combo_box_set_active (_tmp28_, _tmp31_ - 1);
#line 2480 "/home/jens/Source/shotwell/src/Dialogs.vala"
			found = TRUE;
#line 19400 "Dialogs.c"
		}
#line 2464 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (s);
#line 19404 "Dialogs.c"
	}
#line 2484 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp32_ = found;
#line 2484 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (!_tmp32_) {
#line 19410 "Dialogs.c"
		GtkComboBox* _tmp33_ = NULL;
#line 2485 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp33_ = combo_box;
#line 2485 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_combo_box_set_active (_tmp33_, 0);
#line 19416 "Dialogs.c"
	}
#line 2488 "/home/jens/Source/shotwell/src/Dialogs.vala"
	preferences_dialog_on_dir_pattern_combo_changed (self);
#line 2461 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (pattern);
#line 19422 "Dialogs.c"
}


void preferences_dialog_show (void) {
	PreferencesDialog* _tmp0_ = NULL;
	PreferencesDialog* _tmp2_ = NULL;
	PreferencesDialog* _tmp3_ = NULL;
	GtkDialog* _tmp4_ = NULL;
	PreferencesDialog* _tmp5_ = NULL;
	GtkFileChooserButton* _tmp6_ = NULL;
	GFile* _tmp7_ = NULL;
	GFile* _tmp8_ = NULL;
	gchar* _tmp9_ = NULL;
	gchar* _tmp10_ = NULL;
	PreferencesDialog* _tmp11_ = NULL;
	GtkDialog* _tmp12_ = NULL;
#line 2492 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = preferences_dialog_preferences_dialog;
#line 2492 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp0_ == NULL) {
#line 19443 "Dialogs.c"
		PreferencesDialog* _tmp1_ = NULL;
#line 2493 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp1_ = preferences_dialog_new ();
#line 2493 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_preferences_dialog_unref0 (preferences_dialog_preferences_dialog);
#line 2493 "/home/jens/Source/shotwell/src/Dialogs.vala"
		preferences_dialog_preferences_dialog = _tmp1_;
#line 19451 "Dialogs.c"
	}
#line 2495 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = preferences_dialog_preferences_dialog;
#line 2495 "/home/jens/Source/shotwell/src/Dialogs.vala"
	preferences_dialog_populate_preference_options (_tmp2_);
#line 2496 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = preferences_dialog_preferences_dialog;
#line 2496 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = _tmp3_->priv->dialog;
#line 2496 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_show_all (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, gtk_widget_get_type (), GtkWidget));
#line 2497 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = preferences_dialog_preferences_dialog;
#line 2497 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = _tmp5_->priv->library_dir_button;
#line 2497 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = app_dirs_get_import_dir ();
#line 2497 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = _tmp7_;
#line 2497 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = g_file_get_path (_tmp8_);
#line 2497 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp10_ = _tmp9_;
#line 2497 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_file_chooser_set_current_folder (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, GTK_TYPE_FILE_CHOOSER, GtkFileChooser), _tmp10_);
#line 2497 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp10_);
#line 2497 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp8_);
#line 2501 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp11_ = preferences_dialog_preferences_dialog;
#line 2501 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp12_ = _tmp11_->priv->dialog;
#line 2501 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_window_present (G_TYPE_CHECK_INSTANCE_CAST (_tmp12_, gtk_window_get_type (), GtkWindow));
#line 19487 "Dialogs.c"
}


static void preferences_dialog_commit_on_close (PreferencesDialog* self) {
	ConfigFacade* _tmp0_ = NULL;
	ConfigFacade* _tmp1_ = NULL;
	GtkCheckButton* autoimport = NULL;
	GtkBuilder* _tmp2_ = NULL;
	GObject* _tmp3_ = NULL;
	GtkCheckButton* _tmp4_ = NULL;
	GtkCheckButton* _tmp5_ = NULL;
	GtkCheckButton* commit_metadata = NULL;
	GtkBuilder* _tmp11_ = NULL;
	GObject* _tmp12_ = NULL;
	GtkCheckButton* _tmp13_ = NULL;
	GtkCheckButton* _tmp14_ = NULL;
	const gchar* _tmp20_ = NULL;
	PreferencesDialogPathFormat* pf = NULL;
	GeeArrayList* _tmp22_ = NULL;
	GtkComboBoxText* _tmp23_ = NULL;
	gint _tmp24_ = 0;
	gpointer _tmp25_ = NULL;
	PreferencesDialogPathFormat* _tmp26_ = NULL;
	const gchar* _tmp27_ = NULL;
#line 2506 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_PREFERENCES_DIALOG (self));
#line 2507 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = config_facade_get_instance ();
#line 2507 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = _tmp0_;
#line 2507 "/home/jens/Source/shotwell/src/Dialogs.vala"
	config_facade_commit_bg_color (_tmp1_);
#line 2507 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp1_);
#line 2509 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = self->priv->builder;
#line 2509 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = gtk_builder_get_object (_tmp2_, "autoimport");
#line 2509 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, gtk_check_button_get_type ()) ? ((GtkCheckButton*) _tmp3_) : NULL);
#line 2509 "/home/jens/Source/shotwell/src/Dialogs.vala"
	autoimport = _tmp4_;
#line 2510 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = autoimport;
#line 2510 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp5_ != NULL) {
#line 19534 "Dialogs.c"
		ConfigFacade* _tmp6_ = NULL;
		ConfigFacade* _tmp7_ = NULL;
		GtkCheckButton* _tmp8_ = NULL;
		gboolean _tmp9_ = FALSE;
		gboolean _tmp10_ = FALSE;
#line 2511 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp6_ = config_facade_get_instance ();
#line 2511 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp7_ = _tmp6_;
#line 2511 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp8_ = autoimport;
#line 2511 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp9_ = gtk_toggle_button_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, gtk_toggle_button_get_type (), GtkToggleButton));
#line 2511 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp10_ = _tmp9_;
#line 2511 "/home/jens/Source/shotwell/src/Dialogs.vala"
		configuration_facade_set_auto_import_from_library (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade), _tmp10_);
#line 2511 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (_tmp7_);
#line 19554 "Dialogs.c"
	}
#line 2513 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp11_ = self->priv->builder;
#line 2513 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp12_ = gtk_builder_get_object (_tmp11_, "write_metadata");
#line 2513 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp13_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp12_, gtk_check_button_get_type ()) ? ((GtkCheckButton*) _tmp12_) : NULL);
#line 2513 "/home/jens/Source/shotwell/src/Dialogs.vala"
	commit_metadata = _tmp13_;
#line 2514 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp14_ = commit_metadata;
#line 2514 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp14_ != NULL) {
#line 19568 "Dialogs.c"
		ConfigFacade* _tmp15_ = NULL;
		ConfigFacade* _tmp16_ = NULL;
		GtkCheckButton* _tmp17_ = NULL;
		gboolean _tmp18_ = FALSE;
		gboolean _tmp19_ = FALSE;
#line 2515 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp15_ = config_facade_get_instance ();
#line 2515 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp16_ = _tmp15_;
#line 2515 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp17_ = commit_metadata;
#line 2515 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp18_ = gtk_toggle_button_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp17_, gtk_toggle_button_get_type (), GtkToggleButton));
#line 2515 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp19_ = _tmp18_;
#line 2515 "/home/jens/Source/shotwell/src/Dialogs.vala"
		configuration_facade_set_commit_metadata_to_masters (G_TYPE_CHECK_INSTANCE_CAST (_tmp16_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade), _tmp19_);
#line 2515 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (_tmp16_);
#line 19588 "Dialogs.c"
	}
#line 2517 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp20_ = self->priv->lib_dir;
#line 2517 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp20_ != NULL) {
#line 19594 "Dialogs.c"
		const gchar* _tmp21_ = NULL;
#line 2518 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp21_ = self->priv->lib_dir;
#line 2518 "/home/jens/Source/shotwell/src/Dialogs.vala"
		app_dirs_set_import_dir (_tmp21_);
#line 19600 "Dialogs.c"
	}
#line 2520 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp22_ = self->priv->path_formats;
#line 2520 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp23_ = self->priv->dir_pattern_combo;
#line 2520 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp24_ = gtk_combo_box_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp23_, gtk_combo_box_get_type (), GtkComboBox));
#line 2520 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp25_ = gee_abstract_list_get (G_TYPE_CHECK_INSTANCE_CAST (_tmp22_, GEE_TYPE_ABSTRACT_LIST, GeeAbstractList), _tmp24_);
#line 2520 "/home/jens/Source/shotwell/src/Dialogs.vala"
	pf = (PreferencesDialogPathFormat*) _tmp25_;
#line 2521 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp26_ = pf;
#line 2521 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp27_ = _tmp26_->pattern;
#line 2521 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (NULL == _tmp27_) {
#line 19618 "Dialogs.c"
		ConfigFacade* _tmp28_ = NULL;
		ConfigFacade* _tmp29_ = NULL;
		GtkEntry* _tmp30_ = NULL;
		const gchar* _tmp31_ = NULL;
		const gchar* _tmp32_ = NULL;
		ConfigFacade* _tmp33_ = NULL;
		ConfigFacade* _tmp34_ = NULL;
#line 2522 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp28_ = config_facade_get_instance ();
#line 2522 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp29_ = _tmp28_;
#line 2522 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp30_ = self->priv->dir_pattern_entry;
#line 2522 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp31_ = gtk_entry_get_text (_tmp30_);
#line 2522 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp32_ = _tmp31_;
#line 2522 "/home/jens/Source/shotwell/src/Dialogs.vala"
		configuration_facade_set_directory_pattern_custom (G_TYPE_CHECK_INSTANCE_CAST (_tmp29_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade), _tmp32_);
#line 2522 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (_tmp29_);
#line 2523 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp33_ = config_facade_get_instance ();
#line 2523 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp34_ = _tmp33_;
#line 2523 "/home/jens/Source/shotwell/src/Dialogs.vala"
		configuration_facade_set_directory_pattern (G_TYPE_CHECK_INSTANCE_CAST (_tmp34_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade), NULL);
#line 2523 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (_tmp34_);
#line 19648 "Dialogs.c"
	} else {
		ConfigFacade* _tmp35_ = NULL;
		ConfigFacade* _tmp36_ = NULL;
		PreferencesDialogPathFormat* _tmp37_ = NULL;
		const gchar* _tmp38_ = NULL;
#line 2525 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp35_ = config_facade_get_instance ();
#line 2525 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp36_ = _tmp35_;
#line 2525 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp37_ = pf;
#line 2525 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp38_ = _tmp37_->pattern;
#line 2525 "/home/jens/Source/shotwell/src/Dialogs.vala"
		configuration_facade_set_directory_pattern (G_TYPE_CHECK_INSTANCE_CAST (_tmp36_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade), _tmp38_);
#line 2525 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (_tmp36_);
#line 19666 "Dialogs.c"
	}
#line 2506 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_preferences_dialog_path_format_unref0 (pf);
#line 2506 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (commit_metadata);
#line 2506 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (autoimport);
#line 19674 "Dialogs.c"
}


static gboolean preferences_dialog_on_delete (PreferencesDialog* self) {
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
	GtkDialog* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
#line 2529 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_PREFERENCES_DIALOG (self), FALSE);
#line 2530 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = preferences_dialog_get_allow_closing (self);
#line 2530 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (!_tmp0_) {
#line 2531 "/home/jens/Source/shotwell/src/Dialogs.vala"
		result = TRUE;
#line 2531 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return result;
#line 19693 "Dialogs.c"
	}
#line 2533 "/home/jens/Source/shotwell/src/Dialogs.vala"
	preferences_dialog_commit_on_close (self);
#line 2534 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = self->priv->dialog;
#line 2534 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = gtk_widget_hide_on_delete (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, gtk_widget_get_type (), GtkWidget));
#line 2534 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = _tmp2_;
#line 2534 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 19705 "Dialogs.c"
}


static void preferences_dialog_on_close (PreferencesDialog* self) {
	gboolean _tmp0_ = FALSE;
	GtkDialog* _tmp1_ = NULL;
#line 2537 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_PREFERENCES_DIALOG (self));
#line 2538 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = preferences_dialog_get_allow_closing (self);
#line 2538 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (!_tmp0_) {
#line 2539 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return;
#line 19720 "Dialogs.c"
	}
#line 2541 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = self->priv->dialog;
#line 2541 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_hide (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, gtk_widget_get_type (), GtkWidget));
#line 2542 "/home/jens/Source/shotwell/src/Dialogs.vala"
	preferences_dialog_commit_on_close (self);
#line 19728 "Dialogs.c"
}


static void preferences_dialog_on_value_changed (PreferencesDialog* self) {
	GtkAdjustment* _tmp0_ = NULL;
	gdouble _tmp1_ = 0.0;
	GtkAdjustment* _tmp2_ = NULL;
	gdouble _tmp3_ = 0.0;
#line 2545 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_PREFERENCES_DIALOG (self));
#line 2546 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = self->priv->bg_color_adjustment;
#line 2546 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = gtk_adjustment_get_upper (_tmp0_);
#line 2546 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = self->priv->bg_color_adjustment;
#line 2546 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = gtk_adjustment_get_value (_tmp2_);
#line 2546 "/home/jens/Source/shotwell/src/Dialogs.vala"
	preferences_dialog_set_background_color (self, ((gdouble) (_tmp1_ - _tmp3_)) / 65535.0);
#line 19749 "Dialogs.c"
}


static gboolean preferences_dialog_on_bg_color_reset (PreferencesDialog* self, GdkEventButton* event) {
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	GdkEventButton* _tmp2_ = NULL;
	guint _tmp3_ = 0U;
#line 2550 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_PREFERENCES_DIALOG (self), FALSE);
#line 2550 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 2551 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = event;
#line 2551 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = _tmp2_->button;
#line 2551 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp3_ == ((guint) 1)) {
#line 19769 "Dialogs.c"
		GdkEventButton* _tmp4_ = NULL;
		GdkEventType _tmp5_ = 0;
#line 2551 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp4_ = event;
#line 2551 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp5_ = _tmp4_->type;
#line 2551 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp1_ = _tmp5_ == GDK_BUTTON_PRESS;
#line 19778 "Dialogs.c"
	} else {
#line 2551 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp1_ = FALSE;
#line 19782 "Dialogs.c"
	}
#line 2551 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp1_) {
#line 19786 "Dialogs.c"
		GdkEventButton* _tmp6_ = NULL;
		GdkModifierType _tmp7_ = 0;
		gboolean _tmp8_ = FALSE;
#line 2552 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp6_ = event;
#line 2552 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp7_ = _tmp6_->state;
#line 2552 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp8_ = has_only_key_modifier (_tmp7_, GDK_CONTROL_MASK);
#line 2552 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = _tmp8_;
#line 19798 "Dialogs.c"
	} else {
#line 2551 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = FALSE;
#line 19802 "Dialogs.c"
	}
#line 2551 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp0_) {
#line 19806 "Dialogs.c"
		GtkScale* _tmp9_ = NULL;
		GtkAdjustment* _tmp10_ = NULL;
		gdouble _tmp11_ = 0.0;
		GdkRGBA _tmp12_ = {0};
		gdouble _tmp13_ = 0.0;
#line 2554 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp9_ = self->priv->bg_color_slider;
#line 2554 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp10_ = self->priv->bg_color_adjustment;
#line 2554 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp11_ = gtk_adjustment_get_upper (_tmp10_);
#line 2554 "/home/jens/Source/shotwell/src/Dialogs.vala"
		parse_color (CONFIG_FACADE_DEFAULT_BG_COLOR, &_tmp12_);
#line 2554 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp13_ = _tmp12_.red;
#line 2554 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_range_set_value (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, gtk_range_get_type (), GtkRange), _tmp11_ - (_tmp13_ * 65536.0f));
#line 2556 "/home/jens/Source/shotwell/src/Dialogs.vala"
		preferences_dialog_on_value_changed (self);
#line 2558 "/home/jens/Source/shotwell/src/Dialogs.vala"
		result = TRUE;
#line 2558 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return result;
#line 19830 "Dialogs.c"
	}
#line 2561 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = FALSE;
#line 2561 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 19836 "Dialogs.c"
}


static void preferences_dialog_on_dir_pattern_combo_changed (PreferencesDialog* self) {
	PreferencesDialogPathFormat* pf = NULL;
	GeeArrayList* _tmp0_ = NULL;
	GtkComboBoxText* _tmp1_ = NULL;
	gint _tmp2_ = 0;
	gpointer _tmp3_ = NULL;
	PreferencesDialogPathFormat* _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
#line 2564 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_PREFERENCES_DIALOG (self));
#line 2565 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = self->priv->path_formats;
#line 2565 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = self->priv->dir_pattern_combo;
#line 2565 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = gtk_combo_box_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, gtk_combo_box_get_type (), GtkComboBox));
#line 2565 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = gee_abstract_list_get (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, GEE_TYPE_ABSTRACT_LIST, GeeAbstractList), _tmp2_);
#line 2565 "/home/jens/Source/shotwell/src/Dialogs.vala"
	pf = (PreferencesDialogPathFormat*) _tmp3_;
#line 2566 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = pf;
#line 2566 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = _tmp4_->pattern;
#line 2566 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (NULL == _tmp5_) {
#line 19866 "Dialogs.c"
		gchar* dir_pattern = NULL;
		ConfigFacade* _tmp6_ = NULL;
		ConfigFacade* _tmp7_ = NULL;
		gchar* _tmp8_ = NULL;
		gchar* _tmp9_ = NULL;
		const gchar* _tmp10_ = NULL;
		gboolean _tmp11_ = FALSE;
		GtkEntry* _tmp13_ = NULL;
		const gchar* _tmp14_ = NULL;
		GtkEntry* _tmp15_ = NULL;
		GtkEntry* _tmp16_ = NULL;
#line 2568 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp6_ = config_facade_get_instance ();
#line 2568 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp7_ = _tmp6_;
#line 2568 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp8_ = configuration_facade_get_directory_pattern_custom (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade));
#line 2568 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp9_ = _tmp8_;
#line 2568 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (_tmp7_);
#line 2568 "/home/jens/Source/shotwell/src/Dialogs.vala"
		dir_pattern = _tmp9_;
#line 2569 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp10_ = dir_pattern;
#line 2569 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp11_ = is_string_empty (_tmp10_);
#line 2569 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp11_) {
#line 19896 "Dialogs.c"
			gchar* _tmp12_ = NULL;
#line 2570 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp12_ = g_strdup ("");
#line 2570 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (dir_pattern);
#line 2570 "/home/jens/Source/shotwell/src/Dialogs.vala"
			dir_pattern = _tmp12_;
#line 19904 "Dialogs.c"
		}
#line 2571 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp13_ = self->priv->dir_pattern_entry;
#line 2571 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp14_ = dir_pattern;
#line 2571 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_entry_set_text (_tmp13_, _tmp14_);
#line 2572 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp15_ = self->priv->dir_pattern_entry;
#line 2572 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_object_set (_tmp15_, "editable", TRUE, NULL);
#line 2573 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp16_ = self->priv->dir_pattern_entry;
#line 2573 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp16_, gtk_widget_get_type (), GtkWidget), TRUE);
#line 2566 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (dir_pattern);
#line 19922 "Dialogs.c"
	} else {
		GtkEntry* _tmp17_ = NULL;
		PreferencesDialogPathFormat* _tmp18_ = NULL;
		const gchar* _tmp19_ = NULL;
		GtkEntry* _tmp20_ = NULL;
		GtkEntry* _tmp21_ = NULL;
#line 2575 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp17_ = self->priv->dir_pattern_entry;
#line 2575 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp18_ = pf;
#line 2575 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp19_ = _tmp18_->pattern;
#line 2575 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_entry_set_text (_tmp17_, _tmp19_);
#line 2576 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp20_ = self->priv->dir_pattern_entry;
#line 2576 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_object_set (_tmp20_, "editable", FALSE, NULL);
#line 2577 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp21_ = self->priv->dir_pattern_entry;
#line 2577 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp21_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 19945 "Dialogs.c"
	}
#line 2564 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_preferences_dialog_path_format_unref0 (pf);
#line 19949 "Dialogs.c"
}


static void preferences_dialog_on_dir_pattern_entry_changed (PreferencesDialog* self) {
	gchar* example = NULL;
	GDateTime* _tmp0_ = NULL;
	GtkEntry* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	gboolean _tmp5_ = FALSE;
	const gchar* _tmp6_ = NULL;
	gboolean _tmp7_ = FALSE;
#line 2581 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_PREFERENCES_DIALOG (self));
#line 2582 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = self->priv->example_date;
#line 2582 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = self->priv->dir_pattern_entry;
#line 2582 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = gtk_entry_get_text (_tmp1_);
#line 2582 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = _tmp2_;
#line 2582 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = g_date_time_format (_tmp0_, _tmp3_);
#line 2582 "/home/jens/Source/shotwell/src/Dialogs.vala"
	example = _tmp4_;
#line 2583 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = example;
#line 2583 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = is_string_empty (_tmp6_);
#line 2583 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp7_) {
#line 19983 "Dialogs.c"
		GtkEntry* _tmp8_ = NULL;
		const gchar* _tmp9_ = NULL;
		const gchar* _tmp10_ = NULL;
		gboolean _tmp11_ = FALSE;
#line 2583 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp8_ = self->priv->dir_pattern_entry;
#line 2583 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp9_ = gtk_entry_get_text (_tmp8_);
#line 2583 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp10_ = _tmp9_;
#line 2583 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp11_ = is_string_empty (_tmp10_);
#line 2583 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp5_ = !_tmp11_;
#line 19998 "Dialogs.c"
	} else {
#line 2583 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp5_ = FALSE;
#line 20002 "Dialogs.c"
	}
#line 2583 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp5_) {
#line 20006 "Dialogs.c"
		GtkLabel* _tmp12_ = NULL;
		const gchar* _tmp13_ = NULL;
		GtkEntry* _tmp14_ = NULL;
		GtkEntry* _tmp15_ = NULL;
#line 2585 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp12_ = self->priv->dir_pattern_example;
#line 2585 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp13_ = _ ("Invalid pattern");
#line 2585 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_label_set_text (_tmp12_, _tmp13_);
#line 2586 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp14_ = self->priv->dir_pattern_entry;
#line 2586 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_entry_set_icon_from_icon_name (_tmp14_, GTK_ENTRY_ICON_SECONDARY, "dialog-error");
#line 2587 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp15_ = self->priv->dir_pattern_entry;
#line 2587 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_entry_set_icon_activatable (_tmp15_, GTK_ENTRY_ICON_SECONDARY, FALSE);
#line 2588 "/home/jens/Source/shotwell/src/Dialogs.vala"
		preferences_dialog_set_allow_closing (self, FALSE);
#line 20027 "Dialogs.c"
	} else {
		GtkLabel* _tmp16_ = NULL;
		const gchar* _tmp17_ = NULL;
		GtkEntry* _tmp18_ = NULL;
#line 2591 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp16_ = self->priv->dir_pattern_example;
#line 2591 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp17_ = example;
#line 2591 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_label_set_text (_tmp16_, _tmp17_);
#line 2592 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp18_ = self->priv->dir_pattern_entry;
#line 2592 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_entry_set_icon_from_icon_name (_tmp18_, GTK_ENTRY_ICON_SECONDARY, NULL);
#line 2593 "/home/jens/Source/shotwell/src/Dialogs.vala"
		preferences_dialog_set_allow_closing (self, TRUE);
#line 20044 "Dialogs.c"
	}
#line 2581 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (example);
#line 20048 "Dialogs.c"
}


static void preferences_dialog_set_allow_closing (PreferencesDialog* self, gboolean allow) {
	GtkDialog* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_ = FALSE;
#line 2597 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_PREFERENCES_DIALOG (self));
#line 2598 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = self->priv->dialog;
#line 2598 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = allow;
#line 2598 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_window_set_deletable (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_window_get_type (), GtkWindow), _tmp1_);
#line 2599 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = allow;
#line 2599 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->allow_closing = _tmp2_;
#line 20068 "Dialogs.c"
}


static gboolean preferences_dialog_get_allow_closing (PreferencesDialog* self) {
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
#line 2602 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_PREFERENCES_DIALOG (self), FALSE);
#line 2603 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = self->priv->allow_closing;
#line 2603 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = _tmp0_;
#line 2603 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 20083 "Dialogs.c"
}


static void preferences_dialog_set_background_color (PreferencesDialog* self, gdouble bg_color_value) {
	ConfigFacade* _tmp0_ = NULL;
	ConfigFacade* _tmp1_ = NULL;
	gdouble _tmp2_ = 0.0;
	GdkRGBA _tmp3_ = {0};
#line 2606 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_PREFERENCES_DIALOG (self));
#line 2607 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = config_facade_get_instance ();
#line 2607 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = _tmp0_;
#line 2607 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = bg_color_value;
#line 2607 "/home/jens/Source/shotwell/src/Dialogs.vala"
	preferences_dialog_to_grayscale (self, _tmp2_, &_tmp3_);
#line 2607 "/home/jens/Source/shotwell/src/Dialogs.vala"
	config_facade_set_bg_color (_tmp1_, &_tmp3_);
#line 2607 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp1_);
#line 20106 "Dialogs.c"
}


static void preferences_dialog_to_grayscale (PreferencesDialog* self, gdouble color_value, GdkRGBA* result) {
	GdkRGBA color = {0};
	gdouble _tmp0_ = 0.0;
	gdouble _tmp1_ = 0.0;
	gdouble _tmp2_ = 0.0;
#line 2610 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_PREFERENCES_DIALOG (self));
#line 2611 "/home/jens/Source/shotwell/src/Dialogs.vala"
	memset (&color, 0, sizeof (GdkRGBA));
#line 2613 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = color_value;
#line 2613 "/home/jens/Source/shotwell/src/Dialogs.vala"
	color.red = _tmp0_;
#line 2614 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = color_value;
#line 2614 "/home/jens/Source/shotwell/src/Dialogs.vala"
	color.green = _tmp1_;
#line 2615 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = color_value;
#line 2615 "/home/jens/Source/shotwell/src/Dialogs.vala"
	color.blue = _tmp2_;
#line 2616 "/home/jens/Source/shotwell/src/Dialogs.vala"
	color.alpha = 1.0;
#line 2618 "/home/jens/Source/shotwell/src/Dialogs.vala"
	*result = color;
#line 2618 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return;
#line 20137 "Dialogs.c"
}


static void preferences_dialog_on_photo_editor_changed (PreferencesDialog* self) {
	gint _tmp0_ = 0;
	GtkComboBox* _tmp1_ = NULL;
	gint _tmp2_ = 0;
	SortedList* _tmp3_ = NULL;
	gint _tmp4_ = 0;
	gint _tmp5_ = 0;
	gint photo_app_choice_index = 0;
	GAppInfo* app = NULL;
	SortedList* _tmp11_ = NULL;
	gpointer _tmp12_ = NULL;
	ConfigFacade* _tmp13_ = NULL;
	ConfigFacade* _tmp14_ = NULL;
	gchar* _tmp15_ = NULL;
	gchar* _tmp16_ = NULL;
	gchar* _tmp17_ = NULL;
	gchar* _tmp18_ = NULL;
#line 2621 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_PREFERENCES_DIALOG (self));
#line 2622 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = self->priv->photo_editor_combo;
#line 2622 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = gtk_combo_box_get_active (_tmp1_);
#line 2622 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = self->priv->external_photo_apps;
#line 2622 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, GEE_TYPE_COLLECTION, GeeCollection));
#line 2622 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = _tmp4_;
#line 2622 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp2_ < _tmp5_) {
#line 20172 "Dialogs.c"
		GtkComboBox* _tmp6_ = NULL;
		gint _tmp7_ = 0;
#line 2623 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp6_ = self->priv->photo_editor_combo;
#line 2623 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp7_ = gtk_combo_box_get_active (_tmp6_);
#line 2623 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = _tmp7_;
#line 20181 "Dialogs.c"
	} else {
		SortedList* _tmp8_ = NULL;
		gint _tmp9_ = 0;
		gint _tmp10_ = 0;
#line 2623 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp8_ = self->priv->external_photo_apps;
#line 2623 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp9_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, GEE_TYPE_COLLECTION, GeeCollection));
#line 2623 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp10_ = _tmp9_;
#line 2623 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = _tmp10_;
#line 20194 "Dialogs.c"
	}
#line 2622 "/home/jens/Source/shotwell/src/Dialogs.vala"
	photo_app_choice_index = _tmp0_;
#line 2625 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp11_ = self->priv->external_photo_apps;
#line 2625 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp12_ = sorted_list_get_at (_tmp11_, photo_app_choice_index);
#line 2625 "/home/jens/Source/shotwell/src/Dialogs.vala"
	app = (GAppInfo*) _tmp12_;
#line 2627 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp13_ = config_facade_get_instance ();
#line 2627 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp14_ = _tmp13_;
#line 2627 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp15_ = desktop_integration_get_app_open_command (app);
#line 2627 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp16_ = _tmp15_;
#line 2627 "/home/jens/Source/shotwell/src/Dialogs.vala"
	configuration_facade_set_external_photo_app (G_TYPE_CHECK_INSTANCE_CAST (_tmp14_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade), _tmp16_);
#line 2627 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp16_);
#line 2627 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp14_);
#line 2629 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp17_ = desktop_integration_get_app_open_command (app);
#line 2629 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp18_ = _tmp17_;
#line 2629 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_debug ("Dialogs.vala:2629: setting external photo editor to: %s", _tmp18_);
#line 2629 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp18_);
#line 2621 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (app);
#line 20228 "Dialogs.c"
}


static void preferences_dialog_on_raw_editor_changed (PreferencesDialog* self) {
	gint _tmp0_ = 0;
	GtkComboBox* _tmp1_ = NULL;
	gint _tmp2_ = 0;
	SortedList* _tmp3_ = NULL;
	gint _tmp4_ = 0;
	gint _tmp5_ = 0;
	gint raw_app_choice_index = 0;
	GAppInfo* app = NULL;
	SortedList* _tmp11_ = NULL;
	gpointer _tmp12_ = NULL;
	ConfigFacade* _tmp13_ = NULL;
	ConfigFacade* _tmp14_ = NULL;
	const gchar* _tmp15_ = NULL;
	const gchar* _tmp16_ = NULL;
#line 2632 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_PREFERENCES_DIALOG (self));
#line 2633 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = self->priv->raw_editor_combo;
#line 2633 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = gtk_combo_box_get_active (_tmp1_);
#line 2633 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = self->priv->external_raw_apps;
#line 2633 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, GEE_TYPE_COLLECTION, GeeCollection));
#line 2633 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = _tmp4_;
#line 2633 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp2_ < _tmp5_) {
#line 20261 "Dialogs.c"
		GtkComboBox* _tmp6_ = NULL;
		gint _tmp7_ = 0;
#line 2634 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp6_ = self->priv->raw_editor_combo;
#line 2634 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp7_ = gtk_combo_box_get_active (_tmp6_);
#line 2634 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = _tmp7_;
#line 20270 "Dialogs.c"
	} else {
		SortedList* _tmp8_ = NULL;
		gint _tmp9_ = 0;
		gint _tmp10_ = 0;
#line 2634 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp8_ = self->priv->external_raw_apps;
#line 2634 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp9_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, GEE_TYPE_COLLECTION, GeeCollection));
#line 2634 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp10_ = _tmp9_;
#line 2634 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = _tmp10_;
#line 20283 "Dialogs.c"
	}
#line 2633 "/home/jens/Source/shotwell/src/Dialogs.vala"
	raw_app_choice_index = _tmp0_;
#line 2636 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp11_ = self->priv->external_raw_apps;
#line 2636 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp12_ = sorted_list_get_at (_tmp11_, raw_app_choice_index);
#line 2636 "/home/jens/Source/shotwell/src/Dialogs.vala"
	app = (GAppInfo*) _tmp12_;
#line 2638 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp13_ = config_facade_get_instance ();
#line 2638 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp14_ = _tmp13_;
#line 2638 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp15_ = g_app_info_get_commandline (app);
#line 2638 "/home/jens/Source/shotwell/src/Dialogs.vala"
	configuration_facade_set_external_raw_app (G_TYPE_CHECK_INSTANCE_CAST (_tmp14_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade), _tmp15_);
#line 2638 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp14_);
#line 2640 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp16_ = g_app_info_get_commandline (app);
#line 2640 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_debug ("Dialogs.vala:2640: setting external raw editor to: %s", _tmp16_);
#line 2632 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (app);
#line 20309 "Dialogs.c"
}


static RawDeveloper preferences_dialog_raw_developer_from_combo (PreferencesDialog* self) {
	RawDeveloper result = 0;
	GtkComboBoxText* _tmp0_ = NULL;
	gint _tmp1_ = 0;
#line 2643 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_PREFERENCES_DIALOG (self), 0);
#line 2644 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = self->priv->default_raw_developer_combo;
#line 2644 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = gtk_combo_box_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_combo_box_get_type (), GtkComboBox));
#line 2644 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp1_ == 0) {
#line 2645 "/home/jens/Source/shotwell/src/Dialogs.vala"
		result = RAW_DEVELOPER_CAMERA;
#line 2645 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return result;
#line 20329 "Dialogs.c"
	}
#line 2646 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = RAW_DEVELOPER_SHOTWELL;
#line 2646 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 20335 "Dialogs.c"
}


static void preferences_dialog_set_raw_developer_combo (PreferencesDialog* self, RawDeveloper d) {
	RawDeveloper _tmp0_ = 0;
#line 2649 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_PREFERENCES_DIALOG (self));
#line 2650 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = d;
#line 2650 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp0_ == RAW_DEVELOPER_CAMERA) {
#line 20347 "Dialogs.c"
		GtkComboBoxText* _tmp1_ = NULL;
#line 2651 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp1_ = self->priv->default_raw_developer_combo;
#line 2651 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_combo_box_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, gtk_combo_box_get_type (), GtkComboBox), 0);
#line 20353 "Dialogs.c"
	} else {
		GtkComboBoxText* _tmp2_ = NULL;
#line 2653 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp2_ = self->priv->default_raw_developer_combo;
#line 2653 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_combo_box_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, gtk_combo_box_get_type (), GtkComboBox), 1);
#line 20360 "Dialogs.c"
	}
}


static void preferences_dialog_on_default_raw_developer_changed (PreferencesDialog* self) {
	ConfigFacade* _tmp0_ = NULL;
	ConfigFacade* _tmp1_ = NULL;
	RawDeveloper _tmp2_ = 0;
#line 2656 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_PREFERENCES_DIALOG (self));
#line 2657 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = config_facade_get_instance ();
#line 2657 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = _tmp0_;
#line 2657 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = preferences_dialog_raw_developer_from_combo (self);
#line 2657 "/home/jens/Source/shotwell/src/Dialogs.vala"
	configuration_facade_set_default_raw_developer (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade), _tmp2_);
#line 2657 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp1_);
#line 20381 "Dialogs.c"
}


static void preferences_dialog_on_current_folder_changed (PreferencesDialog* self) {
	GtkFileChooserButton* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 2660 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_PREFERENCES_DIALOG (self));
#line 2661 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = self->priv->library_dir_button;
#line 2661 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = gtk_file_chooser_get_filename (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, GTK_TYPE_FILE_CHOOSER, GtkFileChooser));
#line 2661 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (self->priv->lib_dir);
#line 2661 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->lib_dir = _tmp1_;
#line 20398 "Dialogs.c"
}


static void _preferences_dialog_on_current_folder_changed_gtk_file_chooser_current_folder_changed (GtkFileChooser* _sender, gpointer self) {
#line 2669 "/home/jens/Source/shotwell/src/Dialogs.vala"
	preferences_dialog_on_current_folder_changed ((PreferencesDialog*) self);
#line 20405 "Dialogs.c"
}


static gboolean preferences_dialog_map_event (PreferencesDialog* self) {
	gboolean result = FALSE;
	GtkFileChooserButton* _tmp0_ = NULL;
#line 2664 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_PREFERENCES_DIALOG (self), FALSE);
#line 2669 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = self->priv->library_dir_button;
#line 2669 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_connect (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, GTK_TYPE_FILE_CHOOSER, GtkFileChooser), "current-folder-changed", (GCallback) _preferences_dialog_on_current_folder_changed_gtk_file_chooser_current_folder_changed, self);
#line 2670 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = TRUE;
#line 2670 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 20422 "Dialogs.c"
}


static void preferences_dialog_add_to_dir_formats (PreferencesDialog* self, const gchar* name, const gchar* pattern) {
	PreferencesDialogPathFormat* pf = NULL;
	const gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	PreferencesDialogPathFormat* _tmp2_ = NULL;
	GeeArrayList* _tmp3_ = NULL;
	GtkComboBoxText* _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
#line 2673 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_PREFERENCES_DIALOG (self));
#line 2673 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (name != NULL);
#line 2674 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = name;
#line 2674 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = pattern;
#line 2674 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = preferences_dialog_path_format_new (_tmp0_, _tmp1_);
#line 2674 "/home/jens/Source/shotwell/src/Dialogs.vala"
	pf = _tmp2_;
#line 2675 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = self->priv->path_formats;
#line 2675 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gee_abstract_collection_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection), pf);
#line 2676 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = self->priv->dir_pattern_combo;
#line 2676 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = name;
#line 2676 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_combo_box_text_append_text (_tmp4_, _tmp5_);
#line 2673 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_preferences_dialog_path_format_unref0 (pf);
#line 20458 "Dialogs.c"
}


static void preferences_dialog_on_lowercase_toggled (PreferencesDialog* self) {
	ConfigFacade* _tmp0_ = NULL;
	ConfigFacade* _tmp1_ = NULL;
	GtkCheckButton* _tmp2_ = NULL;
	gboolean _tmp3_ = FALSE;
#line 2679 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_PREFERENCES_DIALOG (self));
#line 2680 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = config_facade_get_instance ();
#line 2680 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = _tmp0_;
#line 2680 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = self->priv->lowercase;
#line 2680 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = gtk_toggle_button_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, gtk_toggle_button_get_type (), GtkToggleButton));
#line 2680 "/home/jens/Source/shotwell/src/Dialogs.vala"
	configuration_facade_set_use_lowercase_filenames (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade), _tmp3_);
#line 2680 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp1_);
#line 20481 "Dialogs.c"
}


static PreferencesDialogPathFormat* preferences_dialog_path_format_construct (GType object_type, const gchar* name, const gchar* pattern) {
	PreferencesDialogPathFormat* self = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
#line 2258 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (name != NULL, NULL);
#line 2258 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = (PreferencesDialogPathFormat*) g_type_create_instance (object_type);
#line 2259 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = name;
#line 2259 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 2259 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (self->name);
#line 2259 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->name = _tmp1_;
#line 2260 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = pattern;
#line 2260 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = g_strdup (_tmp2_);
#line 2260 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (self->pattern);
#line 2260 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->pattern = _tmp3_;
#line 2258 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return self;
#line 20513 "Dialogs.c"
}


static PreferencesDialogPathFormat* preferences_dialog_path_format_new (const gchar* name, const gchar* pattern) {
#line 2258 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return preferences_dialog_path_format_construct (PREFERENCES_DIALOG_TYPE_PATH_FORMAT, name, pattern);
#line 20520 "Dialogs.c"
}


static void preferences_dialog_value_path_format_init (GValue* value) {
#line 2257 "/home/jens/Source/shotwell/src/Dialogs.vala"
	value->data[0].v_pointer = NULL;
#line 20527 "Dialogs.c"
}


static void preferences_dialog_value_path_format_free_value (GValue* value) {
#line 2257 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (value->data[0].v_pointer) {
#line 2257 "/home/jens/Source/shotwell/src/Dialogs.vala"
		preferences_dialog_path_format_unref (value->data[0].v_pointer);
#line 20536 "Dialogs.c"
	}
}


static void preferences_dialog_value_path_format_copy_value (const GValue* src_value, GValue* dest_value) {
#line 2257 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (src_value->data[0].v_pointer) {
#line 2257 "/home/jens/Source/shotwell/src/Dialogs.vala"
		dest_value->data[0].v_pointer = preferences_dialog_path_format_ref (src_value->data[0].v_pointer);
#line 20546 "Dialogs.c"
	} else {
#line 2257 "/home/jens/Source/shotwell/src/Dialogs.vala"
		dest_value->data[0].v_pointer = NULL;
#line 20550 "Dialogs.c"
	}
}


static gpointer preferences_dialog_value_path_format_peek_pointer (const GValue* value) {
#line 2257 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return value->data[0].v_pointer;
#line 20558 "Dialogs.c"
}


static gchar* preferences_dialog_value_path_format_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
#line 2257 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (collect_values[0].v_pointer) {
#line 20565 "Dialogs.c"
		PreferencesDialogPathFormat* object;
		object = collect_values[0].v_pointer;
#line 2257 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (object->parent_instance.g_class == NULL) {
#line 2257 "/home/jens/Source/shotwell/src/Dialogs.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 20572 "Dialogs.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 2257 "/home/jens/Source/shotwell/src/Dialogs.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 20576 "Dialogs.c"
		}
#line 2257 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = preferences_dialog_path_format_ref (object);
#line 20580 "Dialogs.c"
	} else {
#line 2257 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = NULL;
#line 20584 "Dialogs.c"
	}
#line 2257 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return NULL;
#line 20588 "Dialogs.c"
}


static gchar* preferences_dialog_value_path_format_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	PreferencesDialogPathFormat** object_p;
	object_p = collect_values[0].v_pointer;
#line 2257 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (!object_p) {
#line 2257 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 20599 "Dialogs.c"
	}
#line 2257 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (!value->data[0].v_pointer) {
#line 2257 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*object_p = NULL;
#line 20605 "Dialogs.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 2257 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*object_p = value->data[0].v_pointer;
#line 20609 "Dialogs.c"
	} else {
#line 2257 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*object_p = preferences_dialog_path_format_ref (value->data[0].v_pointer);
#line 20613 "Dialogs.c"
	}
#line 2257 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return NULL;
#line 20617 "Dialogs.c"
}


static GParamSpec* preferences_dialog_param_spec_path_format (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
	PreferencesDialogParamSpecPathFormat* spec;
#line 2257 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (g_type_is_a (object_type, PREFERENCES_DIALOG_TYPE_PATH_FORMAT), NULL);
#line 2257 "/home/jens/Source/shotwell/src/Dialogs.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 2257 "/home/jens/Source/shotwell/src/Dialogs.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 2257 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return G_PARAM_SPEC (spec);
#line 20631 "Dialogs.c"
}


static gpointer preferences_dialog_value_get_path_format (const GValue* value) {
#line 2257 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PREFERENCES_DIALOG_TYPE_PATH_FORMAT), NULL);
#line 2257 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return value->data[0].v_pointer;
#line 20640 "Dialogs.c"
}


static void preferences_dialog_value_set_path_format (GValue* value, gpointer v_object) {
	PreferencesDialogPathFormat* old;
#line 2257 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PREFERENCES_DIALOG_TYPE_PATH_FORMAT));
#line 2257 "/home/jens/Source/shotwell/src/Dialogs.vala"
	old = value->data[0].v_pointer;
#line 2257 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (v_object) {
#line 2257 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PREFERENCES_DIALOG_TYPE_PATH_FORMAT));
#line 2257 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 2257 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = v_object;
#line 2257 "/home/jens/Source/shotwell/src/Dialogs.vala"
		preferences_dialog_path_format_ref (value->data[0].v_pointer);
#line 20660 "Dialogs.c"
	} else {
#line 2257 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = NULL;
#line 20664 "Dialogs.c"
	}
#line 2257 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (old) {
#line 2257 "/home/jens/Source/shotwell/src/Dialogs.vala"
		preferences_dialog_path_format_unref (old);
#line 20670 "Dialogs.c"
	}
}


static void preferences_dialog_value_take_path_format (GValue* value, gpointer v_object) {
	PreferencesDialogPathFormat* old;
#line 2257 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PREFERENCES_DIALOG_TYPE_PATH_FORMAT));
#line 2257 "/home/jens/Source/shotwell/src/Dialogs.vala"
	old = value->data[0].v_pointer;
#line 2257 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (v_object) {
#line 2257 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PREFERENCES_DIALOG_TYPE_PATH_FORMAT));
#line 2257 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 2257 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = v_object;
#line 20689 "Dialogs.c"
	} else {
#line 2257 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = NULL;
#line 20693 "Dialogs.c"
	}
#line 2257 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (old) {
#line 2257 "/home/jens/Source/shotwell/src/Dialogs.vala"
		preferences_dialog_path_format_unref (old);
#line 20699 "Dialogs.c"
	}
}


static void preferences_dialog_path_format_class_init (PreferencesDialogPathFormatClass * klass) {
#line 2257 "/home/jens/Source/shotwell/src/Dialogs.vala"
	preferences_dialog_path_format_parent_class = g_type_class_peek_parent (klass);
#line 2257 "/home/jens/Source/shotwell/src/Dialogs.vala"
	((PreferencesDialogPathFormatClass *) klass)->finalize = preferences_dialog_path_format_finalize;
#line 20709 "Dialogs.c"
}


static void preferences_dialog_path_format_instance_init (PreferencesDialogPathFormat * self) {
#line 2257 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->ref_count = 1;
#line 20716 "Dialogs.c"
}


static void preferences_dialog_path_format_finalize (PreferencesDialogPathFormat* obj) {
	PreferencesDialogPathFormat * self;
#line 2257 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PREFERENCES_DIALOG_TYPE_PATH_FORMAT, PreferencesDialogPathFormat);
#line 2257 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_handlers_destroy (self);
#line 2262 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (self->name);
#line 2263 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (self->pattern);
#line 20730 "Dialogs.c"
}


static GType preferences_dialog_path_format_get_type (void) {
	static volatile gsize preferences_dialog_path_format_type_id__volatile = 0;
	if (g_once_init_enter (&preferences_dialog_path_format_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { preferences_dialog_value_path_format_init, preferences_dialog_value_path_format_free_value, preferences_dialog_value_path_format_copy_value, preferences_dialog_value_path_format_peek_pointer, "p", preferences_dialog_value_path_format_collect_value, "p", preferences_dialog_value_path_format_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (PreferencesDialogPathFormatClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) preferences_dialog_path_format_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PreferencesDialogPathFormat), 0, (GInstanceInitFunc) preferences_dialog_path_format_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType preferences_dialog_path_format_type_id;
		preferences_dialog_path_format_type_id = g_type_register_fundamental (g_type_fundamental_next (), "PreferencesDialogPathFormat", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&preferences_dialog_path_format_type_id__volatile, preferences_dialog_path_format_type_id);
	}
	return preferences_dialog_path_format_type_id__volatile;
}


static gpointer preferences_dialog_path_format_ref (gpointer instance) {
	PreferencesDialogPathFormat* self;
	self = instance;
#line 2257 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_atomic_int_inc (&self->ref_count);
#line 2257 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return instance;
#line 20755 "Dialogs.c"
}


static void preferences_dialog_path_format_unref (gpointer instance) {
	PreferencesDialogPathFormat* self;
	self = instance;
#line 2257 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 2257 "/home/jens/Source/shotwell/src/Dialogs.vala"
		PREFERENCES_DIALOG_PATH_FORMAT_GET_CLASS (self)->finalize (self);
#line 2257 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 20768 "Dialogs.c"
	}
}


static void value_preferences_dialog_init (GValue* value) {
#line 2256 "/home/jens/Source/shotwell/src/Dialogs.vala"
	value->data[0].v_pointer = NULL;
#line 20776 "Dialogs.c"
}


static void value_preferences_dialog_free_value (GValue* value) {
#line 2256 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (value->data[0].v_pointer) {
#line 2256 "/home/jens/Source/shotwell/src/Dialogs.vala"
		preferences_dialog_unref (value->data[0].v_pointer);
#line 20785 "Dialogs.c"
	}
}


static void value_preferences_dialog_copy_value (const GValue* src_value, GValue* dest_value) {
#line 2256 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (src_value->data[0].v_pointer) {
#line 2256 "/home/jens/Source/shotwell/src/Dialogs.vala"
		dest_value->data[0].v_pointer = preferences_dialog_ref (src_value->data[0].v_pointer);
#line 20795 "Dialogs.c"
	} else {
#line 2256 "/home/jens/Source/shotwell/src/Dialogs.vala"
		dest_value->data[0].v_pointer = NULL;
#line 20799 "Dialogs.c"
	}
}


static gpointer value_preferences_dialog_peek_pointer (const GValue* value) {
#line 2256 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return value->data[0].v_pointer;
#line 20807 "Dialogs.c"
}


static gchar* value_preferences_dialog_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
#line 2256 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (collect_values[0].v_pointer) {
#line 20814 "Dialogs.c"
		PreferencesDialog* object;
		object = collect_values[0].v_pointer;
#line 2256 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (object->parent_instance.g_class == NULL) {
#line 2256 "/home/jens/Source/shotwell/src/Dialogs.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 20821 "Dialogs.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 2256 "/home/jens/Source/shotwell/src/Dialogs.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 20825 "Dialogs.c"
		}
#line 2256 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = preferences_dialog_ref (object);
#line 20829 "Dialogs.c"
	} else {
#line 2256 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = NULL;
#line 20833 "Dialogs.c"
	}
#line 2256 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return NULL;
#line 20837 "Dialogs.c"
}


static gchar* value_preferences_dialog_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	PreferencesDialog** object_p;
	object_p = collect_values[0].v_pointer;
#line 2256 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (!object_p) {
#line 2256 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 20848 "Dialogs.c"
	}
#line 2256 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (!value->data[0].v_pointer) {
#line 2256 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*object_p = NULL;
#line 20854 "Dialogs.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 2256 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*object_p = value->data[0].v_pointer;
#line 20858 "Dialogs.c"
	} else {
#line 2256 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*object_p = preferences_dialog_ref (value->data[0].v_pointer);
#line 20862 "Dialogs.c"
	}
#line 2256 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return NULL;
#line 20866 "Dialogs.c"
}


GParamSpec* param_spec_preferences_dialog (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
	ParamSpecPreferencesDialog* spec;
#line 2256 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (g_type_is_a (object_type, TYPE_PREFERENCES_DIALOG), NULL);
#line 2256 "/home/jens/Source/shotwell/src/Dialogs.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 2256 "/home/jens/Source/shotwell/src/Dialogs.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 2256 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return G_PARAM_SPEC (spec);
#line 20880 "Dialogs.c"
}


gpointer value_get_preferences_dialog (const GValue* value) {
#line 2256 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_PREFERENCES_DIALOG), NULL);
#line 2256 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return value->data[0].v_pointer;
#line 20889 "Dialogs.c"
}


void value_set_preferences_dialog (GValue* value, gpointer v_object) {
	PreferencesDialog* old;
#line 2256 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_PREFERENCES_DIALOG));
#line 2256 "/home/jens/Source/shotwell/src/Dialogs.vala"
	old = value->data[0].v_pointer;
#line 2256 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (v_object) {
#line 2256 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, TYPE_PREFERENCES_DIALOG));
#line 2256 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 2256 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = v_object;
#line 2256 "/home/jens/Source/shotwell/src/Dialogs.vala"
		preferences_dialog_ref (value->data[0].v_pointer);
#line 20909 "Dialogs.c"
	} else {
#line 2256 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = NULL;
#line 20913 "Dialogs.c"
	}
#line 2256 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (old) {
#line 2256 "/home/jens/Source/shotwell/src/Dialogs.vala"
		preferences_dialog_unref (old);
#line 20919 "Dialogs.c"
	}
}


void value_take_preferences_dialog (GValue* value, gpointer v_object) {
	PreferencesDialog* old;
#line 2256 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_PREFERENCES_DIALOG));
#line 2256 "/home/jens/Source/shotwell/src/Dialogs.vala"
	old = value->data[0].v_pointer;
#line 2256 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (v_object) {
#line 2256 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, TYPE_PREFERENCES_DIALOG));
#line 2256 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 2256 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = v_object;
#line 20938 "Dialogs.c"
	} else {
#line 2256 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = NULL;
#line 20942 "Dialogs.c"
	}
#line 2256 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (old) {
#line 2256 "/home/jens/Source/shotwell/src/Dialogs.vala"
		preferences_dialog_unref (old);
#line 20948 "Dialogs.c"
	}
}


static void preferences_dialog_class_init (PreferencesDialogClass * klass) {
#line 2256 "/home/jens/Source/shotwell/src/Dialogs.vala"
	preferences_dialog_parent_class = g_type_class_peek_parent (klass);
#line 2256 "/home/jens/Source/shotwell/src/Dialogs.vala"
	((PreferencesDialogClass *) klass)->finalize = preferences_dialog_finalize;
#line 2256 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_type_class_add_private (klass, sizeof (PreferencesDialogPrivate));
#line 20960 "Dialogs.c"
}


static void preferences_dialog_instance_init (PreferencesDialog * self) {
	GeeArrayList* _tmp0_ = NULL;
	GDateTime* _tmp1_ = NULL;
	PluginsManifestWidgetMediator* _tmp2_ = NULL;
#line 2256 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv = PREFERENCES_DIALOG_GET_PRIVATE (self);
#line 2280 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->allow_closing = FALSE;
#line 2281 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->lib_dir = NULL;
#line 2282 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = gee_array_list_new (PREFERENCES_DIALOG_TYPE_PATH_FORMAT, (GBoxedCopyFunc) preferences_dialog_path_format_ref, preferences_dialog_path_format_unref, NULL, NULL, NULL);
#line 2282 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->path_formats = _tmp0_;
#line 2283 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = g_date_time_new_local (2009, 3, 10, 18, 16, (gdouble) 11);
#line 2283 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->example_date = _tmp1_;
#line 2285 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = plugins_manifest_widget_mediator_new ();
#line 2285 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->plugins_mediator = _tmp2_;
#line 2256 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->ref_count = 1;
#line 20988 "Dialogs.c"
}


static void preferences_dialog_finalize (PreferencesDialog* obj) {
	PreferencesDialog * self;
#line 2256 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_PREFERENCES_DIALOG, PreferencesDialog);
#line 2256 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_handlers_destroy (self);
#line 2268 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->dialog);
#line 2269 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->builder);
#line 2270 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->bg_color_adjustment);
#line 2271 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->bg_color_slider);
#line 2272 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->photo_editor_combo);
#line 2273 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->raw_editor_combo);
#line 2274 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->external_raw_apps);
#line 2275 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->external_photo_apps);
#line 2276 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->library_dir_button);
#line 2277 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->dir_pattern_combo);
#line 2278 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->dir_pattern_entry);
#line 2279 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->dir_pattern_example);
#line 2281 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (self->priv->lib_dir);
#line 2282 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->path_formats);
#line 2283 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_date_time_unref0 (self->priv->example_date);
#line 2284 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->lowercase);
#line 2285 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_plugins_manifest_widget_mediator_unref0 (self->priv->plugins_mediator);
#line 2286 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->default_raw_developer_combo);
#line 21034 "Dialogs.c"
}


GType preferences_dialog_get_type (void) {
	static volatile gsize preferences_dialog_type_id__volatile = 0;
	if (g_once_init_enter (&preferences_dialog_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { value_preferences_dialog_init, value_preferences_dialog_free_value, value_preferences_dialog_copy_value, value_preferences_dialog_peek_pointer, "p", value_preferences_dialog_collect_value, "p", value_preferences_dialog_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (PreferencesDialogClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) preferences_dialog_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PreferencesDialog), 0, (GInstanceInitFunc) preferences_dialog_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType preferences_dialog_type_id;
		preferences_dialog_type_id = g_type_register_fundamental (g_type_fundamental_next (), "PreferencesDialog", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&preferences_dialog_type_id__volatile, preferences_dialog_type_id);
	}
	return preferences_dialog_type_id__volatile;
}


gpointer preferences_dialog_ref (gpointer instance) {
	PreferencesDialog* self;
	self = instance;
#line 2256 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_atomic_int_inc (&self->ref_count);
#line 2256 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return instance;
#line 21059 "Dialogs.c"
}


void preferences_dialog_unref (gpointer instance) {
	PreferencesDialog* self;
	self = instance;
#line 2256 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 2256 "/home/jens/Source/shotwell/src/Dialogs.vala"
		PREFERENCES_DIALOG_GET_CLASS (self)->finalize (self);
#line 2256 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 21072 "Dialogs.c"
	}
}


GtkResponseType copy_files_dialog (void) {
	GtkResponseType result = 0;
	gchar* msg = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	GtkMessageDialog* dialog = NULL;
	AppWindow* _tmp2_ = NULL;
	AppWindow* _tmp3_ = NULL;
	GtkMessageDialog* _tmp4_ = NULL;
	GtkMessageDialog* _tmp5_ = NULL;
	const gchar* _tmp6_ = NULL;
	const gchar* _tmp7_ = NULL;
	const gchar* _tmp8_ = NULL;
	GtkResponseType _result_ = 0;
	gint _tmp9_ = 0;
#line 2687 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = _ ("Shotwell can copy the photos into your library folder or it can import" \
" them without copying.");
#line 2687 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 2687 "/home/jens/Source/shotwell/src/Dialogs.vala"
	msg = _tmp1_;
#line 2689 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = app_window_get_instance ();
#line 2689 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = _tmp2_;
#line 2689 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = (GtkMessageDialog*) gtk_message_dialog_new (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, gtk_window_get_type (), GtkWindow), GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_CANCEL, "%s", msg);
#line 2689 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp4_);
#line 2689 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = _tmp4_;
#line 2689 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp3_);
#line 2689 "/home/jens/Source/shotwell/src/Dialogs.vala"
	dialog = _tmp5_;
#line 2692 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = _ ("Co_py Photos");
#line 2692 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_dialog_add_button (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_dialog_get_type (), GtkDialog), _tmp6_, (gint) GTK_RESPONSE_ACCEPT);
#line 2693 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = _ ("_Import in Place");
#line 2693 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_dialog_add_button (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_dialog_get_type (), GtkDialog), _tmp7_, (gint) GTK_RESPONSE_REJECT);
#line 2694 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = _ ("Import to Library");
#line 2694 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_window_set_title (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_window_get_type (), GtkWindow), _tmp8_);
#line 2696 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_dialog_get_type (), GtkDialog));
#line 2696 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_result_ = (GtkResponseType) _tmp9_;
#line 2698 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_widget_get_type (), GtkWidget));
#line 2700 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = _result_;
#line 2700 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (dialog);
#line 2700 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (msg);
#line 2700 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 21138 "Dialogs.c"
}


void remove_photos_from_library (GeeCollection* photos) {
	const gchar* _tmp0_ = NULL;
	GeeCollection* _tmp1_ = NULL;
	gint _tmp2_ = 0;
	gint _tmp3_ = 0;
	GeeCollection* _tmp6_ = NULL;
	const gchar* _tmp7_ = NULL;
#line 2703 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (GEE_IS_COLLECTION (photos));
#line 2705 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = photos;
#line 2705 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = gee_collection_get_size (_tmp1_);
#line 2705 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = _tmp2_;
#line 2705 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp3_ == 1) {
#line 21159 "Dialogs.c"
		const gchar* _tmp4_ = NULL;
#line 2705 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp4_ = _ ("Removing Photo From Library");
#line 2705 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = _tmp4_;
#line 21165 "Dialogs.c"
	} else {
		const gchar* _tmp5_ = NULL;
#line 2705 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp5_ = _ ("Removing Photos From Library");
#line 2705 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = _tmp5_;
#line 21172 "Dialogs.c"
	}
#line 2704 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = photos;
#line 2704 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = _ ("Remove From Library");
#line 2704 "/home/jens/Source/shotwell/src/Dialogs.vala"
	remove_from_app (_tmp6_, _tmp7_, _tmp0_);
#line 21180 "Dialogs.c"
}


static gboolean _progress_dialog_monitor_progress_monitor (guint64 current, guint64 total, gboolean do_event_loop, gpointer self) {
	gboolean result;
	result = progress_dialog_monitor ((ProgressDialog*) self, current, total, do_event_loop);
#line 2745 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 21189 "Dialogs.c"
}


void remove_from_app (GeeCollection* sources, const gchar* dialog_title, const gchar* progress_dialog_text) {
	GeeCollection* _tmp0_ = NULL;
	gint _tmp1_ = 0;
	gint _tmp2_ = 0;
	GeeArrayList* photos = NULL;
	GeeArrayList* _tmp3_ = NULL;
	GeeArrayList* videos = NULL;
	GeeArrayList* _tmp4_ = NULL;
	GeeCollection* _tmp5_ = NULL;
	GeeArrayList* _tmp6_ = NULL;
	GeeArrayList* _tmp7_ = NULL;
	gchar* user_message = NULL;
	gboolean _tmp8_ = FALSE;
	GeeArrayList* _tmp9_ = NULL;
	gboolean _tmp10_ = FALSE;
	gboolean _tmp11_ = FALSE;
	GtkResponseType _result_ = 0;
	AppWindow* _tmp42_ = NULL;
	AppWindow* _tmp43_ = NULL;
	const gchar* _tmp44_ = NULL;
	const gchar* _tmp45_ = NULL;
	GeeCollection* _tmp46_ = NULL;
	gint _tmp47_ = 0;
	gint _tmp48_ = 0;
	GtkResponseType _tmp49_ = 0;
	GtkResponseType _tmp50_ = 0;
	gboolean _tmp51_ = FALSE;
	GtkResponseType _tmp52_ = 0;
	gboolean delete_backing = FALSE;
	GtkResponseType _tmp54_ = 0;
	AppWindow* _tmp55_ = NULL;
	AppWindow* _tmp56_ = NULL;
	ProgressDialog* progress = NULL;
	ProgressMonitor monitor = NULL;
	void* monitor_target = NULL;
	GDestroyNotify monitor_target_destroy_notify = NULL;
	GeeCollection* _tmp57_ = NULL;
	gint _tmp58_ = 0;
	gint _tmp59_ = 0;
	GeeArrayList* not_removed_photos = NULL;
	GeeArrayList* _tmp65_ = NULL;
	GeeArrayList* not_removed_videos = NULL;
	GeeArrayList* _tmp66_ = NULL;
	LibraryPhotoSourceCollection* _tmp67_ = NULL;
	GeeArrayList* _tmp68_ = NULL;
	gboolean _tmp69_ = FALSE;
	ProgressMonitor _tmp70_ = NULL;
	void* _tmp70__target = NULL;
	GeeArrayList* _tmp71_ = NULL;
	VideoSourceCollection* _tmp72_ = NULL;
	GeeArrayList* _tmp73_ = NULL;
	gboolean _tmp74_ = FALSE;
	ProgressMonitor _tmp75_ = NULL;
	void* _tmp75__target = NULL;
	GeeArrayList* _tmp76_ = NULL;
	gint num_not_removed = 0;
	GeeArrayList* _tmp77_ = NULL;
	gint _tmp78_ = 0;
	gint _tmp79_ = 0;
	GeeArrayList* _tmp80_ = NULL;
	gint _tmp81_ = 0;
	gint _tmp82_ = 0;
	gboolean _tmp83_ = FALSE;
	gboolean _tmp84_ = FALSE;
	ProgressDialog* _tmp122_ = NULL;
	AppWindow* _tmp124_ = NULL;
	AppWindow* _tmp125_ = NULL;
#line 2708 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (GEE_IS_COLLECTION (sources));
#line 2708 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (dialog_title != NULL);
#line 2708 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (progress_dialog_text != NULL);
#line 2710 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = sources;
#line 2710 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = gee_collection_get_size (_tmp0_);
#line 2710 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = _tmp1_;
#line 2710 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp2_ == 0) {
#line 2711 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return;
#line 21276 "Dialogs.c"
	}
#line 2713 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = gee_array_list_new (TYPE_LIBRARY_PHOTO, (GBoxedCopyFunc) g_object_ref, g_object_unref, NULL, NULL, NULL);
#line 2713 "/home/jens/Source/shotwell/src/Dialogs.vala"
	photos = _tmp3_;
#line 2714 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = gee_array_list_new (TYPE_VIDEO, (GBoxedCopyFunc) g_object_ref, g_object_unref, NULL, NULL, NULL);
#line 2714 "/home/jens/Source/shotwell/src/Dialogs.vala"
	videos = _tmp4_;
#line 2715 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = sources;
#line 2715 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = photos;
#line 2715 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = videos;
#line 2715 "/home/jens/Source/shotwell/src/Dialogs.vala"
	media_source_collection_filter_media (_tmp5_, G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, GEE_TYPE_COLLECTION, GeeCollection), G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, GEE_TYPE_COLLECTION, GeeCollection));
#line 2717 "/home/jens/Source/shotwell/src/Dialogs.vala"
	user_message = NULL;
#line 2718 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = photos;
#line 2718 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp10_ = gee_collection_get_is_empty (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, GEE_TYPE_COLLECTION, GeeCollection));
#line 2718 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp11_ = _tmp10_;
#line 2718 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (!_tmp11_) {
#line 21304 "Dialogs.c"
		GeeArrayList* _tmp12_ = NULL;
		gboolean _tmp13_ = FALSE;
		gboolean _tmp14_ = FALSE;
#line 2718 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp12_ = videos;
#line 2718 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp13_ = gee_collection_get_is_empty (G_TYPE_CHECK_INSTANCE_CAST (_tmp12_, GEE_TYPE_COLLECTION, GeeCollection));
#line 2718 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp14_ = _tmp13_;
#line 2718 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp8_ = !_tmp14_;
#line 21316 "Dialogs.c"
	} else {
#line 2718 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp8_ = FALSE;
#line 21320 "Dialogs.c"
	}
#line 2718 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp8_) {
#line 21324 "Dialogs.c"
		GeeCollection* _tmp15_ = NULL;
		gint _tmp16_ = 0;
		gint _tmp17_ = 0;
		const gchar* _tmp18_ = NULL;
		GeeCollection* _tmp19_ = NULL;
		gint _tmp20_ = 0;
		gint _tmp21_ = 0;
		gchar* _tmp22_ = NULL;
#line 2719 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp15_ = sources;
#line 2719 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp16_ = gee_collection_get_size (_tmp15_);
#line 2719 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp17_ = _tmp16_;
#line 2719 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp18_ = ngettext ("This will remove the photo/video from your Shotwell library.  Would yo" \
"u also like to move the file to your desktop trash?\n" \
"\n" \
"This action cannot be undone.", "This will remove %d photos/videos from your Shotwell library.  Would y" \
"ou also like to move the files to your desktop trash?\n" \
"\n" \
"This action cannot be undone.", (gulong) _tmp17_);
#line 2719 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp19_ = sources;
#line 2719 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp20_ = gee_collection_get_size (_tmp19_);
#line 2719 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp21_ = _tmp20_;
#line 2719 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp22_ = g_strdup_printf (_tmp18_, _tmp21_);
#line 2719 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (user_message);
#line 2719 "/home/jens/Source/shotwell/src/Dialogs.vala"
		user_message = _tmp22_;
#line 21353 "Dialogs.c"
	} else {
		GeeArrayList* _tmp23_ = NULL;
		gboolean _tmp24_ = FALSE;
		gboolean _tmp25_ = FALSE;
#line 2722 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp23_ = videos;
#line 2722 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp24_ = gee_collection_get_is_empty (G_TYPE_CHECK_INSTANCE_CAST (_tmp23_, GEE_TYPE_COLLECTION, GeeCollection));
#line 2722 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp25_ = _tmp24_;
#line 2722 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (!_tmp25_) {
#line 21366 "Dialogs.c"
			GeeCollection* _tmp26_ = NULL;
			gint _tmp27_ = 0;
			gint _tmp28_ = 0;
			const gchar* _tmp29_ = NULL;
			GeeCollection* _tmp30_ = NULL;
			gint _tmp31_ = 0;
			gint _tmp32_ = 0;
			gchar* _tmp33_ = NULL;
#line 2723 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp26_ = sources;
#line 2723 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp27_ = gee_collection_get_size (_tmp26_);
#line 2723 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp28_ = _tmp27_;
#line 2723 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp29_ = ngettext ("This will remove the video from your Shotwell library.  Would you also" \
" like to move the file to your desktop trash?\n" \
"\n" \
"This action cannot be undone.", "This will remove %d videos from your Shotwell library.  Would you also" \
" like to move the files to your desktop trash?\n" \
"\n" \
"This action cannot be undone.", (gulong) _tmp28_);
#line 2723 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp30_ = sources;
#line 2723 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp31_ = gee_collection_get_size (_tmp30_);
#line 2723 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp32_ = _tmp31_;
#line 2723 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp33_ = g_strdup_printf (_tmp29_, _tmp32_);
#line 2723 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (user_message);
#line 2723 "/home/jens/Source/shotwell/src/Dialogs.vala"
			user_message = _tmp33_;
#line 21395 "Dialogs.c"
		} else {
			GeeCollection* _tmp34_ = NULL;
			gint _tmp35_ = 0;
			gint _tmp36_ = 0;
			const gchar* _tmp37_ = NULL;
			GeeCollection* _tmp38_ = NULL;
			gint _tmp39_ = 0;
			gint _tmp40_ = 0;
			gchar* _tmp41_ = NULL;
#line 2727 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp34_ = sources;
#line 2727 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp35_ = gee_collection_get_size (_tmp34_);
#line 2727 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp36_ = _tmp35_;
#line 2727 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp37_ = ngettext ("This will remove the photo from your Shotwell library.  Would you also" \
" like to move the file to your desktop trash?\n" \
"\n" \
"This action cannot be undone.", "This will remove %d photos from your Shotwell library.  Would you also" \
" like to move the files to your desktop trash?\n" \
"\n" \
"This action cannot be undone.", (gulong) _tmp36_);
#line 2727 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp38_ = sources;
#line 2727 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp39_ = gee_collection_get_size (_tmp38_);
#line 2727 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp40_ = _tmp39_;
#line 2727 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp41_ = g_strdup_printf (_tmp37_, _tmp40_);
#line 2727 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (user_message);
#line 2727 "/home/jens/Source/shotwell/src/Dialogs.vala"
			user_message = _tmp41_;
#line 21425 "Dialogs.c"
		}
	}
#line 2732 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp42_ = app_window_get_instance ();
#line 2732 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp43_ = _tmp42_;
#line 2732 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp44_ = dialog_title;
#line 2732 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp45_ = user_message;
#line 2732 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp46_ = sources;
#line 2732 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp47_ = gee_collection_get_size (_tmp46_);
#line 2732 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp48_ = _tmp47_;
#line 2732 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp49_ = remove_from_library_dialog (G_TYPE_CHECK_INSTANCE_CAST (_tmp43_, gtk_window_get_type (), GtkWindow), _tmp44_, _tmp45_, _tmp48_);
#line 2732 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp50_ = _tmp49_;
#line 2732 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp43_);
#line 2732 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_result_ = _tmp50_;
#line 2734 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp52_ = _result_;
#line 2734 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp52_ != GTK_RESPONSE_YES) {
#line 21454 "Dialogs.c"
		GtkResponseType _tmp53_ = 0;
#line 2734 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp53_ = _result_;
#line 2734 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp51_ = _tmp53_ != GTK_RESPONSE_NO;
#line 21460 "Dialogs.c"
	} else {
#line 2734 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp51_ = FALSE;
#line 21464 "Dialogs.c"
	}
#line 2734 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp51_) {
#line 2735 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (user_message);
#line 2735 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (videos);
#line 2735 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (photos);
#line 2735 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return;
#line 21476 "Dialogs.c"
	}
#line 2737 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp54_ = _result_;
#line 2737 "/home/jens/Source/shotwell/src/Dialogs.vala"
	delete_backing = _tmp54_ == GTK_RESPONSE_YES;
#line 2739 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp55_ = app_window_get_instance ();
#line 2739 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp56_ = _tmp55_;
#line 2739 "/home/jens/Source/shotwell/src/Dialogs.vala"
	page_window_set_busy_cursor (G_TYPE_CHECK_INSTANCE_CAST (_tmp56_, TYPE_PAGE_WINDOW, PageWindow));
#line 2739 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp56_);
#line 2741 "/home/jens/Source/shotwell/src/Dialogs.vala"
	progress = NULL;
#line 2742 "/home/jens/Source/shotwell/src/Dialogs.vala"
	monitor = NULL;
#line 2742 "/home/jens/Source/shotwell/src/Dialogs.vala"
	monitor_target = NULL;
#line 2742 "/home/jens/Source/shotwell/src/Dialogs.vala"
	monitor_target_destroy_notify = NULL;
#line 2743 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp57_ = sources;
#line 2743 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp58_ = gee_collection_get_size (_tmp57_);
#line 2743 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp59_ = _tmp58_;
#line 2743 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp59_ >= 20) {
#line 21506 "Dialogs.c"
		AppWindow* _tmp60_ = NULL;
		AppWindow* _tmp61_ = NULL;
		const gchar* _tmp62_ = NULL;
		ProgressDialog* _tmp63_ = NULL;
		ProgressDialog* _tmp64_ = NULL;
#line 2744 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp60_ = app_window_get_instance ();
#line 2744 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp61_ = _tmp60_;
#line 2744 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp62_ = progress_dialog_text;
#line 2744 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp63_ = progress_dialog_new (G_TYPE_CHECK_INSTANCE_CAST (_tmp61_, gtk_window_get_type (), GtkWindow), _tmp62_, NULL);
#line 2744 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_object_ref_sink (_tmp63_);
#line 2744 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (progress);
#line 2744 "/home/jens/Source/shotwell/src/Dialogs.vala"
		progress = _tmp63_;
#line 2744 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (_tmp61_);
#line 2745 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp64_ = progress;
#line 2745 "/home/jens/Source/shotwell/src/Dialogs.vala"
		(monitor_target_destroy_notify == NULL) ? NULL : (monitor_target_destroy_notify (monitor_target), NULL);
#line 2745 "/home/jens/Source/shotwell/src/Dialogs.vala"
		monitor = NULL;
#line 2745 "/home/jens/Source/shotwell/src/Dialogs.vala"
		monitor_target = NULL;
#line 2745 "/home/jens/Source/shotwell/src/Dialogs.vala"
		monitor_target_destroy_notify = NULL;
#line 2745 "/home/jens/Source/shotwell/src/Dialogs.vala"
		monitor = _progress_dialog_monitor_progress_monitor;
#line 2745 "/home/jens/Source/shotwell/src/Dialogs.vala"
		monitor_target = g_object_ref (_tmp64_);
#line 2745 "/home/jens/Source/shotwell/src/Dialogs.vala"
		monitor_target_destroy_notify = g_object_unref;
#line 21544 "Dialogs.c"
	}
#line 2748 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp65_ = gee_array_list_new (TYPE_LIBRARY_PHOTO, (GBoxedCopyFunc) g_object_ref, g_object_unref, NULL, NULL, NULL);
#line 2748 "/home/jens/Source/shotwell/src/Dialogs.vala"
	not_removed_photos = _tmp65_;
#line 2749 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp66_ = gee_array_list_new (TYPE_VIDEO, (GBoxedCopyFunc) g_object_ref, g_object_unref, NULL, NULL, NULL);
#line 2749 "/home/jens/Source/shotwell/src/Dialogs.vala"
	not_removed_videos = _tmp66_;
#line 2752 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp67_ = library_photo_global;
#line 2752 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp68_ = photos;
#line 2752 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp69_ = delete_backing;
#line 2752 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp70_ = monitor;
#line 2752 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp70__target = monitor_target;
#line 2752 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp71_ = not_removed_photos;
#line 2752 "/home/jens/Source/shotwell/src/Dialogs.vala"
	media_source_collection_remove_from_app (G_TYPE_CHECK_INSTANCE_CAST (_tmp67_, TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollection), G_TYPE_CHECK_INSTANCE_CAST (_tmp68_, GEE_TYPE_COLLECTION, GeeCollection), _tmp69_, _tmp70_, _tmp70__target, G_TYPE_CHECK_INSTANCE_CAST (_tmp71_, GEE_TYPE_LIST, GeeList));
#line 2753 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp72_ = video_global;
#line 2753 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp73_ = videos;
#line 2753 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp74_ = delete_backing;
#line 2753 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp75_ = monitor;
#line 2753 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp75__target = monitor_target;
#line 2753 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp76_ = not_removed_videos;
#line 2753 "/home/jens/Source/shotwell/src/Dialogs.vala"
	media_source_collection_remove_from_app (G_TYPE_CHECK_INSTANCE_CAST (_tmp72_, TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollection), G_TYPE_CHECK_INSTANCE_CAST (_tmp73_, GEE_TYPE_COLLECTION, GeeCollection), _tmp74_, _tmp75_, _tmp75__target, G_TYPE_CHECK_INSTANCE_CAST (_tmp76_, GEE_TYPE_LIST, GeeList));
#line 2756 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp77_ = not_removed_photos;
#line 2756 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp78_ = gee_abstract_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp77_, GEE_TYPE_COLLECTION, GeeCollection));
#line 2756 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp79_ = _tmp78_;
#line 2756 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp80_ = not_removed_videos;
#line 2756 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp81_ = gee_abstract_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp80_, GEE_TYPE_COLLECTION, GeeCollection));
#line 2756 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp82_ = _tmp81_;
#line 2756 "/home/jens/Source/shotwell/src/Dialogs.vala"
	num_not_removed = _tmp79_ + _tmp82_;
#line 2757 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp84_ = delete_backing;
#line 2757 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp84_) {
#line 21600 "Dialogs.c"
		gint _tmp85_ = 0;
#line 2757 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp85_ = num_not_removed;
#line 2757 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp83_ = _tmp85_ > 0;
#line 21606 "Dialogs.c"
	} else {
#line 2757 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp83_ = FALSE;
#line 21610 "Dialogs.c"
	}
#line 2757 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp83_) {
#line 21614 "Dialogs.c"
		gchar* not_deleted_message = NULL;
		gint _tmp86_ = 0;
		const gchar* _tmp87_ = NULL;
		gint _tmp88_ = 0;
		gchar* _tmp89_ = NULL;
		GtkResponseType result_delete = 0;
		AppWindow* _tmp90_ = NULL;
		AppWindow* _tmp91_ = NULL;
		const gchar* _tmp92_ = NULL;
		const gchar* _tmp93_ = NULL;
		GtkResponseType _tmp94_ = 0;
		GtkResponseType _tmp95_ = 0;
		GtkResponseType _tmp96_ = 0;
#line 2758 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp86_ = num_not_removed;
#line 2758 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp87_ = ngettext ("The photo or video cannot be moved to your desktop trash.  Delete this" \
" file?", "%d photos/videos cannot be moved to your desktop trash.  Delete these " \
"files?", (gulong) _tmp86_);
#line 2758 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp88_ = num_not_removed;
#line 2758 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp89_ = g_strdup_printf (_tmp87_, _tmp88_);
#line 2758 "/home/jens/Source/shotwell/src/Dialogs.vala"
		not_deleted_message = _tmp89_;
#line 2762 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp90_ = app_window_get_instance ();
#line 2762 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp91_ = _tmp90_;
#line 2762 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp92_ = dialog_title;
#line 2762 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp93_ = not_deleted_message;
#line 2762 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp94_ = remove_from_filesystem_dialog (G_TYPE_CHECK_INSTANCE_CAST (_tmp91_, gtk_window_get_type (), GtkWindow), _tmp92_, _tmp93_);
#line 2762 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp95_ = _tmp94_;
#line 2762 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (_tmp91_);
#line 2762 "/home/jens/Source/shotwell/src/Dialogs.vala"
		result_delete = _tmp95_;
#line 2765 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp96_ = result_delete;
#line 2765 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (GTK_RESPONSE_YES == _tmp96_) {
#line 21658 "Dialogs.c"
			GeeArrayList* not_deleted_photos = NULL;
			GeeArrayList* _tmp97_ = NULL;
			GeeArrayList* not_deleted_videos = NULL;
			GeeArrayList* _tmp98_ = NULL;
			LibraryPhotoSourceCollection* _tmp99_ = NULL;
			GeeArrayList* _tmp100_ = NULL;
			ProgressMonitor _tmp101_ = NULL;
			void* _tmp101__target = NULL;
			GeeArrayList* _tmp102_ = NULL;
			VideoSourceCollection* _tmp103_ = NULL;
			GeeArrayList* _tmp104_ = NULL;
			ProgressMonitor _tmp105_ = NULL;
			void* _tmp105__target = NULL;
			GeeArrayList* _tmp106_ = NULL;
			gint num_not_deleted = 0;
			GeeArrayList* _tmp107_ = NULL;
			gint _tmp108_ = 0;
			gint _tmp109_ = 0;
			GeeArrayList* _tmp110_ = NULL;
			gint _tmp111_ = 0;
			gint _tmp112_ = 0;
			gint _tmp113_ = 0;
#line 2767 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp97_ = gee_array_list_new (TYPE_LIBRARY_PHOTO, (GBoxedCopyFunc) g_object_ref, g_object_unref, NULL, NULL, NULL);
#line 2767 "/home/jens/Source/shotwell/src/Dialogs.vala"
			not_deleted_photos = _tmp97_;
#line 2768 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp98_ = gee_array_list_new (TYPE_VIDEO, (GBoxedCopyFunc) g_object_ref, g_object_unref, NULL, NULL, NULL);
#line 2768 "/home/jens/Source/shotwell/src/Dialogs.vala"
			not_deleted_videos = _tmp98_;
#line 2769 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp99_ = library_photo_global;
#line 2769 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp100_ = not_removed_photos;
#line 2769 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp101_ = monitor;
#line 2769 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp101__target = monitor_target;
#line 2769 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp102_ = not_deleted_photos;
#line 2769 "/home/jens/Source/shotwell/src/Dialogs.vala"
			media_source_collection_delete_backing_files (G_TYPE_CHECK_INSTANCE_CAST (_tmp99_, TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollection), G_TYPE_CHECK_INSTANCE_CAST (_tmp100_, GEE_TYPE_COLLECTION, GeeCollection), _tmp101_, _tmp101__target, G_TYPE_CHECK_INSTANCE_CAST (_tmp102_, GEE_TYPE_LIST, GeeList));
#line 2770 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp103_ = video_global;
#line 2770 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp104_ = not_removed_videos;
#line 2770 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp105_ = monitor;
#line 2770 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp105__target = monitor_target;
#line 2770 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp106_ = not_deleted_videos;
#line 2770 "/home/jens/Source/shotwell/src/Dialogs.vala"
			media_source_collection_delete_backing_files (G_TYPE_CHECK_INSTANCE_CAST (_tmp103_, TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollection), G_TYPE_CHECK_INSTANCE_CAST (_tmp104_, GEE_TYPE_COLLECTION, GeeCollection), _tmp105_, _tmp105__target, G_TYPE_CHECK_INSTANCE_CAST (_tmp106_, GEE_TYPE_LIST, GeeList));
#line 2772 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp107_ = not_deleted_photos;
#line 2772 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp108_ = gee_abstract_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp107_, GEE_TYPE_COLLECTION, GeeCollection));
#line 2772 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp109_ = _tmp108_;
#line 2772 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp110_ = not_deleted_videos;
#line 2772 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp111_ = gee_abstract_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp110_, GEE_TYPE_COLLECTION, GeeCollection));
#line 2772 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp112_ = _tmp111_;
#line 2772 "/home/jens/Source/shotwell/src/Dialogs.vala"
			num_not_deleted = _tmp109_ + _tmp112_;
#line 2773 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp113_ = num_not_deleted;
#line 2773 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (_tmp113_ > 0) {
#line 21731 "Dialogs.c"
				gchar* delete_failed_message = NULL;
				gint _tmp114_ = 0;
				const gchar* _tmp115_ = NULL;
				gint _tmp116_ = 0;
				gchar* _tmp117_ = NULL;
				const gchar* _tmp118_ = NULL;
				const gchar* _tmp119_ = NULL;
				AppWindow* _tmp120_ = NULL;
				AppWindow* _tmp121_ = NULL;
#line 2775 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp114_ = num_not_deleted;
#line 2775 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp115_ = ngettext ("The photo or video cannot be deleted.", "%d photos/videos cannot be deleted.", (gulong) _tmp114_);
#line 2775 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp116_ = num_not_deleted;
#line 2775 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp117_ = g_strdup_printf (_tmp115_, _tmp116_);
#line 2775 "/home/jens/Source/shotwell/src/Dialogs.vala"
				delete_failed_message = _tmp117_;
#line 2779 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp118_ = dialog_title;
#line 2779 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp119_ = delete_failed_message;
#line 2779 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp120_ = app_window_get_instance ();
#line 2779 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp121_ = _tmp120_;
#line 2779 "/home/jens/Source/shotwell/src/Dialogs.vala"
				app_window_error_message_with_title (_tmp118_, _tmp119_, G_TYPE_CHECK_INSTANCE_CAST (_tmp121_, gtk_window_get_type (), GtkWindow), TRUE);
#line 2779 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_object_unref0 (_tmp121_);
#line 2773 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (delete_failed_message);
#line 21765 "Dialogs.c"
			}
#line 2765 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_object_unref0 (not_deleted_videos);
#line 2765 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_object_unref0 (not_deleted_photos);
#line 21771 "Dialogs.c"
		}
#line 2757 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (not_deleted_message);
#line 21775 "Dialogs.c"
	}
#line 2784 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp122_ = progress;
#line 2784 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp122_ != NULL) {
#line 21781 "Dialogs.c"
		ProgressDialog* _tmp123_ = NULL;
#line 2785 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp123_ = progress;
#line 2785 "/home/jens/Source/shotwell/src/Dialogs.vala"
		progress_dialog_close (_tmp123_);
#line 21787 "Dialogs.c"
	}
#line 2787 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp124_ = app_window_get_instance ();
#line 2787 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp125_ = _tmp124_;
#line 2787 "/home/jens/Source/shotwell/src/Dialogs.vala"
	page_window_set_normal_cursor (G_TYPE_CHECK_INSTANCE_CAST (_tmp125_, TYPE_PAGE_WINDOW, PageWindow));
#line 2787 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp125_);
#line 2708 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (not_removed_videos);
#line 2708 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (not_removed_photos);
#line 2708 "/home/jens/Source/shotwell/src/Dialogs.vala"
	(monitor_target_destroy_notify == NULL) ? NULL : (monitor_target_destroy_notify (monitor_target), NULL);
#line 2708 "/home/jens/Source/shotwell/src/Dialogs.vala"
	monitor = NULL;
#line 2708 "/home/jens/Source/shotwell/src/Dialogs.vala"
	monitor_target = NULL;
#line 2708 "/home/jens/Source/shotwell/src/Dialogs.vala"
	monitor_target_destroy_notify = NULL;
#line 2708 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (progress);
#line 2708 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (user_message);
#line 2708 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (videos);
#line 2708 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (photos);
#line 21817 "Dialogs.c"
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}


static gint _vala_array_length (gpointer array) {
	int length;
	length = 0;
	if (array) {
		while (((gpointer*) array)[length]) {
			length++;
		}
	}
	return length;
}



