/* PiwigoPublishing.c generated by valac 0.32.1, the Vala compiler
 * generated from PiwigoPublishing.vala, do not modify */

/* Copyright 2016 Software Freedom Conservancy Inc.
 *
 * This software is licensed under the GNU Lesser General Public License
 * (version 2.1 or later).  See the COPYING file in this distribution.
 */

#include <glib.h>
#include <glib-object.h>
#include <shotwell-plugin-dev-1.0.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <stdlib.h>
#include <string.h>
#include <gio/gio.h>
#include "shotwell-plugin-common.h"
#include <glib/gi18n-lib.h>
#include <gtk/gtk.h>
#include <libxml/tree.h>
#include <float.h>
#include <math.h>
#include <libsoup/soup.h>
#include <gobject/gvaluecollector.h>


#define TYPE_PIWIGO_SERVICE (piwigo_service_get_type ())
#define PIWIGO_SERVICE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PIWIGO_SERVICE, PiwigoService))
#define PIWIGO_SERVICE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PIWIGO_SERVICE, PiwigoServiceClass))
#define IS_PIWIGO_SERVICE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PIWIGO_SERVICE))
#define IS_PIWIGO_SERVICE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PIWIGO_SERVICE))
#define PIWIGO_SERVICE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PIWIGO_SERVICE, PiwigoServiceClass))

typedef struct _PiwigoService PiwigoService;
typedef struct _PiwigoServiceClass PiwigoServiceClass;
typedef struct _PiwigoServicePrivate PiwigoServicePrivate;
#define _g_free0(var) (var = (g_free (var), NULL))

#define PUBLISHING_PIWIGO_TYPE_PIWIGO_PUBLISHER (publishing_piwigo_piwigo_publisher_get_type ())
#define PUBLISHING_PIWIGO_PIWIGO_PUBLISHER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_PIWIGO_TYPE_PIWIGO_PUBLISHER, PublishingPiwigoPiwigoPublisher))
#define PUBLISHING_PIWIGO_PIWIGO_PUBLISHER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_PIWIGO_TYPE_PIWIGO_PUBLISHER, PublishingPiwigoPiwigoPublisherClass))
#define PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_PIWIGO_TYPE_PIWIGO_PUBLISHER))
#define PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_PIWIGO_TYPE_PIWIGO_PUBLISHER))
#define PUBLISHING_PIWIGO_PIWIGO_PUBLISHER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_PIWIGO_TYPE_PIWIGO_PUBLISHER, PublishingPiwigoPiwigoPublisherClass))

typedef struct _PublishingPiwigoPiwigoPublisher PublishingPiwigoPiwigoPublisher;
typedef struct _PublishingPiwigoPiwigoPublisherClass PublishingPiwigoPiwigoPublisherClass;

#define PUBLISHING_PIWIGO_TYPE_CATEGORY (publishing_piwigo_category_get_type ())
#define PUBLISHING_PIWIGO_CATEGORY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_PIWIGO_TYPE_CATEGORY, PublishingPiwigoCategory))
#define PUBLISHING_PIWIGO_CATEGORY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_PIWIGO_TYPE_CATEGORY, PublishingPiwigoCategoryClass))
#define PUBLISHING_PIWIGO_IS_CATEGORY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_PIWIGO_TYPE_CATEGORY))
#define PUBLISHING_PIWIGO_IS_CATEGORY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_PIWIGO_TYPE_CATEGORY))
#define PUBLISHING_PIWIGO_CATEGORY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_PIWIGO_TYPE_CATEGORY, PublishingPiwigoCategoryClass))

typedef struct _PublishingPiwigoCategory PublishingPiwigoCategory;
typedef struct _PublishingPiwigoCategoryClass PublishingPiwigoCategoryClass;
typedef struct _PublishingPiwigoCategoryPrivate PublishingPiwigoCategoryPrivate;
typedef struct _PublishingPiwigoParamSpecCategory PublishingPiwigoParamSpecCategory;

#define PUBLISHING_PIWIGO_TYPE_PERMISSION_LEVEL (publishing_piwigo_permission_level_get_type ())
#define PUBLISHING_PIWIGO_PERMISSION_LEVEL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_PIWIGO_TYPE_PERMISSION_LEVEL, PublishingPiwigoPermissionLevel))
#define PUBLISHING_PIWIGO_PERMISSION_LEVEL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_PIWIGO_TYPE_PERMISSION_LEVEL, PublishingPiwigoPermissionLevelClass))
#define PUBLISHING_PIWIGO_IS_PERMISSION_LEVEL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_PIWIGO_TYPE_PERMISSION_LEVEL))
#define PUBLISHING_PIWIGO_IS_PERMISSION_LEVEL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_PIWIGO_TYPE_PERMISSION_LEVEL))
#define PUBLISHING_PIWIGO_PERMISSION_LEVEL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_PIWIGO_TYPE_PERMISSION_LEVEL, PublishingPiwigoPermissionLevelClass))

typedef struct _PublishingPiwigoPermissionLevel PublishingPiwigoPermissionLevel;
typedef struct _PublishingPiwigoPermissionLevelClass PublishingPiwigoPermissionLevelClass;
typedef struct _PublishingPiwigoPermissionLevelPrivate PublishingPiwigoPermissionLevelPrivate;
typedef struct _PublishingPiwigoParamSpecPermissionLevel PublishingPiwigoParamSpecPermissionLevel;

#define PUBLISHING_PIWIGO_TYPE_SIZE_ENTRY (publishing_piwigo_size_entry_get_type ())
#define PUBLISHING_PIWIGO_SIZE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_PIWIGO_TYPE_SIZE_ENTRY, PublishingPiwigoSizeEntry))
#define PUBLISHING_PIWIGO_SIZE_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_PIWIGO_TYPE_SIZE_ENTRY, PublishingPiwigoSizeEntryClass))
#define PUBLISHING_PIWIGO_IS_SIZE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_PIWIGO_TYPE_SIZE_ENTRY))
#define PUBLISHING_PIWIGO_IS_SIZE_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_PIWIGO_TYPE_SIZE_ENTRY))
#define PUBLISHING_PIWIGO_SIZE_ENTRY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_PIWIGO_TYPE_SIZE_ENTRY, PublishingPiwigoSizeEntryClass))

typedef struct _PublishingPiwigoSizeEntry PublishingPiwigoSizeEntry;
typedef struct _PublishingPiwigoSizeEntryClass PublishingPiwigoSizeEntryClass;
typedef struct _PublishingPiwigoSizeEntryPrivate PublishingPiwigoSizeEntryPrivate;
typedef struct _PublishingPiwigoParamSpecSizeEntry PublishingPiwigoParamSpecSizeEntry;

#define PUBLISHING_PIWIGO_TYPE_PUBLISHING_PARAMETERS (publishing_piwigo_publishing_parameters_get_type ())
#define PUBLISHING_PIWIGO_PUBLISHING_PARAMETERS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_PIWIGO_TYPE_PUBLISHING_PARAMETERS, PublishingPiwigoPublishingParameters))
#define PUBLISHING_PIWIGO_PUBLISHING_PARAMETERS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_PIWIGO_TYPE_PUBLISHING_PARAMETERS, PublishingPiwigoPublishingParametersClass))
#define PUBLISHING_PIWIGO_IS_PUBLISHING_PARAMETERS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_PIWIGO_TYPE_PUBLISHING_PARAMETERS))
#define PUBLISHING_PIWIGO_IS_PUBLISHING_PARAMETERS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_PIWIGO_TYPE_PUBLISHING_PARAMETERS))
#define PUBLISHING_PIWIGO_PUBLISHING_PARAMETERS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_PIWIGO_TYPE_PUBLISHING_PARAMETERS, PublishingPiwigoPublishingParametersClass))

typedef struct _PublishingPiwigoPublishingParameters PublishingPiwigoPublishingParameters;
typedef struct _PublishingPiwigoPublishingParametersClass PublishingPiwigoPublishingParametersClass;
typedef struct _PublishingPiwigoPublishingParametersPrivate PublishingPiwigoPublishingParametersPrivate;
#define _publishing_piwigo_category_unref0(var) ((var == NULL) ? NULL : (var = (publishing_piwigo_category_unref (var), NULL)))
#define _publishing_piwigo_permission_level_unref0(var) ((var == NULL) ? NULL : (var = (publishing_piwigo_permission_level_unref (var), NULL)))
#define _publishing_piwigo_size_entry_unref0(var) ((var == NULL) ? NULL : (var = (publishing_piwigo_size_entry_unref (var), NULL)))
typedef struct _PublishingPiwigoParamSpecPublishingParameters PublishingPiwigoParamSpecPublishingParameters;
typedef struct _PublishingPiwigoPiwigoPublisherPrivate PublishingPiwigoPiwigoPublisherPrivate;

#define PUBLISHING_PIWIGO_TYPE_SESSION (publishing_piwigo_session_get_type ())
#define PUBLISHING_PIWIGO_SESSION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_PIWIGO_TYPE_SESSION, PublishingPiwigoSession))
#define PUBLISHING_PIWIGO_SESSION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_PIWIGO_TYPE_SESSION, PublishingPiwigoSessionClass))
#define PUBLISHING_PIWIGO_IS_SESSION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_PIWIGO_TYPE_SESSION))
#define PUBLISHING_PIWIGO_IS_SESSION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_PIWIGO_TYPE_SESSION))
#define PUBLISHING_PIWIGO_SESSION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_PIWIGO_TYPE_SESSION, PublishingPiwigoSessionClass))

typedef struct _PublishingPiwigoSession PublishingPiwigoSession;
typedef struct _PublishingPiwigoSessionClass PublishingPiwigoSessionClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _publishing_rest_support_session_unref0(var) ((var == NULL) ? NULL : (var = (publishing_rest_support_session_unref (var), NULL)))
#define _publishing_piwigo_publishing_parameters_unref0(var) ((var == NULL) ? NULL : (var = (publishing_piwigo_publishing_parameters_unref (var), NULL)))

#define PUBLISHING_PIWIGO_AUTHENTICATION_PANE_TYPE_MODE (publishing_piwigo_authentication_pane_mode_get_type ())

#define PUBLISHING_PIWIGO_TYPE_AUTHENTICATION_PANE (publishing_piwigo_authentication_pane_get_type ())
#define PUBLISHING_PIWIGO_AUTHENTICATION_PANE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_PIWIGO_TYPE_AUTHENTICATION_PANE, PublishingPiwigoAuthenticationPane))
#define PUBLISHING_PIWIGO_AUTHENTICATION_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_PIWIGO_TYPE_AUTHENTICATION_PANE, PublishingPiwigoAuthenticationPaneClass))
#define PUBLISHING_PIWIGO_IS_AUTHENTICATION_PANE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_PIWIGO_TYPE_AUTHENTICATION_PANE))
#define PUBLISHING_PIWIGO_IS_AUTHENTICATION_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_PIWIGO_TYPE_AUTHENTICATION_PANE))
#define PUBLISHING_PIWIGO_AUTHENTICATION_PANE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_PIWIGO_TYPE_AUTHENTICATION_PANE, PublishingPiwigoAuthenticationPaneClass))

typedef struct _PublishingPiwigoAuthenticationPane PublishingPiwigoAuthenticationPane;
typedef struct _PublishingPiwigoAuthenticationPaneClass PublishingPiwigoAuthenticationPaneClass;

#define PUBLISHING_PIWIGO_TYPE_TRANSACTION (publishing_piwigo_transaction_get_type ())
#define PUBLISHING_PIWIGO_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_PIWIGO_TYPE_TRANSACTION, PublishingPiwigoTransaction))
#define PUBLISHING_PIWIGO_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_PIWIGO_TYPE_TRANSACTION, PublishingPiwigoTransactionClass))
#define PUBLISHING_PIWIGO_IS_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_PIWIGO_TYPE_TRANSACTION))
#define PUBLISHING_PIWIGO_IS_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_PIWIGO_TYPE_TRANSACTION))
#define PUBLISHING_PIWIGO_TRANSACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_PIWIGO_TYPE_TRANSACTION, PublishingPiwigoTransactionClass))

typedef struct _PublishingPiwigoTransaction PublishingPiwigoTransaction;
typedef struct _PublishingPiwigoTransactionClass PublishingPiwigoTransactionClass;

#define PUBLISHING_PIWIGO_TYPE_SESSION_LOGIN_TRANSACTION (publishing_piwigo_session_login_transaction_get_type ())
#define PUBLISHING_PIWIGO_SESSION_LOGIN_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_PIWIGO_TYPE_SESSION_LOGIN_TRANSACTION, PublishingPiwigoSessionLoginTransaction))
#define PUBLISHING_PIWIGO_SESSION_LOGIN_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_PIWIGO_TYPE_SESSION_LOGIN_TRANSACTION, PublishingPiwigoSessionLoginTransactionClass))
#define PUBLISHING_PIWIGO_IS_SESSION_LOGIN_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_PIWIGO_TYPE_SESSION_LOGIN_TRANSACTION))
#define PUBLISHING_PIWIGO_IS_SESSION_LOGIN_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_PIWIGO_TYPE_SESSION_LOGIN_TRANSACTION))
#define PUBLISHING_PIWIGO_SESSION_LOGIN_TRANSACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_PIWIGO_TYPE_SESSION_LOGIN_TRANSACTION, PublishingPiwigoSessionLoginTransactionClass))

typedef struct _PublishingPiwigoSessionLoginTransaction PublishingPiwigoSessionLoginTransaction;
typedef struct _PublishingPiwigoSessionLoginTransactionClass PublishingPiwigoSessionLoginTransactionClass;
#define _publishing_rest_support_transaction_unref0(var) ((var == NULL) ? NULL : (var = (publishing_rest_support_transaction_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
#define _publishing_rest_support_xml_document_unref0(var) ((var == NULL) ? NULL : (var = (publishing_rest_support_xml_document_unref (var), NULL)))

#define PUBLISHING_PIWIGO_TYPE_SESSION_GET_STATUS_TRANSACTION (publishing_piwigo_session_get_status_transaction_get_type ())
#define PUBLISHING_PIWIGO_SESSION_GET_STATUS_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_PIWIGO_TYPE_SESSION_GET_STATUS_TRANSACTION, PublishingPiwigoSessionGetStatusTransaction))
#define PUBLISHING_PIWIGO_SESSION_GET_STATUS_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_PIWIGO_TYPE_SESSION_GET_STATUS_TRANSACTION, PublishingPiwigoSessionGetStatusTransactionClass))
#define PUBLISHING_PIWIGO_IS_SESSION_GET_STATUS_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_PIWIGO_TYPE_SESSION_GET_STATUS_TRANSACTION))
#define PUBLISHING_PIWIGO_IS_SESSION_GET_STATUS_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_PIWIGO_TYPE_SESSION_GET_STATUS_TRANSACTION))
#define PUBLISHING_PIWIGO_SESSION_GET_STATUS_TRANSACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_PIWIGO_TYPE_SESSION_GET_STATUS_TRANSACTION, PublishingPiwigoSessionGetStatusTransactionClass))

typedef struct _PublishingPiwigoSessionGetStatusTransaction PublishingPiwigoSessionGetStatusTransaction;
typedef struct _PublishingPiwigoSessionGetStatusTransactionClass PublishingPiwigoSessionGetStatusTransactionClass;

#define PUBLISHING_PIWIGO_TYPE_CATEGORIES_GET_LIST_TRANSACTION (publishing_piwigo_categories_get_list_transaction_get_type ())
#define PUBLISHING_PIWIGO_CATEGORIES_GET_LIST_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_PIWIGO_TYPE_CATEGORIES_GET_LIST_TRANSACTION, PublishingPiwigoCategoriesGetListTransaction))
#define PUBLISHING_PIWIGO_CATEGORIES_GET_LIST_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_PIWIGO_TYPE_CATEGORIES_GET_LIST_TRANSACTION, PublishingPiwigoCategoriesGetListTransactionClass))
#define PUBLISHING_PIWIGO_IS_CATEGORIES_GET_LIST_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_PIWIGO_TYPE_CATEGORIES_GET_LIST_TRANSACTION))
#define PUBLISHING_PIWIGO_IS_CATEGORIES_GET_LIST_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_PIWIGO_TYPE_CATEGORIES_GET_LIST_TRANSACTION))
#define PUBLISHING_PIWIGO_CATEGORIES_GET_LIST_TRANSACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_PIWIGO_TYPE_CATEGORIES_GET_LIST_TRANSACTION, PublishingPiwigoCategoriesGetListTransactionClass))

typedef struct _PublishingPiwigoCategoriesGetListTransaction PublishingPiwigoCategoriesGetListTransaction;
typedef struct _PublishingPiwigoCategoriesGetListTransactionClass PublishingPiwigoCategoriesGetListTransactionClass;
#define _g_string_free0(var) ((var == NULL) ? NULL : (var = (g_string_free (var, TRUE), NULL)))

#define PUBLISHING_PIWIGO_TYPE_PUBLISHING_OPTIONS_PANE (publishing_piwigo_publishing_options_pane_get_type ())
#define PUBLISHING_PIWIGO_PUBLISHING_OPTIONS_PANE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_PIWIGO_TYPE_PUBLISHING_OPTIONS_PANE, PublishingPiwigoPublishingOptionsPane))
#define PUBLISHING_PIWIGO_PUBLISHING_OPTIONS_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_PIWIGO_TYPE_PUBLISHING_OPTIONS_PANE, PublishingPiwigoPublishingOptionsPaneClass))
#define PUBLISHING_PIWIGO_IS_PUBLISHING_OPTIONS_PANE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_PIWIGO_TYPE_PUBLISHING_OPTIONS_PANE))
#define PUBLISHING_PIWIGO_IS_PUBLISHING_OPTIONS_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_PIWIGO_TYPE_PUBLISHING_OPTIONS_PANE))
#define PUBLISHING_PIWIGO_PUBLISHING_OPTIONS_PANE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_PIWIGO_TYPE_PUBLISHING_OPTIONS_PANE, PublishingPiwigoPublishingOptionsPaneClass))

typedef struct _PublishingPiwigoPublishingOptionsPane PublishingPiwigoPublishingOptionsPane;
typedef struct _PublishingPiwigoPublishingOptionsPaneClass PublishingPiwigoPublishingOptionsPaneClass;

#define PUBLISHING_PIWIGO_TYPE_SESSION_LOGOUT_TRANSACTION (publishing_piwigo_session_logout_transaction_get_type ())
#define PUBLISHING_PIWIGO_SESSION_LOGOUT_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_PIWIGO_TYPE_SESSION_LOGOUT_TRANSACTION, PublishingPiwigoSessionLogoutTransaction))
#define PUBLISHING_PIWIGO_SESSION_LOGOUT_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_PIWIGO_TYPE_SESSION_LOGOUT_TRANSACTION, PublishingPiwigoSessionLogoutTransactionClass))
#define PUBLISHING_PIWIGO_IS_SESSION_LOGOUT_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_PIWIGO_TYPE_SESSION_LOGOUT_TRANSACTION))
#define PUBLISHING_PIWIGO_IS_SESSION_LOGOUT_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_PIWIGO_TYPE_SESSION_LOGOUT_TRANSACTION))
#define PUBLISHING_PIWIGO_SESSION_LOGOUT_TRANSACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_PIWIGO_TYPE_SESSION_LOGOUT_TRANSACTION, PublishingPiwigoSessionLogoutTransactionClass))

typedef struct _PublishingPiwigoSessionLogoutTransaction PublishingPiwigoSessionLogoutTransaction;
typedef struct _PublishingPiwigoSessionLogoutTransactionClass PublishingPiwigoSessionLogoutTransactionClass;

#define PUBLISHING_PIWIGO_TYPE_CATEGORIES_ADD_TRANSACTION (publishing_piwigo_categories_add_transaction_get_type ())
#define PUBLISHING_PIWIGO_CATEGORIES_ADD_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_PIWIGO_TYPE_CATEGORIES_ADD_TRANSACTION, PublishingPiwigoCategoriesAddTransaction))
#define PUBLISHING_PIWIGO_CATEGORIES_ADD_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_PIWIGO_TYPE_CATEGORIES_ADD_TRANSACTION, PublishingPiwigoCategoriesAddTransactionClass))
#define PUBLISHING_PIWIGO_IS_CATEGORIES_ADD_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_PIWIGO_TYPE_CATEGORIES_ADD_TRANSACTION))
#define PUBLISHING_PIWIGO_IS_CATEGORIES_ADD_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_PIWIGO_TYPE_CATEGORIES_ADD_TRANSACTION))
#define PUBLISHING_PIWIGO_CATEGORIES_ADD_TRANSACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_PIWIGO_TYPE_CATEGORIES_ADD_TRANSACTION, PublishingPiwigoCategoriesAddTransactionClass))

typedef struct _PublishingPiwigoCategoriesAddTransaction PublishingPiwigoCategoriesAddTransaction;
typedef struct _PublishingPiwigoCategoriesAddTransactionClass PublishingPiwigoCategoriesAddTransactionClass;

#define PUBLISHING_PIWIGO_TYPE_UPLOADER (publishing_piwigo_uploader_get_type ())
#define PUBLISHING_PIWIGO_UPLOADER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_PIWIGO_TYPE_UPLOADER, PublishingPiwigoUploader))
#define PUBLISHING_PIWIGO_UPLOADER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_PIWIGO_TYPE_UPLOADER, PublishingPiwigoUploaderClass))
#define PUBLISHING_PIWIGO_IS_UPLOADER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_PIWIGO_TYPE_UPLOADER))
#define PUBLISHING_PIWIGO_IS_UPLOADER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_PIWIGO_TYPE_UPLOADER))
#define PUBLISHING_PIWIGO_UPLOADER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_PIWIGO_TYPE_UPLOADER, PublishingPiwigoUploaderClass))

typedef struct _PublishingPiwigoUploader PublishingPiwigoUploader;
typedef struct _PublishingPiwigoUploaderClass PublishingPiwigoUploaderClass;
#define _publishing_rest_support_batch_uploader_unref0(var) ((var == NULL) ? NULL : (var = (publishing_rest_support_batch_uploader_unref (var), NULL)))
#define __vala_SoupCookie_free0(var) ((var == NULL) ? NULL : (var = (_vala_SoupCookie_free (var), NULL)))
#define __g_slist_free___vala_SoupCookie_free0_0(var) ((var == NULL) ? NULL : (var = (_g_slist_free___vala_SoupCookie_free0_ (var), NULL)))
typedef struct _PublishingPiwigoUploaderPrivate PublishingPiwigoUploaderPrivate;

#define PUBLISHING_PIWIGO_TYPE_IMAGES_ADD_TRANSACTION (publishing_piwigo_images_add_transaction_get_type ())
#define PUBLISHING_PIWIGO_IMAGES_ADD_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_PIWIGO_TYPE_IMAGES_ADD_TRANSACTION, PublishingPiwigoImagesAddTransaction))
#define PUBLISHING_PIWIGO_IMAGES_ADD_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_PIWIGO_TYPE_IMAGES_ADD_TRANSACTION, PublishingPiwigoImagesAddTransactionClass))
#define PUBLISHING_PIWIGO_IS_IMAGES_ADD_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_PIWIGO_TYPE_IMAGES_ADD_TRANSACTION))
#define PUBLISHING_PIWIGO_IS_IMAGES_ADD_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_PIWIGO_TYPE_IMAGES_ADD_TRANSACTION))
#define PUBLISHING_PIWIGO_IMAGES_ADD_TRANSACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_PIWIGO_TYPE_IMAGES_ADD_TRANSACTION, PublishingPiwigoImagesAddTransactionClass))

typedef struct _PublishingPiwigoImagesAddTransaction PublishingPiwigoImagesAddTransaction;
typedef struct _PublishingPiwigoImagesAddTransactionClass PublishingPiwigoImagesAddTransactionClass;
typedef struct _PublishingPiwigoAuthenticationPanePrivate PublishingPiwigoAuthenticationPanePrivate;
typedef struct _PublishingPiwigoPublishingOptionsPanePrivate PublishingPiwigoPublishingOptionsPanePrivate;
typedef struct _PublishingPiwigoSessionPrivate PublishingPiwigoSessionPrivate;
typedef struct _PublishingPiwigoTransactionPrivate PublishingPiwigoTransactionPrivate;
typedef struct _PublishingPiwigoSessionLoginTransactionPrivate PublishingPiwigoSessionLoginTransactionPrivate;
typedef struct _PublishingPiwigoSessionGetStatusTransactionPrivate PublishingPiwigoSessionGetStatusTransactionPrivate;
typedef struct _PublishingPiwigoCategoriesGetListTransactionPrivate PublishingPiwigoCategoriesGetListTransactionPrivate;
typedef struct _PublishingPiwigoSessionLogoutTransactionPrivate PublishingPiwigoSessionLogoutTransactionPrivate;
typedef struct _PublishingPiwigoCategoriesAddTransactionPrivate PublishingPiwigoCategoriesAddTransactionPrivate;
typedef struct _PublishingPiwigoImagesAddTransactionPrivate PublishingPiwigoImagesAddTransactionPrivate;
#define _g_hash_table_unref0(var) ((var == NULL) ? NULL : (var = (g_hash_table_unref (var), NULL)))
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _PiwigoService {
	GObject parent_instance;
	PiwigoServicePrivate * priv;
};

struct _PiwigoServiceClass {
	GObjectClass parent_class;
};

struct _PublishingPiwigoCategory {
	GTypeInstance parent_instance;
	volatile int ref_count;
	PublishingPiwigoCategoryPrivate * priv;
	gint id;
	gchar* name;
	gchar* comment;
	gchar* display_name;
	gchar* uppercats;
};

struct _PublishingPiwigoCategoryClass {
	GTypeClass parent_class;
	void (*finalize) (PublishingPiwigoCategory *self);
};

struct _PublishingPiwigoParamSpecCategory {
	GParamSpec parent_instance;
};

struct _PublishingPiwigoPermissionLevel {
	GTypeInstance parent_instance;
	volatile int ref_count;
	PublishingPiwigoPermissionLevelPrivate * priv;
	gint id;
	gchar* name;
};

struct _PublishingPiwigoPermissionLevelClass {
	GTypeClass parent_class;
	void (*finalize) (PublishingPiwigoPermissionLevel *self);
};

struct _PublishingPiwigoParamSpecPermissionLevel {
	GParamSpec parent_instance;
};

struct _PublishingPiwigoSizeEntry {
	GTypeInstance parent_instance;
	volatile int ref_count;
	PublishingPiwigoSizeEntryPrivate * priv;
	gint id;
	gchar* name;
};

struct _PublishingPiwigoSizeEntryClass {
	GTypeClass parent_class;
	void (*finalize) (PublishingPiwigoSizeEntry *self);
};

struct _PublishingPiwigoParamSpecSizeEntry {
	GParamSpec parent_instance;
};

struct _PublishingPiwigoPublishingParameters {
	GTypeInstance parent_instance;
	volatile int ref_count;
	PublishingPiwigoPublishingParametersPrivate * priv;
	PublishingPiwigoCategory* category;
	PublishingPiwigoPermissionLevel* perm_level;
	PublishingPiwigoSizeEntry* photo_size;
	gboolean title_as_comment;
	gboolean no_upload_tags;
};

struct _PublishingPiwigoPublishingParametersClass {
	GTypeClass parent_class;
	void (*finalize) (PublishingPiwigoPublishingParameters *self);
};

struct _PublishingPiwigoParamSpecPublishingParameters {
	GParamSpec parent_instance;
};

struct _PublishingPiwigoPiwigoPublisher {
	GObject parent_instance;
	PublishingPiwigoPiwigoPublisherPrivate * priv;
};

struct _PublishingPiwigoPiwigoPublisherClass {
	GObjectClass parent_class;
};

struct _PublishingPiwigoPiwigoPublisherPrivate {
	SpitPublishingService* service;
	SpitPublishingPluginHost* host;
	gboolean running;
	gboolean strip_metadata;
	PublishingPiwigoSession* session;
	PublishingPiwigoCategory** categories;
	gint categories_length1;
	gint _categories_size_;
	PublishingPiwigoPublishingParameters* parameters;
	SpitPublishingProgressCallback progress_reporter;
	gpointer progress_reporter_target;
	GDestroyNotify progress_reporter_target_destroy_notify;
};

typedef enum  {
	PUBLISHING_PIWIGO_AUTHENTICATION_PANE_MODE_INTRO,
	PUBLISHING_PIWIGO_AUTHENTICATION_PANE_MODE_FAILED_RETRY_URL,
	PUBLISHING_PIWIGO_AUTHENTICATION_PANE_MODE_FAILED_RETRY_USER
} PublishingPiwigoAuthenticationPaneMode;

struct _PublishingPiwigoUploader {
	PublishingRESTSupportBatchUploader parent_instance;
	PublishingPiwigoUploaderPrivate * priv;
};

struct _PublishingPiwigoUploaderClass {
	PublishingRESTSupportBatchUploaderClass parent_class;
};

struct _PublishingPiwigoUploaderPrivate {
	PublishingPiwigoPublishingParameters* parameters;
};

struct _PublishingPiwigoAuthenticationPane {
	GObject parent_instance;
	PublishingPiwigoAuthenticationPanePrivate * priv;
};

struct _PublishingPiwigoAuthenticationPaneClass {
	GObjectClass parent_class;
};

struct _PublishingPiwigoAuthenticationPanePrivate {
	GtkBox* pane_widget;
	GtkBuilder* builder;
	GtkEntry* url_entry;
	GtkEntry* username_entry;
	GtkEntry* password_entry;
	GtkCheckButton* remember_password_checkbutton;
	GtkButton* login_button;
};

struct _PublishingPiwigoPublishingOptionsPane {
	GObject parent_instance;
	PublishingPiwigoPublishingOptionsPanePrivate * priv;
};

struct _PublishingPiwigoPublishingOptionsPaneClass {
	GObjectClass parent_class;
};

struct _PublishingPiwigoPublishingOptionsPanePrivate {
	GtkBox* pane_widget;
	GtkBuilder* builder;
	GtkRadioButton* use_existing_radio;
	GtkRadioButton* create_new_radio;
	GtkComboBoxText* existing_categories_combo;
	GtkEntry* new_category_entry;
	GtkLabel* within_existing_label;
	GtkComboBoxText* within_existing_combo;
	GtkComboBoxText* perms_combo;
	GtkComboBoxText* size_combo;
	GtkCheckButton* strip_metadata_check;
	GtkCheckButton* title_as_comment_check;
	GtkCheckButton* no_upload_tags_check;
	GtkButton* logout_button;
	GtkButton* publish_button;
	GtkTextView* album_comment;
	GtkLabel* album_comment_label;
	PublishingPiwigoCategory** existing_categories;
	gint existing_categories_length1;
	gint _existing_categories_size_;
	PublishingPiwigoPermissionLevel** perm_levels;
	gint perm_levels_length1;
	gint _perm_levels_size_;
	PublishingPiwigoSizeEntry** photo_sizes;
	gint photo_sizes_length1;
	gint _photo_sizes_size_;
	gint last_category;
	gint last_permission_level;
	gint last_photo_size;
	gboolean last_title_as_comment;
	gboolean last_no_upload_tags;
};

struct _PublishingPiwigoSession {
	PublishingRESTSupportSession parent_instance;
	PublishingPiwigoSessionPrivate * priv;
};

struct _PublishingPiwigoSessionClass {
	PublishingRESTSupportSessionClass parent_class;
};

struct _PublishingPiwigoSessionPrivate {
	gchar* pwg_url;
	gchar* pwg_id;
	gchar* username;
};

struct _PublishingPiwigoTransaction {
	PublishingRESTSupportTransaction parent_instance;
	PublishingPiwigoTransactionPrivate * priv;
};

struct _PublishingPiwigoTransactionClass {
	PublishingRESTSupportTransactionClass parent_class;
};

struct _PublishingPiwigoSessionLoginTransaction {
	PublishingPiwigoTransaction parent_instance;
	PublishingPiwigoSessionLoginTransactionPrivate * priv;
};

struct _PublishingPiwigoSessionLoginTransactionClass {
	PublishingPiwigoTransactionClass parent_class;
};

struct _PublishingPiwigoSessionGetStatusTransaction {
	PublishingPiwigoTransaction parent_instance;
	PublishingPiwigoSessionGetStatusTransactionPrivate * priv;
};

struct _PublishingPiwigoSessionGetStatusTransactionClass {
	PublishingPiwigoTransactionClass parent_class;
};

struct _PublishingPiwigoCategoriesGetListTransaction {
	PublishingPiwigoTransaction parent_instance;
	PublishingPiwigoCategoriesGetListTransactionPrivate * priv;
};

struct _PublishingPiwigoCategoriesGetListTransactionClass {
	PublishingPiwigoTransactionClass parent_class;
};

struct _PublishingPiwigoSessionLogoutTransaction {
	PublishingPiwigoTransaction parent_instance;
	PublishingPiwigoSessionLogoutTransactionPrivate * priv;
};

struct _PublishingPiwigoSessionLogoutTransactionClass {
	PublishingPiwigoTransactionClass parent_class;
};

struct _PublishingPiwigoCategoriesAddTransaction {
	PublishingPiwigoTransaction parent_instance;
	PublishingPiwigoCategoriesAddTransactionPrivate * priv;
};

struct _PublishingPiwigoCategoriesAddTransactionClass {
	PublishingPiwigoTransactionClass parent_class;
};

struct _PublishingPiwigoImagesAddTransaction {
	PublishingRESTSupportUploadTransaction parent_instance;
	PublishingPiwigoImagesAddTransactionPrivate * priv;
};

struct _PublishingPiwigoImagesAddTransactionClass {
	PublishingRESTSupportUploadTransactionClass parent_class;
};

struct _PublishingPiwigoImagesAddTransactionPrivate {
	PublishingPiwigoPublishingParameters* parameters;
};


static gpointer piwigo_service_parent_class = NULL;
static GdkPixbuf** piwigo_service_icon_pixbuf_set;
static gint piwigo_service_icon_pixbuf_set_length1;
static GdkPixbuf** piwigo_service_icon_pixbuf_set = NULL;
static gint piwigo_service_icon_pixbuf_set_length1 = 0;
static gint _piwigo_service_icon_pixbuf_set_size_ = 0;
static SpitPluggableIface* piwigo_service_spit_pluggable_parent_iface = NULL;
static SpitPublishingServiceIface* piwigo_service_spit_publishing_service_parent_iface = NULL;
static gpointer publishing_piwigo_category_parent_class = NULL;
static gpointer publishing_piwigo_permission_level_parent_class = NULL;
static gpointer publishing_piwigo_size_entry_parent_class = NULL;
static gpointer publishing_piwigo_publishing_parameters_parent_class = NULL;
static gpointer publishing_piwigo_piwigo_publisher_parent_class = NULL;
static SpitPublishingPublisherIface* publishing_piwigo_piwigo_publisher_spit_publishing_publisher_parent_iface = NULL;
static gpointer publishing_piwigo_uploader_parent_class = NULL;
static gpointer publishing_piwigo_authentication_pane_parent_class = NULL;
static gchar* publishing_piwigo_authentication_pane_INTRO_MESSAGE;
static gchar* publishing_piwigo_authentication_pane_INTRO_MESSAGE = NULL;
static gchar* publishing_piwigo_authentication_pane_FAILED_RETRY_URL_MESSAGE;
static gchar* publishing_piwigo_authentication_pane_FAILED_RETRY_URL_MESSAGE = NULL;
static gchar* publishing_piwigo_authentication_pane_FAILED_RETRY_USER_MESSAGE;
static gchar* publishing_piwigo_authentication_pane_FAILED_RETRY_USER_MESSAGE = NULL;
static SpitPublishingDialogPaneIface* publishing_piwigo_authentication_pane_spit_publishing_dialog_pane_parent_iface = NULL;
static gpointer publishing_piwigo_publishing_options_pane_parent_class = NULL;
static gchar* publishing_piwigo_publishing_options_pane_DEFAULT_CATEGORY_NAME;
static gchar* publishing_piwigo_publishing_options_pane_DEFAULT_CATEGORY_NAME = NULL;
static SpitPublishingDialogPaneIface* publishing_piwigo_publishing_options_pane_spit_publishing_dialog_pane_parent_iface = NULL;
static gpointer publishing_piwigo_session_parent_class = NULL;
static gpointer publishing_piwigo_transaction_parent_class = NULL;
static gpointer publishing_piwigo_session_login_transaction_parent_class = NULL;
static gpointer publishing_piwigo_session_get_status_transaction_parent_class = NULL;
static gpointer publishing_piwigo_categories_get_list_transaction_parent_class = NULL;
static gpointer publishing_piwigo_session_logout_transaction_parent_class = NULL;
static gpointer publishing_piwigo_categories_add_transaction_parent_class = NULL;
static gpointer publishing_piwigo_images_add_transaction_parent_class = NULL;

GType piwigo_service_get_type (void) G_GNUC_CONST;
enum  {
	PIWIGO_SERVICE_DUMMY_PROPERTY
};
#define PIWIGO_SERVICE_ICON_FILENAME "piwigo.png"
PiwigoService* piwigo_service_new (GFile* resource_directory);
PiwigoService* piwigo_service_construct (GType object_type, GFile* resource_directory);
static gint piwigo_service_real_get_pluggable_interface (SpitPluggable* base, gint min_host_interface, gint max_host_interface);
static const gchar* piwigo_service_real_get_id (SpitPluggable* base);
static const gchar* piwigo_service_real_get_pluggable_name (SpitPluggable* base);
static void piwigo_service_real_get_info (SpitPluggable* base, SpitPluggableInfo* info);
static GdkPixbuf** _vala_array_dup10 (GdkPixbuf** self, int length);
static void piwigo_service_real_activation (SpitPluggable* base, gboolean enabled);
static SpitPublishingPublisher* piwigo_service_real_create_publisher (SpitPublishingService* base, SpitPublishingPluginHost* host);
PublishingPiwigoPiwigoPublisher* publishing_piwigo_piwigo_publisher_new (SpitPublishingService* service, SpitPublishingPluginHost* host);
PublishingPiwigoPiwigoPublisher* publishing_piwigo_piwigo_publisher_construct (GType object_type, SpitPublishingService* service, SpitPublishingPluginHost* host);
GType publishing_piwigo_piwigo_publisher_get_type (void) G_GNUC_CONST;
static SpitPublishingPublisherMediaType piwigo_service_real_get_supported_media (SpitPublishingService* base);
static void piwigo_service_finalize (GObject* obj);
#define PUBLISHING_PIWIGO_SERVICE_NAME "Piwigo"
#define PUBLISHING_PIWIGO_PIWIGO_WS "ws.php"
#define PUBLISHING_PIWIGO_ORIGINAL_SIZE -1
gpointer publishing_piwigo_category_ref (gpointer instance);
void publishing_piwigo_category_unref (gpointer instance);
GParamSpec* publishing_piwigo_param_spec_category (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void publishing_piwigo_value_set_category (GValue* value, gpointer v_object);
void publishing_piwigo_value_take_category (GValue* value, gpointer v_object);
gpointer publishing_piwigo_value_get_category (const GValue* value);
GType publishing_piwigo_category_get_type (void) G_GNUC_CONST;
enum  {
	PUBLISHING_PIWIGO_CATEGORY_DUMMY_PROPERTY
};
#define PUBLISHING_PIWIGO_CATEGORY_NO_ID -1
PublishingPiwigoCategory* publishing_piwigo_category_new (gint id, const gchar* name, const gchar* uppercats, const gchar* comment);
PublishingPiwigoCategory* publishing_piwigo_category_construct (GType object_type, gint id, const gchar* name, const gchar* uppercats, const gchar* comment);
PublishingPiwigoCategory* publishing_piwigo_category_new_local (const gchar* name, gint parent_id, const gchar* comment);
PublishingPiwigoCategory* publishing_piwigo_category_construct_local (GType object_type, const gchar* name, gint parent_id, const gchar* comment);
gboolean publishing_piwigo_category_is_local (PublishingPiwigoCategory* self);
static void publishing_piwigo_category_finalize (PublishingPiwigoCategory* obj);
gpointer publishing_piwigo_permission_level_ref (gpointer instance);
void publishing_piwigo_permission_level_unref (gpointer instance);
GParamSpec* publishing_piwigo_param_spec_permission_level (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void publishing_piwigo_value_set_permission_level (GValue* value, gpointer v_object);
void publishing_piwigo_value_take_permission_level (GValue* value, gpointer v_object);
gpointer publishing_piwigo_value_get_permission_level (const GValue* value);
GType publishing_piwigo_permission_level_get_type (void) G_GNUC_CONST;
enum  {
	PUBLISHING_PIWIGO_PERMISSION_LEVEL_DUMMY_PROPERTY
};
PublishingPiwigoPermissionLevel* publishing_piwigo_permission_level_new (gint id, const gchar* name);
PublishingPiwigoPermissionLevel* publishing_piwigo_permission_level_construct (GType object_type, gint id, const gchar* name);
static void publishing_piwigo_permission_level_finalize (PublishingPiwigoPermissionLevel* obj);
gpointer publishing_piwigo_size_entry_ref (gpointer instance);
void publishing_piwigo_size_entry_unref (gpointer instance);
GParamSpec* publishing_piwigo_param_spec_size_entry (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void publishing_piwigo_value_set_size_entry (GValue* value, gpointer v_object);
void publishing_piwigo_value_take_size_entry (GValue* value, gpointer v_object);
gpointer publishing_piwigo_value_get_size_entry (const GValue* value);
GType publishing_piwigo_size_entry_get_type (void) G_GNUC_CONST;
enum  {
	PUBLISHING_PIWIGO_SIZE_ENTRY_DUMMY_PROPERTY
};
PublishingPiwigoSizeEntry* publishing_piwigo_size_entry_new (gint id, const gchar* name);
PublishingPiwigoSizeEntry* publishing_piwigo_size_entry_construct (GType object_type, gint id, const gchar* name);
static void publishing_piwigo_size_entry_finalize (PublishingPiwigoSizeEntry* obj);
gpointer publishing_piwigo_publishing_parameters_ref (gpointer instance);
void publishing_piwigo_publishing_parameters_unref (gpointer instance);
GParamSpec* publishing_piwigo_param_spec_publishing_parameters (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void publishing_piwigo_value_set_publishing_parameters (GValue* value, gpointer v_object);
void publishing_piwigo_value_take_publishing_parameters (GValue* value, gpointer v_object);
gpointer publishing_piwigo_value_get_publishing_parameters (const GValue* value);
GType publishing_piwigo_publishing_parameters_get_type (void) G_GNUC_CONST;
enum  {
	PUBLISHING_PIWIGO_PUBLISHING_PARAMETERS_DUMMY_PROPERTY
};
PublishingPiwigoPublishingParameters* publishing_piwigo_publishing_parameters_new (void);
PublishingPiwigoPublishingParameters* publishing_piwigo_publishing_parameters_construct (GType object_type);
static void publishing_piwigo_publishing_parameters_finalize (PublishingPiwigoPublishingParameters* obj);
GType publishing_piwigo_session_get_type (void) G_GNUC_CONST;
#define PUBLISHING_PIWIGO_PIWIGO_PUBLISHER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_PIWIGO_TYPE_PIWIGO_PUBLISHER, PublishingPiwigoPiwigoPublisherPrivate))
enum  {
	PUBLISHING_PIWIGO_PIWIGO_PUBLISHER_DUMMY_PROPERTY
};
PublishingPiwigoSession* publishing_piwigo_session_new (void);
PublishingPiwigoSession* publishing_piwigo_session_construct (GType object_type);
static SpitPublishingService* publishing_piwigo_piwigo_publisher_real_get_service (SpitPublishingPublisher* base);
SpitPublishingPluginHost* publishing_piwigo_piwigo_publisher_get_host (PublishingPiwigoPiwigoPublisher* self);
static gboolean publishing_piwigo_piwigo_publisher_real_is_running (SpitPublishingPublisher* base);
static void publishing_piwigo_piwigo_publisher_real_start (SpitPublishingPublisher* base);
static void publishing_piwigo_piwigo_publisher_do_fetch_categories (PublishingPiwigoPiwigoPublisher* self);
gchar* publishing_piwigo_piwigo_publisher_get_persistent_url (PublishingPiwigoPiwigoPublisher* self);
gchar* publishing_piwigo_piwigo_publisher_get_persistent_username (PublishingPiwigoPiwigoPublisher* self);
gchar* publishing_piwigo_piwigo_publisher_get_persistent_password (PublishingPiwigoPiwigoPublisher* self);
static void publishing_piwigo_piwigo_publisher_do_network_login (PublishingPiwigoPiwigoPublisher* self, const gchar* url, const gchar* username, const gchar* password, gboolean remember_password);
gboolean publishing_piwigo_piwigo_publisher_get_remember_password (PublishingPiwigoPiwigoPublisher* self);
GType publishing_piwigo_authentication_pane_mode_get_type (void) G_GNUC_CONST;
static void publishing_piwigo_piwigo_publisher_do_show_authentication_pane (PublishingPiwigoPiwigoPublisher* self, PublishingPiwigoAuthenticationPaneMode mode);
static void publishing_piwigo_piwigo_publisher_real_stop (SpitPublishingPublisher* base);
static void publishing_piwigo_piwigo_publisher_set_persistent_url (PublishingPiwigoPiwigoPublisher* self, const gchar* url);
static void publishing_piwigo_piwigo_publisher_set_persistent_username (PublishingPiwigoPiwigoPublisher* self, const gchar* username);
static void publishing_piwigo_piwigo_publisher_set_persistent_password (PublishingPiwigoPiwigoPublisher* self, const gchar* password);
static void publishing_piwigo_piwigo_publisher_set_remember_password (PublishingPiwigoPiwigoPublisher* self, gboolean remember_password);
gint publishing_piwigo_piwigo_publisher_get_last_category (PublishingPiwigoPiwigoPublisher* self);
static void publishing_piwigo_piwigo_publisher_set_last_category (PublishingPiwigoPiwigoPublisher* self, gint last_category);
gint publishing_piwigo_piwigo_publisher_get_last_permission_level (PublishingPiwigoPiwigoPublisher* self);
static void publishing_piwigo_piwigo_publisher_set_last_permission_level (PublishingPiwigoPiwigoPublisher* self, gint last_permission_level);
gint publishing_piwigo_piwigo_publisher_get_last_photo_size (PublishingPiwigoPiwigoPublisher* self);
static void publishing_piwigo_piwigo_publisher_set_last_photo_size (PublishingPiwigoPiwigoPublisher* self, gint last_photo_size);
static gboolean publishing_piwigo_piwigo_publisher_get_last_title_as_comment (PublishingPiwigoPiwigoPublisher* self);
static void publishing_piwigo_piwigo_publisher_set_last_title_as_comment (PublishingPiwigoPiwigoPublisher* self, gboolean title_as_comment);
static gboolean publishing_piwigo_piwigo_publisher_get_last_no_upload_tags (PublishingPiwigoPiwigoPublisher* self);
static void publishing_piwigo_piwigo_publisher_set_last_no_upload_tags (PublishingPiwigoPiwigoPublisher* self, gboolean no_upload_tags);
static gboolean publishing_piwigo_piwigo_publisher_get_metadata_removal_choice (PublishingPiwigoPiwigoPublisher* self);
static void publishing_piwigo_piwigo_publisher_set_metadata_removal_choice (PublishingPiwigoPiwigoPublisher* self, gboolean strip_metadata);
GType publishing_piwigo_authentication_pane_get_type (void) G_GNUC_CONST;
PublishingPiwigoAuthenticationPane* publishing_piwigo_authentication_pane_new (PublishingPiwigoPiwigoPublisher* publisher, PublishingPiwigoAuthenticationPaneMode mode);
PublishingPiwigoAuthenticationPane* publishing_piwigo_authentication_pane_construct (GType object_type, PublishingPiwigoPiwigoPublisher* publisher, PublishingPiwigoAuthenticationPaneMode mode);
static void publishing_piwigo_piwigo_publisher_on_authentication_pane_login_clicked (PublishingPiwigoPiwigoPublisher* self, const gchar* url, const gchar* username, const gchar* password, gboolean remember_password);
static void _publishing_piwigo_piwigo_publisher_on_authentication_pane_login_clicked_publishing_piwigo_authentication_pane_login (PublishingPiwigoAuthenticationPane* _sender, const gchar* url, const gchar* user, const gchar* password, gboolean remember_password, gpointer self);
GtkWidget* publishing_piwigo_authentication_pane_get_default_widget (PublishingPiwigoAuthenticationPane* self);
GType publishing_piwigo_transaction_get_type (void) G_GNUC_CONST;
GType publishing_piwigo_session_login_transaction_get_type (void) G_GNUC_CONST;
gchar* publishing_piwigo_piwigo_publisher_normalise_url (const gchar* url);
PublishingPiwigoSessionLoginTransaction* publishing_piwigo_session_login_transaction_new (PublishingPiwigoSession* session, const gchar* url, const gchar* username, const gchar* password);
PublishingPiwigoSessionLoginTransaction* publishing_piwigo_session_login_transaction_construct (GType object_type, PublishingPiwigoSession* session, const gchar* url, const gchar* username, const gchar* password);
static void publishing_piwigo_piwigo_publisher_on_login_network_error (PublishingPiwigoPiwigoPublisher* self, PublishingRESTSupportTransaction* bad_txn, GError* err);
static void _publishing_piwigo_piwigo_publisher_on_login_network_error_publishing_rest_support_transaction_network_error (PublishingRESTSupportTransaction* _sender, GError* err, gpointer self);
static void publishing_piwigo_piwigo_publisher_on_login_network_complete (PublishingPiwigoPiwigoPublisher* self, PublishingRESTSupportTransaction* txn);
static void _publishing_piwigo_piwigo_publisher_on_login_network_complete_publishing_rest_support_transaction_completed (PublishingRESTSupportTransaction* _sender, gpointer self);
static void publishing_piwigo_piwigo_publisher_do_show_error (PublishingPiwigoPiwigoPublisher* self, GError* e);
gchar* publishing_piwigo_transaction_validate_xml (PublishingRESTSupportXmlDocument* doc);
static gchar* _publishing_piwigo_transaction_validate_xml_publishing_rest_support_xml_document_check_for_error_response (PublishingRESTSupportXmlDocument* doc, gpointer self);
gchar* publishing_piwigo_transaction_get_error_code (PublishingRESTSupportXmlDocument* doc);
static gchar* _publishing_piwigo_transaction_get_error_code_publishing_rest_support_xml_document_check_for_error_response (PublishingRESTSupportXmlDocument* doc, gpointer self);
static gchar* publishing_piwigo_piwigo_publisher_get_pwg_id_from_transaction (PublishingPiwigoPiwigoPublisher* self, PublishingRESTSupportTransaction* txn);
void publishing_piwigo_session_set_pwg_id (PublishingPiwigoSession* self, const gchar* id);
static void publishing_piwigo_piwigo_publisher_do_fetch_session_status (PublishingPiwigoPiwigoPublisher* self, const gchar* url, const gchar* pwg_id);
GType publishing_piwigo_session_get_status_transaction_get_type (void) G_GNUC_CONST;
PublishingPiwigoSessionGetStatusTransaction* publishing_piwigo_session_get_status_transaction_new_unauthenticated (PublishingPiwigoSession* session, const gchar* url, const gchar* pwg_id);
PublishingPiwigoSessionGetStatusTransaction* publishing_piwigo_session_get_status_transaction_construct_unauthenticated (GType object_type, PublishingPiwigoSession* session, const gchar* url, const gchar* pwg_id);
static void publishing_piwigo_piwigo_publisher_on_session_get_status_error (PublishingPiwigoPiwigoPublisher* self, PublishingRESTSupportTransaction* bad_txn, GError* err);
static void _publishing_piwigo_piwigo_publisher_on_session_get_status_error_publishing_rest_support_transaction_network_error (PublishingRESTSupportTransaction* _sender, GError* err, gpointer self);
static void publishing_piwigo_piwigo_publisher_on_session_get_status_complete (PublishingPiwigoPiwigoPublisher* self, PublishingRESTSupportTransaction* txn);
static void _publishing_piwigo_piwigo_publisher_on_session_get_status_complete_publishing_rest_support_transaction_completed (PublishingRESTSupportTransaction* _sender, gpointer self);
PublishingPiwigoSessionGetStatusTransaction* publishing_piwigo_session_get_status_transaction_new (PublishingPiwigoSession* session);
PublishingPiwigoSessionGetStatusTransaction* publishing_piwigo_session_get_status_transaction_construct (GType object_type, PublishingPiwigoSession* session);
gchar* publishing_piwigo_session_get_pwg_id (PublishingPiwigoSession* self);
void publishing_piwigo_session_authenticate (PublishingPiwigoSession* self, const gchar* url, const gchar* username, const gchar* id);
gchar* publishing_piwigo_session_get_pwg_url (PublishingPiwigoSession* self);
gchar* publishing_piwigo_session_get_username (PublishingPiwigoSession* self);
static void publishing_piwigo_piwigo_publisher_on_network_error (PublishingPiwigoPiwigoPublisher* self, PublishingRESTSupportTransaction* bad_txn, GError* err);
GType publishing_piwigo_categories_get_list_transaction_get_type (void) G_GNUC_CONST;
PublishingPiwigoCategoriesGetListTransaction* publishing_piwigo_categories_get_list_transaction_new (PublishingPiwigoSession* session);
PublishingPiwigoCategoriesGetListTransaction* publishing_piwigo_categories_get_list_transaction_construct (GType object_type, PublishingPiwigoSession* session);
static void publishing_piwigo_piwigo_publisher_on_category_fetch_error (PublishingPiwigoPiwigoPublisher* self, PublishingRESTSupportTransaction* bad_txn, GError* err);
static void _publishing_piwigo_piwigo_publisher_on_category_fetch_error_publishing_rest_support_transaction_network_error (PublishingRESTSupportTransaction* _sender, GError* err, gpointer self);
static void publishing_piwigo_piwigo_publisher_on_category_fetch_complete (PublishingPiwigoPiwigoPublisher* self, PublishingRESTSupportTransaction* txn);
static void _publishing_piwigo_piwigo_publisher_on_category_fetch_complete_publishing_rest_support_transaction_completed (PublishingRESTSupportTransaction* _sender, gpointer self);
static void _vala_array_add34 (PublishingPiwigoCategory*** array, int* length, int* size, PublishingPiwigoCategory* value);
static void publishing_piwigo_piwigo_publisher_do_show_publishing_options_pane (PublishingPiwigoPiwigoPublisher* self);
GType publishing_piwigo_publishing_options_pane_get_type (void) G_GNUC_CONST;
PublishingPiwigoPublishingOptionsPane* publishing_piwigo_publishing_options_pane_new (PublishingPiwigoPiwigoPublisher* publisher, PublishingPiwigoCategory** categories, int categories_length1, gint last_category, gint last_permission_level, gint last_photo_size, gboolean last_title_as_comment, gboolean last_no_upload_tags, gboolean strip_metadata_enabled);
PublishingPiwigoPublishingOptionsPane* publishing_piwigo_publishing_options_pane_construct (GType object_type, PublishingPiwigoPiwigoPublisher* publisher, PublishingPiwigoCategory** categories, int categories_length1, gint last_category, gint last_permission_level, gint last_photo_size, gboolean last_title_as_comment, gboolean last_no_upload_tags, gboolean strip_metadata_enabled);
static void publishing_piwigo_piwigo_publisher_on_publishing_options_pane_logout_clicked (PublishingPiwigoPiwigoPublisher* self);
static void _publishing_piwigo_piwigo_publisher_on_publishing_options_pane_logout_clicked_publishing_piwigo_publishing_options_pane_logout (PublishingPiwigoPublishingOptionsPane* _sender, gpointer self);
static void publishing_piwigo_piwigo_publisher_on_publishing_options_pane_publish_clicked (PublishingPiwigoPiwigoPublisher* self, PublishingPiwigoPublishingParameters* parameters, gboolean strip_metadata);
static void _publishing_piwigo_piwigo_publisher_on_publishing_options_pane_publish_clicked_publishing_piwigo_publishing_options_pane_publish (PublishingPiwigoPublishingOptionsPane* _sender, PublishingPiwigoPublishingParameters* parameters, gboolean strip_metadata, gpointer self);
GtkWidget* publishing_piwigo_publishing_options_pane_get_default_widget (PublishingPiwigoPublishingOptionsPane* self);
GType publishing_piwigo_session_logout_transaction_get_type (void) G_GNUC_CONST;
PublishingPiwigoSessionLogoutTransaction* publishing_piwigo_session_logout_transaction_new (PublishingPiwigoSession* session);
PublishingPiwigoSessionLogoutTransaction* publishing_piwigo_session_logout_transaction_construct (GType object_type, PublishingPiwigoSession* session);
static void publishing_piwigo_piwigo_publisher_on_logout_network_error (PublishingPiwigoPiwigoPublisher* self, PublishingRESTSupportTransaction* bad_txn, GError* err);
static void _publishing_piwigo_piwigo_publisher_on_logout_network_error_publishing_rest_support_transaction_network_error (PublishingRESTSupportTransaction* _sender, GError* err, gpointer self);
static void publishing_piwigo_piwigo_publisher_on_logout_network_complete (PublishingPiwigoPiwigoPublisher* self, PublishingRESTSupportTransaction* txn);
static void _publishing_piwigo_piwigo_publisher_on_logout_network_complete_publishing_rest_support_transaction_completed (PublishingRESTSupportTransaction* _sender, gpointer self);
void publishing_piwigo_session_deauthenticate (PublishingPiwigoSession* self);
static void publishing_piwigo_piwigo_publisher_do_create_category (PublishingPiwigoPiwigoPublisher* self, PublishingPiwigoCategory* category);
static void publishing_piwigo_piwigo_publisher_do_upload (PublishingPiwigoPiwigoPublisher* self, gboolean strip_metadata);
GType publishing_piwigo_categories_add_transaction_get_type (void) G_GNUC_CONST;
PublishingPiwigoCategoriesAddTransaction* publishing_piwigo_categories_add_transaction_new (PublishingPiwigoSession* session, const gchar* category, gint parent_id, const gchar* comment);
PublishingPiwigoCategoriesAddTransaction* publishing_piwigo_categories_add_transaction_construct (GType object_type, PublishingPiwigoSession* session, const gchar* category, gint parent_id, const gchar* comment);
static void publishing_piwigo_piwigo_publisher_on_category_add_error (PublishingPiwigoPiwigoPublisher* self, PublishingRESTSupportTransaction* bad_txn, GError* err);
static void _publishing_piwigo_piwigo_publisher_on_category_add_error_publishing_rest_support_transaction_network_error (PublishingRESTSupportTransaction* _sender, GError* err, gpointer self);
static void publishing_piwigo_piwigo_publisher_on_category_add_complete (PublishingPiwigoPiwigoPublisher* self, PublishingRESTSupportTransaction* txn);
static void _publishing_piwigo_piwigo_publisher_on_category_add_complete_publishing_rest_support_transaction_completed (PublishingRESTSupportTransaction* _sender, gpointer self);
GType publishing_piwigo_uploader_get_type (void) G_GNUC_CONST;
PublishingPiwigoUploader* publishing_piwigo_uploader_new (PublishingPiwigoSession* session, SpitPublishingPublishable** publishables, int publishables_length1, PublishingPiwigoPublishingParameters* parameters);
PublishingPiwigoUploader* publishing_piwigo_uploader_construct (GType object_type, PublishingPiwigoSession* session, SpitPublishingPublishable** publishables, int publishables_length1, PublishingPiwigoPublishingParameters* parameters);
static void publishing_piwigo_piwigo_publisher_on_upload_complete (PublishingPiwigoPiwigoPublisher* self, PublishingRESTSupportBatchUploader* uploader, gint num_published);
static void _publishing_piwigo_piwigo_publisher_on_upload_complete_publishing_rest_support_batch_uploader_upload_complete (PublishingRESTSupportBatchUploader* _sender, gint num_photos_published, gpointer self);
static void publishing_piwigo_piwigo_publisher_on_upload_error (PublishingPiwigoPiwigoPublisher* self, PublishingRESTSupportBatchUploader* uploader, GError* err);
static void _publishing_piwigo_piwigo_publisher_on_upload_error_publishing_rest_support_batch_uploader_upload_error (PublishingRESTSupportBatchUploader* _sender, GError* err, gpointer self);
static void publishing_piwigo_piwigo_publisher_on_upload_status_updated (PublishingPiwigoPiwigoPublisher* self, gint file_number, gdouble completed_fraction);
static void _publishing_piwigo_piwigo_publisher_on_upload_status_updated_spit_publishing_progress_callback (gint file_number, gdouble fraction_complete, gpointer self);
static void publishing_piwigo_piwigo_publisher_do_show_success_pane (PublishingPiwigoPiwigoPublisher* self);
static void publishing_piwigo_piwigo_publisher_do_show_error_message (PublishingPiwigoPiwigoPublisher* self, const gchar* message);
static SoupCookie* _vala_SoupCookie_copy (SoupCookie* self);
static void _vala_SoupCookie_free (SoupCookie* self);
static void __vala_SoupCookie_free0_ (gpointer var);
static void _g_slist_free___vala_SoupCookie_free0_ (GSList* self);
static void publishing_piwigo_piwigo_publisher_finalize (GObject* obj);
#define PUBLISHING_PIWIGO_UPLOADER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_PIWIGO_TYPE_UPLOADER, PublishingPiwigoUploaderPrivate))
enum  {
	PUBLISHING_PIWIGO_UPLOADER_DUMMY_PROPERTY
};
static PublishingRESTSupportTransaction* publishing_piwigo_uploader_real_create_transaction (PublishingRESTSupportBatchUploader* base, SpitPublishingPublishable* publishable);
PublishingPiwigoImagesAddTransaction* publishing_piwigo_images_add_transaction_new (PublishingPiwigoSession* session, PublishingPiwigoPublishingParameters* parameters, SpitPublishingPublishable* publishable);
PublishingPiwigoImagesAddTransaction* publishing_piwigo_images_add_transaction_construct (GType object_type, PublishingPiwigoSession* session, PublishingPiwigoPublishingParameters* parameters, SpitPublishingPublishable* publishable);
GType publishing_piwigo_images_add_transaction_get_type (void) G_GNUC_CONST;
static void publishing_piwigo_uploader_finalize (PublishingRESTSupportBatchUploader* obj);
#define PUBLISHING_PIWIGO_AUTHENTICATION_PANE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_PIWIGO_TYPE_AUTHENTICATION_PANE, PublishingPiwigoAuthenticationPanePrivate))
enum  {
	PUBLISHING_PIWIGO_AUTHENTICATION_PANE_DUMMY_PROPERTY
};
static void publishing_piwigo_authentication_pane_on_user_changed (PublishingPiwigoAuthenticationPane* self);
static void _publishing_piwigo_authentication_pane_on_user_changed_gtk_editable_changed (GtkEditable* _sender, gpointer self);
static void publishing_piwigo_authentication_pane_on_url_changed (PublishingPiwigoAuthenticationPane* self);
static void _publishing_piwigo_authentication_pane_on_url_changed_gtk_editable_changed (GtkEditable* _sender, gpointer self);
static void publishing_piwigo_authentication_pane_on_password_changed (PublishingPiwigoAuthenticationPane* self);
static void _publishing_piwigo_authentication_pane_on_password_changed_gtk_editable_changed (GtkEditable* _sender, gpointer self);
static void publishing_piwigo_authentication_pane_on_login_button_clicked (PublishingPiwigoAuthenticationPane* self);
static void _publishing_piwigo_authentication_pane_on_login_button_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self);
static void publishing_piwigo_authentication_pane_update_login_button_sensitivity (PublishingPiwigoAuthenticationPane* self);
static GtkWidget* publishing_piwigo_authentication_pane_real_get_widget (SpitPublishingDialogPane* base);
static SpitPublishingDialogPaneGeometryOptions publishing_piwigo_authentication_pane_real_get_preferred_geometry (SpitPublishingDialogPane* base);
static void publishing_piwigo_authentication_pane_real_on_pane_installed (SpitPublishingDialogPane* base);
static void publishing_piwigo_authentication_pane_real_on_pane_uninstalled (SpitPublishingDialogPane* base);
static void g_cclosure_user_marshal_VOID__STRING_STRING_STRING_BOOLEAN (GClosure * closure, GValue * return_value, guint n_param_values, const GValue * param_values, gpointer invocation_hint, gpointer marshal_data);
static void publishing_piwigo_authentication_pane_finalize (GObject* obj);
#define PUBLISHING_PIWIGO_PUBLISHING_OPTIONS_PANE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_PIWIGO_TYPE_PUBLISHING_OPTIONS_PANE, PublishingPiwigoPublishingOptionsPanePrivate))
enum  {
	PUBLISHING_PIWIGO_PUBLISHING_OPTIONS_PANE_DUMMY_PROPERTY
};
static void publishing_piwigo_publishing_options_pane_on_logout_button_clicked (PublishingPiwigoPublishingOptionsPane* self);
static void _publishing_piwigo_publishing_options_pane_on_logout_button_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self);
static void publishing_piwigo_publishing_options_pane_on_publish_button_clicked (PublishingPiwigoPublishingOptionsPane* self);
static void _publishing_piwigo_publishing_options_pane_on_publish_button_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self);
static void publishing_piwigo_publishing_options_pane_on_use_existing_radio_clicked (PublishingPiwigoPublishingOptionsPane* self);
static void _publishing_piwigo_publishing_options_pane_on_use_existing_radio_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self);
static void publishing_piwigo_publishing_options_pane_on_create_new_radio_clicked (PublishingPiwigoPublishingOptionsPane* self);
static void _publishing_piwigo_publishing_options_pane_on_create_new_radio_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self);
static void publishing_piwigo_publishing_options_pane_on_new_category_entry_changed (PublishingPiwigoPublishingOptionsPane* self);
static void _publishing_piwigo_publishing_options_pane_on_new_category_entry_changed_gtk_editable_changed (GtkEditable* _sender, gpointer self);
static void publishing_piwigo_publishing_options_pane_on_existing_combo_changed (PublishingPiwigoPublishingOptionsPane* self);
static void _publishing_piwigo_publishing_options_pane_on_existing_combo_changed_gtk_combo_box_changed (GtkComboBox* _sender, gpointer self);
static PublishingPiwigoCategory** _vala_array_dup11 (PublishingPiwigoCategory** self, int length);
static PublishingPiwigoPermissionLevel** publishing_piwigo_publishing_options_pane_create_perm_levels (PublishingPiwigoPublishingOptionsPane* self, int* result_length1);
static PublishingPiwigoSizeEntry** publishing_piwigo_publishing_options_pane_create_sizes (PublishingPiwigoPublishingOptionsPane* self, int* result_length1);
static gchar* publishing_piwigo_publishing_options_pane_get_common_comment_if_possible (PublishingPiwigoPublishingOptionsPane* self, PublishingPiwigoPiwigoPublisher* publisher);
static void _vala_array_add35 (PublishingPiwigoPermissionLevel*** array, int* length, int* size, PublishingPiwigoPermissionLevel* value);
static void _vala_array_add36 (PublishingPiwigoPermissionLevel*** array, int* length, int* size, PublishingPiwigoPermissionLevel* value);
static void _vala_array_add37 (PublishingPiwigoPermissionLevel*** array, int* length, int* size, PublishingPiwigoPermissionLevel* value);
static void _vala_array_add38 (PublishingPiwigoPermissionLevel*** array, int* length, int* size, PublishingPiwigoPermissionLevel* value);
static void _vala_array_add39 (PublishingPiwigoPermissionLevel*** array, int* length, int* size, PublishingPiwigoPermissionLevel* value);
static void _vala_array_add40 (PublishingPiwigoSizeEntry*** array, int* length, int* size, PublishingPiwigoSizeEntry* value);
static void _vala_array_add41 (PublishingPiwigoSizeEntry*** array, int* length, int* size, PublishingPiwigoSizeEntry* value);
static void _vala_array_add42 (PublishingPiwigoSizeEntry*** array, int* length, int* size, PublishingPiwigoSizeEntry* value);
static void _vala_array_add43 (PublishingPiwigoSizeEntry*** array, int* length, int* size, PublishingPiwigoSizeEntry* value);
static void _vala_array_add44 (PublishingPiwigoSizeEntry*** array, int* length, int* size, PublishingPiwigoSizeEntry* value);
static void publishing_piwigo_publishing_options_pane_update_publish_button_sensitivity (PublishingPiwigoPublishingOptionsPane* self);
static gboolean publishing_piwigo_publishing_options_pane_category_already_exists (PublishingPiwigoPublishingOptionsPane* self, const gchar* category_name);
static GtkWidget* publishing_piwigo_publishing_options_pane_real_get_widget (SpitPublishingDialogPane* base);
static SpitPublishingDialogPaneGeometryOptions publishing_piwigo_publishing_options_pane_real_get_preferred_geometry (SpitPublishingDialogPane* base);
static void publishing_piwigo_publishing_options_pane_real_on_pane_installed (SpitPublishingDialogPane* base);
static void publishing_piwigo_publishing_options_pane_create_categories_combo (PublishingPiwigoPublishingOptionsPane* self);
static void publishing_piwigo_publishing_options_pane_create_within_categories_combo (PublishingPiwigoPublishingOptionsPane* self);
static void publishing_piwigo_publishing_options_pane_create_permissions_combo (PublishingPiwigoPublishingOptionsPane* self);
static void publishing_piwigo_publishing_options_pane_create_size_combo (PublishingPiwigoPublishingOptionsPane* self);
static gint publishing_piwigo_publishing_options_pane_find_category_index (PublishingPiwigoPublishingOptionsPane* self, gint category_id);
static gint publishing_piwigo_publishing_options_pane_find_permission_level_index (PublishingPiwigoPublishingOptionsPane* self, gint permission_level_id);
static gint publishing_piwigo_publishing_options_pane_find_size_index (PublishingPiwigoPublishingOptionsPane* self, gint size_id);
static void publishing_piwigo_publishing_options_pane_real_on_pane_uninstalled (SpitPublishingDialogPane* base);
static void g_cclosure_user_marshal_VOID__PUBLISHING_PIWIGO_PUBLISHING_PARAMETERS_BOOLEAN (GClosure * closure, GValue * return_value, guint n_param_values, const GValue * param_values, gpointer invocation_hint, gpointer marshal_data);
static void publishing_piwigo_publishing_options_pane_finalize (GObject* obj);
#define PUBLISHING_PIWIGO_SESSION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_PIWIGO_TYPE_SESSION, PublishingPiwigoSessionPrivate))
enum  {
	PUBLISHING_PIWIGO_SESSION_DUMMY_PROPERTY
};
static gboolean publishing_piwigo_session_real_is_authenticated (PublishingRESTSupportSession* base);
static void publishing_piwigo_session_finalize (PublishingRESTSupportSession* obj);
enum  {
	PUBLISHING_PIWIGO_TRANSACTION_DUMMY_PROPERTY
};
PublishingPiwigoTransaction* publishing_piwigo_transaction_new (PublishingPiwigoSession* session);
PublishingPiwigoTransaction* publishing_piwigo_transaction_construct (GType object_type, PublishingPiwigoSession* session);
PublishingPiwigoTransaction* publishing_piwigo_transaction_new_authenticated (PublishingPiwigoSession* session);
PublishingPiwigoTransaction* publishing_piwigo_transaction_construct_authenticated (GType object_type, PublishingPiwigoSession* session);
enum  {
	PUBLISHING_PIWIGO_SESSION_LOGIN_TRANSACTION_DUMMY_PROPERTY
};
enum  {
	PUBLISHING_PIWIGO_SESSION_GET_STATUS_TRANSACTION_DUMMY_PROPERTY
};
enum  {
	PUBLISHING_PIWIGO_CATEGORIES_GET_LIST_TRANSACTION_DUMMY_PROPERTY
};
enum  {
	PUBLISHING_PIWIGO_SESSION_LOGOUT_TRANSACTION_DUMMY_PROPERTY
};
enum  {
	PUBLISHING_PIWIGO_CATEGORIES_ADD_TRANSACTION_DUMMY_PROPERTY
};
#define PUBLISHING_PIWIGO_IMAGES_ADD_TRANSACTION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_PIWIGO_TYPE_IMAGES_ADD_TRANSACTION, PublishingPiwigoImagesAddTransactionPrivate))
enum  {
	PUBLISHING_PIWIGO_IMAGES_ADD_TRANSACTION_DUMMY_PROPERTY
};
static void _g_free0_ (gpointer var);
static void publishing_piwigo_images_add_transaction_finalize (PublishingRESTSupportTransaction* obj);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
static gint _vala_array_length (gpointer array);


PiwigoService* piwigo_service_construct (GType object_type, GFile* resource_directory) {
	PiwigoService * self = NULL;
	GdkPixbuf** _tmp0_ = NULL;
	gint _tmp0__length1 = 0;
#line 12 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (G_IS_FILE (resource_directory), NULL);
#line 12 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = (PiwigoService*) g_object_new (object_type, NULL);
#line 13 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = piwigo_service_icon_pixbuf_set;
#line 13 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0__length1 = piwigo_service_icon_pixbuf_set_length1;
#line 13 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (_tmp0_ == NULL) {
#line 874 "PiwigoPublishing.c"
		gint _tmp1_ = 0;
		GdkPixbuf** _tmp2_ = NULL;
#line 14 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp2_ = resources_load_from_resource (PLUGIN_RESOURCE_PATH "/" PIWIGO_SERVICE_ICON_FILENAME, &_tmp1_);
#line 14 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		piwigo_service_icon_pixbuf_set = (_vala_array_free (piwigo_service_icon_pixbuf_set, piwigo_service_icon_pixbuf_set_length1, (GDestroyNotify) g_object_unref), NULL);
#line 14 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		piwigo_service_icon_pixbuf_set = _tmp2_;
#line 14 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		piwigo_service_icon_pixbuf_set_length1 = _tmp1_;
#line 14 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_piwigo_service_icon_pixbuf_set_size_ = piwigo_service_icon_pixbuf_set_length1;
#line 887 "PiwigoPublishing.c"
	}
#line 12 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return self;
#line 891 "PiwigoPublishing.c"
}


PiwigoService* piwigo_service_new (GFile* resource_directory) {
#line 12 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return piwigo_service_construct (TYPE_PIWIGO_SERVICE, resource_directory);
#line 898 "PiwigoPublishing.c"
}


static gint piwigo_service_real_get_pluggable_interface (SpitPluggable* base, gint min_host_interface, gint max_host_interface) {
	PiwigoService * self;
	gint result = 0;
	gint _tmp0_ = 0;
	gint _tmp1_ = 0;
	gint _tmp2_ = 0;
#line 18 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_PIWIGO_SERVICE, PiwigoService);
#line 19 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = min_host_interface;
#line 19 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = max_host_interface;
#line 19 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = spit_negotiate_interfaces (_tmp0_, _tmp1_, SPIT_PUBLISHING_CURRENT_INTERFACE);
#line 19 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = _tmp2_;
#line 19 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 920 "PiwigoPublishing.c"
}


static const gchar* piwigo_service_real_get_id (SpitPluggable* base) {
	PiwigoService * self;
	const gchar* result = NULL;
#line 23 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_PIWIGO_SERVICE, PiwigoService);
#line 24 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = "org.yorba.shotwell.publishing.piwigo";
#line 24 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 933 "PiwigoPublishing.c"
}


static const gchar* piwigo_service_real_get_pluggable_name (SpitPluggable* base) {
	PiwigoService * self;
	const gchar* result = NULL;
#line 27 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_PIWIGO_SERVICE, PiwigoService);
#line 28 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = "Piwigo";
#line 28 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 946 "PiwigoPublishing.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return self ? g_object_ref (self) : NULL;
#line 953 "PiwigoPublishing.c"
}


static GdkPixbuf** _vala_array_dup10 (GdkPixbuf** self, int length) {
	GdkPixbuf** result;
	int i;
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = g_new0 (GdkPixbuf*, length + 1);
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	for (i = 0; i < length; i++) {
#line 964 "PiwigoPublishing.c"
		GdkPixbuf* _tmp0_ = NULL;
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp0_ = _g_object_ref0 (self[i]);
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		result[i] = _tmp0_;
#line 970 "PiwigoPublishing.c"
	}
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 974 "PiwigoPublishing.c"
}


static void piwigo_service_real_get_info (SpitPluggable* base, SpitPluggableInfo* info) {
	PiwigoService * self;
	gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
	GdkPixbuf** _tmp8_ = NULL;
	gint _tmp8__length1 = 0;
	GdkPixbuf** _tmp9_ = NULL;
	gint _tmp9__length1 = 0;
#line 31 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_PIWIGO_SERVICE, PiwigoService);
#line 31 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (info != NULL);
#line 32 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = g_strdup ("Bruno Girin");
#line 32 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 ((*info).authors);
#line 32 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	(*info).authors = _tmp0_;
#line 33 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = _ ("Copyright 2016 Software Freedom Conservancy Inc.");
#line 33 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = g_strdup (_tmp1_);
#line 33 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 ((*info).copyright);
#line 33 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	(*info).copyright = _tmp2_;
#line 34 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3_ = g_strdup (RESOURCES_TRANSLATORS);
#line 34 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 ((*info).translators);
#line 34 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	(*info).translators = _tmp3_;
#line 35 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = g_strdup (_VERSION);
#line 35 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 ((*info).version);
#line 35 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	(*info).version = _tmp4_;
#line 36 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp5_ = g_strdup (RESOURCES_WEBSITE_NAME);
#line 36 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 ((*info).website_name);
#line 36 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	(*info).website_name = _tmp5_;
#line 37 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp6_ = g_strdup (RESOURCES_WEBSITE_URL);
#line 37 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 ((*info).website_url);
#line 37 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	(*info).website_url = _tmp6_;
#line 38 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	(*info).is_license_wordwrapped = FALSE;
#line 39 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp7_ = g_strdup (RESOURCES_LICENSE);
#line 39 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 ((*info).license);
#line 39 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	(*info).license = _tmp7_;
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp8_ = piwigo_service_icon_pixbuf_set;
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp8__length1 = piwigo_service_icon_pixbuf_set_length1;
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp9_ = (_tmp8_ != NULL) ? _vala_array_dup10 (_tmp8_, _tmp8__length1) : ((gpointer) _tmp8_);
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp9__length1 = _tmp8__length1;
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	(*info).icons = (_vala_array_free ((*info).icons, (*info).icons_length1, (GDestroyNotify) g_object_unref), NULL);
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	(*info).icons = _tmp9_;
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	(*info).icons_length1 = _tmp9__length1;
#line 1056 "PiwigoPublishing.c"
}


static void piwigo_service_real_activation (SpitPluggable* base, gboolean enabled) {
	PiwigoService * self;
#line 43 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_PIWIGO_SERVICE, PiwigoService);
#line 1064 "PiwigoPublishing.c"
}


static SpitPublishingPublisher* piwigo_service_real_create_publisher (SpitPublishingService* base, SpitPublishingPluginHost* host) {
	PiwigoService * self;
	SpitPublishingPublisher* result = NULL;
	SpitPublishingPluginHost* _tmp0_ = NULL;
	PublishingPiwigoPiwigoPublisher* _tmp1_ = NULL;
#line 46 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_PIWIGO_SERVICE, PiwigoService);
#line 46 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (SPIT_PUBLISHING_IS_PLUGIN_HOST (host), NULL);
#line 47 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = host;
#line 47 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = publishing_piwigo_piwigo_publisher_new (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_SERVICE, SpitPublishingService), _tmp0_);
#line 47 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher);
#line 47 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 1085 "PiwigoPublishing.c"
}


static SpitPublishingPublisherMediaType piwigo_service_real_get_supported_media (SpitPublishingService* base) {
	PiwigoService * self;
	SpitPublishingPublisherMediaType result = 0;
#line 50 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_PIWIGO_SERVICE, PiwigoService);
#line 51 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = SPIT_PUBLISHING_PUBLISHER_MEDIA_TYPE_PHOTO;
#line 51 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 1098 "PiwigoPublishing.c"
}


static void piwigo_service_class_init (PiwigoServiceClass * klass) {
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	piwigo_service_parent_class = g_type_class_peek_parent (klass);
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	G_OBJECT_CLASS (klass)->finalize = piwigo_service_finalize;
#line 1107 "PiwigoPublishing.c"
}


static void piwigo_service_spit_pluggable_interface_init (SpitPluggableIface * iface) {
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	piwigo_service_spit_pluggable_parent_iface = g_type_interface_peek_parent (iface);
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	iface->get_pluggable_interface = (gint (*)(SpitPluggable*, gint, gint)) piwigo_service_real_get_pluggable_interface;
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	iface->get_id = (const gchar* (*)(SpitPluggable*)) piwigo_service_real_get_id;
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	iface->get_pluggable_name = (const gchar* (*)(SpitPluggable*)) piwigo_service_real_get_pluggable_name;
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	iface->get_info = (void (*)(SpitPluggable*, SpitPluggableInfo*)) piwigo_service_real_get_info;
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	iface->activation = (void (*)(SpitPluggable*, gboolean)) piwigo_service_real_activation;
#line 1124 "PiwigoPublishing.c"
}


static void piwigo_service_spit_publishing_service_interface_init (SpitPublishingServiceIface * iface) {
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	piwigo_service_spit_publishing_service_parent_iface = g_type_interface_peek_parent (iface);
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	iface->create_publisher = (SpitPublishingPublisher* (*)(SpitPublishingService*, SpitPublishingPluginHost*)) piwigo_service_real_create_publisher;
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	iface->get_supported_media = (SpitPublishingPublisherMediaType (*)(SpitPublishingService*)) piwigo_service_real_get_supported_media;
#line 1135 "PiwigoPublishing.c"
}


static void piwigo_service_instance_init (PiwigoService * self) {
}


static void piwigo_service_finalize (GObject* obj) {
	PiwigoService * self;
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_PIWIGO_SERVICE, PiwigoService);
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	G_OBJECT_CLASS (piwigo_service_parent_class)->finalize (obj);
#line 1149 "PiwigoPublishing.c"
}


GType piwigo_service_get_type (void) {
	static volatile gsize piwigo_service_type_id__volatile = 0;
	if (g_once_init_enter (&piwigo_service_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PiwigoServiceClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) piwigo_service_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PiwigoService), 0, (GInstanceInitFunc) piwigo_service_instance_init, NULL };
		static const GInterfaceInfo spit_pluggable_info = { (GInterfaceInitFunc) piwigo_service_spit_pluggable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo spit_publishing_service_info = { (GInterfaceInitFunc) piwigo_service_spit_publishing_service_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType piwigo_service_type_id;
		piwigo_service_type_id = g_type_register_static (G_TYPE_OBJECT, "PiwigoService", &g_define_type_info, 0);
		g_type_add_interface_static (piwigo_service_type_id, SPIT_TYPE_PLUGGABLE, &spit_pluggable_info);
		g_type_add_interface_static (piwigo_service_type_id, SPIT_PUBLISHING_TYPE_SERVICE, &spit_publishing_service_info);
		g_once_init_leave (&piwigo_service_type_id__volatile, piwigo_service_type_id);
	}
	return piwigo_service_type_id__volatile;
}


PublishingPiwigoCategory* publishing_piwigo_category_construct (GType object_type, gint id, const gchar* name, const gchar* uppercats, const gchar* comment) {
	PublishingPiwigoCategory* self = NULL;
	gint _tmp0_ = 0;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
#line 69 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (name != NULL, NULL);
#line 69 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (uppercats != NULL, NULL);
#line 69 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = (PublishingPiwigoCategory*) g_type_create_instance (object_type);
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = id;
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->id = _tmp0_;
#line 71 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = name;
#line 71 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = g_strdup (_tmp1_);
#line 71 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (self->name);
#line 71 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->name = _tmp2_;
#line 72 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3_ = uppercats;
#line 72 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = g_strdup (_tmp3_);
#line 72 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (self->uppercats);
#line 72 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->uppercats = _tmp4_;
#line 73 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp5_ = comment;
#line 73 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp6_ = g_strdup (_tmp5_);
#line 73 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (self->comment);
#line 73 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->comment = _tmp6_;
#line 69 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return self;
#line 1214 "PiwigoPublishing.c"
}


PublishingPiwigoCategory* publishing_piwigo_category_new (gint id, const gchar* name, const gchar* uppercats, const gchar* comment) {
#line 69 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return publishing_piwigo_category_construct (PUBLISHING_PIWIGO_TYPE_CATEGORY, id, name, uppercats, comment);
#line 1221 "PiwigoPublishing.c"
}


PublishingPiwigoCategory* publishing_piwigo_category_construct_local (GType object_type, const gchar* name, gint parent_id, const gchar* comment) {
	PublishingPiwigoCategory* self = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	gint _tmp2_ = 0;
	gchar* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
#line 76 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (name != NULL, NULL);
#line 76 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = (PublishingPiwigoCategory*) g_type_create_instance (object_type);
#line 77 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->id = PUBLISHING_PIWIGO_CATEGORY_NO_ID;
#line 78 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = name;
#line 78 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 78 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (self->name);
#line 78 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->name = _tmp1_;
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = parent_id;
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3_ = g_strdup_printf ("%i", _tmp2_);
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (self->uppercats);
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->uppercats = _tmp3_;
#line 82 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = comment;
#line 82 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp5_ = g_strdup (_tmp4_);
#line 82 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (self->comment);
#line 82 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->comment = _tmp5_;
#line 76 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return self;
#line 1265 "PiwigoPublishing.c"
}


PublishingPiwigoCategory* publishing_piwigo_category_new_local (const gchar* name, gint parent_id, const gchar* comment) {
#line 76 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return publishing_piwigo_category_construct_local (PUBLISHING_PIWIGO_TYPE_CATEGORY, name, parent_id, comment);
#line 1272 "PiwigoPublishing.c"
}


gboolean publishing_piwigo_category_is_local (PublishingPiwigoCategory* self) {
	gboolean result = FALSE;
	gint _tmp0_ = 0;
#line 85 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_CATEGORY (self), FALSE);
#line 86 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->id;
#line 86 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = _tmp0_ == PUBLISHING_PIWIGO_CATEGORY_NO_ID;
#line 86 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 1287 "PiwigoPublishing.c"
}


static void publishing_piwigo_value_category_init (GValue* value) {
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	value->data[0].v_pointer = NULL;
#line 1294 "PiwigoPublishing.c"
}


static void publishing_piwigo_value_category_free_value (GValue* value) {
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (value->data[0].v_pointer) {
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_piwigo_category_unref (value->data[0].v_pointer);
#line 1303 "PiwigoPublishing.c"
	}
}


static void publishing_piwigo_value_category_copy_value (const GValue* src_value, GValue* dest_value) {
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (src_value->data[0].v_pointer) {
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		dest_value->data[0].v_pointer = publishing_piwigo_category_ref (src_value->data[0].v_pointer);
#line 1313 "PiwigoPublishing.c"
	} else {
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		dest_value->data[0].v_pointer = NULL;
#line 1317 "PiwigoPublishing.c"
	}
}


static gpointer publishing_piwigo_value_category_peek_pointer (const GValue* value) {
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return value->data[0].v_pointer;
#line 1325 "PiwigoPublishing.c"
}


static gchar* publishing_piwigo_value_category_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (collect_values[0].v_pointer) {
#line 1332 "PiwigoPublishing.c"
		PublishingPiwigoCategory* object;
		object = collect_values[0].v_pointer;
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		if (object->parent_instance.g_class == NULL) {
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 1339 "PiwigoPublishing.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 1343 "PiwigoPublishing.c"
		}
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		value->data[0].v_pointer = publishing_piwigo_category_ref (object);
#line 1347 "PiwigoPublishing.c"
	} else {
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 1351 "PiwigoPublishing.c"
	}
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return NULL;
#line 1355 "PiwigoPublishing.c"
}


static gchar* publishing_piwigo_value_category_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	PublishingPiwigoCategory** object_p;
	object_p = collect_values[0].v_pointer;
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (!object_p) {
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 1366 "PiwigoPublishing.c"
	}
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (!value->data[0].v_pointer) {
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		*object_p = NULL;
#line 1372 "PiwigoPublishing.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		*object_p = value->data[0].v_pointer;
#line 1376 "PiwigoPublishing.c"
	} else {
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		*object_p = publishing_piwigo_category_ref (value->data[0].v_pointer);
#line 1380 "PiwigoPublishing.c"
	}
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return NULL;
#line 1384 "PiwigoPublishing.c"
}


GParamSpec* publishing_piwigo_param_spec_category (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
	PublishingPiwigoParamSpecCategory* spec;
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (g_type_is_a (object_type, PUBLISHING_PIWIGO_TYPE_CATEGORY), NULL);
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return G_PARAM_SPEC (spec);
#line 1398 "PiwigoPublishing.c"
}


gpointer publishing_piwigo_value_get_category (const GValue* value) {
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_PIWIGO_TYPE_CATEGORY), NULL);
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return value->data[0].v_pointer;
#line 1407 "PiwigoPublishing.c"
}


void publishing_piwigo_value_set_category (GValue* value, gpointer v_object) {
	PublishingPiwigoCategory* old;
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_PIWIGO_TYPE_CATEGORY));
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	old = value->data[0].v_pointer;
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (v_object) {
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PUBLISHING_PIWIGO_TYPE_CATEGORY));
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		value->data[0].v_pointer = v_object;
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_piwigo_category_ref (value->data[0].v_pointer);
#line 1427 "PiwigoPublishing.c"
	} else {
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 1431 "PiwigoPublishing.c"
	}
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (old) {
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_piwigo_category_unref (old);
#line 1437 "PiwigoPublishing.c"
	}
}


void publishing_piwigo_value_take_category (GValue* value, gpointer v_object) {
	PublishingPiwigoCategory* old;
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_PIWIGO_TYPE_CATEGORY));
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	old = value->data[0].v_pointer;
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (v_object) {
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PUBLISHING_PIWIGO_TYPE_CATEGORY));
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		value->data[0].v_pointer = v_object;
#line 1456 "PiwigoPublishing.c"
	} else {
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 1460 "PiwigoPublishing.c"
	}
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (old) {
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_piwigo_category_unref (old);
#line 1466 "PiwigoPublishing.c"
	}
}


static void publishing_piwigo_category_class_init (PublishingPiwigoCategoryClass * klass) {
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_category_parent_class = g_type_class_peek_parent (klass);
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	((PublishingPiwigoCategoryClass *) klass)->finalize = publishing_piwigo_category_finalize;
#line 1476 "PiwigoPublishing.c"
}


static void publishing_piwigo_category_instance_init (PublishingPiwigoCategory * self) {
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->ref_count = 1;
#line 1483 "PiwigoPublishing.c"
}


static void publishing_piwigo_category_finalize (PublishingPiwigoCategory* obj) {
	PublishingPiwigoCategory * self;
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_PIWIGO_TYPE_CATEGORY, PublishingPiwigoCategory);
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_handlers_destroy (self);
#line 63 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (self->name);
#line 64 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (self->comment);
#line 65 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (self->display_name);
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (self->uppercats);
#line 1501 "PiwigoPublishing.c"
}


GType publishing_piwigo_category_get_type (void) {
	static volatile gsize publishing_piwigo_category_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_piwigo_category_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { publishing_piwigo_value_category_init, publishing_piwigo_value_category_free_value, publishing_piwigo_value_category_copy_value, publishing_piwigo_value_category_peek_pointer, "p", publishing_piwigo_value_category_collect_value, "p", publishing_piwigo_value_category_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (PublishingPiwigoCategoryClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_piwigo_category_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingPiwigoCategory), 0, (GInstanceInitFunc) publishing_piwigo_category_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType publishing_piwigo_category_type_id;
		publishing_piwigo_category_type_id = g_type_register_fundamental (g_type_fundamental_next (), "PublishingPiwigoCategory", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&publishing_piwigo_category_type_id__volatile, publishing_piwigo_category_type_id);
	}
	return publishing_piwigo_category_type_id__volatile;
}


gpointer publishing_piwigo_category_ref (gpointer instance) {
	PublishingPiwigoCategory* self;
	self = instance;
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_atomic_int_inc (&self->ref_count);
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return instance;
#line 1526 "PiwigoPublishing.c"
}


void publishing_piwigo_category_unref (gpointer instance) {
	PublishingPiwigoCategory* self;
	self = instance;
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		PUBLISHING_PIWIGO_CATEGORY_GET_CLASS (self)->finalize (self);
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 1539 "PiwigoPublishing.c"
	}
}


PublishingPiwigoPermissionLevel* publishing_piwigo_permission_level_construct (GType object_type, gint id, const gchar* name) {
	PublishingPiwigoPermissionLevel* self = NULL;
	gint _tmp0_ = 0;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
#line 94 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (name != NULL, NULL);
#line 94 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = (PublishingPiwigoPermissionLevel*) g_type_create_instance (object_type);
#line 95 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = id;
#line 95 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->id = _tmp0_;
#line 96 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = name;
#line 96 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = g_strdup (_tmp1_);
#line 96 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (self->name);
#line 96 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->name = _tmp2_;
#line 94 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return self;
#line 1567 "PiwigoPublishing.c"
}


PublishingPiwigoPermissionLevel* publishing_piwigo_permission_level_new (gint id, const gchar* name) {
#line 94 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return publishing_piwigo_permission_level_construct (PUBLISHING_PIWIGO_TYPE_PERMISSION_LEVEL, id, name);
#line 1574 "PiwigoPublishing.c"
}


static void publishing_piwigo_value_permission_level_init (GValue* value) {
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	value->data[0].v_pointer = NULL;
#line 1581 "PiwigoPublishing.c"
}


static void publishing_piwigo_value_permission_level_free_value (GValue* value) {
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (value->data[0].v_pointer) {
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_piwigo_permission_level_unref (value->data[0].v_pointer);
#line 1590 "PiwigoPublishing.c"
	}
}


static void publishing_piwigo_value_permission_level_copy_value (const GValue* src_value, GValue* dest_value) {
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (src_value->data[0].v_pointer) {
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		dest_value->data[0].v_pointer = publishing_piwigo_permission_level_ref (src_value->data[0].v_pointer);
#line 1600 "PiwigoPublishing.c"
	} else {
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		dest_value->data[0].v_pointer = NULL;
#line 1604 "PiwigoPublishing.c"
	}
}


static gpointer publishing_piwigo_value_permission_level_peek_pointer (const GValue* value) {
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return value->data[0].v_pointer;
#line 1612 "PiwigoPublishing.c"
}


static gchar* publishing_piwigo_value_permission_level_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (collect_values[0].v_pointer) {
#line 1619 "PiwigoPublishing.c"
		PublishingPiwigoPermissionLevel* object;
		object = collect_values[0].v_pointer;
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		if (object->parent_instance.g_class == NULL) {
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 1626 "PiwigoPublishing.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 1630 "PiwigoPublishing.c"
		}
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		value->data[0].v_pointer = publishing_piwigo_permission_level_ref (object);
#line 1634 "PiwigoPublishing.c"
	} else {
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 1638 "PiwigoPublishing.c"
	}
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return NULL;
#line 1642 "PiwigoPublishing.c"
}


static gchar* publishing_piwigo_value_permission_level_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	PublishingPiwigoPermissionLevel** object_p;
	object_p = collect_values[0].v_pointer;
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (!object_p) {
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 1653 "PiwigoPublishing.c"
	}
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (!value->data[0].v_pointer) {
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		*object_p = NULL;
#line 1659 "PiwigoPublishing.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		*object_p = value->data[0].v_pointer;
#line 1663 "PiwigoPublishing.c"
	} else {
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		*object_p = publishing_piwigo_permission_level_ref (value->data[0].v_pointer);
#line 1667 "PiwigoPublishing.c"
	}
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return NULL;
#line 1671 "PiwigoPublishing.c"
}


GParamSpec* publishing_piwigo_param_spec_permission_level (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
	PublishingPiwigoParamSpecPermissionLevel* spec;
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (g_type_is_a (object_type, PUBLISHING_PIWIGO_TYPE_PERMISSION_LEVEL), NULL);
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return G_PARAM_SPEC (spec);
#line 1685 "PiwigoPublishing.c"
}


gpointer publishing_piwigo_value_get_permission_level (const GValue* value) {
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_PIWIGO_TYPE_PERMISSION_LEVEL), NULL);
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return value->data[0].v_pointer;
#line 1694 "PiwigoPublishing.c"
}


void publishing_piwigo_value_set_permission_level (GValue* value, gpointer v_object) {
	PublishingPiwigoPermissionLevel* old;
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_PIWIGO_TYPE_PERMISSION_LEVEL));
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	old = value->data[0].v_pointer;
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (v_object) {
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PUBLISHING_PIWIGO_TYPE_PERMISSION_LEVEL));
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		value->data[0].v_pointer = v_object;
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_piwigo_permission_level_ref (value->data[0].v_pointer);
#line 1714 "PiwigoPublishing.c"
	} else {
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 1718 "PiwigoPublishing.c"
	}
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (old) {
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_piwigo_permission_level_unref (old);
#line 1724 "PiwigoPublishing.c"
	}
}


void publishing_piwigo_value_take_permission_level (GValue* value, gpointer v_object) {
	PublishingPiwigoPermissionLevel* old;
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_PIWIGO_TYPE_PERMISSION_LEVEL));
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	old = value->data[0].v_pointer;
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (v_object) {
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PUBLISHING_PIWIGO_TYPE_PERMISSION_LEVEL));
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		value->data[0].v_pointer = v_object;
#line 1743 "PiwigoPublishing.c"
	} else {
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 1747 "PiwigoPublishing.c"
	}
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (old) {
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_piwigo_permission_level_unref (old);
#line 1753 "PiwigoPublishing.c"
	}
}


static void publishing_piwigo_permission_level_class_init (PublishingPiwigoPermissionLevelClass * klass) {
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_permission_level_parent_class = g_type_class_peek_parent (klass);
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	((PublishingPiwigoPermissionLevelClass *) klass)->finalize = publishing_piwigo_permission_level_finalize;
#line 1763 "PiwigoPublishing.c"
}


static void publishing_piwigo_permission_level_instance_init (PublishingPiwigoPermissionLevel * self) {
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->ref_count = 1;
#line 1770 "PiwigoPublishing.c"
}


static void publishing_piwigo_permission_level_finalize (PublishingPiwigoPermissionLevel* obj) {
	PublishingPiwigoPermissionLevel * self;
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_PIWIGO_TYPE_PERMISSION_LEVEL, PublishingPiwigoPermissionLevel);
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_handlers_destroy (self);
#line 92 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (self->name);
#line 1782 "PiwigoPublishing.c"
}


GType publishing_piwigo_permission_level_get_type (void) {
	static volatile gsize publishing_piwigo_permission_level_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_piwigo_permission_level_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { publishing_piwigo_value_permission_level_init, publishing_piwigo_value_permission_level_free_value, publishing_piwigo_value_permission_level_copy_value, publishing_piwigo_value_permission_level_peek_pointer, "p", publishing_piwigo_value_permission_level_collect_value, "p", publishing_piwigo_value_permission_level_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (PublishingPiwigoPermissionLevelClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_piwigo_permission_level_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingPiwigoPermissionLevel), 0, (GInstanceInitFunc) publishing_piwigo_permission_level_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType publishing_piwigo_permission_level_type_id;
		publishing_piwigo_permission_level_type_id = g_type_register_fundamental (g_type_fundamental_next (), "PublishingPiwigoPermissionLevel", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&publishing_piwigo_permission_level_type_id__volatile, publishing_piwigo_permission_level_type_id);
	}
	return publishing_piwigo_permission_level_type_id__volatile;
}


gpointer publishing_piwigo_permission_level_ref (gpointer instance) {
	PublishingPiwigoPermissionLevel* self;
	self = instance;
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_atomic_int_inc (&self->ref_count);
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return instance;
#line 1807 "PiwigoPublishing.c"
}


void publishing_piwigo_permission_level_unref (gpointer instance) {
	PublishingPiwigoPermissionLevel* self;
	self = instance;
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		PUBLISHING_PIWIGO_PERMISSION_LEVEL_GET_CLASS (self)->finalize (self);
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 1820 "PiwigoPublishing.c"
	}
}


PublishingPiwigoSizeEntry* publishing_piwigo_size_entry_construct (GType object_type, gint id, const gchar* name) {
	PublishingPiwigoSizeEntry* self = NULL;
	gint _tmp0_ = 0;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
#line 104 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (name != NULL, NULL);
#line 104 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = (PublishingPiwigoSizeEntry*) g_type_create_instance (object_type);
#line 105 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = id;
#line 105 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->id = _tmp0_;
#line 106 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = name;
#line 106 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = g_strdup (_tmp1_);
#line 106 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (self->name);
#line 106 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->name = _tmp2_;
#line 104 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return self;
#line 1848 "PiwigoPublishing.c"
}


PublishingPiwigoSizeEntry* publishing_piwigo_size_entry_new (gint id, const gchar* name) {
#line 104 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return publishing_piwigo_size_entry_construct (PUBLISHING_PIWIGO_TYPE_SIZE_ENTRY, id, name);
#line 1855 "PiwigoPublishing.c"
}


static void publishing_piwigo_value_size_entry_init (GValue* value) {
#line 100 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	value->data[0].v_pointer = NULL;
#line 1862 "PiwigoPublishing.c"
}


static void publishing_piwigo_value_size_entry_free_value (GValue* value) {
#line 100 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (value->data[0].v_pointer) {
#line 100 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_piwigo_size_entry_unref (value->data[0].v_pointer);
#line 1871 "PiwigoPublishing.c"
	}
}


static void publishing_piwigo_value_size_entry_copy_value (const GValue* src_value, GValue* dest_value) {
#line 100 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (src_value->data[0].v_pointer) {
#line 100 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		dest_value->data[0].v_pointer = publishing_piwigo_size_entry_ref (src_value->data[0].v_pointer);
#line 1881 "PiwigoPublishing.c"
	} else {
#line 100 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		dest_value->data[0].v_pointer = NULL;
#line 1885 "PiwigoPublishing.c"
	}
}


static gpointer publishing_piwigo_value_size_entry_peek_pointer (const GValue* value) {
#line 100 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return value->data[0].v_pointer;
#line 1893 "PiwigoPublishing.c"
}


static gchar* publishing_piwigo_value_size_entry_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
#line 100 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (collect_values[0].v_pointer) {
#line 1900 "PiwigoPublishing.c"
		PublishingPiwigoSizeEntry* object;
		object = collect_values[0].v_pointer;
#line 100 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		if (object->parent_instance.g_class == NULL) {
#line 100 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 1907 "PiwigoPublishing.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 100 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 1911 "PiwigoPublishing.c"
		}
#line 100 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		value->data[0].v_pointer = publishing_piwigo_size_entry_ref (object);
#line 1915 "PiwigoPublishing.c"
	} else {
#line 100 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 1919 "PiwigoPublishing.c"
	}
#line 100 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return NULL;
#line 1923 "PiwigoPublishing.c"
}


static gchar* publishing_piwigo_value_size_entry_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	PublishingPiwigoSizeEntry** object_p;
	object_p = collect_values[0].v_pointer;
#line 100 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (!object_p) {
#line 100 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 1934 "PiwigoPublishing.c"
	}
#line 100 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (!value->data[0].v_pointer) {
#line 100 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		*object_p = NULL;
#line 1940 "PiwigoPublishing.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 100 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		*object_p = value->data[0].v_pointer;
#line 1944 "PiwigoPublishing.c"
	} else {
#line 100 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		*object_p = publishing_piwigo_size_entry_ref (value->data[0].v_pointer);
#line 1948 "PiwigoPublishing.c"
	}
#line 100 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return NULL;
#line 1952 "PiwigoPublishing.c"
}


GParamSpec* publishing_piwigo_param_spec_size_entry (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
	PublishingPiwigoParamSpecSizeEntry* spec;
#line 100 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (g_type_is_a (object_type, PUBLISHING_PIWIGO_TYPE_SIZE_ENTRY), NULL);
#line 100 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 100 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 100 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return G_PARAM_SPEC (spec);
#line 1966 "PiwigoPublishing.c"
}


gpointer publishing_piwigo_value_get_size_entry (const GValue* value) {
#line 100 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_PIWIGO_TYPE_SIZE_ENTRY), NULL);
#line 100 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return value->data[0].v_pointer;
#line 1975 "PiwigoPublishing.c"
}


void publishing_piwigo_value_set_size_entry (GValue* value, gpointer v_object) {
	PublishingPiwigoSizeEntry* old;
#line 100 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_PIWIGO_TYPE_SIZE_ENTRY));
#line 100 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	old = value->data[0].v_pointer;
#line 100 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (v_object) {
#line 100 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PUBLISHING_PIWIGO_TYPE_SIZE_ENTRY));
#line 100 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 100 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		value->data[0].v_pointer = v_object;
#line 100 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_piwigo_size_entry_ref (value->data[0].v_pointer);
#line 1995 "PiwigoPublishing.c"
	} else {
#line 100 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 1999 "PiwigoPublishing.c"
	}
#line 100 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (old) {
#line 100 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_piwigo_size_entry_unref (old);
#line 2005 "PiwigoPublishing.c"
	}
}


void publishing_piwigo_value_take_size_entry (GValue* value, gpointer v_object) {
	PublishingPiwigoSizeEntry* old;
#line 100 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_PIWIGO_TYPE_SIZE_ENTRY));
#line 100 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	old = value->data[0].v_pointer;
#line 100 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (v_object) {
#line 100 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PUBLISHING_PIWIGO_TYPE_SIZE_ENTRY));
#line 100 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 100 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		value->data[0].v_pointer = v_object;
#line 2024 "PiwigoPublishing.c"
	} else {
#line 100 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 2028 "PiwigoPublishing.c"
	}
#line 100 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (old) {
#line 100 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_piwigo_size_entry_unref (old);
#line 2034 "PiwigoPublishing.c"
	}
}


static void publishing_piwigo_size_entry_class_init (PublishingPiwigoSizeEntryClass * klass) {
#line 100 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_size_entry_parent_class = g_type_class_peek_parent (klass);
#line 100 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	((PublishingPiwigoSizeEntryClass *) klass)->finalize = publishing_piwigo_size_entry_finalize;
#line 2044 "PiwigoPublishing.c"
}


static void publishing_piwigo_size_entry_instance_init (PublishingPiwigoSizeEntry * self) {
#line 100 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->ref_count = 1;
#line 2051 "PiwigoPublishing.c"
}


static void publishing_piwigo_size_entry_finalize (PublishingPiwigoSizeEntry* obj) {
	PublishingPiwigoSizeEntry * self;
#line 100 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_PIWIGO_TYPE_SIZE_ENTRY, PublishingPiwigoSizeEntry);
#line 100 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_handlers_destroy (self);
#line 102 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (self->name);
#line 2063 "PiwigoPublishing.c"
}


GType publishing_piwigo_size_entry_get_type (void) {
	static volatile gsize publishing_piwigo_size_entry_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_piwigo_size_entry_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { publishing_piwigo_value_size_entry_init, publishing_piwigo_value_size_entry_free_value, publishing_piwigo_value_size_entry_copy_value, publishing_piwigo_value_size_entry_peek_pointer, "p", publishing_piwigo_value_size_entry_collect_value, "p", publishing_piwigo_value_size_entry_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (PublishingPiwigoSizeEntryClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_piwigo_size_entry_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingPiwigoSizeEntry), 0, (GInstanceInitFunc) publishing_piwigo_size_entry_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType publishing_piwigo_size_entry_type_id;
		publishing_piwigo_size_entry_type_id = g_type_register_fundamental (g_type_fundamental_next (), "PublishingPiwigoSizeEntry", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&publishing_piwigo_size_entry_type_id__volatile, publishing_piwigo_size_entry_type_id);
	}
	return publishing_piwigo_size_entry_type_id__volatile;
}


gpointer publishing_piwigo_size_entry_ref (gpointer instance) {
	PublishingPiwigoSizeEntry* self;
	self = instance;
#line 100 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_atomic_int_inc (&self->ref_count);
#line 100 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return instance;
#line 2088 "PiwigoPublishing.c"
}


void publishing_piwigo_size_entry_unref (gpointer instance) {
	PublishingPiwigoSizeEntry* self;
	self = instance;
#line 100 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 100 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		PUBLISHING_PIWIGO_SIZE_ENTRY_GET_CLASS (self)->finalize (self);
#line 100 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 2101 "PiwigoPublishing.c"
	}
}


PublishingPiwigoPublishingParameters* publishing_piwigo_publishing_parameters_construct (GType object_type) {
	PublishingPiwigoPublishingParameters* self = NULL;
#line 117 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = (PublishingPiwigoPublishingParameters*) g_type_create_instance (object_type);
#line 117 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return self;
#line 2112 "PiwigoPublishing.c"
}


PublishingPiwigoPublishingParameters* publishing_piwigo_publishing_parameters_new (void) {
#line 117 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return publishing_piwigo_publishing_parameters_construct (PUBLISHING_PIWIGO_TYPE_PUBLISHING_PARAMETERS);
#line 2119 "PiwigoPublishing.c"
}


static void publishing_piwigo_value_publishing_parameters_init (GValue* value) {
#line 110 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	value->data[0].v_pointer = NULL;
#line 2126 "PiwigoPublishing.c"
}


static void publishing_piwigo_value_publishing_parameters_free_value (GValue* value) {
#line 110 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (value->data[0].v_pointer) {
#line 110 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_piwigo_publishing_parameters_unref (value->data[0].v_pointer);
#line 2135 "PiwigoPublishing.c"
	}
}


static void publishing_piwigo_value_publishing_parameters_copy_value (const GValue* src_value, GValue* dest_value) {
#line 110 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (src_value->data[0].v_pointer) {
#line 110 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		dest_value->data[0].v_pointer = publishing_piwigo_publishing_parameters_ref (src_value->data[0].v_pointer);
#line 2145 "PiwigoPublishing.c"
	} else {
#line 110 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		dest_value->data[0].v_pointer = NULL;
#line 2149 "PiwigoPublishing.c"
	}
}


static gpointer publishing_piwigo_value_publishing_parameters_peek_pointer (const GValue* value) {
#line 110 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return value->data[0].v_pointer;
#line 2157 "PiwigoPublishing.c"
}


static gchar* publishing_piwigo_value_publishing_parameters_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
#line 110 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (collect_values[0].v_pointer) {
#line 2164 "PiwigoPublishing.c"
		PublishingPiwigoPublishingParameters* object;
		object = collect_values[0].v_pointer;
#line 110 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		if (object->parent_instance.g_class == NULL) {
#line 110 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 2171 "PiwigoPublishing.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 110 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 2175 "PiwigoPublishing.c"
		}
#line 110 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		value->data[0].v_pointer = publishing_piwigo_publishing_parameters_ref (object);
#line 2179 "PiwigoPublishing.c"
	} else {
#line 110 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 2183 "PiwigoPublishing.c"
	}
#line 110 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return NULL;
#line 2187 "PiwigoPublishing.c"
}


static gchar* publishing_piwigo_value_publishing_parameters_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	PublishingPiwigoPublishingParameters** object_p;
	object_p = collect_values[0].v_pointer;
#line 110 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (!object_p) {
#line 110 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 2198 "PiwigoPublishing.c"
	}
#line 110 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (!value->data[0].v_pointer) {
#line 110 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		*object_p = NULL;
#line 2204 "PiwigoPublishing.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 110 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		*object_p = value->data[0].v_pointer;
#line 2208 "PiwigoPublishing.c"
	} else {
#line 110 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		*object_p = publishing_piwigo_publishing_parameters_ref (value->data[0].v_pointer);
#line 2212 "PiwigoPublishing.c"
	}
#line 110 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return NULL;
#line 2216 "PiwigoPublishing.c"
}


GParamSpec* publishing_piwigo_param_spec_publishing_parameters (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
	PublishingPiwigoParamSpecPublishingParameters* spec;
#line 110 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (g_type_is_a (object_type, PUBLISHING_PIWIGO_TYPE_PUBLISHING_PARAMETERS), NULL);
#line 110 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 110 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 110 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return G_PARAM_SPEC (spec);
#line 2230 "PiwigoPublishing.c"
}


gpointer publishing_piwigo_value_get_publishing_parameters (const GValue* value) {
#line 110 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_PIWIGO_TYPE_PUBLISHING_PARAMETERS), NULL);
#line 110 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return value->data[0].v_pointer;
#line 2239 "PiwigoPublishing.c"
}


void publishing_piwigo_value_set_publishing_parameters (GValue* value, gpointer v_object) {
	PublishingPiwigoPublishingParameters* old;
#line 110 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_PIWIGO_TYPE_PUBLISHING_PARAMETERS));
#line 110 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	old = value->data[0].v_pointer;
#line 110 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (v_object) {
#line 110 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PUBLISHING_PIWIGO_TYPE_PUBLISHING_PARAMETERS));
#line 110 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 110 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		value->data[0].v_pointer = v_object;
#line 110 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_piwigo_publishing_parameters_ref (value->data[0].v_pointer);
#line 2259 "PiwigoPublishing.c"
	} else {
#line 110 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 2263 "PiwigoPublishing.c"
	}
#line 110 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (old) {
#line 110 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_piwigo_publishing_parameters_unref (old);
#line 2269 "PiwigoPublishing.c"
	}
}


void publishing_piwigo_value_take_publishing_parameters (GValue* value, gpointer v_object) {
	PublishingPiwigoPublishingParameters* old;
#line 110 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_PIWIGO_TYPE_PUBLISHING_PARAMETERS));
#line 110 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	old = value->data[0].v_pointer;
#line 110 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (v_object) {
#line 110 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PUBLISHING_PIWIGO_TYPE_PUBLISHING_PARAMETERS));
#line 110 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 110 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		value->data[0].v_pointer = v_object;
#line 2288 "PiwigoPublishing.c"
	} else {
#line 110 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 2292 "PiwigoPublishing.c"
	}
#line 110 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (old) {
#line 110 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_piwigo_publishing_parameters_unref (old);
#line 2298 "PiwigoPublishing.c"
	}
}


static void publishing_piwigo_publishing_parameters_class_init (PublishingPiwigoPublishingParametersClass * klass) {
#line 110 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_publishing_parameters_parent_class = g_type_class_peek_parent (klass);
#line 110 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	((PublishingPiwigoPublishingParametersClass *) klass)->finalize = publishing_piwigo_publishing_parameters_finalize;
#line 2308 "PiwigoPublishing.c"
}


static void publishing_piwigo_publishing_parameters_instance_init (PublishingPiwigoPublishingParameters * self) {
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->category = NULL;
#line 112 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->perm_level = NULL;
#line 113 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->photo_size = NULL;
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->title_as_comment = FALSE;
#line 115 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->no_upload_tags = FALSE;
#line 110 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->ref_count = 1;
#line 2325 "PiwigoPublishing.c"
}


static void publishing_piwigo_publishing_parameters_finalize (PublishingPiwigoPublishingParameters* obj) {
	PublishingPiwigoPublishingParameters * self;
#line 110 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_PIWIGO_TYPE_PUBLISHING_PARAMETERS, PublishingPiwigoPublishingParameters);
#line 110 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_handlers_destroy (self);
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_publishing_piwigo_category_unref0 (self->category);
#line 112 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_publishing_piwigo_permission_level_unref0 (self->perm_level);
#line 113 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_publishing_piwigo_size_entry_unref0 (self->photo_size);
#line 2341 "PiwigoPublishing.c"
}


GType publishing_piwigo_publishing_parameters_get_type (void) {
	static volatile gsize publishing_piwigo_publishing_parameters_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_piwigo_publishing_parameters_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { publishing_piwigo_value_publishing_parameters_init, publishing_piwigo_value_publishing_parameters_free_value, publishing_piwigo_value_publishing_parameters_copy_value, publishing_piwigo_value_publishing_parameters_peek_pointer, "p", publishing_piwigo_value_publishing_parameters_collect_value, "p", publishing_piwigo_value_publishing_parameters_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (PublishingPiwigoPublishingParametersClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_piwigo_publishing_parameters_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingPiwigoPublishingParameters), 0, (GInstanceInitFunc) publishing_piwigo_publishing_parameters_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType publishing_piwigo_publishing_parameters_type_id;
		publishing_piwigo_publishing_parameters_type_id = g_type_register_fundamental (g_type_fundamental_next (), "PublishingPiwigoPublishingParameters", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&publishing_piwigo_publishing_parameters_type_id__volatile, publishing_piwigo_publishing_parameters_type_id);
	}
	return publishing_piwigo_publishing_parameters_type_id__volatile;
}


gpointer publishing_piwigo_publishing_parameters_ref (gpointer instance) {
	PublishingPiwigoPublishingParameters* self;
	self = instance;
#line 110 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_atomic_int_inc (&self->ref_count);
#line 110 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return instance;
#line 2366 "PiwigoPublishing.c"
}


void publishing_piwigo_publishing_parameters_unref (gpointer instance) {
	PublishingPiwigoPublishingParameters* self;
	self = instance;
#line 110 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 110 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		PUBLISHING_PIWIGO_PUBLISHING_PARAMETERS_GET_CLASS (self)->finalize (self);
#line 110 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 2379 "PiwigoPublishing.c"
	}
}


PublishingPiwigoPiwigoPublisher* publishing_piwigo_piwigo_publisher_construct (GType object_type, SpitPublishingService* service, SpitPublishingPluginHost* host) {
	PublishingPiwigoPiwigoPublisher * self = NULL;
	SpitPublishingService* _tmp0_ = NULL;
	SpitPublishingService* _tmp1_ = NULL;
	SpitPublishingPluginHost* _tmp2_ = NULL;
	SpitPublishingPluginHost* _tmp3_ = NULL;
	PublishingPiwigoSession* _tmp4_ = NULL;
#line 131 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (SPIT_PUBLISHING_IS_SERVICE (service), NULL);
#line 131 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (SPIT_PUBLISHING_IS_PLUGIN_HOST (host), NULL);
#line 131 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = (PublishingPiwigoPiwigoPublisher*) g_object_new (object_type, NULL);
#line 133 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_debug ("PiwigoPublishing.vala:133: PiwigoPublisher instantiated.");
#line 134 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = service;
#line 134 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 134 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (self->priv->service);
#line 134 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->service = _tmp1_;
#line 135 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = host;
#line 135 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 135 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (self->priv->host);
#line 135 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->host = _tmp3_;
#line 136 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = publishing_piwigo_session_new ();
#line 136 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_publishing_rest_support_session_unref0 (self->priv->session);
#line 136 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->session = _tmp4_;
#line 131 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return self;
#line 2423 "PiwigoPublishing.c"
}


PublishingPiwigoPiwigoPublisher* publishing_piwigo_piwigo_publisher_new (SpitPublishingService* service, SpitPublishingPluginHost* host) {
#line 131 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return publishing_piwigo_piwigo_publisher_construct (PUBLISHING_PIWIGO_TYPE_PIWIGO_PUBLISHER, service, host);
#line 2430 "PiwigoPublishing.c"
}


static SpitPublishingService* publishing_piwigo_piwigo_publisher_real_get_service (SpitPublishingPublisher* base) {
	PublishingPiwigoPiwigoPublisher * self;
	SpitPublishingService* result = NULL;
	SpitPublishingService* _tmp0_ = NULL;
	SpitPublishingService* _tmp1_ = NULL;
#line 141 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_PIWIGO_TYPE_PIWIGO_PUBLISHER, PublishingPiwigoPiwigoPublisher);
#line 142 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->service;
#line 142 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 142 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = _tmp1_;
#line 142 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 2449 "PiwigoPublishing.c"
}


SpitPublishingPluginHost* publishing_piwigo_piwigo_publisher_get_host (PublishingPiwigoPiwigoPublisher* self) {
	SpitPublishingPluginHost* result = NULL;
	SpitPublishingPluginHost* _tmp0_ = NULL;
	SpitPublishingPluginHost* _tmp1_ = NULL;
#line 145 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self), NULL);
#line 146 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->host;
#line 146 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 146 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = _tmp1_;
#line 146 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 2467 "PiwigoPublishing.c"
}


static gboolean publishing_piwigo_piwigo_publisher_real_is_running (SpitPublishingPublisher* base) {
	PublishingPiwigoPiwigoPublisher * self;
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
#line 149 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_PIWIGO_TYPE_PIWIGO_PUBLISHER, PublishingPiwigoPiwigoPublisher);
#line 150 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->running;
#line 150 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = _tmp0_;
#line 150 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 2483 "PiwigoPublishing.c"
}


static void publishing_piwigo_piwigo_publisher_real_start (SpitPublishingPublisher* base) {
	PublishingPiwigoPiwigoPublisher * self;
	gboolean _tmp0_ = FALSE;
	PublishingPiwigoSession* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
#line 153 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_PIWIGO_TYPE_PIWIGO_PUBLISHER, PublishingPiwigoPiwigoPublisher);
#line 154 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher));
#line 154 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (_tmp0_) {
#line 155 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		return;
#line 2500 "PiwigoPublishing.c"
	}
#line 157 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_debug ("PiwigoPublishing.vala:157: PiwigoPublisher: starting interaction.");
#line 159 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->running = TRUE;
#line 161 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = self->priv->session;
#line 161 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = publishing_rest_support_session_is_authenticated (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession));
#line 161 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (_tmp2_) {
#line 162 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_debug ("PiwigoPublishing.vala:162: PiwigoPublisher: session is authenticated.");
#line 163 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_piwigo_piwigo_publisher_do_fetch_categories (self);
#line 2516 "PiwigoPublishing.c"
	} else {
		gchar* persistent_url = NULL;
		gchar* _tmp3_ = NULL;
		gchar* persistent_username = NULL;
		gchar* _tmp4_ = NULL;
		gchar* persistent_password = NULL;
		gchar* _tmp5_ = NULL;
		gboolean _tmp6_ = FALSE;
		gboolean _tmp7_ = FALSE;
		const gchar* _tmp8_ = NULL;
#line 165 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_debug ("PiwigoPublishing.vala:165: PiwigoPublisher: session is not authenticat" \
"ed.");
#line 166 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp3_ = publishing_piwigo_piwigo_publisher_get_persistent_url (self);
#line 166 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		persistent_url = _tmp3_;
#line 167 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp4_ = publishing_piwigo_piwigo_publisher_get_persistent_username (self);
#line 167 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		persistent_username = _tmp4_;
#line 168 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp5_ = publishing_piwigo_piwigo_publisher_get_persistent_password (self);
#line 168 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		persistent_password = _tmp5_;
#line 169 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp8_ = persistent_url;
#line 169 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		if (_tmp8_ != NULL) {
#line 2545 "PiwigoPublishing.c"
			const gchar* _tmp9_ = NULL;
#line 169 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp9_ = persistent_username;
#line 169 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp7_ = _tmp9_ != NULL;
#line 2551 "PiwigoPublishing.c"
		} else {
#line 169 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp7_ = FALSE;
#line 2555 "PiwigoPublishing.c"
		}
#line 169 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		if (_tmp7_) {
#line 2559 "PiwigoPublishing.c"
			const gchar* _tmp10_ = NULL;
#line 169 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp10_ = persistent_password;
#line 169 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp6_ = _tmp10_ != NULL;
#line 2565 "PiwigoPublishing.c"
		} else {
#line 169 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp6_ = FALSE;
#line 2569 "PiwigoPublishing.c"
		}
#line 169 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		if (_tmp6_) {
#line 2573 "PiwigoPublishing.c"
			const gchar* _tmp11_ = NULL;
			const gchar* _tmp12_ = NULL;
			const gchar* _tmp13_ = NULL;
			gboolean _tmp14_ = FALSE;
#line 170 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp11_ = persistent_url;
#line 170 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp12_ = persistent_username;
#line 170 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp13_ = persistent_password;
#line 170 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp14_ = publishing_piwigo_piwigo_publisher_get_remember_password (self);
#line 170 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			publishing_piwigo_piwigo_publisher_do_network_login (self, _tmp11_, _tmp12_, _tmp13_, _tmp14_);
#line 2588 "PiwigoPublishing.c"
		} else {
#line 173 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			publishing_piwigo_piwigo_publisher_do_show_authentication_pane (self, PUBLISHING_PIWIGO_AUTHENTICATION_PANE_MODE_INTRO);
#line 2592 "PiwigoPublishing.c"
		}
#line 161 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_free0 (persistent_password);
#line 161 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_free0 (persistent_username);
#line 161 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_free0 (persistent_url);
#line 2600 "PiwigoPublishing.c"
	}
}


static void publishing_piwigo_piwigo_publisher_real_stop (SpitPublishingPublisher* base) {
	PublishingPiwigoPiwigoPublisher * self;
#line 177 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_PIWIGO_TYPE_PIWIGO_PUBLISHER, PublishingPiwigoPiwigoPublisher);
#line 178 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->running = FALSE;
#line 2611 "PiwigoPublishing.c"
}


gchar* publishing_piwigo_piwigo_publisher_get_persistent_url (PublishingPiwigoPiwigoPublisher* self) {
	gchar* result = NULL;
	SpitPublishingPluginHost* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 183 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self), NULL);
#line 184 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->host;
#line 184 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = spit_host_interface_get_config_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "url", NULL);
#line 184 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = _tmp1_;
#line 184 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 2629 "PiwigoPublishing.c"
}


static void publishing_piwigo_piwigo_publisher_set_persistent_url (PublishingPiwigoPiwigoPublisher* self, const gchar* url) {
	SpitPublishingPluginHost* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
#line 187 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self));
#line 187 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (url != NULL);
#line 188 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->host;
#line 188 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = url;
#line 188 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	spit_host_interface_set_config_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "url", _tmp1_);
#line 2646 "PiwigoPublishing.c"
}


gchar* publishing_piwigo_piwigo_publisher_get_persistent_username (PublishingPiwigoPiwigoPublisher* self) {
	gchar* result = NULL;
	SpitPublishingPluginHost* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 191 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self), NULL);
#line 192 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->host;
#line 192 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = spit_host_interface_get_config_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "username", NULL);
#line 192 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = _tmp1_;
#line 192 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 2664 "PiwigoPublishing.c"
}


static void publishing_piwigo_piwigo_publisher_set_persistent_username (PublishingPiwigoPiwigoPublisher* self, const gchar* username) {
	SpitPublishingPluginHost* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
#line 195 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self));
#line 195 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (username != NULL);
#line 196 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->host;
#line 196 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = username;
#line 196 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	spit_host_interface_set_config_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "username", _tmp1_);
#line 2681 "PiwigoPublishing.c"
}


gchar* publishing_piwigo_piwigo_publisher_get_persistent_password (PublishingPiwigoPiwigoPublisher* self) {
	gchar* result = NULL;
	SpitPublishingPluginHost* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 199 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self), NULL);
#line 200 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->host;
#line 200 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = spit_host_interface_get_config_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "password", NULL);
#line 200 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = _tmp1_;
#line 200 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 2699 "PiwigoPublishing.c"
}


static void publishing_piwigo_piwigo_publisher_set_persistent_password (PublishingPiwigoPiwigoPublisher* self, const gchar* password) {
	SpitPublishingPluginHost* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
#line 203 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self));
#line 204 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->host;
#line 204 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = password;
#line 204 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	spit_host_interface_set_config_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "password", _tmp1_);
#line 2714 "PiwigoPublishing.c"
}


gboolean publishing_piwigo_piwigo_publisher_get_remember_password (PublishingPiwigoPiwigoPublisher* self) {
	gboolean result = FALSE;
	SpitPublishingPluginHost* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
#line 207 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self), FALSE);
#line 208 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->host;
#line 208 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = spit_host_interface_get_config_bool (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "remember-password", FALSE);
#line 208 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = _tmp1_;
#line 208 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 2732 "PiwigoPublishing.c"
}


static void publishing_piwigo_piwigo_publisher_set_remember_password (PublishingPiwigoPiwigoPublisher* self, gboolean remember_password) {
	SpitPublishingPluginHost* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
#line 211 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self));
#line 212 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->host;
#line 212 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = remember_password;
#line 212 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	spit_host_interface_set_config_bool (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "remember-password", _tmp1_);
#line 2747 "PiwigoPublishing.c"
}


gint publishing_piwigo_piwigo_publisher_get_last_category (PublishingPiwigoPiwigoPublisher* self) {
	gint result = 0;
	SpitPublishingPluginHost* _tmp0_ = NULL;
	gint _tmp1_ = 0;
#line 215 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self), 0);
#line 216 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->host;
#line 216 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = spit_host_interface_get_config_int (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "last-category", -1);
#line 216 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = _tmp1_;
#line 216 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 2765 "PiwigoPublishing.c"
}


static void publishing_piwigo_piwigo_publisher_set_last_category (PublishingPiwigoPiwigoPublisher* self, gint last_category) {
	SpitPublishingPluginHost* _tmp0_ = NULL;
	gint _tmp1_ = 0;
#line 219 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self));
#line 220 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->host;
#line 220 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = last_category;
#line 220 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	spit_host_interface_set_config_int (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "last-category", _tmp1_);
#line 2780 "PiwigoPublishing.c"
}


gint publishing_piwigo_piwigo_publisher_get_last_permission_level (PublishingPiwigoPiwigoPublisher* self) {
	gint result = 0;
	SpitPublishingPluginHost* _tmp0_ = NULL;
	gint _tmp1_ = 0;
#line 223 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self), 0);
#line 224 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->host;
#line 224 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = spit_host_interface_get_config_int (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "last-permission-level", -1);
#line 224 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = _tmp1_;
#line 224 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 2798 "PiwigoPublishing.c"
}


static void publishing_piwigo_piwigo_publisher_set_last_permission_level (PublishingPiwigoPiwigoPublisher* self, gint last_permission_level) {
	SpitPublishingPluginHost* _tmp0_ = NULL;
	gint _tmp1_ = 0;
#line 227 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self));
#line 228 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->host;
#line 228 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = last_permission_level;
#line 228 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	spit_host_interface_set_config_int (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "last-permission-level", _tmp1_);
#line 2813 "PiwigoPublishing.c"
}


gint publishing_piwigo_piwigo_publisher_get_last_photo_size (PublishingPiwigoPiwigoPublisher* self) {
	gint result = 0;
	SpitPublishingPluginHost* _tmp0_ = NULL;
	gint _tmp1_ = 0;
#line 231 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self), 0);
#line 232 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->host;
#line 232 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = spit_host_interface_get_config_int (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "last-photo-size", -1);
#line 232 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = _tmp1_;
#line 232 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 2831 "PiwigoPublishing.c"
}


static void publishing_piwigo_piwigo_publisher_set_last_photo_size (PublishingPiwigoPiwigoPublisher* self, gint last_photo_size) {
	SpitPublishingPluginHost* _tmp0_ = NULL;
	gint _tmp1_ = 0;
#line 235 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self));
#line 236 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->host;
#line 236 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = last_photo_size;
#line 236 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	spit_host_interface_set_config_int (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "last-photo-size", _tmp1_);
#line 2846 "PiwigoPublishing.c"
}


static gboolean publishing_piwigo_piwigo_publisher_get_last_title_as_comment (PublishingPiwigoPiwigoPublisher* self) {
	gboolean result = FALSE;
	SpitPublishingPluginHost* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
#line 239 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self), FALSE);
#line 240 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->host;
#line 240 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = spit_host_interface_get_config_bool (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "last-title-as-comment", FALSE);
#line 240 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = _tmp1_;
#line 240 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 2864 "PiwigoPublishing.c"
}


static void publishing_piwigo_piwigo_publisher_set_last_title_as_comment (PublishingPiwigoPiwigoPublisher* self, gboolean title_as_comment) {
	SpitPublishingPluginHost* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
#line 243 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self));
#line 244 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->host;
#line 244 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = title_as_comment;
#line 244 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	spit_host_interface_set_config_bool (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "last-title-as-comment", _tmp1_);
#line 2879 "PiwigoPublishing.c"
}


static gboolean publishing_piwigo_piwigo_publisher_get_last_no_upload_tags (PublishingPiwigoPiwigoPublisher* self) {
	gboolean result = FALSE;
	SpitPublishingPluginHost* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
#line 247 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self), FALSE);
#line 248 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->host;
#line 248 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = spit_host_interface_get_config_bool (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "last-no-upload-tags", FALSE);
#line 248 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = _tmp1_;
#line 248 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 2897 "PiwigoPublishing.c"
}


static void publishing_piwigo_piwigo_publisher_set_last_no_upload_tags (PublishingPiwigoPiwigoPublisher* self, gboolean no_upload_tags) {
	SpitPublishingPluginHost* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
#line 251 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self));
#line 252 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->host;
#line 252 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = no_upload_tags;
#line 252 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	spit_host_interface_set_config_bool (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "last-no-upload-tags", _tmp1_);
#line 2912 "PiwigoPublishing.c"
}


static gboolean publishing_piwigo_piwigo_publisher_get_metadata_removal_choice (PublishingPiwigoPiwigoPublisher* self) {
	gboolean result = FALSE;
	SpitPublishingPluginHost* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
#line 255 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self), FALSE);
#line 256 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->host;
#line 256 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = spit_host_interface_get_config_bool (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "strip_metadata", FALSE);
#line 256 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = _tmp1_;
#line 256 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 2930 "PiwigoPublishing.c"
}


static void publishing_piwigo_piwigo_publisher_set_metadata_removal_choice (PublishingPiwigoPiwigoPublisher* self, gboolean strip_metadata) {
	SpitPublishingPluginHost* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
#line 259 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self));
#line 260 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->host;
#line 260 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = strip_metadata;
#line 260 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	spit_host_interface_set_config_bool (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "strip_metadata", _tmp1_);
#line 2945 "PiwigoPublishing.c"
}


/**
     * Action that shows the authentication pane.
     *
     * This action method shows the authentication pane. It is shown at the
     * very beginning of the interaction when no persistent parameters are found
     * or after a failed login attempt using persisted parameters. It can be
     * given a mode flag to specify whether it should be displayed in initial
     * mode or in any of the error modes that it supports.
     *
     * @param mode the mode for the authentication pane
     */
static void _publishing_piwigo_piwigo_publisher_on_authentication_pane_login_clicked_publishing_piwigo_authentication_pane_login (PublishingPiwigoAuthenticationPane* _sender, const gchar* url, const gchar* user, const gchar* password, gboolean remember_password, gpointer self) {
#line 282 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_piwigo_publisher_on_authentication_pane_login_clicked ((PublishingPiwigoPiwigoPublisher*) self, url, user, password, remember_password);
#line 2963 "PiwigoPublishing.c"
}


static void publishing_piwigo_piwigo_publisher_do_show_authentication_pane (PublishingPiwigoPiwigoPublisher* self, PublishingPiwigoAuthenticationPaneMode mode) {
	SpitPublishingPluginHost* _tmp0_ = NULL;
	PublishingPiwigoAuthenticationPane* authentication_pane = NULL;
	PublishingPiwigoAuthenticationPaneMode _tmp1_ = 0;
	PublishingPiwigoAuthenticationPane* _tmp2_ = NULL;
	SpitPublishingPluginHost* _tmp3_ = NULL;
	SpitPublishingPluginHost* _tmp4_ = NULL;
	GtkWidget* _tmp5_ = NULL;
	GtkWidget* _tmp6_ = NULL;
#line 276 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self));
#line 277 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_debug ("PiwigoPublishing.vala:277: ACTION: installing authentication pane");
#line 279 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->host;
#line 279 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	spit_publishing_plugin_host_set_service_locked (_tmp0_, FALSE);
#line 280 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = mode;
#line 280 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = publishing_piwigo_authentication_pane_new (self, _tmp1_);
#line 280 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	authentication_pane = _tmp2_;
#line 282 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_connect_object (authentication_pane, "login", (GCallback) _publishing_piwigo_piwigo_publisher_on_authentication_pane_login_clicked_publishing_piwigo_authentication_pane_login, self, 0);
#line 283 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3_ = self->priv->host;
#line 283 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	spit_publishing_plugin_host_install_dialog_pane (_tmp3_, G_TYPE_CHECK_INSTANCE_CAST (authentication_pane, SPIT_PUBLISHING_TYPE_DIALOG_PANE, SpitPublishingDialogPane), SPIT_PUBLISHING_PLUGIN_HOST_BUTTON_MODE_CLOSE);
#line 284 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = self->priv->host;
#line 284 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp5_ = publishing_piwigo_authentication_pane_get_default_widget (authentication_pane);
#line 284 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp6_ = _tmp5_;
#line 284 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	spit_publishing_plugin_host_set_dialog_default_widget (_tmp4_, _tmp6_);
#line 284 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (_tmp6_);
#line 276 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (authentication_pane);
#line 3008 "PiwigoPublishing.c"
}


/**
     * Event triggered when the login button in the authentication panel is
     * clicked.
     *
     * This event is triggered when the login button in the authentication
     * panel is clicked. It then triggers a network login interaction.
     *
     * @param url the URL of the Piwigo service as entered in the dialog
     * @param username the name of the Piwigo user as entered in the dialog
     * @param password the password of the Piwigo as entered in the dialog
     */
static void publishing_piwigo_piwigo_publisher_on_authentication_pane_login_clicked (PublishingPiwigoPiwigoPublisher* self, const gchar* url, const gchar* username, const gchar* password, gboolean remember_password) {
	gboolean _tmp0_ = FALSE;
	const gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	gboolean _tmp4_ = FALSE;
#line 298 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self));
#line 298 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (url != NULL);
#line 298 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (username != NULL);
#line 298 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (password != NULL);
#line 301 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_debug ("PiwigoPublishing.vala:301: EVENT: on_authentication_pane_login_clicked");
#line 302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->running;
#line 302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (!_tmp0_) {
#line 303 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		return;
#line 3045 "PiwigoPublishing.c"
	}
#line 305 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = url;
#line 305 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = username;
#line 305 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3_ = password;
#line 305 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = remember_password;
#line 305 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_piwigo_publisher_do_network_login (self, _tmp1_, _tmp2_, _tmp3_, _tmp4_);
#line 3057 "PiwigoPublishing.c"
}


/**
     * Action to perform a network login to a Piwigo service.
     *
     * This action performs a network login a Piwigo service specified by a
     * URL and using the given user name and password as credentials.
     *
     * @param url the URL of the Piwigo service; this URL will be normalised
     *     before being used
     * @param username the name of the Piwigo user used to login
     * @param password the password of the Piwigo user used to login
     */
static void _publishing_piwigo_piwigo_publisher_on_login_network_error_publishing_rest_support_transaction_network_error (PublishingRESTSupportTransaction* _sender, GError* err, gpointer self) {
#line 332 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_piwigo_publisher_on_login_network_error ((PublishingPiwigoPiwigoPublisher*) self, _sender, err);
#line 3075 "PiwigoPublishing.c"
}


static void _publishing_piwigo_piwigo_publisher_on_login_network_complete_publishing_rest_support_transaction_completed (PublishingRESTSupportTransaction* _sender, gpointer self) {
#line 333 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_piwigo_publisher_on_login_network_complete ((PublishingPiwigoPiwigoPublisher*) self, _sender);
#line 3082 "PiwigoPublishing.c"
}


static void publishing_piwigo_piwigo_publisher_do_network_login (PublishingPiwigoPiwigoPublisher* self, const gchar* url, const gchar* username, const gchar* password, gboolean remember_password) {
	SpitPublishingPluginHost* _tmp0_ = NULL;
	SpitPublishingPluginHost* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	gboolean _tmp3_ = FALSE;
	PublishingPiwigoSessionLoginTransaction* login_trans = NULL;
	PublishingPiwigoSession* _tmp5_ = NULL;
	const gchar* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
	gchar* _tmp8_ = NULL;
	const gchar* _tmp9_ = NULL;
	const gchar* _tmp10_ = NULL;
	PublishingPiwigoSessionLoginTransaction* _tmp11_ = NULL;
	PublishingPiwigoSessionLoginTransaction* _tmp12_ = NULL;
	GError * _inner_error_ = NULL;
#line 319 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self));
#line 319 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (url != NULL);
#line 319 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (username != NULL);
#line 319 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (password != NULL);
#line 320 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_debug ("PiwigoPublishing.vala:320: ACTION: logging in");
#line 321 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->host;
#line 321 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	spit_publishing_plugin_host_set_service_locked (_tmp0_, TRUE);
#line 322 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = self->priv->host;
#line 322 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	spit_publishing_plugin_host_install_login_wait_pane (_tmp1_);
#line 324 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = remember_password;
#line 324 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_piwigo_publisher_set_remember_password (self, _tmp2_);
#line 325 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3_ = remember_password;
#line 325 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (_tmp3_) {
#line 3127 "PiwigoPublishing.c"
		const gchar* _tmp4_ = NULL;
#line 326 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp4_ = password;
#line 326 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_piwigo_piwigo_publisher_set_persistent_password (self, _tmp4_);
#line 3133 "PiwigoPublishing.c"
	} else {
#line 328 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_piwigo_piwigo_publisher_set_persistent_password (self, NULL);
#line 3137 "PiwigoPublishing.c"
	}
#line 330 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp5_ = self->priv->session;
#line 330 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp6_ = url;
#line 330 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp7_ = publishing_piwigo_piwigo_publisher_normalise_url (_tmp6_);
#line 330 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp8_ = _tmp7_;
#line 330 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp9_ = username;
#line 330 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp10_ = password;
#line 330 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp11_ = publishing_piwigo_session_login_transaction_new (_tmp5_, _tmp8_, _tmp9_, _tmp10_);
#line 330 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp12_ = _tmp11_;
#line 330 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (_tmp8_);
#line 330 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	login_trans = _tmp12_;
#line 332 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (login_trans, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "network-error", (GCallback) _publishing_piwigo_piwigo_publisher_on_login_network_error_publishing_rest_support_transaction_network_error, self, 0);
#line 333 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (login_trans, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "completed", (GCallback) _publishing_piwigo_piwigo_publisher_on_login_network_complete_publishing_rest_support_transaction_completed, self, 0);
#line 3163 "PiwigoPublishing.c"
	{
#line 336 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_rest_support_transaction_execute (G_TYPE_CHECK_INSTANCE_CAST (login_trans, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), &_inner_error_);
#line 336 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 336 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 3171 "PiwigoPublishing.c"
				goto __catch32_spit_publishing_publishing_error;
			}
#line 336 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_publishing_rest_support_transaction_unref0 (login_trans);
#line 336 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 336 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			g_clear_error (&_inner_error_);
#line 336 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			return;
#line 3182 "PiwigoPublishing.c"
		}
	}
	goto __finally32;
	__catch32_spit_publishing_publishing_error:
	{
		GError* err = NULL;
		GError* _tmp13_ = NULL;
#line 335 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		err = _inner_error_;
#line 335 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_inner_error_ = NULL;
#line 338 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_debug ("PiwigoPublishing.vala:338: ERROR: do_network_login");
#line 339 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp13_ = err;
#line 339 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_piwigo_piwigo_publisher_do_show_error (self, _tmp13_);
#line 335 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_error_free0 (err);
#line 3202 "PiwigoPublishing.c"
	}
	__finally32:
#line 335 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 335 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_publishing_rest_support_transaction_unref0 (login_trans);
#line 335 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 335 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_clear_error (&_inner_error_);
#line 335 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		return;
#line 3215 "PiwigoPublishing.c"
	}
#line 319 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_publishing_rest_support_transaction_unref0 (login_trans);
#line 3219 "PiwigoPublishing.c"
}


gchar* publishing_piwigo_piwigo_publisher_normalise_url (const gchar* url) {
	gchar* result = NULL;
	gchar* norm_url = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	gboolean _tmp3_ = FALSE;
	gboolean _tmp10_ = FALSE;
	const gchar* _tmp11_ = NULL;
	gboolean _tmp12_ = FALSE;
#line 343 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (url != NULL, NULL);
#line 344 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = url;
#line 344 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 344 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	norm_url = _tmp1_;
#line 346 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = norm_url;
#line 346 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3_ = g_str_has_suffix (_tmp2_, ".php");
#line 346 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (!_tmp3_) {
#line 3247 "PiwigoPublishing.c"
		const gchar* _tmp4_ = NULL;
		gboolean _tmp5_ = FALSE;
		const gchar* _tmp8_ = NULL;
		gchar* _tmp9_ = NULL;
#line 347 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp4_ = norm_url;
#line 347 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp5_ = g_str_has_suffix (_tmp4_, "/");
#line 347 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		if (!_tmp5_) {
#line 3258 "PiwigoPublishing.c"
			const gchar* _tmp6_ = NULL;
			gchar* _tmp7_ = NULL;
#line 348 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp6_ = norm_url;
#line 348 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp7_ = g_strconcat (_tmp6_, "/", NULL);
#line 348 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_g_free0 (norm_url);
#line 348 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			norm_url = _tmp7_;
#line 3269 "PiwigoPublishing.c"
		}
#line 350 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp8_ = norm_url;
#line 350 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp9_ = g_strconcat (_tmp8_, PUBLISHING_PIWIGO_PIWIGO_WS, NULL);
#line 350 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_free0 (norm_url);
#line 350 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		norm_url = _tmp9_;
#line 3279 "PiwigoPublishing.c"
	}
#line 353 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp11_ = norm_url;
#line 353 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp12_ = g_str_has_prefix (_tmp11_, "http://");
#line 353 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (!_tmp12_) {
#line 3287 "PiwigoPublishing.c"
		const gchar* _tmp13_ = NULL;
		gboolean _tmp14_ = FALSE;
#line 353 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp13_ = norm_url;
#line 353 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp14_ = g_str_has_prefix (_tmp13_, "https://");
#line 353 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp10_ = !_tmp14_;
#line 3296 "PiwigoPublishing.c"
	} else {
#line 353 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp10_ = FALSE;
#line 3300 "PiwigoPublishing.c"
	}
#line 353 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (_tmp10_) {
#line 3304 "PiwigoPublishing.c"
		const gchar* _tmp15_ = NULL;
		gchar* _tmp16_ = NULL;
#line 354 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp15_ = norm_url;
#line 354 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp16_ = g_strconcat ("http://", _tmp15_, NULL);
#line 354 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_free0 (norm_url);
#line 354 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		norm_url = _tmp16_;
#line 3315 "PiwigoPublishing.c"
	}
#line 357 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = norm_url;
#line 357 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 3321 "PiwigoPublishing.c"
}


/**
     * Event triggered when the network login action is complete and successful.
     *
     * This event is triggered on successful completion of a network login.
     * Calling this event implies that the URL, user name and password provided
     * in the authentication pane are valid and that the transaction should
     * contain a Set-Cookie header that includes the value pwg_id for that
     * user. As a result, this event will also authenticate the session and
     * persist all values so that they can be re-used during the next publishing
     * interaction.
     *
     * @param txn the received REST transaction
     */
static gchar* _publishing_piwigo_transaction_validate_xml_publishing_rest_support_xml_document_check_for_error_response (PublishingRESTSupportXmlDocument* doc, gpointer self) {
	gchar* result;
	result = publishing_piwigo_transaction_validate_xml (doc);
#line 379 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 3343 "PiwigoPublishing.c"
}


static gchar* _publishing_piwigo_transaction_get_error_code_publishing_rest_support_xml_document_check_for_error_response (PublishingRESTSupportXmlDocument* doc, gpointer self) {
	gchar* result;
	result = publishing_piwigo_transaction_get_error_code (doc);
#line 384 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 3352 "PiwigoPublishing.c"
}


static void publishing_piwigo_piwigo_publisher_on_login_network_complete (PublishingPiwigoPiwigoPublisher* self, PublishingRESTSupportTransaction* txn) {
	PublishingRESTSupportTransaction* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
	PublishingRESTSupportTransaction* _tmp2_ = NULL;
	guint _tmp3_ = 0U;
	gchar* endpoint_url = NULL;
	PublishingRESTSupportTransaction* _tmp19_ = NULL;
	gchar* _tmp20_ = NULL;
	const gchar* _tmp21_ = NULL;
	gchar* pwg_id = NULL;
	PublishingRESTSupportTransaction* _tmp22_ = NULL;
	gchar* _tmp23_ = NULL;
	const gchar* _tmp24_ = NULL;
	PublishingPiwigoSession* _tmp25_ = NULL;
	PublishingPiwigoSession* _tmp26_ = NULL;
	const gchar* _tmp27_ = NULL;
	const gchar* _tmp28_ = NULL;
	const gchar* _tmp29_ = NULL;
	GError * _inner_error_ = NULL;
#line 373 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self));
#line 373 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_TRANSACTION (txn));
#line 374 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_debug ("PiwigoPublishing.vala:374: EVENT: on_login_network_complete");
#line 375 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = txn;
#line 375 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_parse_name ("completed", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp1_, NULL, FALSE);
#line 375 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_piwigo_piwigo_publisher_on_login_network_complete_publishing_rest_support_transaction_completed, self);
#line 376 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = txn;
#line 376 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_parse_name ("network-error", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp3_, NULL, FALSE);
#line 376 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp2_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _publishing_piwigo_piwigo_publisher_on_login_network_error_publishing_rest_support_transaction_network_error, self);
#line 3393 "PiwigoPublishing.c"
	{
		PublishingRESTSupportTransaction* _tmp4_ = NULL;
		gchar* _tmp5_ = NULL;
		gchar* _tmp6_ = NULL;
		PublishingRESTSupportXmlDocument* _tmp7_ = NULL;
		PublishingRESTSupportXmlDocument* _tmp8_ = NULL;
#line 379 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp4_ = txn;
#line 379 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp5_ = publishing_rest_support_transaction_get_response (_tmp4_);
#line 379 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp6_ = _tmp5_;
#line 379 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp7_ = publishing_rest_support_xml_document_parse_string (_tmp6_, _publishing_piwigo_transaction_validate_xml_publishing_rest_support_xml_document_check_for_error_response, NULL, &_inner_error_);
#line 379 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp8_ = _tmp7_;
#line 379 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_publishing_rest_support_xml_document_unref0 (_tmp8_);
#line 379 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_free0 (_tmp6_);
#line 379 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 379 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 3418 "PiwigoPublishing.c"
				goto __catch33_spit_publishing_publishing_error;
			}
#line 379 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 379 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			g_clear_error (&_inner_error_);
#line 379 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			return;
#line 3427 "PiwigoPublishing.c"
		}
	}
	goto __finally33;
	__catch33_spit_publishing_publishing_error:
	{
		GError* err = NULL;
#line 378 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		err = _inner_error_;
#line 378 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_inner_error_ = NULL;
#line 3438 "PiwigoPublishing.c"
		{
			PublishingRESTSupportTransaction* _tmp9_ = NULL;
			gchar* _tmp10_ = NULL;
			gchar* _tmp11_ = NULL;
			PublishingRESTSupportXmlDocument* _tmp12_ = NULL;
			PublishingRESTSupportXmlDocument* _tmp13_ = NULL;
#line 384 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp9_ = txn;
#line 384 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp10_ = publishing_rest_support_transaction_get_response (_tmp9_);
#line 384 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp11_ = _tmp10_;
#line 384 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp12_ = publishing_rest_support_xml_document_parse_string (_tmp11_, _publishing_piwigo_transaction_get_error_code_publishing_rest_support_xml_document_check_for_error_response, NULL, &_inner_error_);
#line 384 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp13_ = _tmp12_;
#line 384 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_publishing_rest_support_xml_document_unref0 (_tmp13_);
#line 384 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_g_free0 (_tmp11_);
#line 384 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 384 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 3463 "PiwigoPublishing.c"
					goto __catch34_spit_publishing_publishing_error;
				}
#line 384 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_g_error_free0 (err);
#line 384 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 384 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				g_clear_error (&_inner_error_);
#line 384 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				return;
#line 3474 "PiwigoPublishing.c"
			}
		}
		goto __finally34;
		__catch34_spit_publishing_publishing_error:
		{
			GError* code = NULL;
			gint code_int = 0;
			GError* _tmp14_ = NULL;
			const gchar* _tmp15_ = NULL;
			gint _tmp16_ = 0;
			gint _tmp17_ = 0;
#line 383 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			code = _inner_error_;
#line 383 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_inner_error_ = NULL;
#line 387 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp14_ = code;
#line 387 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp15_ = _tmp14_->message;
#line 387 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp16_ = atoi (_tmp15_);
#line 387 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			code_int = _tmp16_;
#line 388 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp17_ = code_int;
#line 388 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			if (_tmp17_ == 999) {
#line 389 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				g_debug ("PiwigoPublishing.vala:389: ERROR: on_login_network_complete, code 999");
#line 390 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				publishing_piwigo_piwigo_publisher_do_show_authentication_pane (self, PUBLISHING_PIWIGO_AUTHENTICATION_PANE_MODE_FAILED_RETRY_USER);
#line 3506 "PiwigoPublishing.c"
			} else {
				GError* _tmp18_ = NULL;
#line 392 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				g_debug ("PiwigoPublishing.vala:392: ERROR: on_login_network_complete");
#line 393 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp18_ = err;
#line 393 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				publishing_piwigo_piwigo_publisher_do_show_error (self, _tmp18_);
#line 3515 "PiwigoPublishing.c"
			}
#line 383 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_g_error_free0 (code);
#line 3519 "PiwigoPublishing.c"
		}
		__finally34:
#line 383 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 383 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_g_error_free0 (err);
#line 383 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_g_error_free0 (err);
#line 383 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 383 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			g_clear_error (&_inner_error_);
#line 383 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			return;
#line 3534 "PiwigoPublishing.c"
		}
#line 396 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_error_free0 (err);
#line 396 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		return;
#line 3540 "PiwigoPublishing.c"
	}
	__finally33:
#line 378 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 378 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 378 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_clear_error (&_inner_error_);
#line 378 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		return;
#line 3551 "PiwigoPublishing.c"
	}
#line 399 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp19_ = txn;
#line 399 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp20_ = publishing_rest_support_transaction_get_endpoint_url (_tmp19_);
#line 399 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	endpoint_url = _tmp20_;
#line 400 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp21_ = endpoint_url;
#line 400 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_debug ("PiwigoPublishing.vala:400: Setting endpoint URL to %s", _tmp21_);
#line 401 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp22_ = txn;
#line 401 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp23_ = publishing_piwigo_piwigo_publisher_get_pwg_id_from_transaction (self, _tmp22_);
#line 401 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	pwg_id = _tmp23_;
#line 402 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp24_ = pwg_id;
#line 402 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_debug ("PiwigoPublishing.vala:402: Setting session pwg_id to %s", _tmp24_);
#line 403 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp25_ = publishing_piwigo_session_new ();
#line 403 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_publishing_rest_support_session_unref0 (self->priv->session);
#line 403 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->session = _tmp25_;
#line 404 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp26_ = self->priv->session;
#line 404 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp27_ = pwg_id;
#line 404 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_session_set_pwg_id (_tmp26_, _tmp27_);
#line 406 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp28_ = endpoint_url;
#line 406 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp29_ = pwg_id;
#line 406 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_piwigo_publisher_do_fetch_session_status (self, _tmp28_, _tmp29_);
#line 373 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (pwg_id);
#line 373 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (endpoint_url);
#line 3595 "PiwigoPublishing.c"
}


/**
     * Event triggered when a network login action fails due to a network error.
     *
     * This event triggered as a result of a network error during the login
     * transaction. As a result, it assumes that the service URL entered in the
     * authentication dialog is incorrect and re-presents the authentication
     * dialog with FAILED_RETRY_URL mode.
     *
     * @param bad_txn the received REST transaction
     * @param err the received error
     */
static void publishing_piwigo_piwigo_publisher_on_login_network_error (PublishingPiwigoPiwigoPublisher* self, PublishingRESTSupportTransaction* bad_txn, GError* err) {
	PublishingRESTSupportTransaction* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
	PublishingRESTSupportTransaction* _tmp2_ = NULL;
	guint _tmp3_ = 0U;
	PublishingPiwigoSession* _tmp4_ = NULL;
	gboolean _tmp5_ = FALSE;
#line 420 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self));
#line 420 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_TRANSACTION (bad_txn));
#line 424 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_debug ("PiwigoPublishing.vala:424: EVENT: on_login_network_error");
#line 425 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = bad_txn;
#line 425 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_parse_name ("completed", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp1_, NULL, FALSE);
#line 425 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_piwigo_piwigo_publisher_on_login_network_complete_publishing_rest_support_transaction_completed, self);
#line 426 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = bad_txn;
#line 426 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_parse_name ("network-error", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp3_, NULL, FALSE);
#line 426 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp2_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _publishing_piwigo_piwigo_publisher_on_login_network_error_publishing_rest_support_transaction_network_error, self);
#line 428 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = self->priv->session;
#line 428 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp5_ = publishing_rest_support_session_is_authenticated (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession));
#line 428 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (_tmp5_) {
#line 429 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		return;
#line 3643 "PiwigoPublishing.c"
	}
#line 431 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_piwigo_publisher_do_show_authentication_pane (self, PUBLISHING_PIWIGO_AUTHENTICATION_PANE_MODE_FAILED_RETRY_URL);
#line 3647 "PiwigoPublishing.c"
}


/**
     * Action to fetch the session status for a known Piwigo user.
     *
     * This action fetches the session status for a Piwigo user for whom the
     * pwg_id is known. If triggered after a network login, it should just
     * confirm that the session is OK. It can also be triggered as the first
     * action of the interaction for users for who the pwg_id was previously
     * persisted. In this case, it will log the user in and confirm the
     * identity.
     */
static void _publishing_piwigo_piwigo_publisher_on_session_get_status_error_publishing_rest_support_transaction_network_error (PublishingRESTSupportTransaction* _sender, GError* err, gpointer self) {
#line 451 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_piwigo_publisher_on_session_get_status_error ((PublishingPiwigoPiwigoPublisher*) self, _sender, err);
#line 3664 "PiwigoPublishing.c"
}


static void _publishing_piwigo_piwigo_publisher_on_session_get_status_complete_publishing_rest_support_transaction_completed (PublishingRESTSupportTransaction* _sender, gpointer self) {
#line 452 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_piwigo_publisher_on_session_get_status_complete ((PublishingPiwigoPiwigoPublisher*) self, _sender);
#line 3671 "PiwigoPublishing.c"
}


static void publishing_piwigo_piwigo_publisher_do_fetch_session_status (PublishingPiwigoPiwigoPublisher* self, const gchar* url, const gchar* pwg_id) {
	SpitPublishingPluginHost* _tmp0_ = NULL;
	SpitPublishingPluginHost* _tmp1_ = NULL;
	PublishingPiwigoSession* _tmp2_ = NULL;
	gboolean _tmp3_ = FALSE;
	GError * _inner_error_ = NULL;
#line 444 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self));
#line 444 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (url != NULL);
#line 444 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (pwg_id != NULL);
#line 445 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_debug ("PiwigoPublishing.vala:445: ACTION: fetching session status");
#line 446 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->host;
#line 446 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	spit_publishing_plugin_host_set_service_locked (_tmp0_, TRUE);
#line 447 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = self->priv->host;
#line 447 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	spit_publishing_plugin_host_install_account_fetch_wait_pane (_tmp1_);
#line 449 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = self->priv->session;
#line 449 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3_ = publishing_rest_support_session_is_authenticated (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession));
#line 449 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (!_tmp3_) {
#line 3703 "PiwigoPublishing.c"
		PublishingPiwigoSessionGetStatusTransaction* status_txn = NULL;
		PublishingPiwigoSession* _tmp4_ = NULL;
		const gchar* _tmp5_ = NULL;
		const gchar* _tmp6_ = NULL;
		PublishingPiwigoSessionGetStatusTransaction* _tmp7_ = NULL;
		PublishingPiwigoSessionGetStatusTransaction* _tmp8_ = NULL;
		PublishingPiwigoSessionGetStatusTransaction* _tmp9_ = NULL;
#line 450 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp4_ = self->priv->session;
#line 450 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp5_ = url;
#line 450 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp6_ = pwg_id;
#line 450 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp7_ = publishing_piwigo_session_get_status_transaction_new_unauthenticated (_tmp4_, _tmp5_, _tmp6_);
#line 450 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		status_txn = _tmp7_;
#line 451 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp8_ = status_txn;
#line 451 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "network-error", (GCallback) _publishing_piwigo_piwigo_publisher_on_session_get_status_error_publishing_rest_support_transaction_network_error, self, 0);
#line 452 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp9_ = status_txn;
#line 452 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "completed", (GCallback) _publishing_piwigo_piwigo_publisher_on_session_get_status_complete_publishing_rest_support_transaction_completed, self, 0);
#line 3729 "PiwigoPublishing.c"
		{
			PublishingPiwigoSessionGetStatusTransaction* _tmp10_ = NULL;
#line 455 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp10_ = status_txn;
#line 455 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			publishing_rest_support_transaction_execute (G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), &_inner_error_);
#line 455 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 455 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 3740 "PiwigoPublishing.c"
					goto __catch35_spit_publishing_publishing_error;
				}
#line 455 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_publishing_rest_support_transaction_unref0 (status_txn);
#line 455 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 455 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				g_clear_error (&_inner_error_);
#line 455 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				return;
#line 3751 "PiwigoPublishing.c"
			}
		}
		goto __finally35;
		__catch35_spit_publishing_publishing_error:
		{
			GError* err = NULL;
			GError* _tmp11_ = NULL;
#line 454 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			err = _inner_error_;
#line 454 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_inner_error_ = NULL;
#line 457 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			g_debug ("PiwigoPublishing.vala:457: ERROR: do_fetch_session_status, not authent" \
"icated");
#line 458 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp11_ = err;
#line 458 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			publishing_piwigo_piwigo_publisher_do_show_error (self, _tmp11_);
#line 454 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_g_error_free0 (err);
#line 3771 "PiwigoPublishing.c"
		}
		__finally35:
#line 454 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 454 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_publishing_rest_support_transaction_unref0 (status_txn);
#line 454 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 454 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			g_clear_error (&_inner_error_);
#line 454 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			return;
#line 3784 "PiwigoPublishing.c"
		}
#line 449 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_publishing_rest_support_transaction_unref0 (status_txn);
#line 3788 "PiwigoPublishing.c"
	} else {
		PublishingPiwigoSessionGetStatusTransaction* status_txn = NULL;
		PublishingPiwigoSession* _tmp12_ = NULL;
		PublishingPiwigoSessionGetStatusTransaction* _tmp13_ = NULL;
		PublishingPiwigoSessionGetStatusTransaction* _tmp14_ = NULL;
		PublishingPiwigoSessionGetStatusTransaction* _tmp15_ = NULL;
#line 461 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp12_ = self->priv->session;
#line 461 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp13_ = publishing_piwigo_session_get_status_transaction_new (_tmp12_);
#line 461 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		status_txn = _tmp13_;
#line 462 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp14_ = status_txn;
#line 462 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp14_, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "network-error", (GCallback) _publishing_piwigo_piwigo_publisher_on_session_get_status_error_publishing_rest_support_transaction_network_error, self, 0);
#line 463 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp15_ = status_txn;
#line 463 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp15_, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "completed", (GCallback) _publishing_piwigo_piwigo_publisher_on_session_get_status_complete_publishing_rest_support_transaction_completed, self, 0);
#line 3809 "PiwigoPublishing.c"
		{
			PublishingPiwigoSessionGetStatusTransaction* _tmp16_ = NULL;
#line 466 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp16_ = status_txn;
#line 466 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			publishing_rest_support_transaction_execute (G_TYPE_CHECK_INSTANCE_CAST (_tmp16_, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), &_inner_error_);
#line 466 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 466 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 3820 "PiwigoPublishing.c"
					goto __catch36_spit_publishing_publishing_error;
				}
#line 466 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_publishing_rest_support_transaction_unref0 (status_txn);
#line 466 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 466 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				g_clear_error (&_inner_error_);
#line 466 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				return;
#line 3831 "PiwigoPublishing.c"
			}
		}
		goto __finally36;
		__catch36_spit_publishing_publishing_error:
		{
			GError* err = NULL;
			GError* _tmp17_ = NULL;
#line 465 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			err = _inner_error_;
#line 465 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_inner_error_ = NULL;
#line 468 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			g_debug ("PiwigoPublishing.vala:468: ERROR: do_fetch_session_status, authenticat" \
"ed");
#line 469 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp17_ = err;
#line 469 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			publishing_piwigo_piwigo_publisher_do_show_error (self, _tmp17_);
#line 465 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_g_error_free0 (err);
#line 3851 "PiwigoPublishing.c"
		}
		__finally36:
#line 465 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 465 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_publishing_rest_support_transaction_unref0 (status_txn);
#line 465 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 465 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			g_clear_error (&_inner_error_);
#line 465 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			return;
#line 3864 "PiwigoPublishing.c"
		}
#line 449 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_publishing_rest_support_transaction_unref0 (status_txn);
#line 3868 "PiwigoPublishing.c"
	}
}


/**
     * Event triggered when the get session status action completes successfully.
     *
     * This event being triggered confirms that the session is valid and can becyclonic enema
     * used. If the session is not fully authenticated yet, this event finalises
     * session authentication. It then triggers the fetch categories action.
     */
static void publishing_piwigo_piwigo_publisher_on_session_get_status_complete (PublishingPiwigoPiwigoPublisher* self, PublishingRESTSupportTransaction* txn) {
	PublishingRESTSupportTransaction* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
	PublishingRESTSupportTransaction* _tmp2_ = NULL;
	guint _tmp3_ = 0U;
	PublishingPiwigoSession* _tmp4_ = NULL;
	gboolean _tmp5_ = FALSE;
	GError * _inner_error_ = NULL;
#line 481 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self));
#line 481 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_TRANSACTION (txn));
#line 482 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_debug ("PiwigoPublishing.vala:482: EVENT: on_session_get_status_complete");
#line 483 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = txn;
#line 483 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_parse_name ("completed", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp1_, NULL, FALSE);
#line 483 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_piwigo_piwigo_publisher_on_session_get_status_complete_publishing_rest_support_transaction_completed, self);
#line 484 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = txn;
#line 484 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_parse_name ("network-error", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp3_, NULL, FALSE);
#line 484 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp2_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _publishing_piwigo_piwigo_publisher_on_session_get_status_error_publishing_rest_support_transaction_network_error, self);
#line 486 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = self->priv->session;
#line 486 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp5_ = publishing_rest_support_session_is_authenticated (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession));
#line 486 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (!_tmp5_) {
#line 3912 "PiwigoPublishing.c"
		gchar* endpoint_url = NULL;
		PublishingRESTSupportTransaction* _tmp6_ = NULL;
		gchar* _tmp7_ = NULL;
		gchar* pwg_id = NULL;
		PublishingPiwigoSession* _tmp8_ = NULL;
		gchar* _tmp9_ = NULL;
		const gchar* _tmp10_ = NULL;
#line 487 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp6_ = txn;
#line 487 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp7_ = publishing_rest_support_transaction_get_endpoint_url (_tmp6_);
#line 487 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		endpoint_url = _tmp7_;
#line 488 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp8_ = self->priv->session;
#line 488 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp9_ = publishing_piwigo_session_get_pwg_id (_tmp8_);
#line 488 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		pwg_id = _tmp9_;
#line 489 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp10_ = pwg_id;
#line 489 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_debug ("PiwigoPublishing.vala:489: Fetching session status for pwg_id %s", _tmp10_);
#line 3936 "PiwigoPublishing.c"
		{
			PublishingRESTSupportXmlDocument* doc = NULL;
			PublishingRESTSupportTransaction* _tmp11_ = NULL;
			gchar* _tmp12_ = NULL;
			gchar* _tmp13_ = NULL;
			PublishingRESTSupportXmlDocument* _tmp14_ = NULL;
			PublishingRESTSupportXmlDocument* _tmp15_ = NULL;
			xmlNode* root = NULL;
			PublishingRESTSupportXmlDocument* _tmp16_ = NULL;
			xmlNode* _tmp17_ = NULL;
			xmlNode* username_node = NULL;
#line 492 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp11_ = txn;
#line 492 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp12_ = publishing_rest_support_transaction_get_response (_tmp11_);
#line 492 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp13_ = _tmp12_;
#line 492 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp14_ = publishing_rest_support_xml_document_parse_string (_tmp13_, _publishing_piwigo_transaction_validate_xml_publishing_rest_support_xml_document_check_for_error_response, NULL, &_inner_error_);
#line 492 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp15_ = _tmp14_;
#line 492 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_g_free0 (_tmp13_);
#line 492 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			doc = _tmp15_;
#line 492 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 492 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 3966 "PiwigoPublishing.c"
					goto __catch37_spit_publishing_publishing_error;
				}
#line 492 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_g_free0 (pwg_id);
#line 492 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_g_free0 (endpoint_url);
#line 492 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 492 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				g_clear_error (&_inner_error_);
#line 492 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				return;
#line 3979 "PiwigoPublishing.c"
			}
#line 495 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp16_ = doc;
#line 495 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp17_ = publishing_rest_support_xml_document_get_root_node (_tmp16_);
#line 495 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			root = _tmp17_;
#line 3987 "PiwigoPublishing.c"
			{
				xmlNode* _tmp18_ = NULL;
				PublishingRESTSupportXmlDocument* _tmp19_ = NULL;
				xmlNode* _tmp20_ = NULL;
				xmlNode* _tmp21_ = NULL;
				gchar* username = NULL;
				xmlNode* _tmp22_ = NULL;
				gchar* _tmp23_ = NULL;
				const gchar* _tmp24_ = NULL;
				PublishingPiwigoSession* _tmp25_ = NULL;
				const gchar* _tmp26_ = NULL;
				const gchar* _tmp27_ = NULL;
				const gchar* _tmp28_ = NULL;
				PublishingPiwigoSession* _tmp29_ = NULL;
				gchar* _tmp30_ = NULL;
				gchar* _tmp31_ = NULL;
				PublishingPiwigoSession* _tmp32_ = NULL;
				gchar* _tmp33_ = NULL;
				gchar* _tmp34_ = NULL;
#line 498 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp19_ = doc;
#line 498 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp20_ = root;
#line 498 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp21_ = publishing_rest_support_xml_document_get_named_child (_tmp19_, _tmp20_, "username", &_inner_error_);
#line 498 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp18_ = _tmp21_;
#line 498 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 498 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 4019 "PiwigoPublishing.c"
						goto __catch38_spit_publishing_publishing_error;
					}
#line 498 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_publishing_rest_support_xml_document_unref0 (doc);
#line 498 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_g_free0 (pwg_id);
#line 498 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_g_free0 (endpoint_url);
#line 498 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 498 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					g_clear_error (&_inner_error_);
#line 498 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					return;
#line 4034 "PiwigoPublishing.c"
				}
#line 498 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				username_node = _tmp18_;
#line 499 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp22_ = username_node;
#line 499 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp23_ = (gchar*) xmlNodeGetContent (_tmp22_);
#line 499 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				username = _tmp23_;
#line 500 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp24_ = username;
#line 500 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				g_debug ("PiwigoPublishing.vala:500: Returned username is %s", _tmp24_);
#line 501 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp25_ = self->priv->session;
#line 501 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp26_ = endpoint_url;
#line 501 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp27_ = username;
#line 501 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp28_ = pwg_id;
#line 501 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				publishing_piwigo_session_authenticate (_tmp25_, _tmp26_, _tmp27_, _tmp28_);
#line 502 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp29_ = self->priv->session;
#line 502 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp30_ = publishing_piwigo_session_get_pwg_url (_tmp29_);
#line 502 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp31_ = _tmp30_;
#line 502 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				publishing_piwigo_piwigo_publisher_set_persistent_url (self, _tmp31_);
#line 502 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_g_free0 (_tmp31_);
#line 503 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp32_ = self->priv->session;
#line 503 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp33_ = publishing_piwigo_session_get_username (_tmp32_);
#line 503 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp34_ = _tmp33_;
#line 503 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				publishing_piwigo_piwigo_publisher_set_persistent_username (self, _tmp34_);
#line 503 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_g_free0 (_tmp34_);
#line 504 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				publishing_piwigo_piwigo_publisher_do_fetch_categories (self);
#line 497 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_g_free0 (username);
#line 4082 "PiwigoPublishing.c"
			}
			goto __finally38;
			__catch38_spit_publishing_publishing_error:
			{
				GError* err2 = NULL;
				GError* _tmp35_ = NULL;
#line 497 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				err2 = _inner_error_;
#line 497 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_inner_error_ = NULL;
#line 506 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				g_debug ("PiwigoPublishing.vala:506: ERROR: on_session_get_status_complete, inne" \
"r");
#line 507 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp35_ = err2;
#line 507 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				publishing_piwigo_piwigo_publisher_do_show_error (self, _tmp35_);
#line 508 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_g_error_free0 (err2);
#line 508 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_publishing_rest_support_xml_document_unref0 (doc);
#line 508 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_g_free0 (pwg_id);
#line 508 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_g_free0 (endpoint_url);
#line 508 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				return;
#line 4109 "PiwigoPublishing.c"
			}
			__finally38:
#line 497 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 497 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_publishing_rest_support_xml_document_unref0 (doc);
#line 497 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 4118 "PiwigoPublishing.c"
					goto __catch37_spit_publishing_publishing_error;
				}
#line 497 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_publishing_rest_support_xml_document_unref0 (doc);
#line 497 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_g_free0 (pwg_id);
#line 497 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_g_free0 (endpoint_url);
#line 497 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 497 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				g_clear_error (&_inner_error_);
#line 497 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				return;
#line 4133 "PiwigoPublishing.c"
			}
#line 491 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_publishing_rest_support_xml_document_unref0 (doc);
#line 4137 "PiwigoPublishing.c"
		}
		goto __finally37;
		__catch37_spit_publishing_publishing_error:
		{
			GError* err = NULL;
			GError* _tmp36_ = NULL;
#line 491 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			err = _inner_error_;
#line 491 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_inner_error_ = NULL;
#line 511 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			g_debug ("PiwigoPublishing.vala:511: ERROR: on_session_get_status_complete, oute" \
"r");
#line 512 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp36_ = err;
#line 512 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			publishing_piwigo_piwigo_publisher_do_show_error (self, _tmp36_);
#line 513 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_g_error_free0 (err);
#line 513 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_g_free0 (pwg_id);
#line 513 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_g_free0 (endpoint_url);
#line 513 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			return;
#line 4162 "PiwigoPublishing.c"
		}
		__finally37:
#line 491 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 491 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_g_free0 (pwg_id);
#line 491 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_g_free0 (endpoint_url);
#line 491 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 491 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			g_clear_error (&_inner_error_);
#line 491 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			return;
#line 4177 "PiwigoPublishing.c"
		}
#line 486 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_free0 (pwg_id);
#line 486 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_free0 (endpoint_url);
#line 4183 "PiwigoPublishing.c"
	} else {
#line 519 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_piwigo_piwigo_publisher_do_fetch_categories (self);
#line 4187 "PiwigoPublishing.c"
	}
}


/**
     * Event triggered when the get session status fails due to a network error.
     */
static void publishing_piwigo_piwigo_publisher_on_session_get_status_error (PublishingPiwigoPiwigoPublisher* self, PublishingRESTSupportTransaction* bad_txn, GError* err) {
	PublishingRESTSupportTransaction* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
	PublishingRESTSupportTransaction* _tmp2_ = NULL;
	guint _tmp3_ = 0U;
	PublishingRESTSupportTransaction* _tmp4_ = NULL;
	GError* _tmp5_ = NULL;
#line 526 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self));
#line 526 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_TRANSACTION (bad_txn));
#line 530 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_debug ("PiwigoPublishing.vala:530: EVENT: on_session_get_status_error");
#line 531 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = bad_txn;
#line 531 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_parse_name ("completed", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp1_, NULL, FALSE);
#line 531 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_piwigo_piwigo_publisher_on_session_get_status_complete_publishing_rest_support_transaction_completed, self);
#line 532 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = bad_txn;
#line 532 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_parse_name ("network-error", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp3_, NULL, FALSE);
#line 532 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp2_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _publishing_piwigo_piwigo_publisher_on_session_get_status_error_publishing_rest_support_transaction_network_error, self);
#line 533 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = bad_txn;
#line 533 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp5_ = err;
#line 533 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_piwigo_publisher_on_network_error (self, _tmp4_, _tmp5_);
#line 4226 "PiwigoPublishing.c"
}


/**
     * Action that fetches all available categories from the Piwigo service.
     *
     * This action fetches all categories from the Piwigo service in order
     * to populate the publishing pane presented to the user.
     */
static void _publishing_piwigo_piwigo_publisher_on_category_fetch_error_publishing_rest_support_transaction_network_error (PublishingRESTSupportTransaction* _sender, GError* err, gpointer self) {
#line 548 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_piwigo_publisher_on_category_fetch_error ((PublishingPiwigoPiwigoPublisher*) self, _sender, err);
#line 4239 "PiwigoPublishing.c"
}


static void _publishing_piwigo_piwigo_publisher_on_category_fetch_complete_publishing_rest_support_transaction_completed (PublishingRESTSupportTransaction* _sender, gpointer self) {
#line 549 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_piwigo_publisher_on_category_fetch_complete ((PublishingPiwigoPiwigoPublisher*) self, _sender);
#line 4246 "PiwigoPublishing.c"
}


static void publishing_piwigo_piwigo_publisher_do_fetch_categories (PublishingPiwigoPiwigoPublisher* self) {
	SpitPublishingPluginHost* _tmp0_ = NULL;
	SpitPublishingPluginHost* _tmp1_ = NULL;
	PublishingPiwigoCategoriesGetListTransaction* cat_trans = NULL;
	PublishingPiwigoSession* _tmp2_ = NULL;
	PublishingPiwigoCategoriesGetListTransaction* _tmp3_ = NULL;
	GError * _inner_error_ = NULL;
#line 542 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self));
#line 543 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_debug ("PiwigoPublishing.vala:543: ACTION: fetching categories");
#line 544 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->host;
#line 544 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	spit_publishing_plugin_host_set_service_locked (_tmp0_, TRUE);
#line 545 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = self->priv->host;
#line 545 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	spit_publishing_plugin_host_install_account_fetch_wait_pane (_tmp1_);
#line 547 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = self->priv->session;
#line 547 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3_ = publishing_piwigo_categories_get_list_transaction_new (_tmp2_);
#line 547 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	cat_trans = _tmp3_;
#line 548 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (cat_trans, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "network-error", (GCallback) _publishing_piwigo_piwigo_publisher_on_category_fetch_error_publishing_rest_support_transaction_network_error, self, 0);
#line 549 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (cat_trans, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "completed", (GCallback) _publishing_piwigo_piwigo_publisher_on_category_fetch_complete_publishing_rest_support_transaction_completed, self, 0);
#line 4279 "PiwigoPublishing.c"
	{
#line 552 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_rest_support_transaction_execute (G_TYPE_CHECK_INSTANCE_CAST (cat_trans, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), &_inner_error_);
#line 552 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 552 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 4287 "PiwigoPublishing.c"
				goto __catch39_spit_publishing_publishing_error;
			}
#line 552 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_publishing_rest_support_transaction_unref0 (cat_trans);
#line 552 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 552 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			g_clear_error (&_inner_error_);
#line 552 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			return;
#line 4298 "PiwigoPublishing.c"
		}
	}
	goto __finally39;
	__catch39_spit_publishing_publishing_error:
	{
		GError* err = NULL;
		GError* _tmp4_ = NULL;
#line 551 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		err = _inner_error_;
#line 551 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_inner_error_ = NULL;
#line 554 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_debug ("PiwigoPublishing.vala:554: ERROR: do_fetch_categories");
#line 555 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp4_ = err;
#line 555 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_piwigo_piwigo_publisher_do_show_error (self, _tmp4_);
#line 551 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_error_free0 (err);
#line 4318 "PiwigoPublishing.c"
	}
	__finally39:
#line 551 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 551 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_publishing_rest_support_transaction_unref0 (cat_trans);
#line 551 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 551 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_clear_error (&_inner_error_);
#line 551 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		return;
#line 4331 "PiwigoPublishing.c"
	}
#line 542 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_publishing_rest_support_transaction_unref0 (cat_trans);
#line 4335 "PiwigoPublishing.c"
}


/**
     * Event triggered when the fetch categories action completes successfully.
     *
     * This event retrieves all categories from the received transaction and
     * populates the categories list. It then triggers the display of the
     * publishing options pane.
     */
static void _vala_array_add34 (PublishingPiwigoCategory*** array, int* length, int* size, PublishingPiwigoCategory* value) {
#line 597 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if ((*length) == (*size)) {
#line 597 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 597 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		*array = g_renew (PublishingPiwigoCategory*, *array, (*size) + 1);
#line 4353 "PiwigoPublishing.c"
	}
#line 597 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	(*array)[(*length)++] = value;
#line 597 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	(*array)[*length] = NULL;
#line 4359 "PiwigoPublishing.c"
}


static void publishing_piwigo_piwigo_publisher_on_category_fetch_complete (PublishingPiwigoPiwigoPublisher* self, PublishingRESTSupportTransaction* txn) {
	PublishingRESTSupportTransaction* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
	PublishingRESTSupportTransaction* _tmp2_ = NULL;
	guint _tmp3_ = 0U;
	PublishingRESTSupportTransaction* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	PublishingPiwigoCategory** _tmp7_ = NULL;
	gint _tmp7__length1 = 0;
	GError * _inner_error_ = NULL;
#line 566 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self));
#line 566 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_TRANSACTION (txn));
#line 567 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_debug ("PiwigoPublishing.vala:567: EVENT: on_category_fetch_complete");
#line 568 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = txn;
#line 568 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_parse_name ("completed", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp1_, NULL, FALSE);
#line 568 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_piwigo_piwigo_publisher_on_category_fetch_complete_publishing_rest_support_transaction_completed, self);
#line 569 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = txn;
#line 569 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_parse_name ("network-error", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp3_, NULL, FALSE);
#line 569 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp2_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _publishing_piwigo_piwigo_publisher_on_category_fetch_error_publishing_rest_support_transaction_network_error, self);
#line 570 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = txn;
#line 570 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp5_ = publishing_rest_support_transaction_get_response (_tmp4_);
#line 570 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp6_ = _tmp5_;
#line 570 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_debug ("PiwigoPublishing.vala:570: PiwigoConnector: list of categories: %s", _tmp6_);
#line 570 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (_tmp6_);
#line 572 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp7_ = self->priv->categories;
#line 572 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp7__length1 = self->priv->categories_length1;
#line 572 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (_tmp7_ != NULL) {
#line 573 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		self->priv->categories = (_vala_array_free (self->priv->categories, self->priv->categories_length1, (GDestroyNotify) publishing_piwigo_category_unref), NULL);
#line 573 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		self->priv->categories = NULL;
#line 573 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		self->priv->categories_length1 = 0;
#line 573 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		self->priv->_categories_size_ = self->priv->categories_length1;
#line 4416 "PiwigoPublishing.c"
	}
	{
		PublishingRESTSupportXmlDocument* doc = NULL;
		PublishingRESTSupportTransaction* _tmp8_ = NULL;
		gchar* _tmp9_ = NULL;
		gchar* _tmp10_ = NULL;
		PublishingRESTSupportXmlDocument* _tmp11_ = NULL;
		PublishingRESTSupportXmlDocument* _tmp12_ = NULL;
		xmlNode* root = NULL;
		PublishingRESTSupportXmlDocument* _tmp13_ = NULL;
		xmlNode* _tmp14_ = NULL;
		xmlNode* categories_node = NULL;
		xmlNode* _tmp15_ = NULL;
		xmlNode* _tmp16_ = NULL;
		xmlNode* category_node_iter = NULL;
		xmlNode* _tmp17_ = NULL;
		xmlNode* _tmp18_ = NULL;
		xmlNode* name_node = NULL;
		xmlNode* uppercats_node = NULL;
		gchar* name = NULL;
		gchar* _tmp19_ = NULL;
		gchar* id_string = NULL;
		gchar* _tmp20_ = NULL;
		gchar* uppercats = NULL;
		gchar* _tmp21_ = NULL;
#line 577 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp8_ = txn;
#line 577 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp9_ = publishing_rest_support_transaction_get_response (_tmp8_);
#line 577 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp10_ = _tmp9_;
#line 577 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp11_ = publishing_rest_support_xml_document_parse_string (_tmp10_, _publishing_piwigo_transaction_validate_xml_publishing_rest_support_xml_document_check_for_error_response, NULL, &_inner_error_);
#line 577 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp12_ = _tmp11_;
#line 577 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_free0 (_tmp10_);
#line 577 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		doc = _tmp12_;
#line 577 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 577 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 4460 "PiwigoPublishing.c"
				goto __catch40_spit_publishing_publishing_error;
			}
#line 577 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 577 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			g_clear_error (&_inner_error_);
#line 577 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			return;
#line 4469 "PiwigoPublishing.c"
		}
#line 580 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp13_ = doc;
#line 580 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp14_ = publishing_rest_support_xml_document_get_root_node (_tmp13_);
#line 580 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		root = _tmp14_;
#line 581 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp15_ = root;
#line 581 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp16_ = xmlFirstElementChild (_tmp15_);
#line 581 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		categories_node = _tmp16_;
#line 582 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp17_ = categories_node;
#line 582 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp18_ = _tmp17_->children;
#line 582 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		category_node_iter = _tmp18_;
#line 585 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp19_ = g_strdup ("");
#line 585 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		name = _tmp19_;
#line 586 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp20_ = g_strdup ("");
#line 586 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		id_string = _tmp20_;
#line 587 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp21_ = g_strdup ("");
#line 587 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		uppercats = _tmp21_;
#line 4501 "PiwigoPublishing.c"
		{
			gboolean _tmp22_ = FALSE;
#line 588 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp22_ = TRUE;
#line 588 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			while (TRUE) {
#line 4508 "PiwigoPublishing.c"
				xmlNode* _tmp25_ = NULL;
				xmlNode* _tmp26_ = NULL;
				PublishingRESTSupportXmlDocument* _tmp27_ = NULL;
				xmlNode* _tmp28_ = NULL;
				xmlNode* _tmp29_ = NULL;
				xmlNode* _tmp30_ = NULL;
				gchar* _tmp31_ = NULL;
				xmlNode* _tmp32_ = NULL;
				PublishingRESTSupportXmlDocument* _tmp33_ = NULL;
				xmlNode* _tmp34_ = NULL;
				xmlNode* _tmp35_ = NULL;
				xmlNode* _tmp36_ = NULL;
				gchar* _tmp37_ = NULL;
				xmlNode* _tmp38_ = NULL;
				gchar* _tmp39_ = NULL;
				PublishingPiwigoCategory** _tmp40_ = NULL;
				gint _tmp40__length1 = 0;
				PublishingPiwigoCategory** _tmp42_ = NULL;
				gint _tmp42__length1 = 0;
				const gchar* _tmp43_ = NULL;
				gint _tmp44_ = 0;
				const gchar* _tmp45_ = NULL;
				const gchar* _tmp46_ = NULL;
				PublishingPiwigoCategory* _tmp47_ = NULL;
#line 588 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				if (!_tmp22_) {
#line 4535 "PiwigoPublishing.c"
					xmlNode* _tmp23_ = NULL;
					xmlNode* _tmp24_ = NULL;
#line 588 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_tmp23_ = category_node_iter;
#line 588 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_tmp24_ = _tmp23_->next;
#line 588 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					category_node_iter = _tmp24_;
#line 4544 "PiwigoPublishing.c"
				}
#line 588 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp22_ = FALSE;
#line 588 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp25_ = category_node_iter;
#line 588 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				if (!(_tmp25_ != NULL)) {
#line 588 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					break;
#line 4554 "PiwigoPublishing.c"
				}
#line 589 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp27_ = doc;
#line 589 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp28_ = category_node_iter;
#line 589 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp29_ = publishing_rest_support_xml_document_get_named_child (_tmp27_, _tmp28_, "name", &_inner_error_);
#line 589 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp26_ = _tmp29_;
#line 589 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 589 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_g_free0 (uppercats);
#line 589 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_g_free0 (id_string);
#line 589 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_g_free0 (name);
#line 589 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_publishing_rest_support_xml_document_unref0 (doc);
#line 589 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 4576 "PiwigoPublishing.c"
						goto __catch40_spit_publishing_publishing_error;
					}
#line 589 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_g_free0 (uppercats);
#line 589 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_g_free0 (id_string);
#line 589 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_g_free0 (name);
#line 589 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_publishing_rest_support_xml_document_unref0 (doc);
#line 589 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 589 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					g_clear_error (&_inner_error_);
#line 589 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					return;
#line 4593 "PiwigoPublishing.c"
				}
#line 589 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				name_node = _tmp26_;
#line 590 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp30_ = name_node;
#line 590 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp31_ = (gchar*) xmlNodeGetContent (_tmp30_);
#line 590 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_g_free0 (name);
#line 590 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				name = _tmp31_;
#line 591 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp33_ = doc;
#line 591 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp34_ = category_node_iter;
#line 591 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp35_ = publishing_rest_support_xml_document_get_named_child (_tmp33_, _tmp34_, "uppercats", &_inner_error_);
#line 591 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp32_ = _tmp35_;
#line 591 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 591 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_g_free0 (uppercats);
#line 591 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_g_free0 (id_string);
#line 591 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_g_free0 (name);
#line 591 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_publishing_rest_support_xml_document_unref0 (doc);
#line 591 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 4625 "PiwigoPublishing.c"
						goto __catch40_spit_publishing_publishing_error;
					}
#line 591 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_g_free0 (uppercats);
#line 591 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_g_free0 (id_string);
#line 591 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_g_free0 (name);
#line 591 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_publishing_rest_support_xml_document_unref0 (doc);
#line 591 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 591 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					g_clear_error (&_inner_error_);
#line 591 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					return;
#line 4642 "PiwigoPublishing.c"
				}
#line 591 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				uppercats_node = _tmp32_;
#line 592 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp36_ = uppercats_node;
#line 592 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp37_ = (gchar*) xmlNodeGetContent (_tmp36_);
#line 592 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_g_free0 (uppercats);
#line 592 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				uppercats = (gchar*) _tmp37_;
#line 593 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp38_ = category_node_iter;
#line 593 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp39_ = (gchar*) xmlGetProp (_tmp38_, (xmlChar*) "id");
#line 593 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_g_free0 (id_string);
#line 593 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				id_string = _tmp39_;
#line 594 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp40_ = self->priv->categories;
#line 594 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp40__length1 = self->priv->categories_length1;
#line 594 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				if (_tmp40_ == NULL) {
#line 4668 "PiwigoPublishing.c"
					PublishingPiwigoCategory** _tmp41_ = NULL;
#line 595 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_tmp41_ = g_new0 (PublishingPiwigoCategory*, 0 + 1);
#line 595 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					self->priv->categories = (_vala_array_free (self->priv->categories, self->priv->categories_length1, (GDestroyNotify) publishing_piwigo_category_unref), NULL);
#line 595 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					self->priv->categories = _tmp41_;
#line 595 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					self->priv->categories_length1 = 0;
#line 595 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					self->priv->_categories_size_ = self->priv->categories_length1;
#line 4680 "PiwigoPublishing.c"
				}
#line 597 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp42_ = self->priv->categories;
#line 597 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp42__length1 = self->priv->categories_length1;
#line 597 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp43_ = id_string;
#line 597 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp44_ = atoi (_tmp43_);
#line 597 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp45_ = name;
#line 597 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp46_ = uppercats;
#line 597 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp47_ = publishing_piwigo_category_new (_tmp44_, _tmp45_, _tmp46_, "");
#line 597 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_vala_array_add34 (&self->priv->categories, &self->priv->categories_length1, &self->priv->_categories_size_, _tmp47_);
#line 4698 "PiwigoPublishing.c"
			}
		}
		{
			gint i = 0;
#line 605 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			i = 0;
#line 4705 "PiwigoPublishing.c"
			{
				gboolean _tmp48_ = FALSE;
#line 605 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp48_ = TRUE;
#line 605 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				while (TRUE) {
#line 4712 "PiwigoPublishing.c"
					gint _tmp50_ = 0;
					PublishingPiwigoCategory** _tmp51_ = NULL;
					gint _tmp51__length1 = 0;
					gchar** upcatids = NULL;
					PublishingPiwigoCategory** _tmp52_ = NULL;
					gint _tmp52__length1 = 0;
					gint _tmp53_ = 0;
					PublishingPiwigoCategory* _tmp54_ = NULL;
					const gchar* _tmp55_ = NULL;
					gchar** _tmp56_ = NULL;
					gchar** _tmp57_ = NULL;
					gint upcatids_length1 = 0;
					gint _upcatids_size_ = 0;
					GString* builder = NULL;
					GString* _tmp58_ = NULL;
					PublishingPiwigoCategory** _tmp84_ = NULL;
					gint _tmp84__length1 = 0;
					gint _tmp85_ = 0;
					PublishingPiwigoCategory* _tmp86_ = NULL;
					GString* _tmp87_ = NULL;
					const gchar* _tmp88_ = NULL;
					gchar* _tmp89_ = NULL;
#line 605 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					if (!_tmp48_) {
#line 4737 "PiwigoPublishing.c"
						gint _tmp49_ = 0;
#line 605 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
						_tmp49_ = i;
#line 605 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
						i = _tmp49_ + 1;
#line 4743 "PiwigoPublishing.c"
					}
#line 605 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_tmp48_ = FALSE;
#line 605 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_tmp50_ = i;
#line 605 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_tmp51_ = self->priv->categories;
#line 605 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_tmp51__length1 = self->priv->categories_length1;
#line 605 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					if (!(_tmp50_ < _tmp51__length1)) {
#line 605 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
						break;
#line 4757 "PiwigoPublishing.c"
					}
#line 606 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_tmp52_ = self->priv->categories;
#line 606 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_tmp52__length1 = self->priv->categories_length1;
#line 606 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_tmp53_ = i;
#line 606 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_tmp54_ = _tmp52_[_tmp53_];
#line 606 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_tmp55_ = _tmp54_->uppercats;
#line 606 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_tmp57_ = _tmp56_ = g_strsplit (_tmp55_, ",", 0);
#line 606 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					upcatids = _tmp57_;
#line 606 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					upcatids_length1 = _vala_array_length (_tmp56_);
#line 606 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_upcatids_size_ = upcatids_length1;
#line 607 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_tmp58_ = g_string_new ("");
#line 607 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					builder = _tmp58_;
#line 4781 "PiwigoPublishing.c"
					{
						gint j = 0;
#line 608 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
						j = 0;
#line 4786 "PiwigoPublishing.c"
						{
							gboolean _tmp59_ = FALSE;
#line 608 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
							_tmp59_ = TRUE;
#line 608 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
							while (TRUE) {
#line 4793 "PiwigoPublishing.c"
								gint _tmp61_ = 0;
								gchar** _tmp62_ = NULL;
								gint _tmp62__length1 = 0;
								GString* _tmp63_ = NULL;
								GString* _tmp83_ = NULL;
#line 608 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
								if (!_tmp59_) {
#line 4801 "PiwigoPublishing.c"
									gint _tmp60_ = 0;
#line 608 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
									_tmp60_ = j;
#line 608 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
									j = _tmp60_ + 1;
#line 4807 "PiwigoPublishing.c"
								}
#line 608 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
								_tmp59_ = FALSE;
#line 608 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
								_tmp61_ = j;
#line 608 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
								_tmp62_ = upcatids;
#line 608 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
								_tmp62__length1 = upcatids_length1;
#line 608 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
								if (!(_tmp61_ < _tmp62__length1)) {
#line 608 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
									break;
#line 4821 "PiwigoPublishing.c"
								}
#line 609 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
								_tmp63_ = builder;
#line 609 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
								g_string_append (_tmp63_, "/ ");
#line 4827 "PiwigoPublishing.c"
								{
									gint k = 0;
#line 611 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
									k = 0;
#line 4832 "PiwigoPublishing.c"
									{
										gboolean _tmp64_ = FALSE;
#line 611 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
										_tmp64_ = TRUE;
#line 611 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
										while (TRUE) {
#line 4839 "PiwigoPublishing.c"
											gint _tmp66_ = 0;
											PublishingPiwigoCategory** _tmp67_ = NULL;
											gint _tmp67__length1 = 0;
											gchar** _tmp68_ = NULL;
											gint _tmp68__length1 = 0;
											gint _tmp69_ = 0;
											const gchar* _tmp70_ = NULL;
											PublishingPiwigoCategory** _tmp71_ = NULL;
											gint _tmp71__length1 = 0;
											gint _tmp72_ = 0;
											PublishingPiwigoCategory* _tmp73_ = NULL;
											gint _tmp74_ = 0;
											gchar* _tmp75_ = NULL;
											gchar* _tmp76_ = NULL;
											gboolean _tmp77_ = FALSE;
#line 611 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
											if (!_tmp64_) {
#line 4857 "PiwigoPublishing.c"
												gint _tmp65_ = 0;
#line 611 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
												_tmp65_ = k;
#line 611 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
												k = _tmp65_ + 1;
#line 4863 "PiwigoPublishing.c"
											}
#line 611 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
											_tmp64_ = FALSE;
#line 611 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
											_tmp66_ = k;
#line 611 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
											_tmp67_ = self->priv->categories;
#line 611 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
											_tmp67__length1 = self->priv->categories_length1;
#line 611 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
											if (!(_tmp66_ < _tmp67__length1)) {
#line 611 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
												break;
#line 4877 "PiwigoPublishing.c"
											}
#line 612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
											_tmp68_ = upcatids;
#line 612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
											_tmp68__length1 = upcatids_length1;
#line 612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
											_tmp69_ = j;
#line 612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
											_tmp70_ = _tmp68_[_tmp69_];
#line 612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
											_tmp71_ = self->priv->categories;
#line 612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
											_tmp71__length1 = self->priv->categories_length1;
#line 612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
											_tmp72_ = k;
#line 612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
											_tmp73_ = _tmp71_[_tmp72_];
#line 612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
											_tmp74_ = _tmp73_->id;
#line 612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
											_tmp75_ = g_strdup_printf ("%i", _tmp74_);
#line 612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
											_tmp76_ = _tmp75_;
#line 612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
											_tmp77_ = g_strcmp0 (_tmp70_, _tmp76_) == 0;
#line 612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
											_g_free0 (_tmp76_);
#line 612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
											if (_tmp77_) {
#line 4907 "PiwigoPublishing.c"
												GString* _tmp78_ = NULL;
												PublishingPiwigoCategory** _tmp79_ = NULL;
												gint _tmp79__length1 = 0;
												gint _tmp80_ = 0;
												PublishingPiwigoCategory* _tmp81_ = NULL;
												const gchar* _tmp82_ = NULL;
#line 613 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
												_tmp78_ = builder;
#line 613 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
												_tmp79_ = self->priv->categories;
#line 613 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
												_tmp79__length1 = self->priv->categories_length1;
#line 613 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
												_tmp80_ = k;
#line 613 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
												_tmp81_ = _tmp79_[_tmp80_];
#line 613 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
												_tmp82_ = _tmp81_->name;
#line 613 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
												g_string_append (_tmp78_, _tmp82_);
#line 614 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
												break;
#line 4930 "PiwigoPublishing.c"
											}
										}
									}
								}
#line 617 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
								_tmp83_ = builder;
#line 617 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
								g_string_append (_tmp83_, " ");
#line 4939 "PiwigoPublishing.c"
							}
						}
					}
#line 619 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_tmp84_ = self->priv->categories;
#line 619 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_tmp84__length1 = self->priv->categories_length1;
#line 619 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_tmp85_ = i;
#line 619 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_tmp86_ = _tmp84_[_tmp85_];
#line 619 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_tmp87_ = builder;
#line 619 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_tmp88_ = _tmp87_->str;
#line 619 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_tmp89_ = g_strdup (_tmp88_);
#line 619 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_g_free0 (_tmp86_->display_name);
#line 619 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_tmp86_->display_name = _tmp89_;
#line 605 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_g_string_free0 (builder);
#line 605 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					upcatids = (_vala_array_free (upcatids, upcatids_length1, (GDestroyNotify) g_free), NULL);
#line 4965 "PiwigoPublishing.c"
				}
			}
		}
#line 576 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_free0 (uppercats);
#line 576 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_free0 (id_string);
#line 576 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_free0 (name);
#line 576 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_publishing_rest_support_xml_document_unref0 (doc);
#line 4977 "PiwigoPublishing.c"
	}
	goto __finally40;
	__catch40_spit_publishing_publishing_error:
	{
		GError* err = NULL;
		GError* _tmp90_ = NULL;
#line 576 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		err = _inner_error_;
#line 576 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_inner_error_ = NULL;
#line 622 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_debug ("PiwigoPublishing.vala:622: ERROR: on_category_fetch_complete");
#line 623 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp90_ = err;
#line 623 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_piwigo_piwigo_publisher_do_show_error (self, _tmp90_);
#line 624 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_error_free0 (err);
#line 624 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		return;
#line 4998 "PiwigoPublishing.c"
	}
	__finally40:
#line 576 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 576 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 576 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_clear_error (&_inner_error_);
#line 576 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		return;
#line 5009 "PiwigoPublishing.c"
	}
#line 627 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_piwigo_publisher_do_show_publishing_options_pane (self);
#line 5013 "PiwigoPublishing.c"
}


/**
     * Event triggered when the fetch categories transaction fails due to a
     * network error.
     */
static void publishing_piwigo_piwigo_publisher_on_category_fetch_error (PublishingPiwigoPiwigoPublisher* self, PublishingRESTSupportTransaction* bad_txn, GError* err) {
	PublishingRESTSupportTransaction* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
	PublishingRESTSupportTransaction* _tmp2_ = NULL;
	guint _tmp3_ = 0U;
	PublishingRESTSupportTransaction* _tmp4_ = NULL;
	GError* _tmp5_ = NULL;
#line 634 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self));
#line 634 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_TRANSACTION (bad_txn));
#line 638 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_debug ("PiwigoPublishing.vala:638: EVENT: on_category_fetch_error");
#line 639 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = bad_txn;
#line 639 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_parse_name ("completed", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp1_, NULL, FALSE);
#line 639 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_piwigo_piwigo_publisher_on_category_fetch_complete_publishing_rest_support_transaction_completed, self);
#line 640 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = bad_txn;
#line 640 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_parse_name ("network-error", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp3_, NULL, FALSE);
#line 640 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp2_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _publishing_piwigo_piwigo_publisher_on_category_fetch_error_publishing_rest_support_transaction_network_error, self);
#line 641 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = bad_txn;
#line 641 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp5_ = err;
#line 641 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_piwigo_publisher_on_network_error (self, _tmp4_, _tmp5_);
#line 5052 "PiwigoPublishing.c"
}


/**
     * Action that shows the publishing options pane.
     *
     * This action method shows the publishing options pane.
     */
static void _publishing_piwigo_piwigo_publisher_on_publishing_options_pane_logout_clicked_publishing_piwigo_publishing_options_pane_logout (PublishingPiwigoPublishingOptionsPane* _sender, gpointer self) {
#line 656 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_piwigo_publisher_on_publishing_options_pane_logout_clicked ((PublishingPiwigoPiwigoPublisher*) self);
#line 5064 "PiwigoPublishing.c"
}


static void _publishing_piwigo_piwigo_publisher_on_publishing_options_pane_publish_clicked_publishing_piwigo_publishing_options_pane_publish (PublishingPiwigoPublishingOptionsPane* _sender, PublishingPiwigoPublishingParameters* parameters, gboolean strip_metadata, gpointer self) {
#line 657 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_piwigo_publisher_on_publishing_options_pane_publish_clicked ((PublishingPiwigoPiwigoPublisher*) self, parameters, strip_metadata);
#line 5071 "PiwigoPublishing.c"
}


static void publishing_piwigo_piwigo_publisher_do_show_publishing_options_pane (PublishingPiwigoPiwigoPublisher* self) {
	SpitPublishingPluginHost* _tmp0_ = NULL;
	PublishingPiwigoPublishingOptionsPane* opts_pane = NULL;
	PublishingPiwigoCategory** _tmp1_ = NULL;
	gint _tmp1__length1 = 0;
	gint _tmp2_ = 0;
	gint _tmp3_ = 0;
	gint _tmp4_ = 0;
	gboolean _tmp5_ = FALSE;
	gboolean _tmp6_ = FALSE;
	gboolean _tmp7_ = FALSE;
	PublishingPiwigoPublishingOptionsPane* _tmp8_ = NULL;
	SpitPublishingPluginHost* _tmp9_ = NULL;
	SpitPublishingPluginHost* _tmp10_ = NULL;
	GtkWidget* _tmp11_ = NULL;
	GtkWidget* _tmp12_ = NULL;
#line 649 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self));
#line 650 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_debug ("PiwigoPublishing.vala:650: ACTION: installing publishing options pane");
#line 652 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->host;
#line 652 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	spit_publishing_plugin_host_set_service_locked (_tmp0_, FALSE);
#line 653 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = self->priv->categories;
#line 653 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1__length1 = self->priv->categories_length1;
#line 653 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = publishing_piwigo_piwigo_publisher_get_last_category (self);
#line 653 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3_ = publishing_piwigo_piwigo_publisher_get_last_permission_level (self);
#line 653 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = publishing_piwigo_piwigo_publisher_get_last_photo_size (self);
#line 653 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp5_ = publishing_piwigo_piwigo_publisher_get_last_title_as_comment (self);
#line 653 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp6_ = publishing_piwigo_piwigo_publisher_get_last_no_upload_tags (self);
#line 653 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp7_ = publishing_piwigo_piwigo_publisher_get_metadata_removal_choice (self);
#line 653 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp8_ = publishing_piwigo_publishing_options_pane_new (self, _tmp1_, _tmp1__length1, _tmp2_, _tmp3_, _tmp4_, _tmp5_, _tmp6_, _tmp7_);
#line 653 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	opts_pane = _tmp8_;
#line 656 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_connect_object (opts_pane, "logout", (GCallback) _publishing_piwigo_piwigo_publisher_on_publishing_options_pane_logout_clicked_publishing_piwigo_publishing_options_pane_logout, self, 0);
#line 657 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_connect_object (opts_pane, "publish", (GCallback) _publishing_piwigo_piwigo_publisher_on_publishing_options_pane_publish_clicked_publishing_piwigo_publishing_options_pane_publish, self, 0);
#line 658 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp9_ = self->priv->host;
#line 658 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	spit_publishing_plugin_host_install_dialog_pane (_tmp9_, G_TYPE_CHECK_INSTANCE_CAST (opts_pane, SPIT_PUBLISHING_TYPE_DIALOG_PANE, SpitPublishingDialogPane), SPIT_PUBLISHING_PLUGIN_HOST_BUTTON_MODE_CLOSE);
#line 659 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp10_ = self->priv->host;
#line 659 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp11_ = publishing_piwigo_publishing_options_pane_get_default_widget (opts_pane);
#line 659 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp12_ = _tmp11_;
#line 659 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	spit_publishing_plugin_host_set_dialog_default_widget (_tmp10_, _tmp12_);
#line 659 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (_tmp12_);
#line 649 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (opts_pane);
#line 5139 "PiwigoPublishing.c"
}


/**
     * Event triggered when the user clicks logout in the publishing options pane.
     */
static void _publishing_piwigo_piwigo_publisher_on_logout_network_error_publishing_rest_support_transaction_network_error (PublishingRESTSupportTransaction* _sender, GError* err, gpointer self) {
#line 668 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_piwigo_publisher_on_logout_network_error ((PublishingPiwigoPiwigoPublisher*) self, _sender, err);
#line 5149 "PiwigoPublishing.c"
}


static void _publishing_piwigo_piwigo_publisher_on_logout_network_complete_publishing_rest_support_transaction_completed (PublishingRESTSupportTransaction* _sender, gpointer self) {
#line 669 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_piwigo_publisher_on_logout_network_complete ((PublishingPiwigoPiwigoPublisher*) self, _sender);
#line 5156 "PiwigoPublishing.c"
}


static void publishing_piwigo_piwigo_publisher_on_publishing_options_pane_logout_clicked (PublishingPiwigoPiwigoPublisher* self) {
	PublishingPiwigoSessionLogoutTransaction* logout_trans = NULL;
	PublishingPiwigoSession* _tmp0_ = NULL;
	PublishingPiwigoSessionLogoutTransaction* _tmp1_ = NULL;
	GError * _inner_error_ = NULL;
#line 665 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self));
#line 666 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_debug ("PiwigoPublishing.vala:666: EVENT: on_publishing_options_pane_logout_cl" \
"icked");
#line 667 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->session;
#line 667 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = publishing_piwigo_session_logout_transaction_new (_tmp0_);
#line 667 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	logout_trans = _tmp1_;
#line 668 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (logout_trans, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "network-error", (GCallback) _publishing_piwigo_piwigo_publisher_on_logout_network_error_publishing_rest_support_transaction_network_error, self, 0);
#line 669 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (logout_trans, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "completed", (GCallback) _publishing_piwigo_piwigo_publisher_on_logout_network_complete_publishing_rest_support_transaction_completed, self, 0);
#line 5179 "PiwigoPublishing.c"
	{
#line 672 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_rest_support_transaction_execute (G_TYPE_CHECK_INSTANCE_CAST (logout_trans, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), &_inner_error_);
#line 672 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 672 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 5187 "PiwigoPublishing.c"
				goto __catch41_spit_publishing_publishing_error;
			}
#line 672 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_publishing_rest_support_transaction_unref0 (logout_trans);
#line 672 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 672 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			g_clear_error (&_inner_error_);
#line 672 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			return;
#line 5198 "PiwigoPublishing.c"
		}
	}
	goto __finally41;
	__catch41_spit_publishing_publishing_error:
	{
		GError* err = NULL;
		GError* _tmp2_ = NULL;
#line 671 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		err = _inner_error_;
#line 671 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_inner_error_ = NULL;
#line 674 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_debug ("PiwigoPublishing.vala:674: ERROR: on_publishing_options_pane_logout_cl" \
"icked");
#line 675 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp2_ = err;
#line 675 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_piwigo_piwigo_publisher_do_show_error (self, _tmp2_);
#line 671 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_error_free0 (err);
#line 5218 "PiwigoPublishing.c"
	}
	__finally41:
#line 671 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 671 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_publishing_rest_support_transaction_unref0 (logout_trans);
#line 671 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 671 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_clear_error (&_inner_error_);
#line 671 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		return;
#line 5231 "PiwigoPublishing.c"
	}
#line 665 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_publishing_rest_support_transaction_unref0 (logout_trans);
#line 5235 "PiwigoPublishing.c"
}


/**
     * Event triggered when the logout action completes successfully.
     *
     * This event de-authenticates the session and shows the authentication
     * pane again.
     */
static void publishing_piwigo_piwigo_publisher_on_logout_network_complete (PublishingPiwigoPiwigoPublisher* self, PublishingRESTSupportTransaction* txn) {
	PublishingRESTSupportTransaction* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
	PublishingRESTSupportTransaction* _tmp2_ = NULL;
	guint _tmp3_ = 0U;
	PublishingPiwigoSession* _tmp4_ = NULL;
#line 685 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self));
#line 685 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_TRANSACTION (txn));
#line 686 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_debug ("PiwigoPublishing.vala:686: EVENT: on_logout_network_complete");
#line 687 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = txn;
#line 687 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_parse_name ("completed", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp1_, NULL, FALSE);
#line 687 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_piwigo_piwigo_publisher_on_logout_network_complete_publishing_rest_support_transaction_completed, self);
#line 688 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = txn;
#line 688 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_parse_name ("network-error", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp3_, NULL, FALSE);
#line 688 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp2_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _publishing_piwigo_piwigo_publisher_on_logout_network_error_publishing_rest_support_transaction_network_error, self);
#line 690 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = self->priv->session;
#line 690 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_session_deauthenticate (_tmp4_);
#line 692 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_piwigo_publisher_do_show_authentication_pane (self, PUBLISHING_PIWIGO_AUTHENTICATION_PANE_MODE_INTRO);
#line 5275 "PiwigoPublishing.c"
}


/**
     * Event triggered when the logout action fails due to a network error.
     */
static void publishing_piwigo_piwigo_publisher_on_logout_network_error (PublishingPiwigoPiwigoPublisher* self, PublishingRESTSupportTransaction* bad_txn, GError* err) {
	PublishingRESTSupportTransaction* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
	PublishingRESTSupportTransaction* _tmp2_ = NULL;
	guint _tmp3_ = 0U;
	PublishingRESTSupportTransaction* _tmp4_ = NULL;
	GError* _tmp5_ = NULL;
#line 698 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self));
#line 698 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_TRANSACTION (bad_txn));
#line 702 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_debug ("PiwigoPublishing.vala:702: EVENT: on_logout_network_error");
#line 703 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = bad_txn;
#line 703 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_parse_name ("completed", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp1_, NULL, FALSE);
#line 703 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_piwigo_piwigo_publisher_on_logout_network_complete_publishing_rest_support_transaction_completed, self);
#line 704 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = bad_txn;
#line 704 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_parse_name ("network-error", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp3_, NULL, FALSE);
#line 704 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp2_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _publishing_piwigo_piwigo_publisher_on_logout_network_error_publishing_rest_support_transaction_network_error, self);
#line 705 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = bad_txn;
#line 705 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp5_ = err;
#line 705 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_piwigo_publisher_on_network_error (self, _tmp4_, _tmp5_);
#line 5313 "PiwigoPublishing.c"
}


/**
     * Event triggered when the user clicks publish in the publishing options pane.
     *
     * This event first saves the parameters so that they can re-used later.
     * If the publishing parameters indicate that the user wants to create a new
     * category, the create category action is called. Otherwise, the upload
     * action is called.
     *
     * @param parameters the publishing parameters
     */
static gpointer _publishing_piwigo_publishing_parameters_ref0 (gpointer self) {
#line 721 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return self ? publishing_piwigo_publishing_parameters_ref (self) : NULL;
#line 5330 "PiwigoPublishing.c"
}


static void publishing_piwigo_piwigo_publisher_on_publishing_options_pane_publish_clicked (PublishingPiwigoPiwigoPublisher* self, PublishingPiwigoPublishingParameters* parameters, gboolean strip_metadata) {
	PublishingPiwigoPublishingParameters* _tmp0_ = NULL;
	PublishingPiwigoPublishingParameters* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	PublishingPiwigoPublishingParameters* _tmp3_ = NULL;
	PublishingPiwigoCategory* _tmp4_ = NULL;
	gboolean _tmp5_ = FALSE;
#line 718 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self));
#line 718 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PUBLISHING_PARAMETERS (parameters));
#line 720 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_debug ("PiwigoPublishing.vala:720: EVENT: on_publishing_options_pane_publish_c" \
"licked");
#line 721 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = parameters;
#line 721 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = _publishing_piwigo_publishing_parameters_ref0 (_tmp0_);
#line 721 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_publishing_piwigo_publishing_parameters_unref0 (self->priv->parameters);
#line 721 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->parameters = _tmp1_;
#line 722 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = strip_metadata;
#line 722 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->strip_metadata = _tmp2_;
#line 724 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3_ = parameters;
#line 724 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = _tmp3_->category;
#line 724 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp5_ = publishing_piwigo_category_is_local (_tmp4_);
#line 724 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (_tmp5_) {
#line 5367 "PiwigoPublishing.c"
		PublishingPiwigoPublishingParameters* _tmp6_ = NULL;
		PublishingPiwigoCategory* _tmp7_ = NULL;
#line 725 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp6_ = parameters;
#line 725 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp7_ = _tmp6_->category;
#line 725 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_piwigo_piwigo_publisher_do_create_category (self, _tmp7_);
#line 5376 "PiwigoPublishing.c"
	} else {
		gboolean _tmp8_ = FALSE;
#line 727 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp8_ = self->priv->strip_metadata;
#line 727 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_piwigo_piwigo_publisher_do_upload (self, _tmp8_);
#line 5383 "PiwigoPublishing.c"
	}
}


/**
     * Action that creates a new category in the Piwigo library.
     *
     * This actions runs a REST transaction to create a new category in the
     * Piwigo library. It displays a wait pane with an information message
     * while the transaction is running. This action should only be called with
     * a local cateogory, i.e. one that does not exist on the server and does
     * not yet have an ID.
     *
     * @param category the new category to create on the server
     */
static gchar* string_strip (const gchar* self) {
	gchar* result = NULL;
	gchar* _result_ = NULL;
	gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
#line 1207 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1208 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp0_ = g_strdup (self);
#line 1208 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_result_ = _tmp0_;
#line 1209 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp1_ = _result_;
#line 1209 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	g_strstrip (_tmp1_);
#line 1210 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	result = _result_;
#line 1210 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	return result;
#line 5418 "PiwigoPublishing.c"
}


static void _publishing_piwigo_piwigo_publisher_on_category_add_error_publishing_rest_support_transaction_network_error (PublishingRESTSupportTransaction* _sender, GError* err, gpointer self) {
#line 751 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_piwigo_publisher_on_category_add_error ((PublishingPiwigoPiwigoPublisher*) self, _sender, err);
#line 5425 "PiwigoPublishing.c"
}


static void _publishing_piwigo_piwigo_publisher_on_category_add_complete_publishing_rest_support_transaction_completed (PublishingRESTSupportTransaction* _sender, gpointer self) {
#line 752 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_piwigo_publisher_on_category_add_complete ((PublishingPiwigoPiwigoPublisher*) self, _sender);
#line 5432 "PiwigoPublishing.c"
}


static void publishing_piwigo_piwigo_publisher_do_create_category (PublishingPiwigoPiwigoPublisher* self, PublishingPiwigoCategory* category) {
	PublishingPiwigoCategory* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	PublishingPiwigoCategory* _tmp4_ = NULL;
	gboolean _tmp5_ = FALSE;
	SpitPublishingPluginHost* _tmp6_ = NULL;
	SpitPublishingPluginHost* _tmp7_ = NULL;
	const gchar* _tmp8_ = NULL;
	PublishingPiwigoCategory* _tmp9_ = NULL;
	const gchar* _tmp10_ = NULL;
	gchar* _tmp11_ = NULL;
	gchar* _tmp12_ = NULL;
	PublishingPiwigoCategoriesAddTransaction* creation_trans = NULL;
	PublishingPiwigoSession* _tmp13_ = NULL;
	PublishingPiwigoCategory* _tmp14_ = NULL;
	const gchar* _tmp15_ = NULL;
	gchar* _tmp16_ = NULL;
	gchar* _tmp17_ = NULL;
	PublishingPiwigoCategory* _tmp18_ = NULL;
	const gchar* _tmp19_ = NULL;
	gint _tmp20_ = 0;
	PublishingPiwigoCategory* _tmp21_ = NULL;
	const gchar* _tmp22_ = NULL;
	PublishingPiwigoCategoriesAddTransaction* _tmp23_ = NULL;
	PublishingPiwigoCategoriesAddTransaction* _tmp24_ = NULL;
	GError * _inner_error_ = NULL;
#line 742 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self));
#line 742 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_CATEGORY (category));
#line 743 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = category;
#line 743 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = _tmp0_->name;
#line 743 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = g_strdup_printf ("ACTION: creating a new category: %s", _tmp1_);
#line 743 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3_ = _tmp2_;
#line 743 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_debug ("PiwigoPublishing.vala:743: %s", _tmp3_);
#line 743 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (_tmp3_);
#line 744 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = category;
#line 744 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp5_ = publishing_piwigo_category_is_local (_tmp4_);
#line 744 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_vala_assert (_tmp5_, "category.is_local()");
#line 746 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp6_ = self->priv->host;
#line 746 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	spit_publishing_plugin_host_set_service_locked (_tmp6_, TRUE);
#line 747 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp7_ = self->priv->host;
#line 747 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp8_ = _ ("Creating album %s...");
#line 747 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp9_ = category;
#line 747 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp10_ = _tmp9_->name;
#line 747 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp11_ = g_strdup_printf (_tmp8_, _tmp10_);
#line 747 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp12_ = _tmp11_;
#line 747 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	spit_publishing_plugin_host_install_static_message_pane (_tmp7_, _tmp12_, SPIT_PUBLISHING_PLUGIN_HOST_BUTTON_MODE_CANCEL);
#line 747 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (_tmp12_);
#line 749 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp13_ = self->priv->session;
#line 749 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp14_ = category;
#line 749 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp15_ = _tmp14_->name;
#line 749 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp16_ = string_strip (_tmp15_);
#line 749 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp17_ = _tmp16_;
#line 749 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp18_ = category;
#line 749 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp19_ = _tmp18_->uppercats;
#line 749 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp20_ = atoi (_tmp19_);
#line 749 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp21_ = category;
#line 749 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp22_ = _tmp21_->comment;
#line 749 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp23_ = publishing_piwigo_categories_add_transaction_new (_tmp13_, _tmp17_, _tmp20_, _tmp22_);
#line 749 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp24_ = _tmp23_;
#line 749 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (_tmp17_);
#line 749 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	creation_trans = _tmp24_;
#line 751 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (creation_trans, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "network-error", (GCallback) _publishing_piwigo_piwigo_publisher_on_category_add_error_publishing_rest_support_transaction_network_error, self, 0);
#line 752 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (creation_trans, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "completed", (GCallback) _publishing_piwigo_piwigo_publisher_on_category_add_complete_publishing_rest_support_transaction_completed, self, 0);
#line 5538 "PiwigoPublishing.c"
	{
#line 755 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_rest_support_transaction_execute (G_TYPE_CHECK_INSTANCE_CAST (creation_trans, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), &_inner_error_);
#line 755 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 755 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 5546 "PiwigoPublishing.c"
				goto __catch42_spit_publishing_publishing_error;
			}
#line 755 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_publishing_rest_support_transaction_unref0 (creation_trans);
#line 755 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 755 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			g_clear_error (&_inner_error_);
#line 755 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			return;
#line 5557 "PiwigoPublishing.c"
		}
	}
	goto __finally42;
	__catch42_spit_publishing_publishing_error:
	{
		GError* err = NULL;
		GError* _tmp25_ = NULL;
#line 754 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		err = _inner_error_;
#line 754 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_inner_error_ = NULL;
#line 757 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_debug ("PiwigoPublishing.vala:757: ERROR: do_create_category");
#line 758 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp25_ = err;
#line 758 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_piwigo_piwigo_publisher_do_show_error (self, _tmp25_);
#line 754 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_error_free0 (err);
#line 5577 "PiwigoPublishing.c"
	}
	__finally42:
#line 754 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 754 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_publishing_rest_support_transaction_unref0 (creation_trans);
#line 754 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 754 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_clear_error (&_inner_error_);
#line 754 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		return;
#line 5590 "PiwigoPublishing.c"
	}
#line 742 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_publishing_rest_support_transaction_unref0 (creation_trans);
#line 5594 "PiwigoPublishing.c"
}


/**
     * Event triggered when the add category action completes successfully.
     *
     * This event parses the ID assigned to new category out of the received
     * transaction and assigns that ID to the category currently held in
     * the publishing parameters. It then calls the upload action.
     */
static void publishing_piwigo_piwigo_publisher_on_category_add_complete (PublishingPiwigoPiwigoPublisher* self, PublishingRESTSupportTransaction* txn) {
	PublishingRESTSupportTransaction* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
	PublishingRESTSupportTransaction* _tmp2_ = NULL;
	guint _tmp3_ = 0U;
	GError * _inner_error_ = NULL;
#line 769 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self));
#line 769 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_TRANSACTION (txn));
#line 770 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_debug ("PiwigoPublishing.vala:770: EVENT: on_category_add_complete");
#line 771 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = txn;
#line 771 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_parse_name ("completed", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp1_, NULL, FALSE);
#line 771 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_piwigo_piwigo_publisher_on_category_add_complete_publishing_rest_support_transaction_completed, self);
#line 772 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = txn;
#line 772 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_parse_name ("network-error", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp3_, NULL, FALSE);
#line 772 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp2_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _publishing_piwigo_piwigo_publisher_on_category_add_error_publishing_rest_support_transaction_network_error, self);
#line 5629 "PiwigoPublishing.c"
	{
		PublishingRESTSupportXmlDocument* doc = NULL;
		PublishingRESTSupportTransaction* _tmp4_ = NULL;
		gchar* _tmp5_ = NULL;
		gchar* _tmp6_ = NULL;
		PublishingRESTSupportXmlDocument* _tmp7_ = NULL;
		PublishingRESTSupportXmlDocument* _tmp8_ = NULL;
		xmlNode* rsp = NULL;
		PublishingRESTSupportXmlDocument* _tmp9_ = NULL;
		xmlNode* _tmp10_ = NULL;
		xmlNode* id_node = NULL;
		xmlNode* _tmp11_ = NULL;
		PublishingRESTSupportXmlDocument* _tmp12_ = NULL;
		xmlNode* _tmp13_ = NULL;
		xmlNode* _tmp14_ = NULL;
		gchar* id_string = NULL;
		xmlNode* _tmp15_ = NULL;
		gchar* _tmp16_ = NULL;
		gint id = 0;
		const gchar* _tmp17_ = NULL;
		gint _tmp18_ = 0;
		PublishingPiwigoPublishingParameters* _tmp19_ = NULL;
		PublishingPiwigoCategory* _tmp20_ = NULL;
		gint _tmp21_ = 0;
		gboolean _tmp22_ = FALSE;
#line 776 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp4_ = txn;
#line 776 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp5_ = publishing_rest_support_transaction_get_response (_tmp4_);
#line 776 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp6_ = _tmp5_;
#line 776 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp7_ = publishing_rest_support_xml_document_parse_string (_tmp6_, _publishing_piwigo_transaction_validate_xml_publishing_rest_support_xml_document_check_for_error_response, NULL, &_inner_error_);
#line 776 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp8_ = _tmp7_;
#line 776 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_free0 (_tmp6_);
#line 776 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		doc = _tmp8_;
#line 776 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 776 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 5673 "PiwigoPublishing.c"
				goto __catch43_spit_publishing_publishing_error;
			}
#line 776 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 776 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			g_clear_error (&_inner_error_);
#line 776 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			return;
#line 5682 "PiwigoPublishing.c"
		}
#line 779 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp9_ = doc;
#line 779 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp10_ = publishing_rest_support_xml_document_get_root_node (_tmp9_);
#line 779 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		rsp = _tmp10_;
#line 781 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp12_ = doc;
#line 781 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp13_ = rsp;
#line 781 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp14_ = publishing_rest_support_xml_document_get_named_child (_tmp12_, _tmp13_, "id", &_inner_error_);
#line 781 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp11_ = _tmp14_;
#line 781 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 781 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_publishing_rest_support_xml_document_unref0 (doc);
#line 781 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 5704 "PiwigoPublishing.c"
				goto __catch43_spit_publishing_publishing_error;
			}
#line 781 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_publishing_rest_support_xml_document_unref0 (doc);
#line 781 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 781 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			g_clear_error (&_inner_error_);
#line 781 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			return;
#line 5715 "PiwigoPublishing.c"
		}
#line 781 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		id_node = _tmp11_;
#line 782 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp15_ = id_node;
#line 782 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp16_ = (gchar*) xmlNodeGetContent (_tmp15_);
#line 782 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		id_string = _tmp16_;
#line 783 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp17_ = id_string;
#line 783 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp18_ = atoi (_tmp17_);
#line 783 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		id = _tmp18_;
#line 784 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp19_ = self->priv->parameters;
#line 784 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp20_ = _tmp19_->category;
#line 784 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp21_ = id;
#line 784 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp20_->id = _tmp21_;
#line 785 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp22_ = self->priv->strip_metadata;
#line 785 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_piwigo_piwigo_publisher_do_upload (self, _tmp22_);
#line 775 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_free0 (id_string);
#line 775 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_publishing_rest_support_xml_document_unref0 (doc);
#line 5747 "PiwigoPublishing.c"
	}
	goto __finally43;
	__catch43_spit_publishing_publishing_error:
	{
		GError* err = NULL;
		GError* _tmp23_ = NULL;
#line 775 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		err = _inner_error_;
#line 775 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_inner_error_ = NULL;
#line 787 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_debug ("PiwigoPublishing.vala:787: ERROR: on_category_add_complete");
#line 788 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp23_ = err;
#line 788 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_piwigo_piwigo_publisher_do_show_error (self, _tmp23_);
#line 775 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_error_free0 (err);
#line 5766 "PiwigoPublishing.c"
	}
	__finally43:
#line 775 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 775 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 775 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_clear_error (&_inner_error_);
#line 775 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		return;
#line 5777 "PiwigoPublishing.c"
	}
}


/**
     * Event triggered when the add category action fails due to a network error.
     */
static void publishing_piwigo_piwigo_publisher_on_category_add_error (PublishingPiwigoPiwigoPublisher* self, PublishingRESTSupportTransaction* bad_txn, GError* err) {
	PublishingRESTSupportTransaction* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
	PublishingRESTSupportTransaction* _tmp2_ = NULL;
	guint _tmp3_ = 0U;
	PublishingRESTSupportTransaction* _tmp4_ = NULL;
	GError* _tmp5_ = NULL;
#line 795 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self));
#line 795 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_TRANSACTION (bad_txn));
#line 799 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_debug ("PiwigoPublishing.vala:799: EVENT: on_category_add_error");
#line 800 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = bad_txn;
#line 800 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_parse_name ("completed", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp1_, NULL, FALSE);
#line 800 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_piwigo_piwigo_publisher_on_category_add_complete_publishing_rest_support_transaction_completed, self);
#line 801 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = bad_txn;
#line 801 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_parse_name ("network-error", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp3_, NULL, FALSE);
#line 801 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp2_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _publishing_piwigo_piwigo_publisher_on_category_add_error_publishing_rest_support_transaction_network_error, self);
#line 802 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = bad_txn;
#line 802 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp5_ = err;
#line 802 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_piwigo_publisher_on_network_error (self, _tmp4_, _tmp5_);
#line 5816 "PiwigoPublishing.c"
}


/**
     * Upload action: the big one, the one we've been waiting for!
     */
static void _publishing_piwigo_piwigo_publisher_on_upload_complete_publishing_rest_support_batch_uploader_upload_complete (PublishingRESTSupportBatchUploader* _sender, gint num_photos_published, gpointer self) {
#line 825 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_piwigo_publisher_on_upload_complete ((PublishingPiwigoPiwigoPublisher*) self, _sender, num_photos_published);
#line 5826 "PiwigoPublishing.c"
}


static void _publishing_piwigo_piwigo_publisher_on_upload_error_publishing_rest_support_batch_uploader_upload_error (PublishingRESTSupportBatchUploader* _sender, GError* err, gpointer self) {
#line 826 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_piwigo_publisher_on_upload_error ((PublishingPiwigoPiwigoPublisher*) self, _sender, err);
#line 5833 "PiwigoPublishing.c"
}


static void _publishing_piwigo_piwigo_publisher_on_upload_status_updated_spit_publishing_progress_callback (gint file_number, gdouble fraction_complete, gpointer self) {
#line 827 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_piwigo_publisher_on_upload_status_updated ((PublishingPiwigoPiwigoPublisher*) self, file_number, fraction_complete);
#line 5840 "PiwigoPublishing.c"
}


static void publishing_piwigo_piwigo_publisher_do_upload (PublishingPiwigoPiwigoPublisher* self, gboolean strip_metadata) {
	gboolean _tmp0_ = FALSE;
	SpitPublishingPluginHost* _tmp1_ = NULL;
	PublishingPiwigoPublishingParameters* _tmp2_ = NULL;
	PublishingPiwigoCategory* _tmp3_ = NULL;
	gint _tmp4_ = 0;
	PublishingPiwigoPublishingParameters* _tmp5_ = NULL;
	PublishingPiwigoPermissionLevel* _tmp6_ = NULL;
	gint _tmp7_ = 0;
	PublishingPiwigoPublishingParameters* _tmp8_ = NULL;
	PublishingPiwigoSizeEntry* _tmp9_ = NULL;
	gint _tmp10_ = 0;
	PublishingPiwigoPublishingParameters* _tmp11_ = NULL;
	gboolean _tmp12_ = FALSE;
	PublishingPiwigoPublishingParameters* _tmp13_ = NULL;
	gboolean _tmp14_ = FALSE;
	gboolean _tmp15_ = FALSE;
	SpitPublishingPluginHost* _tmp16_ = NULL;
	PublishingPiwigoPublishingParameters* _tmp17_ = NULL;
	PublishingPiwigoSizeEntry* _tmp18_ = NULL;
	gint _tmp19_ = 0;
	gboolean _tmp20_ = FALSE;
	void* _tmp21_ = NULL;
	GDestroyNotify _tmp22_ = NULL;
	SpitPublishingProgressCallback _tmp23_ = NULL;
	SpitPublishingPublishable** publishables = NULL;
	SpitPublishingPluginHost* _tmp24_ = NULL;
	gint _tmp25_ = 0;
	SpitPublishingPublishable** _tmp26_ = NULL;
	gint publishables_length1 = 0;
	gint _publishables_size_ = 0;
	PublishingPiwigoUploader* uploader = NULL;
	PublishingPiwigoSession* _tmp27_ = NULL;
	PublishingPiwigoPublishingParameters* _tmp28_ = NULL;
	PublishingPiwigoUploader* _tmp29_ = NULL;
#line 808 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self));
#line 809 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = strip_metadata;
#line 809 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->strip_metadata = _tmp0_;
#line 810 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_debug ("PiwigoPublishing.vala:810: ACTION: uploading pictures");
#line 812 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = self->priv->host;
#line 812 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	spit_publishing_plugin_host_set_service_locked (_tmp1_, TRUE);
#line 814 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = self->priv->parameters;
#line 814 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3_ = _tmp2_->category;
#line 814 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = _tmp3_->id;
#line 814 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_piwigo_publisher_set_last_category (self, _tmp4_);
#line 815 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp5_ = self->priv->parameters;
#line 815 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp6_ = _tmp5_->perm_level;
#line 815 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp7_ = _tmp6_->id;
#line 815 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_piwigo_publisher_set_last_permission_level (self, _tmp7_);
#line 816 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp8_ = self->priv->parameters;
#line 816 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp9_ = _tmp8_->photo_size;
#line 816 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp10_ = _tmp9_->id;
#line 816 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_piwigo_publisher_set_last_photo_size (self, _tmp10_);
#line 817 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp11_ = self->priv->parameters;
#line 817 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp12_ = _tmp11_->title_as_comment;
#line 817 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_piwigo_publisher_set_last_title_as_comment (self, _tmp12_);
#line 818 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp13_ = self->priv->parameters;
#line 818 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp14_ = _tmp13_->no_upload_tags;
#line 818 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_piwigo_publisher_set_last_no_upload_tags (self, _tmp14_);
#line 819 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp15_ = strip_metadata;
#line 819 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_piwigo_publisher_set_metadata_removal_choice (self, _tmp15_);
#line 821 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp16_ = self->priv->host;
#line 821 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp17_ = self->priv->parameters;
#line 821 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp18_ = _tmp17_->photo_size;
#line 821 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp19_ = _tmp18_->id;
#line 821 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp20_ = self->priv->strip_metadata;
#line 821 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp23_ = spit_publishing_plugin_host_serialize_publishables (_tmp16_, _tmp19_, _tmp20_, &_tmp21_, &_tmp22_);
#line 821 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	(self->priv->progress_reporter_target_destroy_notify == NULL) ? NULL : (self->priv->progress_reporter_target_destroy_notify (self->priv->progress_reporter_target), NULL);
#line 821 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->progress_reporter = NULL;
#line 821 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->progress_reporter_target = NULL;
#line 821 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->progress_reporter_target_destroy_notify = NULL;
#line 821 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->progress_reporter = _tmp23_;
#line 821 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->progress_reporter_target = _tmp21_;
#line 821 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->progress_reporter_target_destroy_notify = _tmp22_;
#line 822 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp24_ = self->priv->host;
#line 822 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp26_ = spit_publishing_plugin_host_get_publishables (_tmp24_, &_tmp25_);
#line 822 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishables = _tmp26_;
#line 822 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishables_length1 = _tmp25_;
#line 822 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_publishables_size_ = publishables_length1;
#line 824 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp27_ = self->priv->session;
#line 824 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp28_ = self->priv->parameters;
#line 824 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp29_ = publishing_piwigo_uploader_new (_tmp27_, publishables, publishables_length1, _tmp28_);
#line 824 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	uploader = _tmp29_;
#line 825 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (uploader, PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, PublishingRESTSupportBatchUploader), "upload-complete", (GCallback) _publishing_piwigo_piwigo_publisher_on_upload_complete_publishing_rest_support_batch_uploader_upload_complete, self, 0);
#line 826 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (uploader, PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, PublishingRESTSupportBatchUploader), "upload-error", (GCallback) _publishing_piwigo_piwigo_publisher_on_upload_error_publishing_rest_support_batch_uploader_upload_error, self, 0);
#line 827 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_rest_support_batch_uploader_upload (G_TYPE_CHECK_INSTANCE_CAST (uploader, PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, PublishingRESTSupportBatchUploader), _publishing_piwigo_piwigo_publisher_on_upload_status_updated_spit_publishing_progress_callback, self);
#line 808 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_publishing_rest_support_batch_uploader_unref0 (uploader);
#line 808 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishables = (_vala_array_free (publishables, publishables_length1, (GDestroyNotify) g_object_unref), NULL);
#line 5985 "PiwigoPublishing.c"
}


/**
     * Event triggered when the batch uploader reports that at least one of the
     * network transactions encapsulating uploads has completed successfully
     */
static void publishing_piwigo_piwigo_publisher_on_upload_complete (PublishingPiwigoPiwigoPublisher* self, PublishingRESTSupportBatchUploader* uploader, gint num_published) {
	PublishingRESTSupportBatchUploader* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
	PublishingRESTSupportBatchUploader* _tmp2_ = NULL;
	guint _tmp3_ = 0U;
#line 834 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self));
#line 834 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_BATCH_UPLOADER (uploader));
#line 835 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_debug ("PiwigoPublishing.vala:835: EVENT: on_upload_complete");
#line 836 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = uploader;
#line 836 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_parse_name ("upload-complete", PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, &_tmp1_, NULL, FALSE);
#line 836 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_piwigo_piwigo_publisher_on_upload_complete_publishing_rest_support_batch_uploader_upload_complete, self);
#line 837 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = uploader;
#line 837 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_parse_name ("upload-error", PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, &_tmp3_, NULL, FALSE);
#line 837 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp2_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _publishing_piwigo_piwigo_publisher_on_upload_error_publishing_rest_support_batch_uploader_upload_error, self);
#line 841 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_piwigo_publisher_do_show_success_pane (self);
#line 6018 "PiwigoPublishing.c"
}


/**
     * Event triggered when the batch uploader reports that at least one of the
     * network transactions encapsulating uploads has caused a network error
     */
static void publishing_piwigo_piwigo_publisher_on_upload_error (PublishingPiwigoPiwigoPublisher* self, PublishingRESTSupportBatchUploader* uploader, GError* err) {
	PublishingRESTSupportBatchUploader* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
	PublishingRESTSupportBatchUploader* _tmp2_ = NULL;
	guint _tmp3_ = 0U;
	GError* _tmp4_ = NULL;
#line 848 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self));
#line 848 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_BATCH_UPLOADER (uploader));
#line 852 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_debug ("PiwigoPublishing.vala:852: EVENT: on_upload_error");
#line 853 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = uploader;
#line 853 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_parse_name ("upload-complete", PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, &_tmp1_, NULL, FALSE);
#line 853 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_piwigo_piwigo_publisher_on_upload_complete_publishing_rest_support_batch_uploader_upload_complete, self);
#line 854 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = uploader;
#line 854 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_parse_name ("upload-error", PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, &_tmp3_, NULL, FALSE);
#line 854 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp2_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _publishing_piwigo_piwigo_publisher_on_upload_error_publishing_rest_support_batch_uploader_upload_error, self);
#line 856 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = err;
#line 856 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_piwigo_publisher_do_show_error (self, _tmp4_);
#line 6054 "PiwigoPublishing.c"
}


/**
     * Event triggered when upload progresses and the status needs to be updated.
     */
static void publishing_piwigo_piwigo_publisher_on_upload_status_updated (PublishingPiwigoPiwigoPublisher* self, gint file_number, gdouble completed_fraction) {
	gboolean _tmp0_ = FALSE;
	gdouble _tmp1_ = 0.0;
	SpitPublishingProgressCallback _tmp2_ = NULL;
	void* _tmp2__target = NULL;
	SpitPublishingProgressCallback _tmp3_ = NULL;
	void* _tmp3__target = NULL;
	gint _tmp4_ = 0;
	gdouble _tmp5_ = 0.0;
#line 862 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self));
#line 863 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher));
#line 863 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (!_tmp0_) {
#line 864 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		return;
#line 6078 "PiwigoPublishing.c"
	}
#line 866 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = completed_fraction;
#line 866 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_debug ("PiwigoPublishing.vala:866: EVENT: uploader reports upload %.2f percent" \
" complete.", 100.0 * _tmp1_);
#line 868 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = self->priv->progress_reporter;
#line 868 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2__target = self->priv->progress_reporter_target;
#line 868 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_vala_assert (_tmp2_ != NULL, "progress_reporter != null");
#line 870 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3_ = self->priv->progress_reporter;
#line 870 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3__target = self->priv->progress_reporter_target;
#line 870 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = file_number;
#line 870 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp5_ = completed_fraction;
#line 870 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3_ (_tmp4_, _tmp5_, _tmp3__target);
#line 6100 "PiwigoPublishing.c"
}


/**
     * Action to display the success pane in the publishing dialog.
     */
static void publishing_piwigo_piwigo_publisher_do_show_success_pane (PublishingPiwigoPiwigoPublisher* self) {
	SpitPublishingPluginHost* _tmp0_ = NULL;
	SpitPublishingPluginHost* _tmp1_ = NULL;
#line 876 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self));
#line 877 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_debug ("PiwigoPublishing.vala:877: ACTION: installing success pane");
#line 879 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->host;
#line 879 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	spit_publishing_plugin_host_set_service_locked (_tmp0_, FALSE);
#line 880 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = self->priv->host;
#line 880 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	spit_publishing_plugin_host_install_success_pane (_tmp1_);
#line 6122 "PiwigoPublishing.c"
}


/**
     * Helper event to handle network errors.
     */
static void publishing_piwigo_piwigo_publisher_on_network_error (PublishingPiwigoPiwigoPublisher* self, PublishingRESTSupportTransaction* bad_txn, GError* err) {
	GError* _tmp0_ = NULL;
#line 886 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self));
#line 886 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_TRANSACTION (bad_txn));
#line 890 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_debug ("PiwigoPublishing.vala:890: EVENT: on_network_error");
#line 891 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = err;
#line 891 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_piwigo_publisher_do_show_error (self, _tmp0_);
#line 6141 "PiwigoPublishing.c"
}


/**
     * Action to display an error to the user.
     */
static void publishing_piwigo_piwigo_publisher_do_show_error (PublishingPiwigoPiwigoPublisher* self, GError* e) {
	gchar* error_type = NULL;
	gchar* _tmp0_ = NULL;
	GError* _tmp1_ = NULL;
	const gchar* _tmp16_ = NULL;
	GError* _tmp17_ = NULL;
	const gchar* _tmp18_ = NULL;
	gchar* _tmp19_ = NULL;
	gchar* _tmp20_ = NULL;
	const gchar* _tmp21_ = NULL;
#line 897 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self));
#line 898 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_debug ("PiwigoPublishing.vala:898: ACTION: do_show_error");
#line 899 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = g_strdup ("UNKNOWN");
#line 899 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	error_type = _tmp0_;
#line 900 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = e;
#line 900 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (g_error_matches (_tmp1_, SPIT_PUBLISHING_PUBLISHING_ERROR, SPIT_PUBLISHING_PUBLISHING_ERROR_NO_ANSWER)) {
#line 901 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_piwigo_piwigo_publisher_do_show_authentication_pane (self, PUBLISHING_PIWIGO_AUTHENTICATION_PANE_MODE_FAILED_RETRY_URL);
#line 902 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_free0 (error_type);
#line 902 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		return;
#line 6176 "PiwigoPublishing.c"
	} else {
		GError* _tmp2_ = NULL;
#line 903 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp2_ = e;
#line 903 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		if (g_error_matches (_tmp2_, SPIT_PUBLISHING_PUBLISHING_ERROR, SPIT_PUBLISHING_PUBLISHING_ERROR_COMMUNICATION_FAILED)) {
#line 6183 "PiwigoPublishing.c"
			gchar* _tmp3_ = NULL;
#line 904 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp3_ = g_strdup ("COMMUNICATION_FAILED");
#line 904 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_g_free0 (error_type);
#line 904 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			error_type = _tmp3_;
#line 6191 "PiwigoPublishing.c"
		} else {
			GError* _tmp4_ = NULL;
#line 905 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp4_ = e;
#line 905 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			if (g_error_matches (_tmp4_, SPIT_PUBLISHING_PUBLISHING_ERROR, SPIT_PUBLISHING_PUBLISHING_ERROR_PROTOCOL_ERROR)) {
#line 6198 "PiwigoPublishing.c"
				gchar* _tmp5_ = NULL;
#line 906 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp5_ = g_strdup ("PROTOCOL_ERROR");
#line 906 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_g_free0 (error_type);
#line 906 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				error_type = _tmp5_;
#line 6206 "PiwigoPublishing.c"
			} else {
				GError* _tmp6_ = NULL;
#line 907 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp6_ = e;
#line 907 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				if (g_error_matches (_tmp6_, SPIT_PUBLISHING_PUBLISHING_ERROR, SPIT_PUBLISHING_PUBLISHING_ERROR_SERVICE_ERROR)) {
#line 6213 "PiwigoPublishing.c"
					gchar* _tmp7_ = NULL;
#line 908 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_tmp7_ = g_strdup ("SERVICE_ERROR");
#line 908 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_g_free0 (error_type);
#line 908 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					error_type = _tmp7_;
#line 6221 "PiwigoPublishing.c"
				} else {
					GError* _tmp8_ = NULL;
#line 909 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_tmp8_ = e;
#line 909 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					if (g_error_matches (_tmp8_, SPIT_PUBLISHING_PUBLISHING_ERROR, SPIT_PUBLISHING_PUBLISHING_ERROR_MALFORMED_RESPONSE)) {
#line 6228 "PiwigoPublishing.c"
						gchar* _tmp9_ = NULL;
#line 910 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
						_tmp9_ = g_strdup ("MALFORMED_RESPONSE");
#line 910 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
						_g_free0 (error_type);
#line 910 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
						error_type = _tmp9_;
#line 6236 "PiwigoPublishing.c"
					} else {
						GError* _tmp10_ = NULL;
#line 911 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
						_tmp10_ = e;
#line 911 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
						if (g_error_matches (_tmp10_, SPIT_PUBLISHING_PUBLISHING_ERROR, SPIT_PUBLISHING_PUBLISHING_ERROR_LOCAL_FILE_ERROR)) {
#line 6243 "PiwigoPublishing.c"
							gchar* _tmp11_ = NULL;
#line 912 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
							_tmp11_ = g_strdup ("LOCAL_FILE_ERROR");
#line 912 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
							_g_free0 (error_type);
#line 912 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
							error_type = _tmp11_;
#line 6251 "PiwigoPublishing.c"
						} else {
							GError* _tmp12_ = NULL;
#line 913 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
							_tmp12_ = e;
#line 913 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
							if (g_error_matches (_tmp12_, SPIT_PUBLISHING_PUBLISHING_ERROR, SPIT_PUBLISHING_PUBLISHING_ERROR_EXPIRED_SESSION)) {
#line 6258 "PiwigoPublishing.c"
								gchar* _tmp13_ = NULL;
#line 914 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
								_tmp13_ = g_strdup ("EXPIRED_SESSION");
#line 914 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
								_g_free0 (error_type);
#line 914 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
								error_type = _tmp13_;
#line 6266 "PiwigoPublishing.c"
							} else {
								GError* _tmp14_ = NULL;
#line 915 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
								_tmp14_ = e;
#line 915 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
								if (g_error_matches (_tmp14_, SPIT_PUBLISHING_PUBLISHING_ERROR, SPIT_PUBLISHING_PUBLISHING_ERROR_SSL_FAILED)) {
#line 6273 "PiwigoPublishing.c"
									gchar* _tmp15_ = NULL;
#line 916 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
									_tmp15_ = g_strdup ("SECURE_CONNECTION_FAILED");
#line 916 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
									_g_free0 (error_type);
#line 916 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
									error_type = _tmp15_;
#line 6281 "PiwigoPublishing.c"
								}
							}
						}
					}
				}
			}
		}
	}
#line 919 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp16_ = error_type;
#line 919 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp17_ = e;
#line 919 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp18_ = _tmp17_->message;
#line 919 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp19_ = g_strdup_printf ("Unhandled error: type=%s; message='%s'", _tmp16_, _tmp18_);
#line 919 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp20_ = _tmp19_;
#line 919 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_debug ("PiwigoPublishing.vala:919: %s", _tmp20_);
#line 919 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (_tmp20_);
#line 920 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp21_ = _ ("An error message occurred when publishing to Piwigo. Please try again.");
#line 920 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_piwigo_publisher_do_show_error_message (self, _tmp21_);
#line 897 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (error_type);
#line 6310 "PiwigoPublishing.c"
}


/**
     * Action to display an error message to the user.
     */
static void publishing_piwigo_piwigo_publisher_do_show_error_message (PublishingPiwigoPiwigoPublisher* self, const gchar* message) {
	SpitPublishingPluginHost* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
#line 926 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self));
#line 926 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (message != NULL);
#line 927 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_debug ("PiwigoPublishing.vala:927: ACTION: do_show_error_message");
#line 928 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->host;
#line 928 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = message;
#line 928 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	spit_publishing_plugin_host_install_static_message_pane (_tmp0_, _tmp1_, SPIT_PUBLISHING_PLUGIN_HOST_BUTTON_MODE_CLOSE);
#line 6332 "PiwigoPublishing.c"
}


/**
     * Retrieves session ID from a REST Transaction received
     *
     * This helper method extracts the pwg_id out of the Set-Cookie header if
     * present in the received transaction.
     *
     * @param txn the received transaction
     * @return the value of pwg_id if present or null if not found
     */
static SoupCookie* _vala_SoupCookie_copy (SoupCookie* self) {
#line 946 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return g_boxed_copy (soup_cookie_get_type (), self);
#line 6348 "PiwigoPublishing.c"
}


static gpointer __vala_SoupCookie_copy0 (gpointer self) {
#line 946 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return self ? _vala_SoupCookie_copy (self) : NULL;
#line 6355 "PiwigoPublishing.c"
}


static void _vala_SoupCookie_free (SoupCookie* self) {
#line 946 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_boxed_free (soup_cookie_get_type (), self);
#line 6362 "PiwigoPublishing.c"
}


static void __vala_SoupCookie_free0_ (gpointer var) {
#line 946 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	(var == NULL) ? NULL : (var = (_vala_SoupCookie_free (var), NULL));
#line 6369 "PiwigoPublishing.c"
}


static void _g_slist_free___vala_SoupCookie_free0_ (GSList* self) {
#line 946 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_slist_foreach (self, (GFunc) __vala_SoupCookie_free0_, NULL);
#line 946 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_slist_free (self);
#line 6378 "PiwigoPublishing.c"
}


static gchar* publishing_piwigo_piwigo_publisher_get_pwg_id_from_transaction (PublishingPiwigoPiwigoPublisher* self, PublishingRESTSupportTransaction* txn) {
	gchar* result = NULL;
	gchar* pwg_id = NULL;
	PublishingRESTSupportTransaction* _tmp0_ = NULL;
	SoupMessage* _tmp1_ = NULL;
	SoupMessage* _tmp2_ = NULL;
	GSList* _tmp3_ = NULL;
	GSList* _tmp4_ = NULL;
#line 943 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self), NULL);
#line 943 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_REST_SUPPORT_IS_TRANSACTION (txn), NULL);
#line 944 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	pwg_id = NULL;
#line 946 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = txn;
#line 946 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = publishing_rest_support_transaction_get_message (_tmp0_);
#line 946 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = _tmp1_;
#line 946 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3_ = soup_cookies_from_response (_tmp2_);
#line 946 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = _tmp3_;
#line 946 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (_tmp2_);
#line 6408 "PiwigoPublishing.c"
	{
		GSList* cookie_collection = NULL;
		GSList* cookie_it = NULL;
#line 946 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		cookie_collection = _tmp4_;
#line 946 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		for (cookie_it = cookie_collection; cookie_it != NULL; cookie_it = cookie_it->next) {
#line 6416 "PiwigoPublishing.c"
			SoupCookie* _tmp5_ = NULL;
			SoupCookie* cookie = NULL;
#line 946 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp5_ = __vala_SoupCookie_copy0 ((SoupCookie*) cookie_it->data);
#line 946 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			cookie = _tmp5_;
#line 6423 "PiwigoPublishing.c"
			{
				SoupCookie* _tmp6_ = NULL;
				const gchar* _tmp7_ = NULL;
#line 947 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp6_ = cookie;
#line 947 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp7_ = soup_cookie_get_name (_tmp6_);
#line 947 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				if (g_strcmp0 (_tmp7_, "pwg_id") == 0) {
#line 6433 "PiwigoPublishing.c"
					SoupCookie* _tmp8_ = NULL;
					const gchar* _tmp9_ = NULL;
					gchar* _tmp10_ = NULL;
					const gchar* _tmp11_ = NULL;
#line 950 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_tmp8_ = cookie;
#line 950 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_tmp9_ = soup_cookie_get_value (_tmp8_);
#line 950 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_tmp10_ = g_strdup (_tmp9_);
#line 950 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_g_free0 (pwg_id);
#line 950 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					pwg_id = _tmp10_;
#line 951 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_tmp11_ = pwg_id;
#line 951 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					g_debug ("PiwigoPublishing.vala:951: Found pwg_id %s", _tmp11_);
#line 6452 "PiwigoPublishing.c"
				}
#line 946 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				__vala_SoupCookie_free0 (cookie);
#line 6456 "PiwigoPublishing.c"
			}
		}
#line 946 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		__g_slist_free___vala_SoupCookie_free0_0 (cookie_collection);
#line 6461 "PiwigoPublishing.c"
	}
#line 955 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = pwg_id;
#line 955 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 6467 "PiwigoPublishing.c"
}


static void publishing_piwigo_piwigo_publisher_class_init (PublishingPiwigoPiwigoPublisherClass * klass) {
#line 121 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_piwigo_publisher_parent_class = g_type_class_peek_parent (klass);
#line 121 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_type_class_add_private (klass, sizeof (PublishingPiwigoPiwigoPublisherPrivate));
#line 121 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	G_OBJECT_CLASS (klass)->finalize = publishing_piwigo_piwigo_publisher_finalize;
#line 6478 "PiwigoPublishing.c"
}


static void publishing_piwigo_piwigo_publisher_spit_publishing_publisher_interface_init (SpitPublishingPublisherIface * iface) {
#line 121 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_piwigo_publisher_spit_publishing_publisher_parent_iface = g_type_interface_peek_parent (iface);
#line 121 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	iface->get_service = (SpitPublishingService* (*)(SpitPublishingPublisher*)) publishing_piwigo_piwigo_publisher_real_get_service;
#line 121 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	iface->is_running = (gboolean (*)(SpitPublishingPublisher*)) publishing_piwigo_piwigo_publisher_real_is_running;
#line 121 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	iface->start = (void (*)(SpitPublishingPublisher*)) publishing_piwigo_piwigo_publisher_real_start;
#line 121 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	iface->stop = (void (*)(SpitPublishingPublisher*)) publishing_piwigo_piwigo_publisher_real_stop;
#line 6493 "PiwigoPublishing.c"
}


static void publishing_piwigo_piwigo_publisher_instance_init (PublishingPiwigoPiwigoPublisher * self) {
#line 121 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv = PUBLISHING_PIWIGO_PIWIGO_PUBLISHER_GET_PRIVATE (self);
#line 124 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->running = FALSE;
#line 125 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->strip_metadata = FALSE;
#line 127 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->categories = NULL;
#line 127 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->categories_length1 = 0;
#line 127 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->_categories_size_ = self->priv->categories_length1;
#line 128 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->parameters = NULL;
#line 129 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->progress_reporter = NULL;
#line 6514 "PiwigoPublishing.c"
}


static void publishing_piwigo_piwigo_publisher_finalize (GObject* obj) {
	PublishingPiwigoPiwigoPublisher * self;
#line 121 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_PIWIGO_TYPE_PIWIGO_PUBLISHER, PublishingPiwigoPiwigoPublisher);
#line 122 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (self->priv->service);
#line 123 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (self->priv->host);
#line 126 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_publishing_rest_support_session_unref0 (self->priv->session);
#line 127 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->categories = (_vala_array_free (self->priv->categories, self->priv->categories_length1, (GDestroyNotify) publishing_piwigo_category_unref), NULL);
#line 128 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_publishing_piwigo_publishing_parameters_unref0 (self->priv->parameters);
#line 129 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	(self->priv->progress_reporter_target_destroy_notify == NULL) ? NULL : (self->priv->progress_reporter_target_destroy_notify (self->priv->progress_reporter_target), NULL);
#line 129 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->progress_reporter = NULL;
#line 129 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->progress_reporter_target = NULL;
#line 129 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->progress_reporter_target_destroy_notify = NULL;
#line 121 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	G_OBJECT_CLASS (publishing_piwigo_piwigo_publisher_parent_class)->finalize (obj);
#line 6542 "PiwigoPublishing.c"
}


GType publishing_piwigo_piwigo_publisher_get_type (void) {
	static volatile gsize publishing_piwigo_piwigo_publisher_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_piwigo_piwigo_publisher_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingPiwigoPiwigoPublisherClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_piwigo_piwigo_publisher_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingPiwigoPiwigoPublisher), 0, (GInstanceInitFunc) publishing_piwigo_piwigo_publisher_instance_init, NULL };
		static const GInterfaceInfo spit_publishing_publisher_info = { (GInterfaceInitFunc) publishing_piwigo_piwigo_publisher_spit_publishing_publisher_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType publishing_piwigo_piwigo_publisher_type_id;
		publishing_piwigo_piwigo_publisher_type_id = g_type_register_static (G_TYPE_OBJECT, "PublishingPiwigoPiwigoPublisher", &g_define_type_info, 0);
		g_type_add_interface_static (publishing_piwigo_piwigo_publisher_type_id, SPIT_PUBLISHING_TYPE_PUBLISHER, &spit_publishing_publisher_info);
		g_once_init_leave (&publishing_piwigo_piwigo_publisher_type_id__volatile, publishing_piwigo_piwigo_publisher_type_id);
	}
	return publishing_piwigo_piwigo_publisher_type_id__volatile;
}


PublishingPiwigoUploader* publishing_piwigo_uploader_construct (GType object_type, PublishingPiwigoSession* session, SpitPublishingPublishable** publishables, int publishables_length1, PublishingPiwigoPublishingParameters* parameters) {
	PublishingPiwigoUploader* self = NULL;
	PublishingPiwigoSession* _tmp0_ = NULL;
	SpitPublishingPublishable** _tmp1_ = NULL;
	gint _tmp1__length1 = 0;
	PublishingPiwigoPublishingParameters* _tmp2_ = NULL;
	PublishingPiwigoPublishingParameters* _tmp3_ = NULL;
#line 964 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_SESSION (session), NULL);
#line 964 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_PUBLISHING_PARAMETERS (parameters), NULL);
#line 966 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = session;
#line 966 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = publishables;
#line 966 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1__length1 = publishables_length1;
#line 966 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = (PublishingPiwigoUploader*) publishing_rest_support_batch_uploader_construct (object_type, G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession), _tmp1_, _tmp1__length1);
#line 968 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = parameters;
#line 968 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3_ = _publishing_piwigo_publishing_parameters_ref0 (_tmp2_);
#line 968 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_publishing_piwigo_publishing_parameters_unref0 (self->priv->parameters);
#line 968 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->parameters = _tmp3_;
#line 964 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return self;
#line 6589 "PiwigoPublishing.c"
}


PublishingPiwigoUploader* publishing_piwigo_uploader_new (PublishingPiwigoSession* session, SpitPublishingPublishable** publishables, int publishables_length1, PublishingPiwigoPublishingParameters* parameters) {
#line 964 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return publishing_piwigo_uploader_construct (PUBLISHING_PIWIGO_TYPE_UPLOADER, session, publishables, publishables_length1, parameters);
#line 6596 "PiwigoPublishing.c"
}


static PublishingRESTSupportTransaction* publishing_piwigo_uploader_real_create_transaction (PublishingRESTSupportBatchUploader* base, SpitPublishingPublishable* publishable) {
	PublishingPiwigoUploader * self;
	PublishingRESTSupportTransaction* result = NULL;
	PublishingRESTSupportSession* _tmp0_ = NULL;
	PublishingPiwigoSession* _tmp1_ = NULL;
	PublishingPiwigoPublishingParameters* _tmp2_ = NULL;
	SpitPublishingPublishable* _tmp3_ = NULL;
	PublishingPiwigoImagesAddTransaction* _tmp4_ = NULL;
	PublishingRESTSupportTransaction* _tmp5_ = NULL;
#line 971 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_PIWIGO_TYPE_UPLOADER, PublishingPiwigoUploader);
#line 971 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (SPIT_PUBLISHING_IS_PUBLISHABLE (publishable), NULL);
#line 973 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = publishing_rest_support_batch_uploader_get_session (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, PublishingRESTSupportBatchUploader));
#line 973 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, PUBLISHING_PIWIGO_TYPE_SESSION, PublishingPiwigoSession);
#line 973 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = self->priv->parameters;
#line 973 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3_ = publishable;
#line 973 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = publishing_piwigo_images_add_transaction_new (_tmp1_, _tmp2_, _tmp3_);
#line 973 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp5_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction);
#line 973 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_publishing_rest_support_session_unref0 (_tmp1_);
#line 973 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = _tmp5_;
#line 973 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 6631 "PiwigoPublishing.c"
}


static void publishing_piwigo_uploader_class_init (PublishingPiwigoUploaderClass * klass) {
#line 961 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_uploader_parent_class = g_type_class_peek_parent (klass);
#line 961 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	((PublishingRESTSupportBatchUploaderClass *) klass)->finalize = publishing_piwigo_uploader_finalize;
#line 961 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_type_class_add_private (klass, sizeof (PublishingPiwigoUploaderPrivate));
#line 961 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	((PublishingRESTSupportBatchUploaderClass *) klass)->create_transaction = publishing_piwigo_uploader_real_create_transaction;
#line 6644 "PiwigoPublishing.c"
}


static void publishing_piwigo_uploader_instance_init (PublishingPiwigoUploader * self) {
#line 961 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv = PUBLISHING_PIWIGO_UPLOADER_GET_PRIVATE (self);
#line 6651 "PiwigoPublishing.c"
}


static void publishing_piwigo_uploader_finalize (PublishingRESTSupportBatchUploader* obj) {
	PublishingPiwigoUploader * self;
#line 961 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_PIWIGO_TYPE_UPLOADER, PublishingPiwigoUploader);
#line 962 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_publishing_piwigo_publishing_parameters_unref0 (self->priv->parameters);
#line 961 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	PUBLISHING_REST_SUPPORT_BATCH_UPLOADER_CLASS (publishing_piwigo_uploader_parent_class)->finalize (obj);
#line 6663 "PiwigoPublishing.c"
}


GType publishing_piwigo_uploader_get_type (void) {
	static volatile gsize publishing_piwigo_uploader_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_piwigo_uploader_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingPiwigoUploaderClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_piwigo_uploader_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingPiwigoUploader), 0, (GInstanceInitFunc) publishing_piwigo_uploader_instance_init, NULL };
		GType publishing_piwigo_uploader_type_id;
		publishing_piwigo_uploader_type_id = g_type_register_static (PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, "PublishingPiwigoUploader", &g_define_type_info, 0);
		g_once_init_leave (&publishing_piwigo_uploader_type_id__volatile, publishing_piwigo_uploader_type_id);
	}
	return publishing_piwigo_uploader_type_id__volatile;
}


GType publishing_piwigo_authentication_pane_mode_get_type (void) {
	static volatile gsize publishing_piwigo_authentication_pane_mode_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_piwigo_authentication_pane_mode_type_id__volatile)) {
		static const GEnumValue values[] = {{PUBLISHING_PIWIGO_AUTHENTICATION_PANE_MODE_INTRO, "PUBLISHING_PIWIGO_AUTHENTICATION_PANE_MODE_INTRO", "intro"}, {PUBLISHING_PIWIGO_AUTHENTICATION_PANE_MODE_FAILED_RETRY_URL, "PUBLISHING_PIWIGO_AUTHENTICATION_PANE_MODE_FAILED_RETRY_URL", "failed-retry-url"}, {PUBLISHING_PIWIGO_AUTHENTICATION_PANE_MODE_FAILED_RETRY_USER, "PUBLISHING_PIWIGO_AUTHENTICATION_PANE_MODE_FAILED_RETRY_USER", "failed-retry-user"}, {0, NULL, NULL}};
		GType publishing_piwigo_authentication_pane_mode_type_id;
		publishing_piwigo_authentication_pane_mode_type_id = g_enum_register_static ("PublishingPiwigoAuthenticationPaneMode", values);
		g_once_init_leave (&publishing_piwigo_authentication_pane_mode_type_id__volatile, publishing_piwigo_authentication_pane_mode_type_id);
	}
	return publishing_piwigo_authentication_pane_mode_type_id__volatile;
}


static void _publishing_piwigo_authentication_pane_on_user_changed_gtk_editable_changed (GtkEditable* _sender, gpointer self) {
#line 1051 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_authentication_pane_on_user_changed ((PublishingPiwigoAuthenticationPane*) self);
#line 6694 "PiwigoPublishing.c"
}


static void _publishing_piwigo_authentication_pane_on_url_changed_gtk_editable_changed (GtkEditable* _sender, gpointer self) {
#line 1052 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_authentication_pane_on_url_changed ((PublishingPiwigoAuthenticationPane*) self);
#line 6701 "PiwigoPublishing.c"
}


static void _publishing_piwigo_authentication_pane_on_password_changed_gtk_editable_changed (GtkEditable* _sender, gpointer self) {
#line 1053 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_authentication_pane_on_password_changed ((PublishingPiwigoAuthenticationPane*) self);
#line 6708 "PiwigoPublishing.c"
}


static void _publishing_piwigo_authentication_pane_on_login_button_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 1054 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_authentication_pane_on_login_button_clicked ((PublishingPiwigoAuthenticationPane*) self);
#line 6715 "PiwigoPublishing.c"
}


PublishingPiwigoAuthenticationPane* publishing_piwigo_authentication_pane_construct (GType object_type, PublishingPiwigoPiwigoPublisher* publisher, PublishingPiwigoAuthenticationPaneMode mode) {
	PublishingPiwigoAuthenticationPane * self = NULL;
	GtkBox* _tmp0_ = NULL;
	GError * _inner_error_ = NULL;
#line 1004 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (publisher), NULL);
#line 1004 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = (PublishingPiwigoAuthenticationPane*) g_object_new (object_type, NULL);
#line 1005 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
#line 1005 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_object_ref_sink (_tmp0_);
#line 1005 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (self->priv->pane_widget);
#line 1005 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->pane_widget = _tmp0_;
#line 6735 "PiwigoPublishing.c"
	{
		GtkBuilder* _tmp1_ = NULL;
		GtkBuilder* _tmp2_ = NULL;
		GtkBuilder* _tmp3_ = NULL;
		GtkAlignment* align = NULL;
		GtkBuilder* _tmp4_ = NULL;
		GObject* _tmp5_ = NULL;
		GtkAlignment* _tmp6_ = NULL;
		GtkLabel* message_label = NULL;
		GtkBuilder* _tmp7_ = NULL;
		GObject* _tmp8_ = NULL;
		GtkLabel* _tmp9_ = NULL;
		PublishingPiwigoAuthenticationPaneMode _tmp10_ = 0;
		GtkBuilder* _tmp23_ = NULL;
		GObject* _tmp24_ = NULL;
		GtkEntry* _tmp25_ = NULL;
		gchar* persistent_url = NULL;
		PublishingPiwigoPiwigoPublisher* _tmp26_ = NULL;
		gchar* _tmp27_ = NULL;
		const gchar* _tmp28_ = NULL;
		GtkBuilder* _tmp31_ = NULL;
		GObject* _tmp32_ = NULL;
		GtkEntry* _tmp33_ = NULL;
		gchar* persistent_username = NULL;
		PublishingPiwigoPiwigoPublisher* _tmp34_ = NULL;
		gchar* _tmp35_ = NULL;
		const gchar* _tmp36_ = NULL;
		GtkBuilder* _tmp39_ = NULL;
		GObject* _tmp40_ = NULL;
		GtkEntry* _tmp41_ = NULL;
		gchar* persistent_password = NULL;
		PublishingPiwigoPiwigoPublisher* _tmp42_ = NULL;
		gchar* _tmp43_ = NULL;
		const gchar* _tmp44_ = NULL;
		GtkBuilder* _tmp47_ = NULL;
		GObject* _tmp48_ = NULL;
		GtkCheckButton* _tmp49_ = NULL;
		GtkCheckButton* _tmp50_ = NULL;
		PublishingPiwigoPiwigoPublisher* _tmp51_ = NULL;
		gboolean _tmp52_ = FALSE;
		GtkBuilder* _tmp53_ = NULL;
		GObject* _tmp54_ = NULL;
		GtkButton* _tmp55_ = NULL;
		GtkEntry* _tmp56_ = NULL;
		GtkEntry* _tmp57_ = NULL;
		GtkEntry* _tmp58_ = NULL;
		GtkButton* _tmp59_ = NULL;
		GtkAlignment* _tmp60_ = NULL;
		GtkBox* _tmp61_ = NULL;
		PublishingPiwigoPiwigoPublisher* _tmp62_ = NULL;
		SpitPublishingPluginHost* _tmp63_ = NULL;
		SpitPublishingPluginHost* _tmp64_ = NULL;
		GtkButton* _tmp65_ = NULL;
#line 1008 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp1_ = gtk_builder_new ();
#line 1008 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_object_unref0 (self->priv->builder);
#line 1008 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		self->priv->builder = _tmp1_;
#line 1009 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp2_ = self->priv->builder;
#line 1009 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		gtk_builder_add_from_resource (_tmp2_, PLUGIN_RESOURCE_PATH "/piwigo_authentication_pane.ui", &_inner_error_);
#line 1009 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 6801 "PiwigoPublishing.c"
			goto __catch44_g_error;
		}
#line 1010 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp3_ = self->priv->builder;
#line 1010 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		gtk_builder_connect_signals (_tmp3_, NULL);
#line 1011 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp4_ = self->priv->builder;
#line 1011 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp5_ = gtk_builder_get_object (_tmp4_, "alignment");
#line 1011 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp6_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp5_, gtk_alignment_get_type ()) ? ((GtkAlignment*) _tmp5_) : NULL);
#line 1011 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		align = _tmp6_;
#line 1013 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp7_ = self->priv->builder;
#line 1013 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp8_ = gtk_builder_get_object (_tmp7_, "message_label");
#line 1013 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp9_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp8_, gtk_label_get_type ()) ? ((GtkLabel*) _tmp8_) : NULL);
#line 1013 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		message_label = _tmp9_;
#line 1014 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp10_ = mode;
#line 1014 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		switch (_tmp10_) {
#line 1014 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			case PUBLISHING_PIWIGO_AUTHENTICATION_PANE_MODE_INTRO:
#line 6830 "PiwigoPublishing.c"
			{
				GtkLabel* _tmp11_ = NULL;
				const gchar* _tmp12_ = NULL;
#line 1016 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp11_ = message_label;
#line 1016 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp12_ = publishing_piwigo_authentication_pane_INTRO_MESSAGE;
#line 1016 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				gtk_label_set_text (_tmp11_, _tmp12_);
#line 1017 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				break;
#line 6842 "PiwigoPublishing.c"
			}
#line 1014 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			case PUBLISHING_PIWIGO_AUTHENTICATION_PANE_MODE_FAILED_RETRY_URL:
#line 6846 "PiwigoPublishing.c"
			{
				GtkLabel* _tmp13_ = NULL;
				const gchar* _tmp14_ = NULL;
				const gchar* _tmp15_ = NULL;
				gchar* _tmp16_ = NULL;
				gchar* _tmp17_ = NULL;
#line 1020 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp13_ = message_label;
#line 1020 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp14_ = _ ("Invalid URL");
#line 1020 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp15_ = publishing_piwigo_authentication_pane_FAILED_RETRY_URL_MESSAGE;
#line 1020 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp16_ = g_strdup_printf ("<b>%s</b>\n\n%s", _tmp14_, _tmp15_);
#line 1020 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp17_ = _tmp16_;
#line 1020 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				gtk_label_set_markup (_tmp13_, _tmp17_);
#line 1020 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_g_free0 (_tmp17_);
#line 1022 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				break;
#line 6869 "PiwigoPublishing.c"
			}
#line 1014 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			case PUBLISHING_PIWIGO_AUTHENTICATION_PANE_MODE_FAILED_RETRY_USER:
#line 6873 "PiwigoPublishing.c"
			{
				GtkLabel* _tmp18_ = NULL;
				const gchar* _tmp19_ = NULL;
				const gchar* _tmp20_ = NULL;
				gchar* _tmp21_ = NULL;
				gchar* _tmp22_ = NULL;
#line 1025 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp18_ = message_label;
#line 1025 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp19_ = _ ("Invalid User Name or Password");
#line 1025 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp20_ = publishing_piwigo_authentication_pane_FAILED_RETRY_USER_MESSAGE;
#line 1025 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp21_ = g_strdup_printf ("<b>%s</b>\n\n%s", _tmp19_, _tmp20_);
#line 1025 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp22_ = _tmp21_;
#line 1025 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				gtk_label_set_markup (_tmp18_, _tmp22_);
#line 1025 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_g_free0 (_tmp22_);
#line 1027 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				break;
#line 6896 "PiwigoPublishing.c"
			}
			default:
#line 1014 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			break;
#line 6901 "PiwigoPublishing.c"
		}
#line 1030 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp23_ = self->priv->builder;
#line 1030 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp24_ = gtk_builder_get_object (_tmp23_, "url_entry");
#line 1030 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp25_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp24_, gtk_entry_get_type ()) ? ((GtkEntry*) _tmp24_) : NULL);
#line 1030 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_object_unref0 (self->priv->url_entry);
#line 1030 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		self->priv->url_entry = _tmp25_;
#line 1031 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp26_ = publisher;
#line 1031 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp27_ = publishing_piwigo_piwigo_publisher_get_persistent_url (_tmp26_);
#line 1031 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		persistent_url = _tmp27_;
#line 1032 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp28_ = persistent_url;
#line 1032 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		if (_tmp28_ != NULL) {
#line 6923 "PiwigoPublishing.c"
			GtkEntry* _tmp29_ = NULL;
			const gchar* _tmp30_ = NULL;
#line 1033 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp29_ = self->priv->url_entry;
#line 1033 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp30_ = persistent_url;
#line 1033 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			gtk_entry_set_text (_tmp29_, _tmp30_);
#line 6932 "PiwigoPublishing.c"
		}
#line 1035 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp31_ = self->priv->builder;
#line 1035 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp32_ = gtk_builder_get_object (_tmp31_, "username_entry");
#line 1035 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp33_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp32_, gtk_entry_get_type ()) ? ((GtkEntry*) _tmp32_) : NULL);
#line 1035 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_object_unref0 (self->priv->username_entry);
#line 1035 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		self->priv->username_entry = _tmp33_;
#line 1036 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp34_ = publisher;
#line 1036 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp35_ = publishing_piwigo_piwigo_publisher_get_persistent_username (_tmp34_);
#line 1036 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		persistent_username = _tmp35_;
#line 1037 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp36_ = persistent_username;
#line 1037 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		if (_tmp36_ != NULL) {
#line 6954 "PiwigoPublishing.c"
			GtkEntry* _tmp37_ = NULL;
			const gchar* _tmp38_ = NULL;
#line 1038 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp37_ = self->priv->username_entry;
#line 1038 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp38_ = persistent_username;
#line 1038 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			gtk_entry_set_text (_tmp37_, _tmp38_);
#line 6963 "PiwigoPublishing.c"
		}
#line 1040 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp39_ = self->priv->builder;
#line 1040 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp40_ = gtk_builder_get_object (_tmp39_, "password_entry");
#line 1040 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp41_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp40_, gtk_entry_get_type ()) ? ((GtkEntry*) _tmp40_) : NULL);
#line 1040 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_object_unref0 (self->priv->password_entry);
#line 1040 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		self->priv->password_entry = _tmp41_;
#line 1041 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp42_ = publisher;
#line 1041 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp43_ = publishing_piwigo_piwigo_publisher_get_persistent_password (_tmp42_);
#line 1041 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		persistent_password = _tmp43_;
#line 1042 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp44_ = persistent_password;
#line 1042 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		if (_tmp44_ != NULL) {
#line 6985 "PiwigoPublishing.c"
			GtkEntry* _tmp45_ = NULL;
			const gchar* _tmp46_ = NULL;
#line 1043 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp45_ = self->priv->password_entry;
#line 1043 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp46_ = persistent_password;
#line 1043 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			gtk_entry_set_text (_tmp45_, _tmp46_);
#line 6994 "PiwigoPublishing.c"
		}
#line 1045 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp47_ = self->priv->builder;
#line 1045 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp48_ = gtk_builder_get_object (_tmp47_, "remember_password_checkbutton");
#line 1045 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp49_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp48_, gtk_check_button_get_type ()) ? ((GtkCheckButton*) _tmp48_) : NULL);
#line 1045 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_object_unref0 (self->priv->remember_password_checkbutton);
#line 1045 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		self->priv->remember_password_checkbutton = _tmp49_;
#line 1047 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp50_ = self->priv->remember_password_checkbutton;
#line 1047 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp51_ = publisher;
#line 1047 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp52_ = publishing_piwigo_piwigo_publisher_get_remember_password (_tmp51_);
#line 1047 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		gtk_toggle_button_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp50_, gtk_toggle_button_get_type (), GtkToggleButton), _tmp52_);
#line 1049 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp53_ = self->priv->builder;
#line 1049 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp54_ = gtk_builder_get_object (_tmp53_, "login_button");
#line 1049 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp55_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp54_, gtk_button_get_type ()) ? ((GtkButton*) _tmp54_) : NULL);
#line 1049 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_object_unref0 (self->priv->login_button);
#line 1049 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		self->priv->login_button = _tmp55_;
#line 1051 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp56_ = self->priv->username_entry;
#line 1051 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp56_, GTK_TYPE_EDITABLE, GtkEditable), "changed", (GCallback) _publishing_piwigo_authentication_pane_on_user_changed_gtk_editable_changed, self, 0);
#line 1052 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp57_ = self->priv->url_entry;
#line 1052 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp57_, GTK_TYPE_EDITABLE, GtkEditable), "changed", (GCallback) _publishing_piwigo_authentication_pane_on_url_changed_gtk_editable_changed, self, 0);
#line 1053 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp58_ = self->priv->password_entry;
#line 1053 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp58_, GTK_TYPE_EDITABLE, GtkEditable), "changed", (GCallback) _publishing_piwigo_authentication_pane_on_password_changed_gtk_editable_changed, self, 0);
#line 1054 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp59_ = self->priv->login_button;
#line 1054 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_signal_connect_object (_tmp59_, "clicked", (GCallback) _publishing_piwigo_authentication_pane_on_login_button_clicked_gtk_button_clicked, self, 0);
#line 1056 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp60_ = align;
#line 1056 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp61_ = self->priv->pane_widget;
#line 1056 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		gtk_widget_reparent (G_TYPE_CHECK_INSTANCE_CAST (_tmp60_, gtk_widget_get_type (), GtkWidget), G_TYPE_CHECK_INSTANCE_CAST (_tmp61_, gtk_widget_get_type (), GtkWidget));
#line 1057 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp62_ = publisher;
#line 1057 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp63_ = publishing_piwigo_piwigo_publisher_get_host (_tmp62_);
#line 1057 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp64_ = _tmp63_;
#line 1057 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp65_ = self->priv->login_button;
#line 1057 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		spit_publishing_plugin_host_set_dialog_default_widget (_tmp64_, G_TYPE_CHECK_INSTANCE_CAST (_tmp65_, gtk_widget_get_type (), GtkWidget));
#line 1057 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_object_unref0 (_tmp64_);
#line 1007 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_free0 (persistent_password);
#line 1007 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_free0 (persistent_username);
#line 1007 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_free0 (persistent_url);
#line 1007 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_object_unref0 (message_label);
#line 1007 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_object_unref0 (align);
#line 7068 "PiwigoPublishing.c"
	}
	goto __finally44;
	__catch44_g_error:
	{
		GError* e = NULL;
		GError* _tmp66_ = NULL;
		const gchar* _tmp67_ = NULL;
#line 1007 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		e = _inner_error_;
#line 1007 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_inner_error_ = NULL;
#line 1059 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp66_ = e;
#line 1059 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp67_ = _tmp66_->message;
#line 1059 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_warning ("PiwigoPublishing.vala:1059: Could not load UI: %s", _tmp67_);
#line 1007 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_error_free0 (e);
#line 7088 "PiwigoPublishing.c"
	}
	__finally44:
#line 1007 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1007 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1007 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_clear_error (&_inner_error_);
#line 1007 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		return NULL;
#line 7099 "PiwigoPublishing.c"
	}
#line 1004 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return self;
#line 7103 "PiwigoPublishing.c"
}


PublishingPiwigoAuthenticationPane* publishing_piwigo_authentication_pane_new (PublishingPiwigoPiwigoPublisher* publisher, PublishingPiwigoAuthenticationPaneMode mode) {
#line 1004 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return publishing_piwigo_authentication_pane_construct (PUBLISHING_PIWIGO_TYPE_AUTHENTICATION_PANE, publisher, mode);
#line 7110 "PiwigoPublishing.c"
}


GtkWidget* publishing_piwigo_authentication_pane_get_default_widget (PublishingPiwigoAuthenticationPane* self) {
	GtkWidget* result = NULL;
	GtkButton* _tmp0_ = NULL;
	GtkWidget* _tmp1_ = NULL;
#line 1063 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_AUTHENTICATION_PANE (self), NULL);
#line 1064 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->login_button;
#line 1064 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_widget_get_type (), GtkWidget));
#line 1064 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = _tmp1_;
#line 1064 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 7128 "PiwigoPublishing.c"
}


static void publishing_piwigo_authentication_pane_on_login_button_clicked (PublishingPiwigoAuthenticationPane* self) {
	GtkEntry* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	GtkEntry* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	GtkEntry* _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
	GtkCheckButton* _tmp6_ = NULL;
	gboolean _tmp7_ = FALSE;
#line 1067 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_AUTHENTICATION_PANE (self));
#line 1068 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->url_entry;
#line 1068 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = gtk_entry_get_text (_tmp0_);
#line 1068 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = self->priv->username_entry;
#line 1068 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3_ = gtk_entry_get_text (_tmp2_);
#line 1068 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = self->priv->password_entry;
#line 1068 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp5_ = gtk_entry_get_text (_tmp4_);
#line 1068 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp6_ = self->priv->remember_password_checkbutton;
#line 1068 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp7_ = gtk_toggle_button_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, gtk_toggle_button_get_type (), GtkToggleButton));
#line 1068 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_emit_by_name (self, "login", _tmp1_, _tmp3_, _tmp5_, _tmp7_);
#line 7161 "PiwigoPublishing.c"
}


static void publishing_piwigo_authentication_pane_on_url_changed (PublishingPiwigoAuthenticationPane* self) {
#line 1072 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_AUTHENTICATION_PANE (self));
#line 1073 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_authentication_pane_update_login_button_sensitivity (self);
#line 7170 "PiwigoPublishing.c"
}


static void publishing_piwigo_authentication_pane_on_user_changed (PublishingPiwigoAuthenticationPane* self) {
#line 1076 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_AUTHENTICATION_PANE (self));
#line 1077 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_authentication_pane_update_login_button_sensitivity (self);
#line 7179 "PiwigoPublishing.c"
}


static void publishing_piwigo_authentication_pane_on_password_changed (PublishingPiwigoAuthenticationPane* self) {
#line 1080 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_AUTHENTICATION_PANE (self));
#line 1081 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_authentication_pane_update_login_button_sensitivity (self);
#line 7188 "PiwigoPublishing.c"
}


static void publishing_piwigo_authentication_pane_update_login_button_sensitivity (PublishingPiwigoAuthenticationPane* self) {
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	GtkEntry* _tmp2_ = NULL;
	guint _tmp3_ = 0U;
	guint _tmp4_ = 0U;
	GtkButton* _tmp11_ = NULL;
#line 1084 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_AUTHENTICATION_PANE (self));
#line 1085 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = self->priv->url_entry;
#line 1085 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3_ = gtk_entry_get_text_length (_tmp2_);
#line 1085 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = _tmp3_;
#line 1085 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (_tmp4_ != ((guint) 0)) {
#line 7209 "PiwigoPublishing.c"
		GtkEntry* _tmp5_ = NULL;
		guint _tmp6_ = 0U;
		guint _tmp7_ = 0U;
#line 1086 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp5_ = self->priv->username_entry;
#line 1086 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp6_ = gtk_entry_get_text_length (_tmp5_);
#line 1086 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp7_ = _tmp6_;
#line 1086 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp1_ = _tmp7_ != ((guint) 0);
#line 7221 "PiwigoPublishing.c"
	} else {
#line 1085 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp1_ = FALSE;
#line 7225 "PiwigoPublishing.c"
	}
#line 1085 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (_tmp1_) {
#line 7229 "PiwigoPublishing.c"
		GtkEntry* _tmp8_ = NULL;
		guint _tmp9_ = 0U;
		guint _tmp10_ = 0U;
#line 1087 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp8_ = self->priv->password_entry;
#line 1087 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp9_ = gtk_entry_get_text_length (_tmp8_);
#line 1087 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp10_ = _tmp9_;
#line 1087 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp0_ = _tmp10_ != ((guint) 0);
#line 7241 "PiwigoPublishing.c"
	} else {
#line 1085 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp0_ = FALSE;
#line 7245 "PiwigoPublishing.c"
	}
#line 1085 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp11_ = self->priv->login_button;
#line 1085 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp11_, gtk_widget_get_type (), GtkWidget), _tmp0_);
#line 7251 "PiwigoPublishing.c"
}


static GtkWidget* publishing_piwigo_authentication_pane_real_get_widget (SpitPublishingDialogPane* base) {
	PublishingPiwigoAuthenticationPane * self;
	GtkWidget* result = NULL;
	GtkBox* _tmp0_ = NULL;
	GtkWidget* _tmp1_ = NULL;
#line 1090 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_PIWIGO_TYPE_AUTHENTICATION_PANE, PublishingPiwigoAuthenticationPane);
#line 1091 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->pane_widget;
#line 1091 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_widget_get_type (), GtkWidget));
#line 1091 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = _tmp1_;
#line 1091 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 7270 "PiwigoPublishing.c"
}


static SpitPublishingDialogPaneGeometryOptions publishing_piwigo_authentication_pane_real_get_preferred_geometry (SpitPublishingDialogPane* base) {
	PublishingPiwigoAuthenticationPane * self;
	SpitPublishingDialogPaneGeometryOptions result = 0;
#line 1094 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_PIWIGO_TYPE_AUTHENTICATION_PANE, PublishingPiwigoAuthenticationPane);
#line 1095 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = SPIT_PUBLISHING_DIALOG_PANE_GEOMETRY_OPTIONS_NONE;
#line 1095 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 7283 "PiwigoPublishing.c"
}


static void publishing_piwigo_authentication_pane_real_on_pane_installed (SpitPublishingDialogPane* base) {
	PublishingPiwigoAuthenticationPane * self;
	GtkEntry* _tmp0_ = NULL;
	GtkEntry* _tmp1_ = NULL;
	GtkButton* _tmp2_ = NULL;
#line 1098 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_PIWIGO_TYPE_AUTHENTICATION_PANE, PublishingPiwigoAuthenticationPane);
#line 1099 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->url_entry;
#line 1099 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	gtk_widget_grab_focus (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_widget_get_type (), GtkWidget));
#line 1100 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = self->priv->password_entry;
#line 1100 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	gtk_entry_set_activates_default (_tmp1_, TRUE);
#line 1101 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = self->priv->login_button;
#line 1101 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	gtk_widget_set_can_default (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, gtk_widget_get_type (), GtkWidget), TRUE);
#line 1102 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_authentication_pane_update_login_button_sensitivity (self);
#line 7308 "PiwigoPublishing.c"
}


static void publishing_piwigo_authentication_pane_real_on_pane_uninstalled (SpitPublishingDialogPane* base) {
	PublishingPiwigoAuthenticationPane * self;
#line 1105 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_PIWIGO_TYPE_AUTHENTICATION_PANE, PublishingPiwigoAuthenticationPane);
#line 7316 "PiwigoPublishing.c"
}


static void g_cclosure_user_marshal_VOID__STRING_STRING_STRING_BOOLEAN (GClosure * closure, GValue * return_value, guint n_param_values, const GValue * param_values, gpointer invocation_hint, gpointer marshal_data) {
	typedef void (*GMarshalFunc_VOID__STRING_STRING_STRING_BOOLEAN) (gpointer data1, const char* arg_1, const char* arg_2, const char* arg_3, gboolean arg_4, gpointer data2);
	register GMarshalFunc_VOID__STRING_STRING_STRING_BOOLEAN callback;
	register GCClosure * cc;
	register gpointer data1;
	register gpointer data2;
	cc = (GCClosure *) closure;
#line 984 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (n_param_values == 5);
#line 984 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (G_CCLOSURE_SWAP_DATA (closure)) {
#line 984 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		data1 = closure->data;
#line 984 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		data2 = param_values->data[0].v_pointer;
#line 7335 "PiwigoPublishing.c"
	} else {
#line 984 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		data1 = param_values->data[0].v_pointer;
#line 984 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		data2 = closure->data;
#line 7341 "PiwigoPublishing.c"
	}
#line 984 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	callback = (GMarshalFunc_VOID__STRING_STRING_STRING_BOOLEAN) (marshal_data ? marshal_data : cc->callback);
#line 984 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	callback (data1, g_value_get_string (param_values + 1), g_value_get_string (param_values + 2), g_value_get_string (param_values + 3), g_value_get_boolean (param_values + 4), data2);
#line 7347 "PiwigoPublishing.c"
}


static void publishing_piwigo_authentication_pane_class_init (PublishingPiwigoAuthenticationPaneClass * klass) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
#line 984 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_authentication_pane_parent_class = g_type_class_peek_parent (klass);
#line 984 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_type_class_add_private (klass, sizeof (PublishingPiwigoAuthenticationPanePrivate));
#line 984 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	G_OBJECT_CLASS (klass)->finalize = publishing_piwigo_authentication_pane_finalize;
#line 984 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_new ("login", PUBLISHING_PIWIGO_TYPE_AUTHENTICATION_PANE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_user_marshal_VOID__STRING_STRING_STRING_BOOLEAN, G_TYPE_NONE, 4, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_BOOLEAN);
#line 990 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = _ ("Enter the URL of your Piwigo photo library as well as the username and" \
" password associated with your Piwigo account for that library.");
#line 990 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 990 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_authentication_pane_INTRO_MESSAGE = _tmp1_;
#line 991 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = _ ("Shotwell cannot contact your Piwigo photo library. Please verify the U" \
"RL you entered");
#line 991 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3_ = g_strdup (_tmp2_);
#line 991 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_authentication_pane_FAILED_RETRY_URL_MESSAGE = _tmp3_;
#line 992 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = _ ("Username and/or password invalid. Please try again");
#line 992 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp5_ = g_strdup (_tmp4_);
#line 992 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_authentication_pane_FAILED_RETRY_USER_MESSAGE = _tmp5_;
#line 7384 "PiwigoPublishing.c"
}


static void publishing_piwigo_authentication_pane_spit_publishing_dialog_pane_interface_init (SpitPublishingDialogPaneIface * iface) {
#line 984 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_authentication_pane_spit_publishing_dialog_pane_parent_iface = g_type_interface_peek_parent (iface);
#line 984 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	iface->get_widget = (GtkWidget* (*)(SpitPublishingDialogPane*)) publishing_piwigo_authentication_pane_real_get_widget;
#line 984 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	iface->get_preferred_geometry = (SpitPublishingDialogPaneGeometryOptions (*)(SpitPublishingDialogPane*)) publishing_piwigo_authentication_pane_real_get_preferred_geometry;
#line 984 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	iface->on_pane_installed = (void (*)(SpitPublishingDialogPane*)) publishing_piwigo_authentication_pane_real_on_pane_installed;
#line 984 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	iface->on_pane_uninstalled = (void (*)(SpitPublishingDialogPane*)) publishing_piwigo_authentication_pane_real_on_pane_uninstalled;
#line 7399 "PiwigoPublishing.c"
}


static void publishing_piwigo_authentication_pane_instance_init (PublishingPiwigoAuthenticationPane * self) {
#line 984 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv = PUBLISHING_PIWIGO_AUTHENTICATION_PANE_GET_PRIVATE (self);
#line 994 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->pane_widget = NULL;
#line 7408 "PiwigoPublishing.c"
}


static void publishing_piwigo_authentication_pane_finalize (GObject* obj) {
	PublishingPiwigoAuthenticationPane * self;
#line 984 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_PIWIGO_TYPE_AUTHENTICATION_PANE, PublishingPiwigoAuthenticationPane);
#line 994 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (self->priv->pane_widget);
#line 995 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (self->priv->builder);
#line 996 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (self->priv->url_entry);
#line 997 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (self->priv->username_entry);
#line 998 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (self->priv->password_entry);
#line 999 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (self->priv->remember_password_checkbutton);
#line 1000 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (self->priv->login_button);
#line 984 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	G_OBJECT_CLASS (publishing_piwigo_authentication_pane_parent_class)->finalize (obj);
#line 7432 "PiwigoPublishing.c"
}


/**
 * The authentication pane used when asking service URL, user name and password
 * from the user.
 */
GType publishing_piwigo_authentication_pane_get_type (void) {
	static volatile gsize publishing_piwigo_authentication_pane_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_piwigo_authentication_pane_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingPiwigoAuthenticationPaneClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_piwigo_authentication_pane_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingPiwigoAuthenticationPane), 0, (GInstanceInitFunc) publishing_piwigo_authentication_pane_instance_init, NULL };
		static const GInterfaceInfo spit_publishing_dialog_pane_info = { (GInterfaceInitFunc) publishing_piwigo_authentication_pane_spit_publishing_dialog_pane_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType publishing_piwigo_authentication_pane_type_id;
		publishing_piwigo_authentication_pane_type_id = g_type_register_static (G_TYPE_OBJECT, "PublishingPiwigoAuthenticationPane", &g_define_type_info, 0);
		g_type_add_interface_static (publishing_piwigo_authentication_pane_type_id, SPIT_PUBLISHING_TYPE_DIALOG_PANE, &spit_publishing_dialog_pane_info);
		g_once_init_leave (&publishing_piwigo_authentication_pane_type_id__volatile, publishing_piwigo_authentication_pane_type_id);
	}
	return publishing_piwigo_authentication_pane_type_id__volatile;
}


static void _publishing_piwigo_publishing_options_pane_on_logout_button_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 1189 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_publishing_options_pane_on_logout_button_clicked ((PublishingPiwigoPublishingOptionsPane*) self);
#line 7457 "PiwigoPublishing.c"
}


static void _publishing_piwigo_publishing_options_pane_on_publish_button_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 1192 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_publishing_options_pane_on_publish_button_clicked ((PublishingPiwigoPublishingOptionsPane*) self);
#line 7464 "PiwigoPublishing.c"
}


static void _publishing_piwigo_publishing_options_pane_on_use_existing_radio_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 1194 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_publishing_options_pane_on_use_existing_radio_clicked ((PublishingPiwigoPublishingOptionsPane*) self);
#line 7471 "PiwigoPublishing.c"
}


static void _publishing_piwigo_publishing_options_pane_on_create_new_radio_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 1195 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_publishing_options_pane_on_create_new_radio_clicked ((PublishingPiwigoPublishingOptionsPane*) self);
#line 7478 "PiwigoPublishing.c"
}


static void _publishing_piwigo_publishing_options_pane_on_new_category_entry_changed_gtk_editable_changed (GtkEditable* _sender, gpointer self) {
#line 1196 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_publishing_options_pane_on_new_category_entry_changed ((PublishingPiwigoPublishingOptionsPane*) self);
#line 7485 "PiwigoPublishing.c"
}


static void _publishing_piwigo_publishing_options_pane_on_existing_combo_changed_gtk_combo_box_changed (GtkComboBox* _sender, gpointer self) {
#line 1197 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_publishing_options_pane_on_existing_combo_changed ((PublishingPiwigoPublishingOptionsPane*) self);
#line 7492 "PiwigoPublishing.c"
}


static gpointer _publishing_piwigo_category_ref0 (gpointer self) {
#line 1205 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return self ? publishing_piwigo_category_ref (self) : NULL;
#line 7499 "PiwigoPublishing.c"
}


static PublishingPiwigoCategory** _vala_array_dup11 (PublishingPiwigoCategory** self, int length) {
	PublishingPiwigoCategory** result;
	int i;
#line 1205 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = g_new0 (PublishingPiwigoCategory*, length + 1);
#line 1205 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	for (i = 0; i < length; i++) {
#line 7510 "PiwigoPublishing.c"
		PublishingPiwigoCategory* _tmp0_ = NULL;
#line 1205 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp0_ = _publishing_piwigo_category_ref0 (self[i]);
#line 1205 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		result[i] = _tmp0_;
#line 7516 "PiwigoPublishing.c"
	}
#line 1205 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 7520 "PiwigoPublishing.c"
}


PublishingPiwigoPublishingOptionsPane* publishing_piwigo_publishing_options_pane_construct (GType object_type, PublishingPiwigoPiwigoPublisher* publisher, PublishingPiwigoCategory** categories, int categories_length1, gint last_category, gint last_permission_level, gint last_photo_size, gboolean last_title_as_comment, gboolean last_no_upload_tags, gboolean strip_metadata_enabled) {
	PublishingPiwigoPublishingOptionsPane * self = NULL;
	GtkBox* _tmp0_ = NULL;
	gint _tmp1_ = 0;
	gint _tmp2_ = 0;
	gint _tmp3_ = 0;
	gboolean _tmp4_ = FALSE;
	gboolean _tmp5_ = FALSE;
	PublishingPiwigoCategory** _tmp78_ = NULL;
	gint _tmp78__length1 = 0;
	PublishingPiwigoCategory** _tmp79_ = NULL;
	gint _tmp79__length1 = 0;
	gint _tmp80_ = 0;
	PublishingPiwigoPermissionLevel** _tmp81_ = NULL;
	gint _tmp82_ = 0;
	PublishingPiwigoSizeEntry** _tmp83_ = NULL;
	GtkTextView* _tmp84_ = NULL;
	GtkTextBuffer* _tmp85_ = NULL;
	GtkTextBuffer* _tmp86_ = NULL;
	PublishingPiwigoPiwigoPublisher* _tmp87_ = NULL;
	gchar* _tmp88_ = NULL;
	gchar* _tmp89_ = NULL;
	GError * _inner_error_ = NULL;
#line 1147 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (publisher), NULL);
#line 1147 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = (PublishingPiwigoPublishingOptionsPane*) g_object_new (object_type, NULL);
#line 1152 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
#line 1152 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_object_ref_sink (_tmp0_);
#line 1152 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (self->priv->pane_widget);
#line 1152 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->pane_widget = _tmp0_;
#line 1153 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = last_category;
#line 1153 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->last_category = _tmp1_;
#line 1154 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = last_permission_level;
#line 1154 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->last_permission_level = _tmp2_;
#line 1155 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3_ = last_photo_size;
#line 1155 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->last_photo_size = _tmp3_;
#line 1156 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = last_title_as_comment;
#line 1156 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->last_title_as_comment = _tmp4_;
#line 1157 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp5_ = last_no_upload_tags;
#line 1157 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->last_no_upload_tags = _tmp5_;
#line 7579 "PiwigoPublishing.c"
	{
		GtkBuilder* _tmp6_ = NULL;
		GtkBuilder* _tmp7_ = NULL;
		GtkBuilder* _tmp8_ = NULL;
		GtkAlignment* align = NULL;
		GtkBuilder* _tmp9_ = NULL;
		GObject* _tmp10_ = NULL;
		GtkAlignment* _tmp11_ = NULL;
		GtkBuilder* _tmp12_ = NULL;
		GObject* _tmp13_ = NULL;
		GtkRadioButton* _tmp14_ = NULL;
		GtkBuilder* _tmp15_ = NULL;
		GObject* _tmp16_ = NULL;
		GtkRadioButton* _tmp17_ = NULL;
		GtkBuilder* _tmp18_ = NULL;
		GObject* _tmp19_ = NULL;
		GtkComboBoxText* _tmp20_ = NULL;
		GtkBuilder* _tmp21_ = NULL;
		GObject* _tmp22_ = NULL;
		GtkEntry* _tmp23_ = NULL;
		GtkBuilder* _tmp24_ = NULL;
		GObject* _tmp25_ = NULL;
		GtkLabel* _tmp26_ = NULL;
		GtkBuilder* _tmp27_ = NULL;
		GObject* _tmp28_ = NULL;
		GtkComboBoxText* _tmp29_ = NULL;
		GtkBuilder* _tmp30_ = NULL;
		GObject* _tmp31_ = NULL;
		GtkTextView* _tmp32_ = NULL;
		GtkTextView* _tmp33_ = NULL;
		GtkTextBuffer* _tmp34_ = NULL;
		GtkTextBuffer* _tmp35_ = NULL;
		GtkBuilder* _tmp36_ = NULL;
		GObject* _tmp37_ = NULL;
		GtkLabel* _tmp38_ = NULL;
		GtkBuilder* _tmp39_ = NULL;
		GObject* _tmp40_ = NULL;
		GtkComboBoxText* _tmp41_ = NULL;
		GtkBuilder* _tmp42_ = NULL;
		GObject* _tmp43_ = NULL;
		GtkComboBoxText* _tmp44_ = NULL;
		GtkBuilder* _tmp45_ = NULL;
		GObject* _tmp46_ = NULL;
		GtkCheckButton* _tmp47_ = NULL;
		GtkCheckButton* _tmp48_ = NULL;
		gboolean _tmp49_ = FALSE;
		GtkBuilder* _tmp50_ = NULL;
		GObject* _tmp51_ = NULL;
		GtkCheckButton* _tmp52_ = NULL;
		GtkCheckButton* _tmp53_ = NULL;
		gboolean _tmp54_ = FALSE;
		GtkBuilder* _tmp55_ = NULL;
		GObject* _tmp56_ = NULL;
		GtkCheckButton* _tmp57_ = NULL;
		GtkCheckButton* _tmp58_ = NULL;
		gboolean _tmp59_ = FALSE;
		GtkBuilder* _tmp60_ = NULL;
		GObject* _tmp61_ = NULL;
		GtkButton* _tmp62_ = NULL;
		GtkButton* _tmp63_ = NULL;
		GtkBuilder* _tmp64_ = NULL;
		GObject* _tmp65_ = NULL;
		GtkButton* _tmp66_ = NULL;
		GtkButton* _tmp67_ = NULL;
		GtkRadioButton* _tmp68_ = NULL;
		GtkRadioButton* _tmp69_ = NULL;
		GtkEntry* _tmp70_ = NULL;
		GtkComboBoxText* _tmp71_ = NULL;
		GtkAlignment* _tmp72_ = NULL;
		GtkBox* _tmp73_ = NULL;
		GtkBox* _tmp74_ = NULL;
		GtkAlignment* _tmp75_ = NULL;
#line 1160 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp6_ = gtk_builder_new ();
#line 1160 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_object_unref0 (self->priv->builder);
#line 1160 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		self->priv->builder = _tmp6_;
#line 1161 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp7_ = self->priv->builder;
#line 1161 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		gtk_builder_add_from_resource (_tmp7_, PLUGIN_RESOURCE_PATH "/piwigo_publishing_options_pane.ui", &_inner_error_);
#line 1161 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 7664 "PiwigoPublishing.c"
			goto __catch45_g_error;
		}
#line 1162 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp8_ = self->priv->builder;
#line 1162 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		gtk_builder_connect_signals (_tmp8_, NULL);
#line 1163 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp9_ = self->priv->builder;
#line 1163 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp10_ = gtk_builder_get_object (_tmp9_, "alignment");
#line 1163 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp11_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp10_, gtk_alignment_get_type ()) ? ((GtkAlignment*) _tmp10_) : NULL);
#line 1163 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		align = _tmp11_;
#line 1165 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp12_ = self->priv->builder;
#line 1165 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp13_ = gtk_builder_get_object (_tmp12_, "use_existing_radio");
#line 1165 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp14_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp13_, gtk_radio_button_get_type ()) ? ((GtkRadioButton*) _tmp13_) : NULL);
#line 1165 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_object_unref0 (self->priv->use_existing_radio);
#line 1165 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		self->priv->use_existing_radio = _tmp14_;
#line 1166 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp15_ = self->priv->builder;
#line 1166 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp16_ = gtk_builder_get_object (_tmp15_, "create_new_radio");
#line 1166 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp17_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp16_, gtk_radio_button_get_type ()) ? ((GtkRadioButton*) _tmp16_) : NULL);
#line 1166 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_object_unref0 (self->priv->create_new_radio);
#line 1166 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		self->priv->create_new_radio = _tmp17_;
#line 1167 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp18_ = self->priv->builder;
#line 1167 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp19_ = gtk_builder_get_object (_tmp18_, "existing_categories_combo");
#line 1167 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp20_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp19_, gtk_combo_box_text_get_type ()) ? ((GtkComboBoxText*) _tmp19_) : NULL);
#line 1167 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_object_unref0 (self->priv->existing_categories_combo);
#line 1167 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		self->priv->existing_categories_combo = _tmp20_;
#line 1168 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp21_ = self->priv->builder;
#line 1168 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp22_ = gtk_builder_get_object (_tmp21_, "new_category_entry");
#line 1168 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp23_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp22_, gtk_entry_get_type ()) ? ((GtkEntry*) _tmp22_) : NULL);
#line 1168 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_object_unref0 (self->priv->new_category_entry);
#line 1168 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		self->priv->new_category_entry = _tmp23_;
#line 1169 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp24_ = self->priv->builder;
#line 1169 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp25_ = gtk_builder_get_object (_tmp24_, "within_existing_label");
#line 1169 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp26_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp25_, gtk_label_get_type ()) ? ((GtkLabel*) _tmp25_) : NULL);
#line 1169 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_object_unref0 (self->priv->within_existing_label);
#line 1169 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		self->priv->within_existing_label = _tmp26_;
#line 1170 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp27_ = self->priv->builder;
#line 1170 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp28_ = gtk_builder_get_object (_tmp27_, "within_existing_combo");
#line 1170 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp29_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp28_, gtk_combo_box_text_get_type ()) ? ((GtkComboBoxText*) _tmp28_) : NULL);
#line 1170 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_object_unref0 (self->priv->within_existing_combo);
#line 1170 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		self->priv->within_existing_combo = _tmp29_;
#line 1172 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp30_ = self->priv->builder;
#line 1172 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp31_ = gtk_builder_get_object (_tmp30_, "album_comment");
#line 1172 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp32_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp31_, gtk_text_view_get_type ()) ? ((GtkTextView*) _tmp31_) : NULL);
#line 1172 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_object_unref0 (self->priv->album_comment);
#line 1172 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		self->priv->album_comment = _tmp32_;
#line 1173 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp33_ = self->priv->album_comment;
#line 1173 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp34_ = gtk_text_buffer_new (NULL);
#line 1173 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp35_ = _tmp34_;
#line 1173 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		gtk_text_view_set_buffer (_tmp33_, _tmp35_);
#line 1173 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_object_unref0 (_tmp35_);
#line 1174 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp36_ = self->priv->builder;
#line 1174 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp37_ = gtk_builder_get_object (_tmp36_, "album_comment_label");
#line 1174 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp38_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp37_, gtk_label_get_type ()) ? ((GtkLabel*) _tmp37_) : NULL);
#line 1174 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_object_unref0 (self->priv->album_comment_label);
#line 1174 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		self->priv->album_comment_label = _tmp38_;
#line 1176 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp39_ = self->priv->builder;
#line 1176 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp40_ = gtk_builder_get_object (_tmp39_, "perms_combo");
#line 1176 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp41_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp40_, gtk_combo_box_text_get_type ()) ? ((GtkComboBoxText*) _tmp40_) : NULL);
#line 1176 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_object_unref0 (self->priv->perms_combo);
#line 1176 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		self->priv->perms_combo = _tmp41_;
#line 1177 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp42_ = self->priv->builder;
#line 1177 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp43_ = gtk_builder_get_object (_tmp42_, "size_combo");
#line 1177 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp44_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp43_, gtk_combo_box_text_get_type ()) ? ((GtkComboBoxText*) _tmp43_) : NULL);
#line 1177 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_object_unref0 (self->priv->size_combo);
#line 1177 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		self->priv->size_combo = _tmp44_;
#line 1179 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp45_ = self->priv->builder;
#line 1179 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp46_ = gtk_builder_get_object (_tmp45_, "strip_metadata_check");
#line 1179 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp47_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp46_, gtk_check_button_get_type ()) ? ((GtkCheckButton*) _tmp46_) : NULL);
#line 1179 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_object_unref0 (self->priv->strip_metadata_check);
#line 1179 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		self->priv->strip_metadata_check = _tmp47_;
#line 1180 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp48_ = self->priv->strip_metadata_check;
#line 1180 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp49_ = strip_metadata_enabled;
#line 1180 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		gtk_toggle_button_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp48_, gtk_toggle_button_get_type (), GtkToggleButton), _tmp49_);
#line 1182 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp50_ = self->priv->builder;
#line 1182 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp51_ = gtk_builder_get_object (_tmp50_, "title_as_comment_check");
#line 1182 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp52_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp51_, gtk_check_button_get_type ()) ? ((GtkCheckButton*) _tmp51_) : NULL);
#line 1182 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_object_unref0 (self->priv->title_as_comment_check);
#line 1182 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		self->priv->title_as_comment_check = _tmp52_;
#line 1183 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp53_ = self->priv->title_as_comment_check;
#line 1183 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp54_ = last_title_as_comment;
#line 1183 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		gtk_toggle_button_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp53_, gtk_toggle_button_get_type (), GtkToggleButton), _tmp54_);
#line 1185 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp55_ = self->priv->builder;
#line 1185 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp56_ = gtk_builder_get_object (_tmp55_, "no_upload_tags_check");
#line 1185 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp57_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp56_, gtk_check_button_get_type ()) ? ((GtkCheckButton*) _tmp56_) : NULL);
#line 1185 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_object_unref0 (self->priv->no_upload_tags_check);
#line 1185 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		self->priv->no_upload_tags_check = _tmp57_;
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp58_ = self->priv->no_upload_tags_check;
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp59_ = last_no_upload_tags;
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		gtk_toggle_button_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp58_, gtk_toggle_button_get_type (), GtkToggleButton), _tmp59_);
#line 1188 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp60_ = self->priv->builder;
#line 1188 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp61_ = gtk_builder_get_object (_tmp60_, "logout_button");
#line 1188 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp62_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp61_, gtk_button_get_type ()) ? ((GtkButton*) _tmp61_) : NULL);
#line 1188 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_object_unref0 (self->priv->logout_button);
#line 1188 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		self->priv->logout_button = _tmp62_;
#line 1189 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp63_ = self->priv->logout_button;
#line 1189 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_signal_connect_object (_tmp63_, "clicked", (GCallback) _publishing_piwigo_publishing_options_pane_on_logout_button_clicked_gtk_button_clicked, self, 0);
#line 1191 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp64_ = self->priv->builder;
#line 1191 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp65_ = gtk_builder_get_object (_tmp64_, "publish_button");
#line 1191 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp66_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp65_, gtk_button_get_type ()) ? ((GtkButton*) _tmp65_) : NULL);
#line 1191 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_object_unref0 (self->priv->publish_button);
#line 1191 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		self->priv->publish_button = _tmp66_;
#line 1192 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp67_ = self->priv->publish_button;
#line 1192 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_signal_connect_object (_tmp67_, "clicked", (GCallback) _publishing_piwigo_publishing_options_pane_on_publish_button_clicked_gtk_button_clicked, self, 0);
#line 1194 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp68_ = self->priv->use_existing_radio;
#line 1194 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp68_, gtk_button_get_type (), GtkButton), "clicked", (GCallback) _publishing_piwigo_publishing_options_pane_on_use_existing_radio_clicked_gtk_button_clicked, self, 0);
#line 1195 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp69_ = self->priv->create_new_radio;
#line 1195 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp69_, gtk_button_get_type (), GtkButton), "clicked", (GCallback) _publishing_piwigo_publishing_options_pane_on_create_new_radio_clicked_gtk_button_clicked, self, 0);
#line 1196 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp70_ = self->priv->new_category_entry;
#line 1196 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp70_, GTK_TYPE_EDITABLE, GtkEditable), "changed", (GCallback) _publishing_piwigo_publishing_options_pane_on_new_category_entry_changed_gtk_editable_changed, self, 0);
#line 1197 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp71_ = self->priv->within_existing_combo;
#line 1197 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp71_, gtk_combo_box_get_type (), GtkComboBox), "changed", (GCallback) _publishing_piwigo_publishing_options_pane_on_existing_combo_changed_gtk_combo_box_changed, self, 0);
#line 1199 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp72_ = align;
#line 1199 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp73_ = self->priv->pane_widget;
#line 1199 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		gtk_widget_reparent (G_TYPE_CHECK_INSTANCE_CAST (_tmp72_, gtk_widget_get_type (), GtkWidget), G_TYPE_CHECK_INSTANCE_CAST (_tmp73_, gtk_widget_get_type (), GtkWidget));
#line 1200 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp74_ = self->priv->pane_widget;
#line 1200 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp75_ = align;
#line 1200 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		gtk_box_set_child_packing (_tmp74_, G_TYPE_CHECK_INSTANCE_CAST (_tmp75_, gtk_widget_get_type (), GtkWidget), TRUE, TRUE, (guint) 0, GTK_PACK_START);
#line 1159 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_object_unref0 (align);
#line 7895 "PiwigoPublishing.c"
	}
	goto __finally45;
	__catch45_g_error:
	{
		GError* e = NULL;
		GError* _tmp76_ = NULL;
		const gchar* _tmp77_ = NULL;
#line 1159 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		e = _inner_error_;
#line 1159 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_inner_error_ = NULL;
#line 1202 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp76_ = e;
#line 1202 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp77_ = _tmp76_->message;
#line 1202 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_warning ("PiwigoPublishing.vala:1202: Could not load UI: %s", _tmp77_);
#line 1159 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_error_free0 (e);
#line 7915 "PiwigoPublishing.c"
	}
	__finally45:
#line 1159 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1159 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1159 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_clear_error (&_inner_error_);
#line 1159 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		return NULL;
#line 7926 "PiwigoPublishing.c"
	}
#line 1205 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp78_ = categories;
#line 1205 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp78__length1 = categories_length1;
#line 1205 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp79_ = (_tmp78_ != NULL) ? _vala_array_dup11 (_tmp78_, _tmp78__length1) : ((gpointer) _tmp78_);
#line 1205 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp79__length1 = _tmp78__length1;
#line 1205 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->existing_categories = (_vala_array_free (self->priv->existing_categories, self->priv->existing_categories_length1, (GDestroyNotify) publishing_piwigo_category_unref), NULL);
#line 1205 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->existing_categories = _tmp79_;
#line 1205 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->existing_categories_length1 = _tmp79__length1;
#line 1205 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->_existing_categories_size_ = self->priv->existing_categories_length1;
#line 1206 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp81_ = publishing_piwigo_publishing_options_pane_create_perm_levels (self, &_tmp80_);
#line 1206 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->perm_levels = (_vala_array_free (self->priv->perm_levels, self->priv->perm_levels_length1, (GDestroyNotify) publishing_piwigo_permission_level_unref), NULL);
#line 1206 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->perm_levels = _tmp81_;
#line 1206 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->perm_levels_length1 = _tmp80_;
#line 1206 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->_perm_levels_size_ = self->priv->perm_levels_length1;
#line 1207 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp83_ = publishing_piwigo_publishing_options_pane_create_sizes (self, &_tmp82_);
#line 1207 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->photo_sizes = (_vala_array_free (self->priv->photo_sizes, self->priv->photo_sizes_length1, (GDestroyNotify) publishing_piwigo_size_entry_unref), NULL);
#line 1207 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->photo_sizes = _tmp83_;
#line 1207 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->photo_sizes_length1 = _tmp82_;
#line 1207 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->_photo_sizes_size_ = self->priv->photo_sizes_length1;
#line 1208 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp84_ = self->priv->album_comment;
#line 1208 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp85_ = gtk_text_view_get_buffer (_tmp84_);
#line 1208 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp86_ = _tmp85_;
#line 1208 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp87_ = publisher;
#line 1208 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp88_ = publishing_piwigo_publishing_options_pane_get_common_comment_if_possible (self, _tmp87_);
#line 1208 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp89_ = _tmp88_;
#line 1208 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	gtk_text_buffer_set_text (_tmp86_, _tmp89_, -1);
#line 1208 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (_tmp89_);
#line 1147 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return self;
#line 7982 "PiwigoPublishing.c"
}


PublishingPiwigoPublishingOptionsPane* publishing_piwigo_publishing_options_pane_new (PublishingPiwigoPiwigoPublisher* publisher, PublishingPiwigoCategory** categories, int categories_length1, gint last_category, gint last_permission_level, gint last_photo_size, gboolean last_title_as_comment, gboolean last_no_upload_tags, gboolean strip_metadata_enabled) {
#line 1147 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return publishing_piwigo_publishing_options_pane_construct (PUBLISHING_PIWIGO_TYPE_PUBLISHING_OPTIONS_PANE, publisher, categories, categories_length1, last_category, last_permission_level, last_photo_size, last_title_as_comment, last_no_upload_tags, strip_metadata_enabled);
#line 7989 "PiwigoPublishing.c"
}


GtkWidget* publishing_piwigo_publishing_options_pane_get_default_widget (PublishingPiwigoPublishingOptionsPane* self) {
	GtkWidget* result = NULL;
	GtkButton* _tmp0_ = NULL;
	GtkWidget* _tmp1_ = NULL;
#line 1211 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_PUBLISHING_OPTIONS_PANE (self), NULL);
#line 1212 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->publish_button;
#line 1212 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_widget_get_type (), GtkWidget));
#line 1212 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = _tmp1_;
#line 1212 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 8007 "PiwigoPublishing.c"
}


static void _vala_array_add35 (PublishingPiwigoPermissionLevel*** array, int* length, int* size, PublishingPiwigoPermissionLevel* value) {
#line 1218 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if ((*length) == (*size)) {
#line 1218 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 1218 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		*array = g_renew (PublishingPiwigoPermissionLevel*, *array, (*size) + 1);
#line 8018 "PiwigoPublishing.c"
	}
#line 1218 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	(*array)[(*length)++] = value;
#line 1218 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	(*array)[*length] = NULL;
#line 8024 "PiwigoPublishing.c"
}


static void _vala_array_add36 (PublishingPiwigoPermissionLevel*** array, int* length, int* size, PublishingPiwigoPermissionLevel* value) {
#line 1219 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if ((*length) == (*size)) {
#line 1219 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 1219 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		*array = g_renew (PublishingPiwigoPermissionLevel*, *array, (*size) + 1);
#line 8035 "PiwigoPublishing.c"
	}
#line 1219 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	(*array)[(*length)++] = value;
#line 1219 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	(*array)[*length] = NULL;
#line 8041 "PiwigoPublishing.c"
}


static void _vala_array_add37 (PublishingPiwigoPermissionLevel*** array, int* length, int* size, PublishingPiwigoPermissionLevel* value) {
#line 1220 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if ((*length) == (*size)) {
#line 1220 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 1220 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		*array = g_renew (PublishingPiwigoPermissionLevel*, *array, (*size) + 1);
#line 8052 "PiwigoPublishing.c"
	}
#line 1220 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	(*array)[(*length)++] = value;
#line 1220 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	(*array)[*length] = NULL;
#line 8058 "PiwigoPublishing.c"
}


static void _vala_array_add38 (PublishingPiwigoPermissionLevel*** array, int* length, int* size, PublishingPiwigoPermissionLevel* value) {
#line 1221 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if ((*length) == (*size)) {
#line 1221 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 1221 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		*array = g_renew (PublishingPiwigoPermissionLevel*, *array, (*size) + 1);
#line 8069 "PiwigoPublishing.c"
	}
#line 1221 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	(*array)[(*length)++] = value;
#line 1221 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	(*array)[*length] = NULL;
#line 8075 "PiwigoPublishing.c"
}


static void _vala_array_add39 (PublishingPiwigoPermissionLevel*** array, int* length, int* size, PublishingPiwigoPermissionLevel* value) {
#line 1222 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if ((*length) == (*size)) {
#line 1222 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 1222 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		*array = g_renew (PublishingPiwigoPermissionLevel*, *array, (*size) + 1);
#line 8086 "PiwigoPublishing.c"
	}
#line 1222 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	(*array)[(*length)++] = value;
#line 1222 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	(*array)[*length] = NULL;
#line 8092 "PiwigoPublishing.c"
}


static PublishingPiwigoPermissionLevel** publishing_piwigo_publishing_options_pane_create_perm_levels (PublishingPiwigoPublishingOptionsPane* self, int* result_length1) {
	PublishingPiwigoPermissionLevel** result = NULL;
	PublishingPiwigoPermissionLevel** _result_ = NULL;
	PublishingPiwigoPermissionLevel** _tmp0_ = NULL;
	gint _result__length1 = 0;
	gint __result__size_ = 0;
	PublishingPiwigoPermissionLevel** _tmp1_ = NULL;
	gint _tmp1__length1 = 0;
	const gchar* _tmp2_ = NULL;
	PublishingPiwigoPermissionLevel* _tmp3_ = NULL;
	PublishingPiwigoPermissionLevel** _tmp4_ = NULL;
	gint _tmp4__length1 = 0;
	const gchar* _tmp5_ = NULL;
	PublishingPiwigoPermissionLevel* _tmp6_ = NULL;
	PublishingPiwigoPermissionLevel** _tmp7_ = NULL;
	gint _tmp7__length1 = 0;
	const gchar* _tmp8_ = NULL;
	PublishingPiwigoPermissionLevel* _tmp9_ = NULL;
	PublishingPiwigoPermissionLevel** _tmp10_ = NULL;
	gint _tmp10__length1 = 0;
	const gchar* _tmp11_ = NULL;
	PublishingPiwigoPermissionLevel* _tmp12_ = NULL;
	PublishingPiwigoPermissionLevel** _tmp13_ = NULL;
	gint _tmp13__length1 = 0;
	const gchar* _tmp14_ = NULL;
	PublishingPiwigoPermissionLevel* _tmp15_ = NULL;
	PublishingPiwigoPermissionLevel** _tmp16_ = NULL;
	gint _tmp16__length1 = 0;
#line 1215 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_PUBLISHING_OPTIONS_PANE (self), NULL);
#line 1216 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = g_new0 (PublishingPiwigoPermissionLevel*, 0 + 1);
#line 1216 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_result_ = _tmp0_;
#line 1216 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_result__length1 = 0;
#line 1216 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	__result__size_ = _result__length1;
#line 1218 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = _result_;
#line 1218 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1__length1 = _result__length1;
#line 1218 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = _ ("Everyone");
#line 1218 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3_ = publishing_piwigo_permission_level_new (0, _tmp2_);
#line 1218 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_vala_array_add35 (&_result_, &_result__length1, &__result__size_, _tmp3_);
#line 1219 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = _result_;
#line 1219 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4__length1 = _result__length1;
#line 1219 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp5_ = _ ("Admins, Family, Friends, Contacts");
#line 1219 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp6_ = publishing_piwigo_permission_level_new (1, _tmp5_);
#line 1219 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_vala_array_add36 (&_result_, &_result__length1, &__result__size_, _tmp6_);
#line 1220 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp7_ = _result_;
#line 1220 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp7__length1 = _result__length1;
#line 1220 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp8_ = _ ("Admins, Family, Friends");
#line 1220 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp9_ = publishing_piwigo_permission_level_new (2, _tmp8_);
#line 1220 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_vala_array_add37 (&_result_, &_result__length1, &__result__size_, _tmp9_);
#line 1221 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp10_ = _result_;
#line 1221 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp10__length1 = _result__length1;
#line 1221 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp11_ = _ ("Admins, Family");
#line 1221 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp12_ = publishing_piwigo_permission_level_new (4, _tmp11_);
#line 1221 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_vala_array_add38 (&_result_, &_result__length1, &__result__size_, _tmp12_);
#line 1222 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp13_ = _result_;
#line 1222 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp13__length1 = _result__length1;
#line 1222 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp14_ = _ ("Admins");
#line 1222 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp15_ = publishing_piwigo_permission_level_new (8, _tmp14_);
#line 1222 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_vala_array_add39 (&_result_, &_result__length1, &__result__size_, _tmp15_);
#line 1224 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp16_ = _result_;
#line 1224 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp16__length1 = _result__length1;
#line 1224 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (result_length1) {
#line 1224 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		*result_length1 = _tmp16__length1;
#line 8192 "PiwigoPublishing.c"
	}
#line 1224 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = _tmp16_;
#line 1224 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 8198 "PiwigoPublishing.c"
}


static void _vala_array_add40 (PublishingPiwigoSizeEntry*** array, int* length, int* size, PublishingPiwigoSizeEntry* value) {
#line 1230 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if ((*length) == (*size)) {
#line 1230 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 1230 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		*array = g_renew (PublishingPiwigoSizeEntry*, *array, (*size) + 1);
#line 8209 "PiwigoPublishing.c"
	}
#line 1230 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	(*array)[(*length)++] = value;
#line 1230 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	(*array)[*length] = NULL;
#line 8215 "PiwigoPublishing.c"
}


static void _vala_array_add41 (PublishingPiwigoSizeEntry*** array, int* length, int* size, PublishingPiwigoSizeEntry* value) {
#line 1231 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if ((*length) == (*size)) {
#line 1231 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 1231 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		*array = g_renew (PublishingPiwigoSizeEntry*, *array, (*size) + 1);
#line 8226 "PiwigoPublishing.c"
	}
#line 1231 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	(*array)[(*length)++] = value;
#line 1231 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	(*array)[*length] = NULL;
#line 8232 "PiwigoPublishing.c"
}


static void _vala_array_add42 (PublishingPiwigoSizeEntry*** array, int* length, int* size, PublishingPiwigoSizeEntry* value) {
#line 1232 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if ((*length) == (*size)) {
#line 1232 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 1232 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		*array = g_renew (PublishingPiwigoSizeEntry*, *array, (*size) + 1);
#line 8243 "PiwigoPublishing.c"
	}
#line 1232 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	(*array)[(*length)++] = value;
#line 1232 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	(*array)[*length] = NULL;
#line 8249 "PiwigoPublishing.c"
}


static void _vala_array_add43 (PublishingPiwigoSizeEntry*** array, int* length, int* size, PublishingPiwigoSizeEntry* value) {
#line 1233 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if ((*length) == (*size)) {
#line 1233 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 1233 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		*array = g_renew (PublishingPiwigoSizeEntry*, *array, (*size) + 1);
#line 8260 "PiwigoPublishing.c"
	}
#line 1233 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	(*array)[(*length)++] = value;
#line 1233 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	(*array)[*length] = NULL;
#line 8266 "PiwigoPublishing.c"
}


static void _vala_array_add44 (PublishingPiwigoSizeEntry*** array, int* length, int* size, PublishingPiwigoSizeEntry* value) {
#line 1234 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if ((*length) == (*size)) {
#line 1234 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 1234 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		*array = g_renew (PublishingPiwigoSizeEntry*, *array, (*size) + 1);
#line 8277 "PiwigoPublishing.c"
	}
#line 1234 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	(*array)[(*length)++] = value;
#line 1234 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	(*array)[*length] = NULL;
#line 8283 "PiwigoPublishing.c"
}


static PublishingPiwigoSizeEntry** publishing_piwigo_publishing_options_pane_create_sizes (PublishingPiwigoPublishingOptionsPane* self, int* result_length1) {
	PublishingPiwigoSizeEntry** result = NULL;
	PublishingPiwigoSizeEntry** _result_ = NULL;
	PublishingPiwigoSizeEntry** _tmp0_ = NULL;
	gint _result__length1 = 0;
	gint __result__size_ = 0;
	PublishingPiwigoSizeEntry** _tmp1_ = NULL;
	gint _tmp1__length1 = 0;
	const gchar* _tmp2_ = NULL;
	PublishingPiwigoSizeEntry* _tmp3_ = NULL;
	PublishingPiwigoSizeEntry** _tmp4_ = NULL;
	gint _tmp4__length1 = 0;
	const gchar* _tmp5_ = NULL;
	PublishingPiwigoSizeEntry* _tmp6_ = NULL;
	PublishingPiwigoSizeEntry** _tmp7_ = NULL;
	gint _tmp7__length1 = 0;
	const gchar* _tmp8_ = NULL;
	PublishingPiwigoSizeEntry* _tmp9_ = NULL;
	PublishingPiwigoSizeEntry** _tmp10_ = NULL;
	gint _tmp10__length1 = 0;
	const gchar* _tmp11_ = NULL;
	PublishingPiwigoSizeEntry* _tmp12_ = NULL;
	PublishingPiwigoSizeEntry** _tmp13_ = NULL;
	gint _tmp13__length1 = 0;
	const gchar* _tmp14_ = NULL;
	PublishingPiwigoSizeEntry* _tmp15_ = NULL;
	PublishingPiwigoSizeEntry** _tmp16_ = NULL;
	gint _tmp16__length1 = 0;
#line 1227 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_PUBLISHING_OPTIONS_PANE (self), NULL);
#line 1228 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = g_new0 (PublishingPiwigoSizeEntry*, 0 + 1);
#line 1228 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_result_ = _tmp0_;
#line 1228 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_result__length1 = 0;
#line 1228 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	__result__size_ = _result__length1;
#line 1230 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = _result_;
#line 1230 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1__length1 = _result__length1;
#line 1230 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = _ ("500 x 375 pixels");
#line 1230 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3_ = publishing_piwigo_size_entry_new (500, _tmp2_);
#line 1230 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_vala_array_add40 (&_result_, &_result__length1, &__result__size_, _tmp3_);
#line 1231 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = _result_;
#line 1231 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4__length1 = _result__length1;
#line 1231 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp5_ = _ ("1024 x 768 pixels");
#line 1231 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp6_ = publishing_piwigo_size_entry_new (1024, _tmp5_);
#line 1231 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_vala_array_add41 (&_result_, &_result__length1, &__result__size_, _tmp6_);
#line 1232 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp7_ = _result_;
#line 1232 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp7__length1 = _result__length1;
#line 1232 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp8_ = _ ("2048 x 1536 pixels");
#line 1232 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp9_ = publishing_piwigo_size_entry_new (2048, _tmp8_);
#line 1232 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_vala_array_add42 (&_result_, &_result__length1, &__result__size_, _tmp9_);
#line 1233 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp10_ = _result_;
#line 1233 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp10__length1 = _result__length1;
#line 1233 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp11_ = _ ("4096 x 3072 pixels");
#line 1233 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp12_ = publishing_piwigo_size_entry_new (4096, _tmp11_);
#line 1233 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_vala_array_add43 (&_result_, &_result__length1, &__result__size_, _tmp12_);
#line 1234 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp13_ = _result_;
#line 1234 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp13__length1 = _result__length1;
#line 1234 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp14_ = _ ("Original size");
#line 1234 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp15_ = publishing_piwigo_size_entry_new (PUBLISHING_PIWIGO_ORIGINAL_SIZE, _tmp14_);
#line 1234 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_vala_array_add44 (&_result_, &_result__length1, &__result__size_, _tmp15_);
#line 1236 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp16_ = _result_;
#line 1236 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp16__length1 = _result__length1;
#line 1236 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (result_length1) {
#line 1236 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		*result_length1 = _tmp16__length1;
#line 8383 "PiwigoPublishing.c"
	}
#line 1236 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = _tmp16_;
#line 1236 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 8389 "PiwigoPublishing.c"
}


static void publishing_piwigo_publishing_options_pane_on_logout_button_clicked (PublishingPiwigoPublishingOptionsPane* self) {
#line 1239 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PUBLISHING_OPTIONS_PANE (self));
#line 1240 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_emit_by_name (self, "logout");
#line 8398 "PiwigoPublishing.c"
}


static gpointer _publishing_piwigo_permission_level_ref0 (gpointer self) {
#line 1245 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return self ? publishing_piwigo_permission_level_ref (self) : NULL;
#line 8405 "PiwigoPublishing.c"
}


static gpointer _publishing_piwigo_size_entry_ref0 (gpointer self) {
#line 1246 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return self ? publishing_piwigo_size_entry_ref (self) : NULL;
#line 8412 "PiwigoPublishing.c"
}


static void publishing_piwigo_publishing_options_pane_on_publish_button_clicked (PublishingPiwigoPublishingOptionsPane* self) {
	PublishingPiwigoPublishingParameters* params = NULL;
	PublishingPiwigoPublishingParameters* _tmp0_ = NULL;
	PublishingPiwigoPublishingParameters* _tmp1_ = NULL;
	PublishingPiwigoPermissionLevel** _tmp2_ = NULL;
	gint _tmp2__length1 = 0;
	GtkComboBoxText* _tmp3_ = NULL;
	gint _tmp4_ = 0;
	PublishingPiwigoPermissionLevel* _tmp5_ = NULL;
	PublishingPiwigoPermissionLevel* _tmp6_ = NULL;
	PublishingPiwigoPublishingParameters* _tmp7_ = NULL;
	PublishingPiwigoSizeEntry** _tmp8_ = NULL;
	gint _tmp8__length1 = 0;
	GtkComboBoxText* _tmp9_ = NULL;
	gint _tmp10_ = 0;
	PublishingPiwigoSizeEntry* _tmp11_ = NULL;
	PublishingPiwigoSizeEntry* _tmp12_ = NULL;
	PublishingPiwigoPublishingParameters* _tmp13_ = NULL;
	GtkCheckButton* _tmp14_ = NULL;
	gboolean _tmp15_ = FALSE;
	PublishingPiwigoPublishingParameters* _tmp16_ = NULL;
	GtkCheckButton* _tmp17_ = NULL;
	gboolean _tmp18_ = FALSE;
	GtkRadioButton* _tmp19_ = NULL;
	gboolean _tmp20_ = FALSE;
	PublishingPiwigoPublishingParameters* _tmp53_ = NULL;
	GtkCheckButton* _tmp54_ = NULL;
	gboolean _tmp55_ = FALSE;
#line 1243 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PUBLISHING_OPTIONS_PANE (self));
#line 1244 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = publishing_piwigo_publishing_parameters_new ();
#line 1244 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	params = _tmp0_;
#line 1245 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = params;
#line 1245 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = self->priv->perm_levels;
#line 1245 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2__length1 = self->priv->perm_levels_length1;
#line 1245 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3_ = self->priv->perms_combo;
#line 1245 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = gtk_combo_box_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, gtk_combo_box_get_type (), GtkComboBox));
#line 1245 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp5_ = _tmp2_[_tmp4_];
#line 1245 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp6_ = _publishing_piwigo_permission_level_ref0 (_tmp5_);
#line 1245 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_publishing_piwigo_permission_level_unref0 (_tmp1_->perm_level);
#line 1245 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_->perm_level = _tmp6_;
#line 1246 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp7_ = params;
#line 1246 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp8_ = self->priv->photo_sizes;
#line 1246 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp8__length1 = self->priv->photo_sizes_length1;
#line 1246 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp9_ = self->priv->size_combo;
#line 1246 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp10_ = gtk_combo_box_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, gtk_combo_box_get_type (), GtkComboBox));
#line 1246 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp11_ = _tmp8_[_tmp10_];
#line 1246 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp12_ = _publishing_piwigo_size_entry_ref0 (_tmp11_);
#line 1246 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_publishing_piwigo_size_entry_unref0 (_tmp7_->photo_size);
#line 1246 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp7_->photo_size = _tmp12_;
#line 1247 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp13_ = params;
#line 1247 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp14_ = self->priv->title_as_comment_check;
#line 1247 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp15_ = gtk_toggle_button_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp14_, gtk_toggle_button_get_type (), GtkToggleButton));
#line 1247 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp13_->title_as_comment = _tmp15_;
#line 1248 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp16_ = params;
#line 1248 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp17_ = self->priv->no_upload_tags_check;
#line 1248 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp18_ = gtk_toggle_button_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp17_, gtk_toggle_button_get_type (), GtkToggleButton));
#line 1248 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp16_->no_upload_tags = _tmp18_;
#line 1249 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp19_ = self->priv->create_new_radio;
#line 1249 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp20_ = gtk_toggle_button_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp19_, gtk_toggle_button_get_type (), GtkToggleButton));
#line 1249 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (_tmp20_) {
#line 8508 "PiwigoPublishing.c"
		gchar* uploadcomment = NULL;
		GtkTextView* _tmp21_ = NULL;
		GtkTextBuffer* _tmp22_ = NULL;
		GtkTextBuffer* _tmp23_ = NULL;
		gchar* _tmp24_ = NULL;
		gchar* _tmp25_ = NULL;
		gchar* _tmp26_ = NULL;
		gchar* _tmp27_ = NULL;
		gchar* _tmp28_ = NULL;
		gint a = 0;
		GtkComboBoxText* _tmp29_ = NULL;
		gint _tmp30_ = 0;
		gint _tmp31_ = 0;
#line 1250 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp21_ = self->priv->album_comment;
#line 1250 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp22_ = gtk_text_view_get_buffer (_tmp21_);
#line 1250 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp23_ = _tmp22_;
#line 1250 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_object_get (_tmp23_, "text", &_tmp24_, NULL);
#line 1250 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp25_ = _tmp24_;
#line 1250 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp26_ = _tmp25_;
#line 1250 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp27_ = string_strip (_tmp26_);
#line 1250 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp28_ = _tmp27_;
#line 1250 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_free0 (_tmp26_);
#line 1250 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		uploadcomment = _tmp28_;
#line 1251 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp29_ = self->priv->within_existing_combo;
#line 1251 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp30_ = gtk_combo_box_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp29_, gtk_combo_box_get_type (), GtkComboBox));
#line 1251 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		a = _tmp30_;
#line 1252 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp31_ = a;
#line 1252 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		if (_tmp31_ == 0) {
#line 8552 "PiwigoPublishing.c"
			PublishingPiwigoPublishingParameters* _tmp32_ = NULL;
			GtkEntry* _tmp33_ = NULL;
			const gchar* _tmp34_ = NULL;
			const gchar* _tmp35_ = NULL;
			PublishingPiwigoCategory* _tmp36_ = NULL;
#line 1253 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp32_ = params;
#line 1253 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp33_ = self->priv->new_category_entry;
#line 1253 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp34_ = gtk_entry_get_text (_tmp33_);
#line 1253 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp35_ = uploadcomment;
#line 1253 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp36_ = publishing_piwigo_category_new_local (_tmp34_, 0, _tmp35_);
#line 1253 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_publishing_piwigo_category_unref0 (_tmp32_->category);
#line 1253 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp32_->category = _tmp36_;
#line 8572 "PiwigoPublishing.c"
		} else {
			gint _tmp37_ = 0;
			PublishingPiwigoPublishingParameters* _tmp38_ = NULL;
			GtkEntry* _tmp39_ = NULL;
			const gchar* _tmp40_ = NULL;
			PublishingPiwigoCategory** _tmp41_ = NULL;
			gint _tmp41__length1 = 0;
			gint _tmp42_ = 0;
			PublishingPiwigoCategory* _tmp43_ = NULL;
			gint _tmp44_ = 0;
			const gchar* _tmp45_ = NULL;
			PublishingPiwigoCategory* _tmp46_ = NULL;
#line 1257 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp37_ = a;
#line 1257 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			a = _tmp37_ - 1;
#line 1258 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp38_ = params;
#line 1258 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp39_ = self->priv->new_category_entry;
#line 1258 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp40_ = gtk_entry_get_text (_tmp39_);
#line 1258 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp41_ = self->priv->existing_categories;
#line 1258 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp41__length1 = self->priv->existing_categories_length1;
#line 1258 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp42_ = a;
#line 1258 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp43_ = _tmp41_[_tmp42_];
#line 1258 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp44_ = _tmp43_->id;
#line 1258 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp45_ = uploadcomment;
#line 1258 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp46_ = publishing_piwigo_category_new_local (_tmp40_, _tmp44_, _tmp45_);
#line 1258 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_publishing_piwigo_category_unref0 (_tmp38_->category);
#line 1258 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp38_->category = _tmp46_;
#line 8613 "PiwigoPublishing.c"
		}
#line 1249 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_free0 (uploadcomment);
#line 8617 "PiwigoPublishing.c"
	} else {
		PublishingPiwigoPublishingParameters* _tmp47_ = NULL;
		PublishingPiwigoCategory** _tmp48_ = NULL;
		gint _tmp48__length1 = 0;
		GtkComboBoxText* _tmp49_ = NULL;
		gint _tmp50_ = 0;
		PublishingPiwigoCategory* _tmp51_ = NULL;
		PublishingPiwigoCategory* _tmp52_ = NULL;
#line 1262 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp47_ = params;
#line 1262 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp48_ = self->priv->existing_categories;
#line 1262 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp48__length1 = self->priv->existing_categories_length1;
#line 1262 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp49_ = self->priv->existing_categories_combo;
#line 1262 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp50_ = gtk_combo_box_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp49_, gtk_combo_box_get_type (), GtkComboBox));
#line 1262 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp51_ = _tmp48_[_tmp50_];
#line 1262 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp52_ = _publishing_piwigo_category_ref0 (_tmp51_);
#line 1262 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_publishing_piwigo_category_unref0 (_tmp47_->category);
#line 1262 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp47_->category = _tmp52_;
#line 8644 "PiwigoPublishing.c"
	}
#line 1264 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp53_ = params;
#line 1264 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp54_ = self->priv->strip_metadata_check;
#line 1264 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp55_ = gtk_toggle_button_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp54_, gtk_toggle_button_get_type (), GtkToggleButton));
#line 1264 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_emit_by_name (self, "publish", _tmp53_, _tmp55_);
#line 1243 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_publishing_piwigo_publishing_parameters_unref0 (params);
#line 8656 "PiwigoPublishing.c"
}


static void publishing_piwigo_publishing_options_pane_on_use_existing_radio_clicked (PublishingPiwigoPublishingOptionsPane* self) {
	GtkComboBoxText* _tmp0_ = NULL;
	GtkEntry* _tmp1_ = NULL;
	GtkLabel* _tmp2_ = NULL;
	GtkComboBoxText* _tmp3_ = NULL;
	GtkComboBoxText* _tmp4_ = NULL;
	GtkLabel* _tmp5_ = NULL;
	GtkTextView* _tmp6_ = NULL;
#line 1268 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PUBLISHING_OPTIONS_PANE (self));
#line 1269 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->existing_categories_combo;
#line 1269 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_widget_get_type (), GtkWidget), TRUE);
#line 1270 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = self->priv->new_category_entry;
#line 1270 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 1271 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = self->priv->within_existing_label;
#line 1271 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 1272 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3_ = self->priv->within_existing_combo;
#line 1272 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 1273 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = self->priv->existing_categories_combo;
#line 1273 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	gtk_widget_grab_focus (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, gtk_widget_get_type (), GtkWidget));
#line 1274 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp5_ = self->priv->album_comment_label;
#line 1274 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 1275 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp6_ = self->priv->album_comment;
#line 1275 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 1276 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_publishing_options_pane_update_publish_button_sensitivity (self);
#line 8700 "PiwigoPublishing.c"
}


static void publishing_piwigo_publishing_options_pane_on_create_new_radio_clicked (PublishingPiwigoPublishingOptionsPane* self) {
	GtkEntry* _tmp0_ = NULL;
	GtkLabel* _tmp1_ = NULL;
	GtkComboBoxText* _tmp2_ = NULL;
	GtkLabel* _tmp3_ = NULL;
	GtkTextView* _tmp4_ = NULL;
	GtkComboBoxText* _tmp5_ = NULL;
	GtkEntry* _tmp6_ = NULL;
#line 1279 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PUBLISHING_OPTIONS_PANE (self));
#line 1280 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->new_category_entry;
#line 1280 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_widget_get_type (), GtkWidget), TRUE);
#line 1281 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = self->priv->within_existing_label;
#line 1281 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, gtk_widget_get_type (), GtkWidget), TRUE);
#line 1282 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = self->priv->within_existing_combo;
#line 1282 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, gtk_widget_get_type (), GtkWidget), TRUE);
#line 1283 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3_ = self->priv->album_comment_label;
#line 1283 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, gtk_widget_get_type (), GtkWidget), TRUE);
#line 1284 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = self->priv->album_comment;
#line 1284 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, gtk_widget_get_type (), GtkWidget), TRUE);
#line 1285 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp5_ = self->priv->existing_categories_combo;
#line 1285 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 1286 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp6_ = self->priv->new_category_entry;
#line 1286 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	gtk_widget_grab_focus (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, gtk_widget_get_type (), GtkWidget));
#line 1287 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_publishing_options_pane_update_publish_button_sensitivity (self);
#line 8744 "PiwigoPublishing.c"
}


static void publishing_piwigo_publishing_options_pane_on_new_category_entry_changed (PublishingPiwigoPublishingOptionsPane* self) {
#line 1290 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PUBLISHING_OPTIONS_PANE (self));
#line 1291 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_publishing_options_pane_update_publish_button_sensitivity (self);
#line 8753 "PiwigoPublishing.c"
}


static void publishing_piwigo_publishing_options_pane_on_existing_combo_changed (PublishingPiwigoPublishingOptionsPane* self) {
#line 1294 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PUBLISHING_OPTIONS_PANE (self));
#line 1295 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_publishing_options_pane_update_publish_button_sensitivity (self);
#line 8762 "PiwigoPublishing.c"
}


static void publishing_piwigo_publishing_options_pane_update_publish_button_sensitivity (PublishingPiwigoPublishingOptionsPane* self) {
	gchar* category_name = NULL;
	GtkEntry* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gint a = 0;
	GtkComboBoxText* _tmp3_ = NULL;
	gint _tmp4_ = 0;
	gchar* search_name = NULL;
	gint _tmp5_ = 0;
	gboolean _tmp17_ = FALSE;
	GtkRadioButton* _tmp18_ = NULL;
	gboolean _tmp19_ = FALSE;
	GtkButton* _tmp24_ = NULL;
#line 1298 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PUBLISHING_OPTIONS_PANE (self));
#line 1299 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->new_category_entry;
#line 1299 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = gtk_entry_get_text (_tmp0_);
#line 1299 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = string_strip (_tmp1_);
#line 1299 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	category_name = _tmp2_;
#line 1300 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3_ = self->priv->within_existing_combo;
#line 1300 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = gtk_combo_box_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, gtk_combo_box_get_type (), GtkComboBox));
#line 1300 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	a = _tmp4_;
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp5_ = a;
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (_tmp5_ <= 0) {
#line 8800 "PiwigoPublishing.c"
		const gchar* _tmp6_ = NULL;
		gchar* _tmp7_ = NULL;
#line 1303 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp6_ = category_name;
#line 1303 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp7_ = g_strconcat ("/ ", _tmp6_, NULL);
#line 1303 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_free0 (search_name);
#line 1303 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		search_name = _tmp7_;
#line 8811 "PiwigoPublishing.c"
	} else {
		gint _tmp8_ = 0;
		PublishingPiwigoCategory** _tmp9_ = NULL;
		gint _tmp9__length1 = 0;
		gint _tmp10_ = 0;
		PublishingPiwigoCategory* _tmp11_ = NULL;
		const gchar* _tmp12_ = NULL;
		gchar* _tmp13_ = NULL;
		gchar* _tmp14_ = NULL;
		const gchar* _tmp15_ = NULL;
		gchar* _tmp16_ = NULL;
#line 1305 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp8_ = a;
#line 1305 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		a = _tmp8_ - 1;
#line 1306 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp9_ = self->priv->existing_categories;
#line 1306 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp9__length1 = self->priv->existing_categories_length1;
#line 1306 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp10_ = a;
#line 1306 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp11_ = _tmp9_[_tmp10_];
#line 1306 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp12_ = _tmp11_->display_name;
#line 1306 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp13_ = g_strconcat (_tmp12_, "/ ", NULL);
#line 1306 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp14_ = _tmp13_;
#line 1306 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp15_ = category_name;
#line 1306 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp16_ = g_strconcat (_tmp14_, _tmp15_, NULL);
#line 1306 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_free0 (search_name);
#line 1306 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		search_name = _tmp16_;
#line 1306 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_free0 (_tmp14_);
#line 8851 "PiwigoPublishing.c"
	}
#line 1310 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp18_ = self->priv->create_new_radio;
#line 1310 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp19_ = gtk_toggle_button_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp18_, gtk_toggle_button_get_type (), GtkToggleButton));
#line 1310 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (_tmp19_) {
#line 8859 "PiwigoPublishing.c"
		gboolean _tmp20_ = FALSE;
		const gchar* _tmp21_ = NULL;
#line 1312 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp21_ = category_name;
#line 1312 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		if (g_strcmp0 (_tmp21_, "") != 0) {
#line 1312 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp20_ = TRUE;
#line 8868 "PiwigoPublishing.c"
		} else {
			const gchar* _tmp22_ = NULL;
			gboolean _tmp23_ = FALSE;
#line 1313 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp22_ = search_name;
#line 1313 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp23_ = publishing_piwigo_publishing_options_pane_category_already_exists (self, _tmp22_);
#line 1313 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp20_ = _tmp23_;
#line 8878 "PiwigoPublishing.c"
		}
#line 1312 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp17_ = _tmp20_;
#line 8882 "PiwigoPublishing.c"
	} else {
#line 1310 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp17_ = FALSE;
#line 8886 "PiwigoPublishing.c"
	}
#line 1308 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp24_ = self->priv->publish_button;
#line 1308 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp24_, gtk_widget_get_type (), GtkWidget), !_tmp17_);
#line 1298 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (search_name);
#line 1298 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (category_name);
#line 8896 "PiwigoPublishing.c"
}


static GtkWidget* publishing_piwigo_publishing_options_pane_real_get_widget (SpitPublishingDialogPane* base) {
	PublishingPiwigoPublishingOptionsPane * self;
	GtkWidget* result = NULL;
	GtkBox* _tmp0_ = NULL;
	GtkWidget* _tmp1_ = NULL;
#line 1319 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_PIWIGO_TYPE_PUBLISHING_OPTIONS_PANE, PublishingPiwigoPublishingOptionsPane);
#line 1320 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->pane_widget;
#line 1320 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_widget_get_type (), GtkWidget));
#line 1320 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = _tmp1_;
#line 1320 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 8915 "PiwigoPublishing.c"
}


static SpitPublishingDialogPaneGeometryOptions publishing_piwigo_publishing_options_pane_real_get_preferred_geometry (SpitPublishingDialogPane* base) {
	PublishingPiwigoPublishingOptionsPane * self;
	SpitPublishingDialogPaneGeometryOptions result = 0;
#line 1323 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_PIWIGO_TYPE_PUBLISHING_OPTIONS_PANE, PublishingPiwigoPublishingOptionsPane);
#line 1324 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = SPIT_PUBLISHING_DIALOG_PANE_GEOMETRY_OPTIONS_NONE;
#line 1324 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 8928 "PiwigoPublishing.c"
}


static void publishing_piwigo_publishing_options_pane_real_on_pane_installed (SpitPublishingDialogPane* base) {
	PublishingPiwigoPublishingOptionsPane * self;
	GtkButton* _tmp0_ = NULL;
#line 1327 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_PIWIGO_TYPE_PUBLISHING_OPTIONS_PANE, PublishingPiwigoPublishingOptionsPane);
#line 1328 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_publishing_options_pane_create_categories_combo (self);
#line 1329 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_publishing_options_pane_create_within_categories_combo (self);
#line 1330 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_publishing_options_pane_create_permissions_combo (self);
#line 1331 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_publishing_options_pane_create_size_combo (self);
#line 1333 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->publish_button;
#line 1333 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	gtk_widget_set_can_default (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_widget_get_type (), GtkWidget), TRUE);
#line 1334 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_publishing_options_pane_update_publish_button_sensitivity (self);
#line 8951 "PiwigoPublishing.c"
}


static gchar* publishing_piwigo_publishing_options_pane_get_common_comment_if_possible (PublishingPiwigoPublishingOptionsPane* self, PublishingPiwigoPiwigoPublisher* publisher) {
	gchar* result = NULL;
	SpitPublishingPublishable** publishables = NULL;
	PublishingPiwigoPiwigoPublisher* _tmp0_ = NULL;
	SpitPublishingPluginHost* _tmp1_ = NULL;
	SpitPublishingPluginHost* _tmp2_ = NULL;
	gint _tmp3_ = 0;
	SpitPublishingPublishable** _tmp4_ = NULL;
	SpitPublishingPublishable** _tmp5_ = NULL;
	gint _tmp5__length1 = 0;
	gint publishables_length1 = 0;
	gint _publishables_size_ = 0;
	gchar* common = NULL;
	gchar* _tmp6_ = NULL;
	gboolean isfirst = FALSE;
	SpitPublishingPublishable** _tmp7_ = NULL;
	gint _tmp7__length1 = 0;
	const gchar* _tmp18_ = NULL;
#line 1337 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_PUBLISHING_OPTIONS_PANE (self), NULL);
#line 1337 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (publisher), NULL);
#line 1340 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = publisher;
#line 1340 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = publishing_piwigo_piwigo_publisher_get_host (_tmp0_);
#line 1340 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = _tmp1_;
#line 1340 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = spit_publishing_plugin_host_get_publishables (_tmp2_, &_tmp3_);
#line 1340 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp5_ = _tmp4_;
#line 1340 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp5__length1 = _tmp3_;
#line 1340 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (_tmp2_);
#line 1340 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishables = _tmp5_;
#line 1340 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishables_length1 = _tmp5__length1;
#line 1340 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_publishables_size_ = publishables_length1;
#line 1341 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp6_ = g_strdup ("");
#line 1341 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	common = _tmp6_;
#line 1342 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	isfirst = TRUE;
#line 1343 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp7_ = publishables;
#line 1343 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp7__length1 = publishables_length1;
#line 1343 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (_tmp7_ != NULL) {
#line 9009 "PiwigoPublishing.c"
		SpitPublishingPublishable** _tmp8_ = NULL;
		gint _tmp8__length1 = 0;
#line 1344 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp8_ = publishables;
#line 1344 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp8__length1 = publishables_length1;
#line 9016 "PiwigoPublishing.c"
		{
			SpitPublishingPublishable** pub_collection = NULL;
			gint pub_collection_length1 = 0;
			gint _pub_collection_size_ = 0;
			gint pub_it = 0;
#line 1344 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			pub_collection = _tmp8_;
#line 1344 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			pub_collection_length1 = _tmp8__length1;
#line 1344 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			for (pub_it = 0; pub_it < _tmp8__length1; pub_it = pub_it + 1) {
#line 9028 "PiwigoPublishing.c"
				SpitPublishingPublishable* _tmp9_ = NULL;
				SpitPublishingPublishable* pub = NULL;
#line 1344 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp9_ = _g_object_ref0 (pub_collection[pub_it]);
#line 1344 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				pub = _tmp9_;
#line 9035 "PiwigoPublishing.c"
				{
					gchar* cur = NULL;
					SpitPublishingPublishable* _tmp10_ = NULL;
					gchar* _tmp11_ = NULL;
					gboolean _tmp12_ = FALSE;
#line 1345 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_tmp10_ = pub;
#line 1345 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_tmp11_ = spit_publishing_publishable_get_param_string (_tmp10_, SPIT_PUBLISHING_PUBLISHABLE_PARAM_STRING_EVENTCOMMENT);
#line 1345 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					cur = _tmp11_;
#line 1347 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_tmp12_ = isfirst;
#line 1347 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					if (_tmp12_) {
#line 9051 "PiwigoPublishing.c"
						const gchar* _tmp13_ = NULL;
						gchar* _tmp14_ = NULL;
#line 1348 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
						_tmp13_ = cur;
#line 1348 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
						_tmp14_ = g_strdup (_tmp13_);
#line 1348 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
						_g_free0 (common);
#line 1348 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
						common = _tmp14_;
#line 1349 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
						isfirst = FALSE;
#line 9064 "PiwigoPublishing.c"
					} else {
						const gchar* _tmp15_ = NULL;
						const gchar* _tmp16_ = NULL;
#line 1351 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
						_tmp15_ = cur;
#line 1351 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
						_tmp16_ = common;
#line 1351 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
						if (g_strcmp0 (_tmp15_, _tmp16_) != 0) {
#line 9074 "PiwigoPublishing.c"
							gchar* _tmp17_ = NULL;
#line 1352 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
							_tmp17_ = g_strdup ("");
#line 1352 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
							_g_free0 (common);
#line 1352 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
							common = _tmp17_;
#line 1353 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
							_g_free0 (cur);
#line 1353 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
							_g_object_unref0 (pub);
#line 1353 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
							break;
#line 9088 "PiwigoPublishing.c"
						}
					}
#line 1344 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_g_free0 (cur);
#line 1344 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_g_object_unref0 (pub);
#line 9095 "PiwigoPublishing.c"
				}
			}
		}
	}
#line 1358 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp18_ = common;
#line 1358 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_debug ("PiwigoPublishing.vala:1358: PiwigoConnector: found common event commen" \
"t %s\n", _tmp18_);
#line 1359 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = common;
#line 1359 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishables = (_vala_array_free (publishables, publishables_length1, (GDestroyNotify) g_object_unref), NULL);
#line 1359 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 9110 "PiwigoPublishing.c"
}


static void publishing_piwigo_publishing_options_pane_create_categories_combo (PublishingPiwigoPublishingOptionsPane* self) {
	PublishingPiwigoCategory** _tmp0_ = NULL;
	gint _tmp0__length1 = 0;
	PublishingPiwigoCategory** _tmp5_ = NULL;
	gint _tmp5__length1 = 0;
	const gchar* _tmp21_ = NULL;
	gboolean _tmp22_ = FALSE;
#line 1362 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PUBLISHING_OPTIONS_PANE (self));
#line 1363 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->existing_categories;
#line 1363 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0__length1 = self->priv->existing_categories_length1;
#line 9127 "PiwigoPublishing.c"
	{
		PublishingPiwigoCategory** cat_collection = NULL;
		gint cat_collection_length1 = 0;
		gint _cat_collection_size_ = 0;
		gint cat_it = 0;
#line 1363 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		cat_collection = _tmp0_;
#line 1363 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		cat_collection_length1 = _tmp0__length1;
#line 1363 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		for (cat_it = 0; cat_it < _tmp0__length1; cat_it = cat_it + 1) {
#line 9139 "PiwigoPublishing.c"
			PublishingPiwigoCategory* _tmp1_ = NULL;
			PublishingPiwigoCategory* cat = NULL;
#line 1363 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp1_ = _publishing_piwigo_category_ref0 (cat_collection[cat_it]);
#line 1363 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			cat = _tmp1_;
#line 9146 "PiwigoPublishing.c"
			{
				GtkComboBoxText* _tmp2_ = NULL;
				PublishingPiwigoCategory* _tmp3_ = NULL;
				const gchar* _tmp4_ = NULL;
#line 1364 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp2_ = self->priv->existing_categories_combo;
#line 1364 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp3_ = cat;
#line 1364 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp4_ = _tmp3_->display_name;
#line 1364 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				gtk_combo_box_text_append_text (_tmp2_, _tmp4_);
#line 1363 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_publishing_piwigo_category_unref0 (cat);
#line 9161 "PiwigoPublishing.c"
			}
		}
	}
#line 1366 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp5_ = self->priv->existing_categories;
#line 1366 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp5__length1 = self->priv->existing_categories_length1;
#line 1366 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (_tmp5__length1 == 0) {
#line 9171 "PiwigoPublishing.c"
		GtkComboBoxText* _tmp6_ = NULL;
		GtkRadioButton* _tmp7_ = NULL;
		GtkRadioButton* _tmp8_ = NULL;
		GtkTextView* _tmp9_ = NULL;
		GtkLabel* _tmp10_ = NULL;
		GtkEntry* _tmp11_ = NULL;
#line 1368 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp6_ = self->priv->existing_categories_combo;
#line 1368 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 1369 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp7_ = self->priv->use_existing_radio;
#line 1369 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 1370 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp8_ = self->priv->create_new_radio;
#line 1370 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		gtk_toggle_button_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, gtk_toggle_button_get_type (), GtkToggleButton), TRUE);
#line 1371 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp9_ = self->priv->album_comment;
#line 1371 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, gtk_widget_get_type (), GtkWidget), TRUE);
#line 1372 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp10_ = self->priv->album_comment_label;
#line 1372 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, gtk_widget_get_type (), GtkWidget), TRUE);
#line 1373 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp11_ = self->priv->new_category_entry;
#line 1373 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		gtk_widget_grab_focus (G_TYPE_CHECK_INSTANCE_CAST (_tmp11_, gtk_widget_get_type (), GtkWidget));
#line 9202 "PiwigoPublishing.c"
	} else {
		gint last_category_index = 0;
		gint _tmp12_ = 0;
		gint _tmp13_ = 0;
		gint _tmp14_ = 0;
		GtkEntry* _tmp18_ = NULL;
		GtkTextView* _tmp19_ = NULL;
		GtkLabel* _tmp20_ = NULL;
#line 1375 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp12_ = self->priv->last_category;
#line 1375 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp13_ = publishing_piwigo_publishing_options_pane_find_category_index (self, _tmp12_);
#line 1375 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		last_category_index = _tmp13_;
#line 1376 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp14_ = last_category_index;
#line 1376 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		if (_tmp14_ < 0) {
#line 9221 "PiwigoPublishing.c"
			GtkComboBoxText* _tmp15_ = NULL;
#line 1377 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp15_ = self->priv->existing_categories_combo;
#line 1377 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			gtk_combo_box_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp15_, gtk_combo_box_get_type (), GtkComboBox), 0);
#line 9227 "PiwigoPublishing.c"
		} else {
			GtkComboBoxText* _tmp16_ = NULL;
			gint _tmp17_ = 0;
#line 1379 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp16_ = self->priv->existing_categories_combo;
#line 1379 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp17_ = last_category_index;
#line 1379 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			gtk_combo_box_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp16_, gtk_combo_box_get_type (), GtkComboBox), _tmp17_);
#line 9237 "PiwigoPublishing.c"
		}
#line 1381 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp18_ = self->priv->new_category_entry;
#line 1381 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp18_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 1382 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp19_ = self->priv->album_comment;
#line 1382 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp19_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 1383 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp20_ = self->priv->album_comment_label;
#line 1383 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp20_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 9251 "PiwigoPublishing.c"
	}
#line 1385 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp21_ = publishing_piwigo_publishing_options_pane_DEFAULT_CATEGORY_NAME;
#line 1385 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp22_ = publishing_piwigo_publishing_options_pane_category_already_exists (self, _tmp21_);
#line 1385 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (!_tmp22_) {
#line 9259 "PiwigoPublishing.c"
		GtkEntry* _tmp23_ = NULL;
		const gchar* _tmp24_ = NULL;
#line 1386 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp23_ = self->priv->new_category_entry;
#line 1386 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp24_ = publishing_piwigo_publishing_options_pane_DEFAULT_CATEGORY_NAME;
#line 1386 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		gtk_entry_set_text (_tmp23_, _tmp24_);
#line 9268 "PiwigoPublishing.c"
	}
}


static void publishing_piwigo_publishing_options_pane_create_within_categories_combo (PublishingPiwigoPublishingOptionsPane* self) {
	GtkComboBoxText* _tmp0_ = NULL;
	PublishingPiwigoCategory** _tmp1_ = NULL;
	gint _tmp1__length1 = 0;
	GtkLabel* _tmp6_ = NULL;
	GtkComboBoxText* _tmp7_ = NULL;
	GtkComboBoxText* _tmp8_ = NULL;
#line 1389 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PUBLISHING_OPTIONS_PANE (self));
#line 1391 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->within_existing_combo;
#line 1391 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	gtk_combo_box_text_append_text (_tmp0_, "/ ");
#line 1392 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = self->priv->existing_categories;
#line 1392 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1__length1 = self->priv->existing_categories_length1;
#line 9290 "PiwigoPublishing.c"
	{
		PublishingPiwigoCategory** cat_collection = NULL;
		gint cat_collection_length1 = 0;
		gint _cat_collection_size_ = 0;
		gint cat_it = 0;
#line 1392 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		cat_collection = _tmp1_;
#line 1392 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		cat_collection_length1 = _tmp1__length1;
#line 1392 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		for (cat_it = 0; cat_it < _tmp1__length1; cat_it = cat_it + 1) {
#line 9302 "PiwigoPublishing.c"
			PublishingPiwigoCategory* _tmp2_ = NULL;
			PublishingPiwigoCategory* cat = NULL;
#line 1392 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp2_ = _publishing_piwigo_category_ref0 (cat_collection[cat_it]);
#line 1392 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			cat = _tmp2_;
#line 9309 "PiwigoPublishing.c"
			{
				GtkComboBoxText* _tmp3_ = NULL;
				PublishingPiwigoCategory* _tmp4_ = NULL;
				const gchar* _tmp5_ = NULL;
#line 1393 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp3_ = self->priv->within_existing_combo;
#line 1393 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp4_ = cat;
#line 1393 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp5_ = _tmp4_->display_name;
#line 1393 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				gtk_combo_box_text_append_text (_tmp3_, _tmp5_);
#line 1392 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_publishing_piwigo_category_unref0 (cat);
#line 9324 "PiwigoPublishing.c"
			}
		}
	}
#line 1396 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp6_ = self->priv->within_existing_label;
#line 1396 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 1397 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp7_ = self->priv->within_existing_combo;
#line 1397 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	gtk_combo_box_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, gtk_combo_box_get_type (), GtkComboBox), 0);
#line 1398 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp8_ = self->priv->within_existing_combo;
#line 1398 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 9340 "PiwigoPublishing.c"
}


static void publishing_piwigo_publishing_options_pane_create_permissions_combo (PublishingPiwigoPublishingOptionsPane* self) {
	PublishingPiwigoPermissionLevel** _tmp0_ = NULL;
	gint _tmp0__length1 = 0;
	gint last_permission_level_index = 0;
	gint _tmp5_ = 0;
	gint _tmp6_ = 0;
	gint _tmp7_ = 0;
#line 1401 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PUBLISHING_OPTIONS_PANE (self));
#line 1402 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->perm_levels;
#line 1402 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0__length1 = self->priv->perm_levels_length1;
#line 9357 "PiwigoPublishing.c"
	{
		PublishingPiwigoPermissionLevel** perm_collection = NULL;
		gint perm_collection_length1 = 0;
		gint _perm_collection_size_ = 0;
		gint perm_it = 0;
#line 1402 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		perm_collection = _tmp0_;
#line 1402 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		perm_collection_length1 = _tmp0__length1;
#line 1402 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		for (perm_it = 0; perm_it < _tmp0__length1; perm_it = perm_it + 1) {
#line 9369 "PiwigoPublishing.c"
			PublishingPiwigoPermissionLevel* _tmp1_ = NULL;
			PublishingPiwigoPermissionLevel* perm = NULL;
#line 1402 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp1_ = _publishing_piwigo_permission_level_ref0 (perm_collection[perm_it]);
#line 1402 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			perm = _tmp1_;
#line 9376 "PiwigoPublishing.c"
			{
				GtkComboBoxText* _tmp2_ = NULL;
				PublishingPiwigoPermissionLevel* _tmp3_ = NULL;
				const gchar* _tmp4_ = NULL;
#line 1403 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp2_ = self->priv->perms_combo;
#line 1403 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp3_ = perm;
#line 1403 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp4_ = _tmp3_->name;
#line 1403 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				gtk_combo_box_text_append_text (_tmp2_, _tmp4_);
#line 1402 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_publishing_piwigo_permission_level_unref0 (perm);
#line 9391 "PiwigoPublishing.c"
			}
		}
	}
#line 1405 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp5_ = self->priv->last_permission_level;
#line 1405 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp6_ = publishing_piwigo_publishing_options_pane_find_permission_level_index (self, _tmp5_);
#line 1405 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	last_permission_level_index = _tmp6_;
#line 1406 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp7_ = last_permission_level_index;
#line 1406 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (_tmp7_ < 0) {
#line 9405 "PiwigoPublishing.c"
		GtkComboBoxText* _tmp8_ = NULL;
#line 1407 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp8_ = self->priv->perms_combo;
#line 1407 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		gtk_combo_box_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, gtk_combo_box_get_type (), GtkComboBox), 0);
#line 9411 "PiwigoPublishing.c"
	} else {
		GtkComboBoxText* _tmp9_ = NULL;
		gint _tmp10_ = 0;
#line 1409 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp9_ = self->priv->perms_combo;
#line 1409 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp10_ = last_permission_level_index;
#line 1409 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		gtk_combo_box_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, gtk_combo_box_get_type (), GtkComboBox), _tmp10_);
#line 9421 "PiwigoPublishing.c"
	}
}


static void publishing_piwigo_publishing_options_pane_create_size_combo (PublishingPiwigoPublishingOptionsPane* self) {
	PublishingPiwigoSizeEntry** _tmp0_ = NULL;
	gint _tmp0__length1 = 0;
	gint last_size_index = 0;
	gint _tmp5_ = 0;
	gint _tmp6_ = 0;
	gint _tmp7_ = 0;
#line 1413 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PUBLISHING_OPTIONS_PANE (self));
#line 1414 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->photo_sizes;
#line 1414 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0__length1 = self->priv->photo_sizes_length1;
#line 9439 "PiwigoPublishing.c"
	{
		PublishingPiwigoSizeEntry** size_collection = NULL;
		gint size_collection_length1 = 0;
		gint _size_collection_size_ = 0;
		gint size_it = 0;
#line 1414 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		size_collection = _tmp0_;
#line 1414 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		size_collection_length1 = _tmp0__length1;
#line 1414 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		for (size_it = 0; size_it < _tmp0__length1; size_it = size_it + 1) {
#line 9451 "PiwigoPublishing.c"
			PublishingPiwigoSizeEntry* _tmp1_ = NULL;
			PublishingPiwigoSizeEntry* size = NULL;
#line 1414 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp1_ = _publishing_piwigo_size_entry_ref0 (size_collection[size_it]);
#line 1414 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			size = _tmp1_;
#line 9458 "PiwigoPublishing.c"
			{
				GtkComboBoxText* _tmp2_ = NULL;
				PublishingPiwigoSizeEntry* _tmp3_ = NULL;
				const gchar* _tmp4_ = NULL;
#line 1415 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp2_ = self->priv->size_combo;
#line 1415 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp3_ = size;
#line 1415 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp4_ = _tmp3_->name;
#line 1415 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				gtk_combo_box_text_append_text (_tmp2_, _tmp4_);
#line 1414 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_publishing_piwigo_size_entry_unref0 (size);
#line 9473 "PiwigoPublishing.c"
			}
		}
	}
#line 1417 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp5_ = self->priv->last_photo_size;
#line 1417 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp6_ = publishing_piwigo_publishing_options_pane_find_size_index (self, _tmp5_);
#line 1417 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	last_size_index = _tmp6_;
#line 1418 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp7_ = last_size_index;
#line 1418 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (_tmp7_ < 0) {
#line 9487 "PiwigoPublishing.c"
		GtkComboBoxText* _tmp8_ = NULL;
		gint _tmp9_ = 0;
#line 1419 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp8_ = self->priv->size_combo;
#line 1419 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp9_ = publishing_piwigo_publishing_options_pane_find_size_index (self, PUBLISHING_PIWIGO_ORIGINAL_SIZE);
#line 1419 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		gtk_combo_box_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, gtk_combo_box_get_type (), GtkComboBox), _tmp9_);
#line 9496 "PiwigoPublishing.c"
	} else {
		GtkComboBoxText* _tmp10_ = NULL;
		gint _tmp11_ = 0;
#line 1421 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp10_ = self->priv->size_combo;
#line 1421 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp11_ = last_size_index;
#line 1421 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		gtk_combo_box_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, gtk_combo_box_get_type (), GtkComboBox), _tmp11_);
#line 9506 "PiwigoPublishing.c"
	}
}


static void publishing_piwigo_publishing_options_pane_real_on_pane_uninstalled (SpitPublishingDialogPane* base) {
	PublishingPiwigoPublishingOptionsPane * self;
#line 1425 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_PIWIGO_TYPE_PUBLISHING_OPTIONS_PANE, PublishingPiwigoPublishingOptionsPane);
#line 9515 "PiwigoPublishing.c"
}


static gint publishing_piwigo_publishing_options_pane_find_category_index (PublishingPiwigoPublishingOptionsPane* self, gint category_id) {
	gint result = 0;
	gint _result_ = 0;
#line 1428 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_PUBLISHING_OPTIONS_PANE (self), 0);
#line 1429 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_result_ = -1;
#line 9526 "PiwigoPublishing.c"
	{
		gint i = 0;
#line 1430 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		i = 0;
#line 9531 "PiwigoPublishing.c"
		{
			gboolean _tmp0_ = FALSE;
#line 1430 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp0_ = TRUE;
#line 1430 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			while (TRUE) {
#line 9538 "PiwigoPublishing.c"
				gint _tmp2_ = 0;
				PublishingPiwigoCategory** _tmp3_ = NULL;
				gint _tmp3__length1 = 0;
				PublishingPiwigoCategory** _tmp4_ = NULL;
				gint _tmp4__length1 = 0;
				gint _tmp5_ = 0;
				PublishingPiwigoCategory* _tmp6_ = NULL;
				gint _tmp7_ = 0;
				gint _tmp8_ = 0;
#line 1430 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				if (!_tmp0_) {
#line 9550 "PiwigoPublishing.c"
					gint _tmp1_ = 0;
#line 1430 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_tmp1_ = i;
#line 1430 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					i = _tmp1_ + 1;
#line 9556 "PiwigoPublishing.c"
				}
#line 1430 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp0_ = FALSE;
#line 1430 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp2_ = i;
#line 1430 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp3_ = self->priv->existing_categories;
#line 1430 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp3__length1 = self->priv->existing_categories_length1;
#line 1430 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				if (!(_tmp2_ < _tmp3__length1)) {
#line 1430 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					break;
#line 9570 "PiwigoPublishing.c"
				}
#line 1431 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp4_ = self->priv->existing_categories;
#line 1431 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp4__length1 = self->priv->existing_categories_length1;
#line 1431 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp5_ = i;
#line 1431 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp6_ = _tmp4_[_tmp5_];
#line 1431 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp7_ = _tmp6_->id;
#line 1431 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp8_ = category_id;
#line 1431 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				if (_tmp7_ == _tmp8_) {
#line 9586 "PiwigoPublishing.c"
					gint _tmp9_ = 0;
#line 1432 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_tmp9_ = i;
#line 1432 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_result_ = _tmp9_;
#line 1433 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					break;
#line 9594 "PiwigoPublishing.c"
				}
			}
		}
	}
#line 1436 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = _result_;
#line 1436 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 9603 "PiwigoPublishing.c"
}


static gint publishing_piwigo_publishing_options_pane_find_permission_level_index (PublishingPiwigoPublishingOptionsPane* self, gint permission_level_id) {
	gint result = 0;
	gint _result_ = 0;
#line 1439 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_PUBLISHING_OPTIONS_PANE (self), 0);
#line 1440 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_result_ = -1;
#line 9614 "PiwigoPublishing.c"
	{
		gint i = 0;
#line 1441 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		i = 0;
#line 9619 "PiwigoPublishing.c"
		{
			gboolean _tmp0_ = FALSE;
#line 1441 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp0_ = TRUE;
#line 1441 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			while (TRUE) {
#line 9626 "PiwigoPublishing.c"
				gint _tmp2_ = 0;
				PublishingPiwigoPermissionLevel** _tmp3_ = NULL;
				gint _tmp3__length1 = 0;
				PublishingPiwigoPermissionLevel** _tmp4_ = NULL;
				gint _tmp4__length1 = 0;
				gint _tmp5_ = 0;
				PublishingPiwigoPermissionLevel* _tmp6_ = NULL;
				gint _tmp7_ = 0;
				gint _tmp8_ = 0;
#line 1441 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				if (!_tmp0_) {
#line 9638 "PiwigoPublishing.c"
					gint _tmp1_ = 0;
#line 1441 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_tmp1_ = i;
#line 1441 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					i = _tmp1_ + 1;
#line 9644 "PiwigoPublishing.c"
				}
#line 1441 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp0_ = FALSE;
#line 1441 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp2_ = i;
#line 1441 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp3_ = self->priv->perm_levels;
#line 1441 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp3__length1 = self->priv->perm_levels_length1;
#line 1441 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				if (!(_tmp2_ < _tmp3__length1)) {
#line 1441 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					break;
#line 9658 "PiwigoPublishing.c"
				}
#line 1442 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp4_ = self->priv->perm_levels;
#line 1442 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp4__length1 = self->priv->perm_levels_length1;
#line 1442 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp5_ = i;
#line 1442 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp6_ = _tmp4_[_tmp5_];
#line 1442 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp7_ = _tmp6_->id;
#line 1442 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp8_ = permission_level_id;
#line 1442 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				if (_tmp7_ == _tmp8_) {
#line 9674 "PiwigoPublishing.c"
					gint _tmp9_ = 0;
#line 1443 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_tmp9_ = i;
#line 1443 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_result_ = _tmp9_;
#line 1444 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					break;
#line 9682 "PiwigoPublishing.c"
				}
			}
		}
	}
#line 1447 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = _result_;
#line 1447 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 9691 "PiwigoPublishing.c"
}


static gint publishing_piwigo_publishing_options_pane_find_size_index (PublishingPiwigoPublishingOptionsPane* self, gint size_id) {
	gint result = 0;
	gint _result_ = 0;
#line 1450 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_PUBLISHING_OPTIONS_PANE (self), 0);
#line 1451 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_result_ = -1;
#line 9702 "PiwigoPublishing.c"
	{
		gint i = 0;
#line 1452 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		i = 0;
#line 9707 "PiwigoPublishing.c"
		{
			gboolean _tmp0_ = FALSE;
#line 1452 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp0_ = TRUE;
#line 1452 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			while (TRUE) {
#line 9714 "PiwigoPublishing.c"
				gint _tmp2_ = 0;
				PublishingPiwigoSizeEntry** _tmp3_ = NULL;
				gint _tmp3__length1 = 0;
				PublishingPiwigoSizeEntry** _tmp4_ = NULL;
				gint _tmp4__length1 = 0;
				gint _tmp5_ = 0;
				PublishingPiwigoSizeEntry* _tmp6_ = NULL;
				gint _tmp7_ = 0;
				gint _tmp8_ = 0;
#line 1452 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				if (!_tmp0_) {
#line 9726 "PiwigoPublishing.c"
					gint _tmp1_ = 0;
#line 1452 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_tmp1_ = i;
#line 1452 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					i = _tmp1_ + 1;
#line 9732 "PiwigoPublishing.c"
				}
#line 1452 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp0_ = FALSE;
#line 1452 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp2_ = i;
#line 1452 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp3_ = self->priv->photo_sizes;
#line 1452 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp3__length1 = self->priv->photo_sizes_length1;
#line 1452 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				if (!(_tmp2_ < _tmp3__length1)) {
#line 1452 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					break;
#line 9746 "PiwigoPublishing.c"
				}
#line 1453 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp4_ = self->priv->photo_sizes;
#line 1453 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp4__length1 = self->priv->photo_sizes_length1;
#line 1453 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp5_ = i;
#line 1453 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp6_ = _tmp4_[_tmp5_];
#line 1453 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp7_ = _tmp6_->id;
#line 1453 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp8_ = size_id;
#line 1453 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				if (_tmp7_ == _tmp8_) {
#line 9762 "PiwigoPublishing.c"
					gint _tmp9_ = 0;
#line 1454 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_tmp9_ = i;
#line 1454 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_result_ = _tmp9_;
#line 1455 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					break;
#line 9770 "PiwigoPublishing.c"
				}
			}
		}
	}
#line 1458 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = _result_;
#line 1458 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 9779 "PiwigoPublishing.c"
}


static gboolean publishing_piwigo_publishing_options_pane_category_already_exists (PublishingPiwigoPublishingOptionsPane* self, const gchar* category_name) {
	gboolean result = FALSE;
	gboolean _result_ = FALSE;
	PublishingPiwigoCategory** _tmp0_ = NULL;
	gint _tmp0__length1 = 0;
#line 1461 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_PUBLISHING_OPTIONS_PANE (self), FALSE);
#line 1461 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (category_name != NULL, FALSE);
#line 1462 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_result_ = FALSE;
#line 1463 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->existing_categories;
#line 1463 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0__length1 = self->priv->existing_categories_length1;
#line 9798 "PiwigoPublishing.c"
	{
		PublishingPiwigoCategory** category_collection = NULL;
		gint category_collection_length1 = 0;
		gint _category_collection_size_ = 0;
		gint category_it = 0;
#line 1463 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		category_collection = _tmp0_;
#line 1463 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		category_collection_length1 = _tmp0__length1;
#line 1463 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		for (category_it = 0; category_it < _tmp0__length1; category_it = category_it + 1) {
#line 9810 "PiwigoPublishing.c"
			PublishingPiwigoCategory* _tmp1_ = NULL;
			PublishingPiwigoCategory* category = NULL;
#line 1463 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp1_ = _publishing_piwigo_category_ref0 (category_collection[category_it]);
#line 1463 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			category = _tmp1_;
#line 9817 "PiwigoPublishing.c"
			{
				PublishingPiwigoCategory* _tmp2_ = NULL;
				const gchar* _tmp3_ = NULL;
				gchar* _tmp4_ = NULL;
				gchar* _tmp5_ = NULL;
				const gchar* _tmp6_ = NULL;
				gboolean _tmp7_ = FALSE;
#line 1464 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp2_ = category;
#line 1464 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp3_ = _tmp2_->display_name;
#line 1464 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp4_ = string_strip (_tmp3_);
#line 1464 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp5_ = _tmp4_;
#line 1464 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp6_ = category_name;
#line 1464 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp7_ = g_strcmp0 (_tmp5_, _tmp6_) == 0;
#line 1464 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_g_free0 (_tmp5_);
#line 1464 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				if (_tmp7_) {
#line 1465 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_result_ = TRUE;
#line 1466 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_publishing_piwigo_category_unref0 (category);
#line 1466 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					break;
#line 9847 "PiwigoPublishing.c"
				}
#line 1463 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_publishing_piwigo_category_unref0 (category);
#line 9851 "PiwigoPublishing.c"
			}
		}
	}
#line 1469 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = _result_;
#line 1469 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 9859 "PiwigoPublishing.c"
}


static void g_cclosure_user_marshal_VOID__PUBLISHING_PIWIGO_PUBLISHING_PARAMETERS_BOOLEAN (GClosure * closure, GValue * return_value, guint n_param_values, const GValue * param_values, gpointer invocation_hint, gpointer marshal_data) {
	typedef void (*GMarshalFunc_VOID__PUBLISHING_PIWIGO_PUBLISHING_PARAMETERS_BOOLEAN) (gpointer data1, gpointer arg_1, gboolean arg_2, gpointer data2);
	register GMarshalFunc_VOID__PUBLISHING_PIWIGO_PUBLISHING_PARAMETERS_BOOLEAN callback;
	register GCClosure * cc;
	register gpointer data1;
	register gpointer data2;
	cc = (GCClosure *) closure;
#line 1112 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (n_param_values == 3);
#line 1112 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (G_CCLOSURE_SWAP_DATA (closure)) {
#line 1112 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		data1 = closure->data;
#line 1112 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		data2 = param_values->data[0].v_pointer;
#line 9878 "PiwigoPublishing.c"
	} else {
#line 1112 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		data1 = param_values->data[0].v_pointer;
#line 1112 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		data2 = closure->data;
#line 9884 "PiwigoPublishing.c"
	}
#line 1112 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	callback = (GMarshalFunc_VOID__PUBLISHING_PIWIGO_PUBLISHING_PARAMETERS_BOOLEAN) (marshal_data ? marshal_data : cc->callback);
#line 1112 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	callback (data1, publishing_piwigo_value_get_publishing_parameters (param_values + 1), g_value_get_boolean (param_values + 2), data2);
#line 9890 "PiwigoPublishing.c"
}


static void publishing_piwigo_publishing_options_pane_class_init (PublishingPiwigoPublishingOptionsPaneClass * klass) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 1112 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_publishing_options_pane_parent_class = g_type_class_peek_parent (klass);
#line 1112 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_type_class_add_private (klass, sizeof (PublishingPiwigoPublishingOptionsPanePrivate));
#line 1112 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	G_OBJECT_CLASS (klass)->finalize = publishing_piwigo_publishing_options_pane_finalize;
#line 1112 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_new ("publish", PUBLISHING_PIWIGO_TYPE_PUBLISHING_OPTIONS_PANE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_user_marshal_VOID__PUBLISHING_PIWIGO_PUBLISHING_PARAMETERS_BOOLEAN, G_TYPE_NONE, 2, PUBLISHING_PIWIGO_TYPE_PUBLISHING_PARAMETERS, G_TYPE_BOOLEAN);
#line 1112 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_new ("logout", PUBLISHING_PIWIGO_TYPE_PUBLISHING_OPTIONS_PANE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
#line 1114 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = _ ("Shotwell Connect");
#line 1114 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 1114 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_publishing_options_pane_DEFAULT_CATEGORY_NAME = _tmp1_;
#line 9913 "PiwigoPublishing.c"
}


static void publishing_piwigo_publishing_options_pane_spit_publishing_dialog_pane_interface_init (SpitPublishingDialogPaneIface * iface) {
#line 1112 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_publishing_options_pane_spit_publishing_dialog_pane_parent_iface = g_type_interface_peek_parent (iface);
#line 1112 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	iface->get_widget = (GtkWidget* (*)(SpitPublishingDialogPane*)) publishing_piwigo_publishing_options_pane_real_get_widget;
#line 1112 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	iface->get_preferred_geometry = (SpitPublishingDialogPaneGeometryOptions (*)(SpitPublishingDialogPane*)) publishing_piwigo_publishing_options_pane_real_get_preferred_geometry;
#line 1112 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	iface->on_pane_installed = (void (*)(SpitPublishingDialogPane*)) publishing_piwigo_publishing_options_pane_real_on_pane_installed;
#line 1112 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	iface->on_pane_uninstalled = (void (*)(SpitPublishingDialogPane*)) publishing_piwigo_publishing_options_pane_real_on_pane_uninstalled;
#line 9928 "PiwigoPublishing.c"
}


static void publishing_piwigo_publishing_options_pane_instance_init (PublishingPiwigoPublishingOptionsPane * self) {
#line 1112 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv = PUBLISHING_PIWIGO_PUBLISHING_OPTIONS_PANE_GET_PRIVATE (self);
#line 1116 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->pane_widget = NULL;
#line 1126 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->strip_metadata_check = NULL;
#line 1127 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->title_as_comment_check = NULL;
#line 1128 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->no_upload_tags_check = NULL;
#line 9943 "PiwigoPublishing.c"
}


static void publishing_piwigo_publishing_options_pane_finalize (GObject* obj) {
	PublishingPiwigoPublishingOptionsPane * self;
#line 1112 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_PIWIGO_TYPE_PUBLISHING_OPTIONS_PANE, PublishingPiwigoPublishingOptionsPane);
#line 1116 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (self->priv->pane_widget);
#line 1117 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (self->priv->builder);
#line 1118 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (self->priv->use_existing_radio);
#line 1119 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (self->priv->create_new_radio);
#line 1120 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (self->priv->existing_categories_combo);
#line 1121 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (self->priv->new_category_entry);
#line 1122 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (self->priv->within_existing_label);
#line 1123 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (self->priv->within_existing_combo);
#line 1124 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (self->priv->perms_combo);
#line 1125 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (self->priv->size_combo);
#line 1126 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (self->priv->strip_metadata_check);
#line 1127 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (self->priv->title_as_comment_check);
#line 1128 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (self->priv->no_upload_tags_check);
#line 1129 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (self->priv->logout_button);
#line 1130 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (self->priv->publish_button);
#line 1131 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (self->priv->album_comment);
#line 1132 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (self->priv->album_comment_label);
#line 1134 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->existing_categories = (_vala_array_free (self->priv->existing_categories, self->priv->existing_categories_length1, (GDestroyNotify) publishing_piwigo_category_unref), NULL);
#line 1135 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->perm_levels = (_vala_array_free (self->priv->perm_levels, self->priv->perm_levels_length1, (GDestroyNotify) publishing_piwigo_permission_level_unref), NULL);
#line 1136 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->photo_sizes = (_vala_array_free (self->priv->photo_sizes, self->priv->photo_sizes_length1, (GDestroyNotify) publishing_piwigo_size_entry_unref), NULL);
#line 1112 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	G_OBJECT_CLASS (publishing_piwigo_publishing_options_pane_parent_class)->finalize (obj);
#line 9993 "PiwigoPublishing.c"
}


/**
 * The publishing options pane.
 */
GType publishing_piwigo_publishing_options_pane_get_type (void) {
	static volatile gsize publishing_piwigo_publishing_options_pane_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_piwigo_publishing_options_pane_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingPiwigoPublishingOptionsPaneClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_piwigo_publishing_options_pane_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingPiwigoPublishingOptionsPane), 0, (GInstanceInitFunc) publishing_piwigo_publishing_options_pane_instance_init, NULL };
		static const GInterfaceInfo spit_publishing_dialog_pane_info = { (GInterfaceInitFunc) publishing_piwigo_publishing_options_pane_spit_publishing_dialog_pane_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType publishing_piwigo_publishing_options_pane_type_id;
		publishing_piwigo_publishing_options_pane_type_id = g_type_register_static (G_TYPE_OBJECT, "PublishingPiwigoPublishingOptionsPane", &g_define_type_info, 0);
		g_type_add_interface_static (publishing_piwigo_publishing_options_pane_type_id, SPIT_PUBLISHING_TYPE_DIALOG_PANE, &spit_publishing_dialog_pane_info);
		g_once_init_leave (&publishing_piwigo_publishing_options_pane_type_id__volatile, publishing_piwigo_publishing_options_pane_type_id);
	}
	return publishing_piwigo_publishing_options_pane_type_id__volatile;
}


PublishingPiwigoSession* publishing_piwigo_session_construct (GType object_type) {
	PublishingPiwigoSession* self = NULL;
#line 1485 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = (PublishingPiwigoSession*) publishing_rest_support_session_construct (object_type, "");
#line 1484 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return self;
#line 10020 "PiwigoPublishing.c"
}


PublishingPiwigoSession* publishing_piwigo_session_new (void) {
#line 1484 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return publishing_piwigo_session_construct (PUBLISHING_PIWIGO_TYPE_SESSION);
#line 10027 "PiwigoPublishing.c"
}


static gboolean publishing_piwigo_session_real_is_authenticated (PublishingRESTSupportSession* base) {
	PublishingPiwigoSession * self;
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	const gchar* _tmp2_ = NULL;
#line 1488 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_PIWIGO_TYPE_SESSION, PublishingPiwigoSession);
#line 1489 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = self->priv->pwg_id;
#line 1489 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (_tmp2_ != NULL) {
#line 10043 "PiwigoPublishing.c"
		const gchar* _tmp3_ = NULL;
#line 1489 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp3_ = self->priv->pwg_url;
#line 1489 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp1_ = _tmp3_ != NULL;
#line 10049 "PiwigoPublishing.c"
	} else {
#line 1489 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp1_ = FALSE;
#line 10053 "PiwigoPublishing.c"
	}
#line 1489 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (_tmp1_) {
#line 10057 "PiwigoPublishing.c"
		const gchar* _tmp4_ = NULL;
#line 1489 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp4_ = self->priv->username;
#line 1489 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp0_ = _tmp4_ != NULL;
#line 10063 "PiwigoPublishing.c"
	} else {
#line 1489 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp0_ = FALSE;
#line 10067 "PiwigoPublishing.c"
	}
#line 1489 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = _tmp0_;
#line 1489 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 10073 "PiwigoPublishing.c"
}


void publishing_piwigo_session_authenticate (PublishingPiwigoSession* self, const gchar* url, const gchar* username, const gchar* id) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
#line 1492 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_SESSION (self));
#line 1492 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (url != NULL);
#line 1492 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (username != NULL);
#line 1492 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (id != NULL);
#line 1493 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = url;
#line 1493 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 1493 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (self->priv->pwg_url);
#line 1493 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->pwg_url = _tmp1_;
#line 1494 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = username;
#line 1494 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3_ = g_strdup (_tmp2_);
#line 1494 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (self->priv->username);
#line 1494 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->username = _tmp3_;
#line 1495 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = id;
#line 1495 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp5_ = g_strdup (_tmp4_);
#line 1495 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (self->priv->pwg_id);
#line 1495 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->pwg_id = _tmp5_;
#line 10116 "PiwigoPublishing.c"
}


void publishing_piwigo_session_deauthenticate (PublishingPiwigoSession* self) {
#line 1498 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_SESSION (self));
#line 1499 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (self->priv->pwg_url);
#line 1499 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->pwg_url = NULL;
#line 1500 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (self->priv->pwg_id);
#line 1500 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->pwg_id = NULL;
#line 1501 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (self->priv->username);
#line 1501 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->username = NULL;
#line 10135 "PiwigoPublishing.c"
}


gchar* publishing_piwigo_session_get_username (PublishingPiwigoSession* self) {
	gchar* result = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 1504 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_SESSION (self), NULL);
#line 1505 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->username;
#line 1505 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 1505 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = _tmp1_;
#line 1505 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 10153 "PiwigoPublishing.c"
}


gchar* publishing_piwigo_session_get_pwg_url (PublishingPiwigoSession* self) {
	gchar* result = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 1508 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_SESSION (self), NULL);
#line 1509 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->pwg_url;
#line 1509 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 1509 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = _tmp1_;
#line 1509 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 10171 "PiwigoPublishing.c"
}


gchar* publishing_piwigo_session_get_pwg_id (PublishingPiwigoSession* self) {
	gchar* result = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 1512 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_SESSION (self), NULL);
#line 1513 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->pwg_id;
#line 1513 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 1513 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = _tmp1_;
#line 1513 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 10189 "PiwigoPublishing.c"
}


void publishing_piwigo_session_set_pwg_id (PublishingPiwigoSession* self, const gchar* id) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 1516 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_SESSION (self));
#line 1516 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (id != NULL);
#line 1517 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = id;
#line 1517 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 1517 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (self->priv->pwg_id);
#line 1517 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->pwg_id = _tmp1_;
#line 10208 "PiwigoPublishing.c"
}


static void publishing_piwigo_session_class_init (PublishingPiwigoSessionClass * klass) {
#line 1479 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_session_parent_class = g_type_class_peek_parent (klass);
#line 1479 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	((PublishingRESTSupportSessionClass *) klass)->finalize = publishing_piwigo_session_finalize;
#line 1479 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_type_class_add_private (klass, sizeof (PublishingPiwigoSessionPrivate));
#line 1479 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	((PublishingRESTSupportSessionClass *) klass)->is_authenticated = publishing_piwigo_session_real_is_authenticated;
#line 10221 "PiwigoPublishing.c"
}


static void publishing_piwigo_session_instance_init (PublishingPiwigoSession * self) {
#line 1479 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv = PUBLISHING_PIWIGO_SESSION_GET_PRIVATE (self);
#line 1480 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->pwg_url = NULL;
#line 1481 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->pwg_id = NULL;
#line 1482 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->username = NULL;
#line 10234 "PiwigoPublishing.c"
}


static void publishing_piwigo_session_finalize (PublishingRESTSupportSession* obj) {
	PublishingPiwigoSession * self;
#line 1479 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_PIWIGO_TYPE_SESSION, PublishingPiwigoSession);
#line 1480 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (self->priv->pwg_url);
#line 1481 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (self->priv->pwg_id);
#line 1482 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (self->priv->username);
#line 1479 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	PUBLISHING_REST_SUPPORT_SESSION_CLASS (publishing_piwigo_session_parent_class)->finalize (obj);
#line 10250 "PiwigoPublishing.c"
}


/**
 * Session class that keeps track of the authentication status and of the
 * user token pwg_id.
 */
GType publishing_piwigo_session_get_type (void) {
	static volatile gsize publishing_piwigo_session_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_piwigo_session_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingPiwigoSessionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_piwigo_session_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingPiwigoSession), 0, (GInstanceInitFunc) publishing_piwigo_session_instance_init, NULL };
		GType publishing_piwigo_session_type_id;
		publishing_piwigo_session_type_id = g_type_register_static (PUBLISHING_REST_SUPPORT_TYPE_SESSION, "PublishingPiwigoSession", &g_define_type_info, 0);
		g_once_init_leave (&publishing_piwigo_session_type_id__volatile, publishing_piwigo_session_type_id);
	}
	return publishing_piwigo_session_type_id__volatile;
}


PublishingPiwigoTransaction* publishing_piwigo_transaction_construct (GType object_type, PublishingPiwigoSession* session) {
	PublishingPiwigoTransaction* self = NULL;
	PublishingPiwigoSession* _tmp0_ = NULL;
	PublishingPiwigoSession* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
#line 1530 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_SESSION (session), NULL);
#line 1531 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = session;
#line 1531 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = (PublishingPiwigoTransaction*) publishing_rest_support_transaction_construct (object_type, G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession), PUBLISHING_REST_SUPPORT_HTTP_METHOD_POST);
#line 1532 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = session;
#line 1532 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = publishing_rest_support_session_is_authenticated (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession));
#line 1532 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (_tmp2_) {
#line 10287 "PiwigoPublishing.c"
		PublishingPiwigoSession* _tmp3_ = NULL;
		gchar* _tmp4_ = NULL;
		gchar* _tmp5_ = NULL;
		gchar* _tmp6_ = NULL;
		gchar* _tmp7_ = NULL;
#line 1533 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp3_ = session;
#line 1533 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp4_ = publishing_piwigo_session_get_pwg_id (_tmp3_);
#line 1533 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp5_ = _tmp4_;
#line 1533 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp6_ = g_strconcat ("pwg_id=", _tmp5_, NULL);
#line 1533 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp7_ = _tmp6_;
#line 1533 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_rest_support_transaction_add_header (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "Cookie", _tmp7_);
#line 1533 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_free0 (_tmp7_);
#line 1533 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_free0 (_tmp5_);
#line 10309 "PiwigoPublishing.c"
	}
#line 1530 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return self;
#line 10313 "PiwigoPublishing.c"
}


PublishingPiwigoTransaction* publishing_piwigo_transaction_new (PublishingPiwigoSession* session) {
#line 1530 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return publishing_piwigo_transaction_construct (PUBLISHING_PIWIGO_TYPE_TRANSACTION, session);
#line 10320 "PiwigoPublishing.c"
}


PublishingPiwigoTransaction* publishing_piwigo_transaction_construct_authenticated (GType object_type, PublishingPiwigoSession* session) {
	PublishingPiwigoTransaction* self = NULL;
	PublishingPiwigoSession* _tmp0_ = NULL;
	PublishingPiwigoSession* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	PublishingPiwigoSession* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
	gchar* _tmp8_ = NULL;
#line 1537 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_SESSION (session), NULL);
#line 1538 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = session;
#line 1538 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = session;
#line 1538 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = publishing_piwigo_session_get_pwg_url (_tmp1_);
#line 1538 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3_ = _tmp2_;
#line 1538 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = (PublishingPiwigoTransaction*) publishing_rest_support_transaction_construct_with_endpoint_url (object_type, G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession), _tmp3_, PUBLISHING_REST_SUPPORT_HTTP_METHOD_POST);
#line 1538 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (_tmp3_);
#line 1539 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = session;
#line 1539 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp5_ = publishing_piwigo_session_get_pwg_id (_tmp4_);
#line 1539 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp6_ = _tmp5_;
#line 1539 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp7_ = g_strconcat ("pwg_id=", _tmp6_, NULL);
#line 1539 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp8_ = _tmp7_;
#line 1539 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_rest_support_transaction_add_header (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "Cookie", _tmp8_);
#line 1539 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (_tmp8_);
#line 1539 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (_tmp6_);
#line 1537 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return self;
#line 10367 "PiwigoPublishing.c"
}


PublishingPiwigoTransaction* publishing_piwigo_transaction_new_authenticated (PublishingPiwigoSession* session) {
#line 1537 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return publishing_piwigo_transaction_construct_authenticated (PUBLISHING_PIWIGO_TYPE_TRANSACTION, session);
#line 10374 "PiwigoPublishing.c"
}


gchar* publishing_piwigo_transaction_validate_xml (PublishingRESTSupportXmlDocument* doc) {
	gchar* result = NULL;
	xmlNode* root = NULL;
	PublishingRESTSupportXmlDocument* _tmp0_ = NULL;
	xmlNode* _tmp1_ = NULL;
	gchar* status = NULL;
	xmlNode* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	const gchar* _tmp6_ = NULL;
	xmlNode* errcode = NULL;
	xmlNode* _tmp12_ = NULL;
	gchar* _tmp13_ = NULL;
	gchar* _tmp14_ = NULL;
	xmlNode* _tmp15_ = NULL;
	gchar* _tmp16_ = NULL;
	gchar* _tmp17_ = NULL;
	gchar* _tmp18_ = NULL;
	gchar* _tmp19_ = NULL;
	GError * _inner_error_ = NULL;
#line 1542 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_REST_SUPPORT_IS_XML_DOCUMENT (doc), NULL);
#line 1543 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = doc;
#line 1543 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = publishing_rest_support_xml_document_get_root_node (_tmp0_);
#line 1543 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	root = _tmp1_;
#line 1544 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = root;
#line 1544 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3_ = (gchar*) xmlGetProp (_tmp2_, (xmlChar*) "stat");
#line 1544 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	status = _tmp3_;
#line 1547 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = status;
#line 1547 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (_tmp4_ == NULL) {
#line 10416 "PiwigoPublishing.c"
		gchar* _tmp5_ = NULL;
#line 1548 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp5_ = g_strdup ("No status property in root node");
#line 1548 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		result = _tmp5_;
#line 1548 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_free0 (status);
#line 1548 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		return result;
#line 10426 "PiwigoPublishing.c"
	}
#line 1550 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp6_ = status;
#line 1550 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (g_strcmp0 (_tmp6_, "ok") == 0) {
#line 1551 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		result = NULL;
#line 1551 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_free0 (status);
#line 1551 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		return result;
#line 10438 "PiwigoPublishing.c"
	}
	{
		xmlNode* _tmp7_ = NULL;
		PublishingRESTSupportXmlDocument* _tmp8_ = NULL;
		xmlNode* _tmp9_ = NULL;
		xmlNode* _tmp10_ = NULL;
#line 1555 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp8_ = doc;
#line 1555 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp9_ = root;
#line 1555 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp10_ = publishing_rest_support_xml_document_get_named_child (_tmp8_, _tmp9_, "err", &_inner_error_);
#line 1555 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp7_ = _tmp10_;
#line 1555 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1555 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 10457 "PiwigoPublishing.c"
				goto __catch46_spit_publishing_publishing_error;
			}
#line 1555 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_g_free0 (status);
#line 1555 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1555 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			g_clear_error (&_inner_error_);
#line 1555 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			return NULL;
#line 10468 "PiwigoPublishing.c"
		}
#line 1555 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		errcode = _tmp7_;
#line 10472 "PiwigoPublishing.c"
	}
	goto __finally46;
	__catch46_spit_publishing_publishing_error:
	{
		GError* err = NULL;
		gchar* _tmp11_ = NULL;
#line 1554 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		err = _inner_error_;
#line 1554 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_inner_error_ = NULL;
#line 1557 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp11_ = g_strdup ("No error code specified");
#line 1557 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		result = _tmp11_;
#line 1557 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_error_free0 (err);
#line 1557 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_free0 (status);
#line 1557 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		return result;
#line 10493 "PiwigoPublishing.c"
	}
	__finally46:
#line 1554 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1554 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_free0 (status);
#line 1554 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1554 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_clear_error (&_inner_error_);
#line 1554 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		return NULL;
#line 10506 "PiwigoPublishing.c"
	}
#line 1560 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp12_ = errcode;
#line 1560 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp13_ = (gchar*) xmlGetProp (_tmp12_, (xmlChar*) "msg");
#line 1560 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp14_ = _tmp13_;
#line 1560 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp15_ = errcode;
#line 1560 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp16_ = (gchar*) xmlGetProp (_tmp15_, (xmlChar*) "code");
#line 1560 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp17_ = _tmp16_;
#line 1560 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp18_ = g_strdup_printf ("%s (error code %s)", _tmp14_, _tmp17_);
#line 1560 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp19_ = _tmp18_;
#line 1560 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (_tmp17_);
#line 1560 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (_tmp14_);
#line 1560 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = _tmp19_;
#line 1560 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (status);
#line 1560 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 10534 "PiwigoPublishing.c"
}


gchar* publishing_piwigo_transaction_get_error_code (PublishingRESTSupportXmlDocument* doc) {
	gchar* result = NULL;
	xmlNode* root = NULL;
	PublishingRESTSupportXmlDocument* _tmp0_ = NULL;
	xmlNode* _tmp1_ = NULL;
	xmlNode* errcode = NULL;
	xmlNode* _tmp7_ = NULL;
	gchar* _tmp8_ = NULL;
	GError * _inner_error_ = NULL;
#line 1563 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_REST_SUPPORT_IS_XML_DOCUMENT (doc), NULL);
#line 1564 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = doc;
#line 1564 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = publishing_rest_support_xml_document_get_root_node (_tmp0_);
#line 1564 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	root = _tmp1_;
#line 10555 "PiwigoPublishing.c"
	{
		xmlNode* _tmp2_ = NULL;
		PublishingRESTSupportXmlDocument* _tmp3_ = NULL;
		xmlNode* _tmp4_ = NULL;
		xmlNode* _tmp5_ = NULL;
#line 1567 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp3_ = doc;
#line 1567 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp4_ = root;
#line 1567 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp5_ = publishing_rest_support_xml_document_get_named_child (_tmp3_, _tmp4_, "err", &_inner_error_);
#line 1567 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp2_ = _tmp5_;
#line 1567 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1567 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 10573 "PiwigoPublishing.c"
				goto __catch47_spit_publishing_publishing_error;
			}
#line 1567 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1567 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			g_clear_error (&_inner_error_);
#line 1567 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			return NULL;
#line 10582 "PiwigoPublishing.c"
		}
#line 1567 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		errcode = _tmp2_;
#line 10586 "PiwigoPublishing.c"
	}
	goto __finally47;
	__catch47_spit_publishing_publishing_error:
	{
		GError* err = NULL;
		gchar* _tmp6_ = NULL;
#line 1566 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		err = _inner_error_;
#line 1566 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_inner_error_ = NULL;
#line 1569 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp6_ = g_strdup ("0");
#line 1569 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		result = _tmp6_;
#line 1569 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_error_free0 (err);
#line 1569 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		return result;
#line 10605 "PiwigoPublishing.c"
	}
	__finally47:
#line 1566 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1566 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1566 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_clear_error (&_inner_error_);
#line 1566 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		return NULL;
#line 10616 "PiwigoPublishing.c"
	}
#line 1571 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp7_ = errcode;
#line 1571 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp8_ = (gchar*) xmlGetProp (_tmp7_, (xmlChar*) "code");
#line 1571 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = _tmp8_;
#line 1571 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 10626 "PiwigoPublishing.c"
}


static void publishing_piwigo_transaction_class_init (PublishingPiwigoTransactionClass * klass) {
#line 1529 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_transaction_parent_class = g_type_class_peek_parent (klass);
#line 10633 "PiwigoPublishing.c"
}


static void publishing_piwigo_transaction_instance_init (PublishingPiwigoTransaction * self) {
}


/**
 * Generic REST transaction class.
 *
 * This class implements the generic logic for all REST transactions used
 * by the Piwigo publishing plugin. In particular, it ensures that if the
 * session has been authenticated, the pwg_id token is included in the
 * transaction header.
 */
GType publishing_piwigo_transaction_get_type (void) {
	static volatile gsize publishing_piwigo_transaction_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_piwigo_transaction_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingPiwigoTransactionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_piwigo_transaction_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingPiwigoTransaction), 0, (GInstanceInitFunc) publishing_piwigo_transaction_instance_init, NULL };
		GType publishing_piwigo_transaction_type_id;
		publishing_piwigo_transaction_type_id = g_type_register_static (PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, "PublishingPiwigoTransaction", &g_define_type_info, 0);
		g_once_init_leave (&publishing_piwigo_transaction_type_id__volatile, publishing_piwigo_transaction_type_id);
	}
	return publishing_piwigo_transaction_type_id__volatile;
}


PublishingPiwigoSessionLoginTransaction* publishing_piwigo_session_login_transaction_construct (GType object_type, PublishingPiwigoSession* session, const gchar* url, const gchar* username, const gchar* password) {
	PublishingPiwigoSessionLoginTransaction* self = NULL;
	PublishingPiwigoSession* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
#line 1579 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_SESSION (session), NULL);
#line 1579 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (url != NULL, NULL);
#line 1579 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (username != NULL, NULL);
#line 1579 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (password != NULL, NULL);
#line 1580 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = session;
#line 1580 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = url;
#line 1580 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = (PublishingPiwigoSessionLoginTransaction*) publishing_rest_support_transaction_construct_with_endpoint_url (object_type, G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession), _tmp1_, PUBLISHING_REST_SUPPORT_HTTP_METHOD_POST);
#line 1582 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "method", "pwg.session.login");
#line 1583 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = username;
#line 1583 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "username", _tmp2_);
#line 1584 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3_ = password;
#line 1584 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "password", _tmp3_);
#line 1579 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return self;
#line 10693 "PiwigoPublishing.c"
}


PublishingPiwigoSessionLoginTransaction* publishing_piwigo_session_login_transaction_new (PublishingPiwigoSession* session, const gchar* url, const gchar* username, const gchar* password) {
#line 1579 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return publishing_piwigo_session_login_transaction_construct (PUBLISHING_PIWIGO_TYPE_SESSION_LOGIN_TRANSACTION, session, url, username, password);
#line 10700 "PiwigoPublishing.c"
}


static void publishing_piwigo_session_login_transaction_class_init (PublishingPiwigoSessionLoginTransactionClass * klass) {
#line 1578 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_session_login_transaction_parent_class = g_type_class_peek_parent (klass);
#line 10707 "PiwigoPublishing.c"
}


static void publishing_piwigo_session_login_transaction_instance_init (PublishingPiwigoSessionLoginTransaction * self) {
}


/**
 * Transaction used to implement the network login interaction.
 */
GType publishing_piwigo_session_login_transaction_get_type (void) {
	static volatile gsize publishing_piwigo_session_login_transaction_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_piwigo_session_login_transaction_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingPiwigoSessionLoginTransactionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_piwigo_session_login_transaction_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingPiwigoSessionLoginTransaction), 0, (GInstanceInitFunc) publishing_piwigo_session_login_transaction_instance_init, NULL };
		GType publishing_piwigo_session_login_transaction_type_id;
		publishing_piwigo_session_login_transaction_type_id = g_type_register_static (PUBLISHING_PIWIGO_TYPE_TRANSACTION, "PublishingPiwigoSessionLoginTransaction", &g_define_type_info, 0);
		g_once_init_leave (&publishing_piwigo_session_login_transaction_type_id__volatile, publishing_piwigo_session_login_transaction_type_id);
	}
	return publishing_piwigo_session_login_transaction_type_id__volatile;
}


PublishingPiwigoSessionGetStatusTransaction* publishing_piwigo_session_get_status_transaction_construct_unauthenticated (GType object_type, PublishingPiwigoSession* session, const gchar* url, const gchar* pwg_id) {
	PublishingPiwigoSessionGetStatusTransaction* self = NULL;
	PublishingPiwigoSession* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	PublishingPiwigoSession* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
#line 1592 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_SESSION (session), NULL);
#line 1592 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (url != NULL, NULL);
#line 1592 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (pwg_id != NULL, NULL);
#line 1593 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = session;
#line 1593 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = url;
#line 1593 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = (PublishingPiwigoSessionGetStatusTransaction*) publishing_rest_support_transaction_construct_with_endpoint_url (object_type, G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession), _tmp1_, PUBLISHING_REST_SUPPORT_HTTP_METHOD_POST);
#line 1594 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = session;
#line 1594 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3_ = publishing_piwigo_session_get_pwg_id (_tmp2_);
#line 1594 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = _tmp3_;
#line 1594 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp5_ = g_strconcat ("pwg_id=", _tmp4_, NULL);
#line 1594 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp6_ = _tmp5_;
#line 1594 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_rest_support_transaction_add_header (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "Cookie", _tmp6_);
#line 1594 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (_tmp6_);
#line 1594 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (_tmp4_);
#line 1596 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "method", "pwg.session.getStatus");
#line 1592 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return self;
#line 10771 "PiwigoPublishing.c"
}


PublishingPiwigoSessionGetStatusTransaction* publishing_piwigo_session_get_status_transaction_new_unauthenticated (PublishingPiwigoSession* session, const gchar* url, const gchar* pwg_id) {
#line 1592 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return publishing_piwigo_session_get_status_transaction_construct_unauthenticated (PUBLISHING_PIWIGO_TYPE_SESSION_GET_STATUS_TRANSACTION, session, url, pwg_id);
#line 10778 "PiwigoPublishing.c"
}


PublishingPiwigoSessionGetStatusTransaction* publishing_piwigo_session_get_status_transaction_construct (GType object_type, PublishingPiwigoSession* session) {
	PublishingPiwigoSessionGetStatusTransaction* self = NULL;
	PublishingPiwigoSession* _tmp0_ = NULL;
#line 1599 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_SESSION (session), NULL);
#line 1600 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = session;
#line 1600 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = (PublishingPiwigoSessionGetStatusTransaction*) publishing_piwigo_transaction_construct_authenticated (object_type, _tmp0_);
#line 1602 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "method", "pwg.session.getStatus");
#line 1599 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return self;
#line 10795 "PiwigoPublishing.c"
}


PublishingPiwigoSessionGetStatusTransaction* publishing_piwigo_session_get_status_transaction_new (PublishingPiwigoSession* session) {
#line 1599 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return publishing_piwigo_session_get_status_transaction_construct (PUBLISHING_PIWIGO_TYPE_SESSION_GET_STATUS_TRANSACTION, session);
#line 10802 "PiwigoPublishing.c"
}


static void publishing_piwigo_session_get_status_transaction_class_init (PublishingPiwigoSessionGetStatusTransactionClass * klass) {
#line 1591 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_session_get_status_transaction_parent_class = g_type_class_peek_parent (klass);
#line 10809 "PiwigoPublishing.c"
}


static void publishing_piwigo_session_get_status_transaction_instance_init (PublishingPiwigoSessionGetStatusTransaction * self) {
}


/**
 * Transaction used to implement the get status interaction.
 */
GType publishing_piwigo_session_get_status_transaction_get_type (void) {
	static volatile gsize publishing_piwigo_session_get_status_transaction_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_piwigo_session_get_status_transaction_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingPiwigoSessionGetStatusTransactionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_piwigo_session_get_status_transaction_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingPiwigoSessionGetStatusTransaction), 0, (GInstanceInitFunc) publishing_piwigo_session_get_status_transaction_instance_init, NULL };
		GType publishing_piwigo_session_get_status_transaction_type_id;
		publishing_piwigo_session_get_status_transaction_type_id = g_type_register_static (PUBLISHING_PIWIGO_TYPE_TRANSACTION, "PublishingPiwigoSessionGetStatusTransaction", &g_define_type_info, 0);
		g_once_init_leave (&publishing_piwigo_session_get_status_transaction_type_id__volatile, publishing_piwigo_session_get_status_transaction_type_id);
	}
	return publishing_piwigo_session_get_status_transaction_type_id__volatile;
}


PublishingPiwigoCategoriesGetListTransaction* publishing_piwigo_categories_get_list_transaction_construct (GType object_type, PublishingPiwigoSession* session) {
	PublishingPiwigoCategoriesGetListTransaction* self = NULL;
	PublishingPiwigoSession* _tmp0_ = NULL;
#line 1610 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_SESSION (session), NULL);
#line 1611 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = session;
#line 1611 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = (PublishingPiwigoCategoriesGetListTransaction*) publishing_piwigo_transaction_construct_authenticated (object_type, _tmp0_);
#line 1613 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "method", "pwg.categories.getList");
#line 1614 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "recursive", "true");
#line 1610 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return self;
#line 10847 "PiwigoPublishing.c"
}


PublishingPiwigoCategoriesGetListTransaction* publishing_piwigo_categories_get_list_transaction_new (PublishingPiwigoSession* session) {
#line 1610 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return publishing_piwigo_categories_get_list_transaction_construct (PUBLISHING_PIWIGO_TYPE_CATEGORIES_GET_LIST_TRANSACTION, session);
#line 10854 "PiwigoPublishing.c"
}


static void publishing_piwigo_categories_get_list_transaction_class_init (PublishingPiwigoCategoriesGetListTransactionClass * klass) {
#line 1609 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_categories_get_list_transaction_parent_class = g_type_class_peek_parent (klass);
#line 10861 "PiwigoPublishing.c"
}


static void publishing_piwigo_categories_get_list_transaction_instance_init (PublishingPiwigoCategoriesGetListTransaction * self) {
}


/**
 * Transaction used to implement the fetch categories interaction.
 */
GType publishing_piwigo_categories_get_list_transaction_get_type (void) {
	static volatile gsize publishing_piwigo_categories_get_list_transaction_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_piwigo_categories_get_list_transaction_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingPiwigoCategoriesGetListTransactionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_piwigo_categories_get_list_transaction_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingPiwigoCategoriesGetListTransaction), 0, (GInstanceInitFunc) publishing_piwigo_categories_get_list_transaction_instance_init, NULL };
		GType publishing_piwigo_categories_get_list_transaction_type_id;
		publishing_piwigo_categories_get_list_transaction_type_id = g_type_register_static (PUBLISHING_PIWIGO_TYPE_TRANSACTION, "PublishingPiwigoCategoriesGetListTransaction", &g_define_type_info, 0);
		g_once_init_leave (&publishing_piwigo_categories_get_list_transaction_type_id__volatile, publishing_piwigo_categories_get_list_transaction_type_id);
	}
	return publishing_piwigo_categories_get_list_transaction_type_id__volatile;
}


PublishingPiwigoSessionLogoutTransaction* publishing_piwigo_session_logout_transaction_construct (GType object_type, PublishingPiwigoSession* session) {
	PublishingPiwigoSessionLogoutTransaction* self = NULL;
	PublishingPiwigoSession* _tmp0_ = NULL;
#line 1619 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_SESSION (session), NULL);
#line 1620 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = session;
#line 1620 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = (PublishingPiwigoSessionLogoutTransaction*) publishing_piwigo_transaction_construct_authenticated (object_type, _tmp0_);
#line 1622 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "method", "pwg.session.logout");
#line 1619 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return self;
#line 10897 "PiwigoPublishing.c"
}


PublishingPiwigoSessionLogoutTransaction* publishing_piwigo_session_logout_transaction_new (PublishingPiwigoSession* session) {
#line 1619 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return publishing_piwigo_session_logout_transaction_construct (PUBLISHING_PIWIGO_TYPE_SESSION_LOGOUT_TRANSACTION, session);
#line 10904 "PiwigoPublishing.c"
}


static void publishing_piwigo_session_logout_transaction_class_init (PublishingPiwigoSessionLogoutTransactionClass * klass) {
#line 1618 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_session_logout_transaction_parent_class = g_type_class_peek_parent (klass);
#line 10911 "PiwigoPublishing.c"
}


static void publishing_piwigo_session_logout_transaction_instance_init (PublishingPiwigoSessionLogoutTransaction * self) {
}


GType publishing_piwigo_session_logout_transaction_get_type (void) {
	static volatile gsize publishing_piwigo_session_logout_transaction_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_piwigo_session_logout_transaction_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingPiwigoSessionLogoutTransactionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_piwigo_session_logout_transaction_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingPiwigoSessionLogoutTransaction), 0, (GInstanceInitFunc) publishing_piwigo_session_logout_transaction_instance_init, NULL };
		GType publishing_piwigo_session_logout_transaction_type_id;
		publishing_piwigo_session_logout_transaction_type_id = g_type_register_static (PUBLISHING_PIWIGO_TYPE_TRANSACTION, "PublishingPiwigoSessionLogoutTransaction", &g_define_type_info, 0);
		g_once_init_leave (&publishing_piwigo_session_logout_transaction_type_id__volatile, publishing_piwigo_session_logout_transaction_type_id);
	}
	return publishing_piwigo_session_logout_transaction_type_id__volatile;
}


PublishingPiwigoCategoriesAddTransaction* publishing_piwigo_categories_add_transaction_construct (GType object_type, PublishingPiwigoSession* session, const gchar* category, gint parent_id, const gchar* comment) {
	PublishingPiwigoCategoriesAddTransaction* self = NULL;
	PublishingPiwigoSession* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gint _tmp2_ = 0;
	const gchar* _tmp6_ = NULL;
#line 1627 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_SESSION (session), NULL);
#line 1627 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (category != NULL, NULL);
#line 1628 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = session;
#line 1628 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = (PublishingPiwigoCategoriesAddTransaction*) publishing_piwigo_transaction_construct_authenticated (object_type, _tmp0_);
#line 1630 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "method", "pwg.categories.add");
#line 1631 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = category;
#line 1631 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "name", _tmp1_);
#line 1633 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = parent_id;
#line 1633 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (_tmp2_ != 0) {
#line 10955 "PiwigoPublishing.c"
		gint _tmp3_ = 0;
		gchar* _tmp4_ = NULL;
		gchar* _tmp5_ = NULL;
#line 1634 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp3_ = parent_id;
#line 1634 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp4_ = g_strdup_printf ("%i", _tmp3_);
#line 1634 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp5_ = _tmp4_;
#line 1634 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "parent", _tmp5_);
#line 1634 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_free0 (_tmp5_);
#line 10969 "PiwigoPublishing.c"
	}
#line 1637 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp6_ = comment;
#line 1637 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (g_strcmp0 (_tmp6_, "") != 0) {
#line 10975 "PiwigoPublishing.c"
		const gchar* _tmp7_ = NULL;
#line 1638 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp7_ = comment;
#line 1638 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "comment", _tmp7_);
#line 10981 "PiwigoPublishing.c"
	}
#line 1627 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return self;
#line 10985 "PiwigoPublishing.c"
}


PublishingPiwigoCategoriesAddTransaction* publishing_piwigo_categories_add_transaction_new (PublishingPiwigoSession* session, const gchar* category, gint parent_id, const gchar* comment) {
#line 1627 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return publishing_piwigo_categories_add_transaction_construct (PUBLISHING_PIWIGO_TYPE_CATEGORIES_ADD_TRANSACTION, session, category, parent_id, comment);
#line 10992 "PiwigoPublishing.c"
}


static void publishing_piwigo_categories_add_transaction_class_init (PublishingPiwigoCategoriesAddTransactionClass * klass) {
#line 1626 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_categories_add_transaction_parent_class = g_type_class_peek_parent (klass);
#line 10999 "PiwigoPublishing.c"
}


static void publishing_piwigo_categories_add_transaction_instance_init (PublishingPiwigoCategoriesAddTransaction * self) {
}


GType publishing_piwigo_categories_add_transaction_get_type (void) {
	static volatile gsize publishing_piwigo_categories_add_transaction_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_piwigo_categories_add_transaction_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingPiwigoCategoriesAddTransactionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_piwigo_categories_add_transaction_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingPiwigoCategoriesAddTransaction), 0, (GInstanceInitFunc) publishing_piwigo_categories_add_transaction_instance_init, NULL };
		GType publishing_piwigo_categories_add_transaction_type_id;
		publishing_piwigo_categories_add_transaction_type_id = g_type_register_static (PUBLISHING_PIWIGO_TYPE_TRANSACTION, "PublishingPiwigoCategoriesAddTransaction", &g_define_type_info, 0);
		g_once_init_leave (&publishing_piwigo_categories_add_transaction_type_id__volatile, publishing_piwigo_categories_add_transaction_type_id);
	}
	return publishing_piwigo_categories_add_transaction_type_id__volatile;
}


static gchar* _vala_g_strjoinv (const gchar* separator, gchar** str_array, int str_array_length1) {
	gchar* result = NULL;
	const gchar* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_ = FALSE;
	gchar** _tmp3_ = NULL;
	gint _tmp3__length1 = 0;
#line 1054 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp0_ = separator;
#line 1054 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	if (_tmp0_ == NULL) {
#line 1055 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		separator = "";
#line 11032 "PiwigoPublishing.c"
	}
#line 1057 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp3_ = str_array;
#line 1057 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp3__length1 = str_array_length1;
#line 1057 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	if (_tmp3_ != NULL) {
#line 1057 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp2_ = TRUE;
#line 11042 "PiwigoPublishing.c"
	} else {
		gchar** _tmp4_ = NULL;
		gint _tmp4__length1 = 0;
#line 1057 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp4_ = str_array;
#line 1057 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp4__length1 = str_array_length1;
#line 1057 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp2_ = _tmp4__length1 > 0;
#line 11052 "PiwigoPublishing.c"
	}
#line 1057 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	if (_tmp2_) {
#line 1057 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp1_ = TRUE;
#line 11058 "PiwigoPublishing.c"
	} else {
		gboolean _tmp5_ = FALSE;
		gchar** _tmp6_ = NULL;
		gint _tmp6__length1 = 0;
#line 1057 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp6_ = str_array;
#line 1057 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp6__length1 = str_array_length1;
#line 1057 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		if (_tmp6__length1 == -1) {
#line 11069 "PiwigoPublishing.c"
			gchar** _tmp7_ = NULL;
			gint _tmp7__length1 = 0;
			const gchar* _tmp8_ = NULL;
#line 1057 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
			_tmp7_ = str_array;
#line 1057 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
			_tmp7__length1 = str_array_length1;
#line 1057 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
			_tmp8_ = _tmp7_[0];
#line 1057 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
			_tmp5_ = _tmp8_ != NULL;
#line 11081 "PiwigoPublishing.c"
		} else {
#line 1057 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
			_tmp5_ = FALSE;
#line 11085 "PiwigoPublishing.c"
		}
#line 1057 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp1_ = _tmp5_;
#line 11089 "PiwigoPublishing.c"
	}
#line 1057 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	if (_tmp1_) {
#line 11093 "PiwigoPublishing.c"
		gint i = 0;
		gsize len = 0UL;
		gint _tmp31_ = 0;
		gint _tmp33_ = 0;
		gint _tmp34_ = 0;
		gsize _tmp35_ = 0UL;
		const gchar* _tmp36_ = NULL;
		gint _tmp37_ = 0;
		gint _tmp38_ = 0;
		gint _tmp39_ = 0;
		const gchar* res = NULL;
		gsize _tmp40_ = 0UL;
		void* _tmp41_ = NULL;
		void* ptr = NULL;
		const gchar* _tmp42_ = NULL;
		gchar** _tmp43_ = NULL;
		gint _tmp43__length1 = 0;
		const gchar* _tmp44_ = NULL;
		void* _tmp45_ = NULL;
		const gchar* _tmp62_ = NULL;
#line 1059 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		len = (gsize) 1;
#line 11116 "PiwigoPublishing.c"
		{
			gboolean _tmp9_ = FALSE;
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
			i = 0;
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
			_tmp9_ = TRUE;
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
			while (TRUE) {
#line 11125 "PiwigoPublishing.c"
				gboolean _tmp11_ = FALSE;
				gboolean _tmp12_ = FALSE;
				gchar** _tmp13_ = NULL;
				gint _tmp13__length1 = 0;
				gint _tmp21_ = 0;
				gchar** _tmp22_ = NULL;
				gint _tmp22__length1 = 0;
				gint _tmp23_ = 0;
				const gchar* _tmp24_ = NULL;
				gsize _tmp30_ = 0UL;
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				if (!_tmp9_) {
#line 11138 "PiwigoPublishing.c"
					gint _tmp10_ = 0;
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp10_ = i;
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					i = _tmp10_ + 1;
#line 11144 "PiwigoPublishing.c"
				}
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp9_ = FALSE;
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp13_ = str_array;
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp13__length1 = str_array_length1;
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				if (_tmp13__length1 != -1) {
#line 11154 "PiwigoPublishing.c"
					gint _tmp14_ = 0;
					gchar** _tmp15_ = NULL;
					gint _tmp15__length1 = 0;
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp14_ = i;
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp15_ = str_array;
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp15__length1 = str_array_length1;
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp12_ = _tmp14_ < _tmp15__length1;
#line 11166 "PiwigoPublishing.c"
				} else {
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp12_ = FALSE;
#line 11170 "PiwigoPublishing.c"
				}
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				if (_tmp12_) {
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp11_ = TRUE;
#line 11176 "PiwigoPublishing.c"
				} else {
					gboolean _tmp16_ = FALSE;
					gchar** _tmp17_ = NULL;
					gint _tmp17__length1 = 0;
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp17_ = str_array;
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp17__length1 = str_array_length1;
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					if (_tmp17__length1 == -1) {
#line 11187 "PiwigoPublishing.c"
						gchar** _tmp18_ = NULL;
						gint _tmp18__length1 = 0;
						gint _tmp19_ = 0;
						const gchar* _tmp20_ = NULL;
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
						_tmp18_ = str_array;
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
						_tmp18__length1 = str_array_length1;
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
						_tmp19_ = i;
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
						_tmp20_ = _tmp18_[_tmp19_];
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
						_tmp16_ = _tmp20_ != NULL;
#line 11202 "PiwigoPublishing.c"
					} else {
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
						_tmp16_ = FALSE;
#line 11206 "PiwigoPublishing.c"
					}
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp11_ = _tmp16_;
#line 11210 "PiwigoPublishing.c"
				}
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				if (!_tmp11_) {
#line 1060 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					break;
#line 11216 "PiwigoPublishing.c"
				}
#line 1061 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp22_ = str_array;
#line 1061 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp22__length1 = str_array_length1;
#line 1061 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp23_ = i;
#line 1061 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp24_ = _tmp22_[_tmp23_];
#line 1061 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				if (_tmp24_ != NULL) {
#line 11228 "PiwigoPublishing.c"
					gchar** _tmp25_ = NULL;
					gint _tmp25__length1 = 0;
					gint _tmp26_ = 0;
					const gchar* _tmp27_ = NULL;
					gint _tmp28_ = 0;
					gint _tmp29_ = 0;
#line 1061 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp25_ = str_array;
#line 1061 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp25__length1 = str_array_length1;
#line 1061 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp26_ = i;
#line 1061 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp27_ = _tmp25_[_tmp26_];
#line 1061 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp28_ = strlen ((const gchar*) _tmp27_);
#line 1061 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp29_ = _tmp28_;
#line 1061 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp21_ = _tmp29_;
#line 11249 "PiwigoPublishing.c"
				} else {
#line 1061 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp21_ = 0;
#line 11253 "PiwigoPublishing.c"
				}
#line 1061 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp30_ = len;
#line 1061 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				len = _tmp30_ + _tmp21_;
#line 11259 "PiwigoPublishing.c"
			}
		}
#line 1063 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp31_ = i;
#line 1063 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		if (_tmp31_ == 0) {
#line 11266 "PiwigoPublishing.c"
			gchar* _tmp32_ = NULL;
#line 1064 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
			_tmp32_ = g_strdup ("");
#line 1064 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
			result = _tmp32_;
#line 1064 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
			return result;
#line 11274 "PiwigoPublishing.c"
		}
#line 1066 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp33_ = i;
#line 1066 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		str_array_length1 = _tmp33_;
#line 1066 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp34_ = str_array_length1;
#line 1067 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp35_ = len;
#line 1067 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp36_ = separator;
#line 1067 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp37_ = strlen ((const gchar*) _tmp36_);
#line 1067 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp38_ = _tmp37_;
#line 1067 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp39_ = i;
#line 1067 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		len = _tmp35_ + (_tmp38_ * (_tmp39_ - 1));
#line 1069 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp40_ = len;
#line 1069 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp41_ = g_malloc (_tmp40_);
#line 1069 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		res = _tmp41_;
#line 1070 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp42_ = res;
#line 1070 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp43_ = str_array;
#line 1070 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp43__length1 = str_array_length1;
#line 1070 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp44_ = _tmp43_[0];
#line 1070 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp45_ = g_stpcpy ((void*) _tmp42_, (const gchar*) _tmp44_);
#line 1070 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		ptr = _tmp45_;
#line 11312 "PiwigoPublishing.c"
		{
			gboolean _tmp46_ = FALSE;
#line 1071 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
			i = 1;
#line 1071 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
			_tmp46_ = TRUE;
#line 1071 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
			while (TRUE) {
#line 11321 "PiwigoPublishing.c"
				gint _tmp48_ = 0;
				gchar** _tmp49_ = NULL;
				gint _tmp49__length1 = 0;
				void* _tmp50_ = NULL;
				const gchar* _tmp51_ = NULL;
				void* _tmp52_ = NULL;
				const gchar* _tmp53_ = NULL;
				gchar** _tmp54_ = NULL;
				gint _tmp54__length1 = 0;
				gint _tmp55_ = 0;
				const gchar* _tmp56_ = NULL;
				void* _tmp60_ = NULL;
				void* _tmp61_ = NULL;
#line 1071 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				if (!_tmp46_) {
#line 11337 "PiwigoPublishing.c"
					gint _tmp47_ = 0;
#line 1071 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp47_ = i;
#line 1071 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					i = _tmp47_ + 1;
#line 11343 "PiwigoPublishing.c"
				}
#line 1071 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp46_ = FALSE;
#line 1071 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp48_ = i;
#line 1071 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp49_ = str_array;
#line 1071 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp49__length1 = str_array_length1;
#line 1071 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				if (!(_tmp48_ < _tmp49__length1)) {
#line 1071 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					break;
#line 11357 "PiwigoPublishing.c"
				}
#line 1072 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp50_ = ptr;
#line 1072 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp51_ = separator;
#line 1072 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp52_ = g_stpcpy (_tmp50_, (const gchar*) _tmp51_);
#line 1072 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				ptr = _tmp52_;
#line 1073 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp54_ = str_array;
#line 1073 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp54__length1 = str_array_length1;
#line 1073 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp55_ = i;
#line 1073 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp56_ = _tmp54_[_tmp55_];
#line 1073 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				if (_tmp56_ != NULL) {
#line 11377 "PiwigoPublishing.c"
					gchar** _tmp57_ = NULL;
					gint _tmp57__length1 = 0;
					gint _tmp58_ = 0;
					const gchar* _tmp59_ = NULL;
#line 1073 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp57_ = str_array;
#line 1073 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp57__length1 = str_array_length1;
#line 1073 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp58_ = i;
#line 1073 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp59_ = _tmp57_[_tmp58_];
#line 1073 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp53_ = (const gchar*) _tmp59_;
#line 11392 "PiwigoPublishing.c"
				} else {
#line 1073 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
					_tmp53_ = "";
#line 11396 "PiwigoPublishing.c"
				}
#line 1073 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp60_ = ptr;
#line 1073 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				_tmp61_ = g_stpcpy (_tmp60_, _tmp53_);
#line 1073 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
				ptr = _tmp61_;
#line 11404 "PiwigoPublishing.c"
			}
		}
#line 1076 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp62_ = res;
#line 1076 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		res = NULL;
#line 1076 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		result = (gchar*) _tmp62_;
#line 1076 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		return result;
#line 11415 "PiwigoPublishing.c"
	} else {
		gchar* _tmp63_ = NULL;
#line 1078 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp63_ = g_strdup ("");
#line 1078 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		result = _tmp63_;
#line 1078 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		return result;
#line 11424 "PiwigoPublishing.c"
	}
}


static void _g_free0_ (gpointer var) {
#line 1703 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	var = (g_free (var), NULL);
#line 11432 "PiwigoPublishing.c"
}


PublishingPiwigoImagesAddTransaction* publishing_piwigo_images_add_transaction_construct (GType object_type, PublishingPiwigoSession* session, PublishingPiwigoPublishingParameters* parameters, SpitPublishingPublishable* publishable) {
	PublishingPiwigoImagesAddTransaction* self = NULL;
	PublishingPiwigoSession* _tmp0_ = NULL;
	SpitPublishingPublishable* _tmp1_ = NULL;
	PublishingPiwigoSession* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	PublishingPiwigoSession* _tmp5_ = NULL;
	gboolean _tmp6_ = FALSE;
	PublishingPiwigoPublishingParameters* _tmp12_ = NULL;
	PublishingPiwigoPublishingParameters* _tmp13_ = NULL;
	gchar** keywords = NULL;
	SpitPublishingPublishable* _tmp14_ = NULL;
	gint _tmp15_ = 0;
	gchar** _tmp16_ = NULL;
	gint keywords_length1 = 0;
	gint _keywords_size_ = 0;
	gchar* tags = NULL;
	gchar* _tmp17_ = NULL;
	gchar** _tmp18_ = NULL;
	gint _tmp18__length1 = 0;
	SpitPublishingPublishable* _tmp21_ = NULL;
	GFile* _tmp22_ = NULL;
	GFile* _tmp23_ = NULL;
	gchar* _tmp24_ = NULL;
	gchar* _tmp25_ = NULL;
	PublishingPiwigoPublishingParameters* _tmp26_ = NULL;
	PublishingPiwigoCategory* _tmp27_ = NULL;
	gint _tmp28_ = 0;
	PublishingPiwigoPublishingParameters* _tmp29_ = NULL;
	PublishingPiwigoPermissionLevel* _tmp30_ = NULL;
	gint _tmp31_ = 0;
	gchar* name = NULL;
	SpitPublishingPublishable* _tmp32_ = NULL;
	gchar* _tmp33_ = NULL;
	gchar* comment = NULL;
	SpitPublishingPublishable* _tmp34_ = NULL;
	gchar* _tmp35_ = NULL;
	const gchar* _tmp36_ = NULL;
	PublishingPiwigoPublishingParameters* _tmp53_ = NULL;
	PublishingPiwigoCategory* _tmp54_ = NULL;
	gint _tmp55_ = 0;
	gchar* _tmp56_ = NULL;
	gchar* _tmp57_ = NULL;
	PublishingPiwigoPublishingParameters* _tmp58_ = NULL;
	PublishingPiwigoPermissionLevel* _tmp59_ = NULL;
	gint _tmp60_ = 0;
	gchar* _tmp61_ = NULL;
	gchar* _tmp62_ = NULL;
	PublishingPiwigoPublishingParameters* _tmp63_ = NULL;
	gboolean _tmp64_ = FALSE;
	GHashTable* disposition_table = NULL;
	GHashFunc _tmp67_ = NULL;
	GEqualFunc _tmp68_ = NULL;
	GHashTable* _tmp69_ = NULL;
	gchar* _tmp70_ = NULL;
	SpitPublishingPublishable* _tmp71_ = NULL;
	gchar* _tmp72_ = NULL;
	gchar* _tmp73_ = NULL;
	gchar* _tmp74_ = NULL;
	gchar* _tmp75_ = NULL;
	gchar* _tmp76_ = NULL;
#line 1646 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_SESSION (session), NULL);
#line 1646 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_PUBLISHING_PARAMETERS (parameters), NULL);
#line 1646 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (SPIT_PUBLISHING_IS_PUBLISHABLE (publishable), NULL);
#line 1647 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = session;
#line 1647 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = publishable;
#line 1647 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = session;
#line 1647 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3_ = publishing_piwigo_session_get_pwg_url (_tmp2_);
#line 1647 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = _tmp3_;
#line 1647 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = (PublishingPiwigoImagesAddTransaction*) publishing_rest_support_upload_transaction_construct_with_endpoint_url (object_type, G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession), _tmp1_, _tmp4_);
#line 1647 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (_tmp4_);
#line 1648 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp5_ = session;
#line 1648 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp6_ = publishing_rest_support_session_is_authenticated (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession));
#line 1648 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (_tmp6_) {
#line 11524 "PiwigoPublishing.c"
		PublishingPiwigoSession* _tmp7_ = NULL;
		gchar* _tmp8_ = NULL;
		gchar* _tmp9_ = NULL;
		gchar* _tmp10_ = NULL;
		gchar* _tmp11_ = NULL;
#line 1649 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp7_ = session;
#line 1649 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp8_ = publishing_piwigo_session_get_pwg_id (_tmp7_);
#line 1649 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp9_ = _tmp8_;
#line 1649 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp10_ = g_strconcat ("pwg_id=", _tmp9_, NULL);
#line 1649 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp11_ = _tmp10_;
#line 1649 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_rest_support_transaction_add_header (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "Cookie", _tmp11_);
#line 1649 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_free0 (_tmp11_);
#line 1649 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_free0 (_tmp9_);
#line 11546 "PiwigoPublishing.c"
	}
#line 1651 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp12_ = parameters;
#line 1651 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp13_ = _publishing_piwigo_publishing_parameters_ref0 (_tmp12_);
#line 1651 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_publishing_piwigo_publishing_parameters_unref0 (self->priv->parameters);
#line 1651 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->parameters = _tmp13_;
#line 1653 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp14_ = publishable;
#line 1653 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp16_ = spit_publishing_publishable_get_publishing_keywords (_tmp14_, &_tmp15_);
#line 1653 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	keywords = _tmp16_;
#line 1653 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	keywords_length1 = _tmp15_;
#line 1653 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_keywords_size_ = keywords_length1;
#line 1654 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp17_ = g_strdup ("");
#line 1654 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	tags = _tmp17_;
#line 1655 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp18_ = keywords;
#line 1655 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp18__length1 = keywords_length1;
#line 1655 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (_tmp18_ != NULL) {
#line 11576 "PiwigoPublishing.c"
		gchar** _tmp19_ = NULL;
		gint _tmp19__length1 = 0;
		gchar* _tmp20_ = NULL;
#line 1656 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp19_ = keywords;
#line 1656 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp19__length1 = keywords_length1;
#line 1656 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp20_ = _vala_g_strjoinv (",", _tmp19_, _tmp19__length1);
#line 1656 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_free0 (tags);
#line 1656 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		tags = _tmp20_;
#line 11590 "PiwigoPublishing.c"
	}
#line 1659 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp21_ = publishable;
#line 1659 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp22_ = spit_publishing_publishable_get_serialized_file (_tmp21_);
#line 1659 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp23_ = _tmp22_;
#line 1659 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp24_ = g_file_get_basename (_tmp23_);
#line 1659 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp25_ = _tmp24_;
#line 1659 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp26_ = parameters;
#line 1659 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp27_ = _tmp26_->category;
#line 1659 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp28_ = _tmp27_->id;
#line 1659 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp29_ = parameters;
#line 1659 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp30_ = _tmp29_->perm_level;
#line 1659 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp31_ = _tmp30_->id;
#line 1659 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_debug ("PiwigoPublishing.vala:1659: PiwigoConnector: Uploading photo %s to cat" \
"egory id %d with perm level %d", _tmp25_, _tmp28_, _tmp31_);
#line 1659 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (_tmp25_);
#line 1659 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (_tmp23_);
#line 1662 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp32_ = publishable;
#line 1662 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp33_ = spit_publishing_publishable_get_publishing_name (_tmp32_);
#line 1662 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	name = _tmp33_;
#line 1663 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp34_ = publishable;
#line 1663 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp35_ = spit_publishing_publishable_get_param_string (_tmp34_, SPIT_PUBLISHING_PUBLISHABLE_PARAM_STRING_COMMENT);
#line 1663 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	comment = _tmp35_;
#line 1665 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp36_ = name;
#line 1665 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (g_strcmp0 (_tmp36_, "") != 0) {
#line 11636 "PiwigoPublishing.c"
		SpitPublishingPublishable* _tmp37_ = NULL;
		gchar* _tmp38_ = NULL;
		const gchar* _tmp39_ = NULL;
		gboolean _tmp40_ = FALSE;
		const gchar* _tmp41_ = NULL;
#line 1666 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp37_ = publishable;
#line 1666 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp38_ = spit_publishing_publishable_get_param_string (_tmp37_, SPIT_PUBLISHING_PUBLISHABLE_PARAM_STRING_BASENAME);
#line 1666 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_free0 (name);
#line 1666 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		name = _tmp38_;
#line 1668 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp39_ = name;
#line 1668 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "name", _tmp39_);
#line 1669 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp41_ = comment;
#line 1669 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		if (_tmp41_ != NULL) {
#line 11658 "PiwigoPublishing.c"
			const gchar* _tmp42_ = NULL;
#line 1669 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp42_ = comment;
#line 1669 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp40_ = g_strcmp0 (_tmp42_, "") != 0;
#line 11664 "PiwigoPublishing.c"
		} else {
#line 1669 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp40_ = FALSE;
#line 11668 "PiwigoPublishing.c"
		}
#line 1669 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		if (_tmp40_) {
#line 11672 "PiwigoPublishing.c"
			const gchar* _tmp43_ = NULL;
#line 1670 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp43_ = comment;
#line 1670 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "comment", _tmp43_);
#line 11678 "PiwigoPublishing.c"
		}
	} else {
		gboolean _tmp44_ = FALSE;
		const gchar* _tmp45_ = NULL;
#line 1674 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp45_ = comment;
#line 1674 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		if (_tmp45_ != NULL) {
#line 11687 "PiwigoPublishing.c"
			const gchar* _tmp46_ = NULL;
#line 1674 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp46_ = comment;
#line 1674 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp44_ = g_strcmp0 (_tmp46_, "") != 0;
#line 11693 "PiwigoPublishing.c"
		} else {
#line 1674 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp44_ = FALSE;
#line 11697 "PiwigoPublishing.c"
		}
#line 1674 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		if (_tmp44_) {
#line 11701 "PiwigoPublishing.c"
			const gchar* _tmp47_ = NULL;
			const gchar* _tmp48_ = NULL;
#line 1675 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp47_ = name;
#line 1675 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "name", _tmp47_);
#line 1676 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp48_ = comment;
#line 1676 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "comment", _tmp48_);
#line 11712 "PiwigoPublishing.c"
		} else {
			PublishingPiwigoPublishingParameters* _tmp49_ = NULL;
			gboolean _tmp50_ = FALSE;
#line 1681 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp49_ = parameters;
#line 1681 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp50_ = _tmp49_->title_as_comment;
#line 1681 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			if (_tmp50_) {
#line 11722 "PiwigoPublishing.c"
				const gchar* _tmp51_ = NULL;
#line 1682 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp51_ = name;
#line 1682 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "comment", _tmp51_);
#line 11728 "PiwigoPublishing.c"
			} else {
				const gchar* _tmp52_ = NULL;
#line 1684 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp52_ = name;
#line 1684 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "name", _tmp52_);
#line 11735 "PiwigoPublishing.c"
			}
		}
	}
#line 1688 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "method", "pwg.images.addSimple");
#line 1689 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp53_ = parameters;
#line 1689 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp54_ = _tmp53_->category;
#line 1689 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp55_ = _tmp54_->id;
#line 1689 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp56_ = g_strdup_printf ("%i", _tmp55_);
#line 1689 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp57_ = _tmp56_;
#line 1689 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "category", _tmp57_);
#line 1689 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (_tmp57_);
#line 1690 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp58_ = parameters;
#line 1690 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp59_ = _tmp58_->perm_level;
#line 1690 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp60_ = _tmp59_->id;
#line 1690 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp61_ = g_strdup_printf ("%i", _tmp60_);
#line 1690 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp62_ = _tmp61_;
#line 1690 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "level", _tmp62_);
#line 1690 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (_tmp62_);
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp63_ = parameters;
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp64_ = _tmp63_->no_upload_tags;
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (!_tmp64_) {
#line 11775 "PiwigoPublishing.c"
		const gchar* _tmp65_ = NULL;
#line 1692 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp65_ = tags;
#line 1692 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		if (g_strcmp0 (_tmp65_, "") != 0) {
#line 11781 "PiwigoPublishing.c"
			const gchar* _tmp66_ = NULL;
#line 1693 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp66_ = tags;
#line 1693 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "tags", _tmp66_);
#line 11787 "PiwigoPublishing.c"
		}
	}
#line 1703 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp67_ = g_str_hash;
#line 1703 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp68_ = g_str_equal;
#line 1703 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp69_ = g_hash_table_new_full (_tmp67_, _tmp68_, _g_free0_, _g_free0_);
#line 1703 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	disposition_table = _tmp69_;
#line 1705 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp70_ = g_strdup ("filename");
#line 1705 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp71_ = publishable;
#line 1705 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp72_ = spit_publishing_publishable_get_param_string (_tmp71_, SPIT_PUBLISHING_PUBLISHABLE_PARAM_STRING_BASENAME);
#line 1705 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp73_ = _tmp72_;
#line 1705 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp74_ = soup_uri_encode (_tmp73_, NULL);
#line 1705 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_hash_table_insert (disposition_table, _tmp70_, _tmp74_);
#line 1705 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (_tmp73_);
#line 1708 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp75_ = g_strdup ("name");
#line 1708 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp76_ = g_strdup ("image");
#line 1708 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_hash_table_insert (disposition_table, _tmp75_, _tmp76_);
#line 1710 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_rest_support_upload_transaction_set_binary_disposition_table (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_UPLOAD_TRANSACTION, PublishingRESTSupportUploadTransaction), disposition_table);
#line 1646 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_hash_table_unref0 (disposition_table);
#line 1646 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (comment);
#line 1646 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (name);
#line 1646 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (tags);
#line 1646 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	keywords = (_vala_array_free (keywords, keywords_length1, (GDestroyNotify) g_free), NULL);
#line 1646 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return self;
#line 11832 "PiwigoPublishing.c"
}


PublishingPiwigoImagesAddTransaction* publishing_piwigo_images_add_transaction_new (PublishingPiwigoSession* session, PublishingPiwigoPublishingParameters* parameters, SpitPublishingPublishable* publishable) {
#line 1646 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return publishing_piwigo_images_add_transaction_construct (PUBLISHING_PIWIGO_TYPE_IMAGES_ADD_TRANSACTION, session, parameters, publishable);
#line 11839 "PiwigoPublishing.c"
}


static void publishing_piwigo_images_add_transaction_class_init (PublishingPiwigoImagesAddTransactionClass * klass) {
#line 1643 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_images_add_transaction_parent_class = g_type_class_peek_parent (klass);
#line 1643 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	((PublishingRESTSupportTransactionClass *) klass)->finalize = publishing_piwigo_images_add_transaction_finalize;
#line 1643 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_type_class_add_private (klass, sizeof (PublishingPiwigoImagesAddTransactionPrivate));
#line 11850 "PiwigoPublishing.c"
}


static void publishing_piwigo_images_add_transaction_instance_init (PublishingPiwigoImagesAddTransaction * self) {
#line 1643 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv = PUBLISHING_PIWIGO_IMAGES_ADD_TRANSACTION_GET_PRIVATE (self);
#line 1644 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->parameters = NULL;
#line 11859 "PiwigoPublishing.c"
}


static void publishing_piwigo_images_add_transaction_finalize (PublishingRESTSupportTransaction* obj) {
	PublishingPiwigoImagesAddTransaction * self;
#line 1643 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_PIWIGO_TYPE_IMAGES_ADD_TRANSACTION, PublishingPiwigoImagesAddTransaction);
#line 1644 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_publishing_piwigo_publishing_parameters_unref0 (self->priv->parameters);
#line 1643 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	PUBLISHING_REST_SUPPORT_TRANSACTION_CLASS (publishing_piwigo_images_add_transaction_parent_class)->finalize (obj);
#line 11871 "PiwigoPublishing.c"
}


GType publishing_piwigo_images_add_transaction_get_type (void) {
	static volatile gsize publishing_piwigo_images_add_transaction_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_piwigo_images_add_transaction_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingPiwigoImagesAddTransactionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_piwigo_images_add_transaction_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingPiwigoImagesAddTransaction), 0, (GInstanceInitFunc) publishing_piwigo_images_add_transaction_instance_init, NULL };
		GType publishing_piwigo_images_add_transaction_type_id;
		publishing_piwigo_images_add_transaction_type_id = g_type_register_static (PUBLISHING_REST_SUPPORT_TYPE_UPLOAD_TRANSACTION, "PublishingPiwigoImagesAddTransaction", &g_define_type_info, 0);
		g_once_init_leave (&publishing_piwigo_images_add_transaction_type_id__volatile, publishing_piwigo_images_add_transaction_type_id);
	}
	return publishing_piwigo_images_add_transaction_type_id__volatile;
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}


static gint _vala_array_length (gpointer array) {
	int length;
	length = 0;
	if (array) {
		while (((gpointer*) array)[length]) {
			length++;
		}
	}
	return length;
}



