/* FlickrPublishing.c generated by valac 0.32.1, the Vala compiler
 * generated from FlickrPublishing.vala, do not modify */

/* Copyright 2016 Software Freedom Conservancy Inc.
 *
 * This software is licensed under the GNU Lesser General Public License
 * (version 2.1 or later).  See the COPYING file in this distribution.
 */

#include <glib.h>
#include <glib-object.h>
#include <shotwell-plugin-dev-1.0.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <stdlib.h>
#include <string.h>
#include <gio/gio.h>
#include "shotwell-plugin-common.h"
#include <glib/gi18n-lib.h>
#include <float.h>
#include <math.h>
#include <gtk/gtk.h>
#include <libxml/tree.h>
#include <gee.h>
#include <libsoup/soup.h>
#include <gexiv2/gexiv2.h>
#include <gobject/gvaluecollector.h>


#define TYPE_FLICKR_SERVICE (flickr_service_get_type ())
#define FLICKR_SERVICE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_FLICKR_SERVICE, FlickrService))
#define FLICKR_SERVICE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_FLICKR_SERVICE, FlickrServiceClass))
#define IS_FLICKR_SERVICE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_FLICKR_SERVICE))
#define IS_FLICKR_SERVICE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_FLICKR_SERVICE))
#define FLICKR_SERVICE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_FLICKR_SERVICE, FlickrServiceClass))

typedef struct _FlickrService FlickrService;
typedef struct _FlickrServiceClass FlickrServiceClass;
typedef struct _FlickrServicePrivate FlickrServicePrivate;
#define _g_free0(var) (var = (g_free (var), NULL))

#define PUBLISHING_FLICKR_TYPE_FLICKR_PUBLISHER (publishing_flickr_flickr_publisher_get_type ())
#define PUBLISHING_FLICKR_FLICKR_PUBLISHER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_FLICKR_TYPE_FLICKR_PUBLISHER, PublishingFlickrFlickrPublisher))
#define PUBLISHING_FLICKR_FLICKR_PUBLISHER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_FLICKR_TYPE_FLICKR_PUBLISHER, PublishingFlickrFlickrPublisherClass))
#define PUBLISHING_FLICKR_IS_FLICKR_PUBLISHER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_FLICKR_TYPE_FLICKR_PUBLISHER))
#define PUBLISHING_FLICKR_IS_FLICKR_PUBLISHER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_FLICKR_TYPE_FLICKR_PUBLISHER))
#define PUBLISHING_FLICKR_FLICKR_PUBLISHER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_FLICKR_TYPE_FLICKR_PUBLISHER, PublishingFlickrFlickrPublisherClass))

typedef struct _PublishingFlickrFlickrPublisher PublishingFlickrFlickrPublisher;
typedef struct _PublishingFlickrFlickrPublisherClass PublishingFlickrFlickrPublisherClass;

#define PUBLISHING_FLICKR_TYPE_USER_KIND (publishing_flickr_user_kind_get_type ())

#define PUBLISHING_FLICKR_TYPE_VISIBILITY_SPECIFICATION (publishing_flickr_visibility_specification_get_type ())
#define PUBLISHING_FLICKR_VISIBILITY_SPECIFICATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_FLICKR_TYPE_VISIBILITY_SPECIFICATION, PublishingFlickrVisibilitySpecification))
#define PUBLISHING_FLICKR_VISIBILITY_SPECIFICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_FLICKR_TYPE_VISIBILITY_SPECIFICATION, PublishingFlickrVisibilitySpecificationClass))
#define PUBLISHING_FLICKR_IS_VISIBILITY_SPECIFICATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_FLICKR_TYPE_VISIBILITY_SPECIFICATION))
#define PUBLISHING_FLICKR_IS_VISIBILITY_SPECIFICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_FLICKR_TYPE_VISIBILITY_SPECIFICATION))
#define PUBLISHING_FLICKR_VISIBILITY_SPECIFICATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_FLICKR_TYPE_VISIBILITY_SPECIFICATION, PublishingFlickrVisibilitySpecificationClass))

typedef struct _PublishingFlickrVisibilitySpecification PublishingFlickrVisibilitySpecification;
typedef struct _PublishingFlickrVisibilitySpecificationClass PublishingFlickrVisibilitySpecificationClass;
typedef struct _PublishingFlickrVisibilitySpecificationPrivate PublishingFlickrVisibilitySpecificationPrivate;
typedef struct _PublishingFlickrParamSpecVisibilitySpecification PublishingFlickrParamSpecVisibilitySpecification;

#define PUBLISHING_FLICKR_TYPE_PUBLISHING_PARAMETERS (publishing_flickr_publishing_parameters_get_type ())
#define PUBLISHING_FLICKR_PUBLISHING_PARAMETERS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_FLICKR_TYPE_PUBLISHING_PARAMETERS, PublishingFlickrPublishingParameters))
#define PUBLISHING_FLICKR_PUBLISHING_PARAMETERS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_FLICKR_TYPE_PUBLISHING_PARAMETERS, PublishingFlickrPublishingParametersClass))
#define PUBLISHING_FLICKR_IS_PUBLISHING_PARAMETERS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_FLICKR_TYPE_PUBLISHING_PARAMETERS))
#define PUBLISHING_FLICKR_IS_PUBLISHING_PARAMETERS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_FLICKR_TYPE_PUBLISHING_PARAMETERS))
#define PUBLISHING_FLICKR_PUBLISHING_PARAMETERS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_FLICKR_TYPE_PUBLISHING_PARAMETERS, PublishingFlickrPublishingParametersClass))

typedef struct _PublishingFlickrPublishingParameters PublishingFlickrPublishingParameters;
typedef struct _PublishingFlickrPublishingParametersClass PublishingFlickrPublishingParametersClass;
typedef struct _PublishingFlickrPublishingParametersPrivate PublishingFlickrPublishingParametersPrivate;
#define _publishing_flickr_visibility_specification_unref0(var) ((var == NULL) ? NULL : (var = (publishing_flickr_visibility_specification_unref (var), NULL)))
typedef struct _PublishingFlickrParamSpecPublishingParameters PublishingFlickrParamSpecPublishingParameters;
typedef struct _PublishingFlickrFlickrPublisherPrivate PublishingFlickrFlickrPublisherPrivate;

#define PUBLISHING_FLICKR_TYPE_SESSION (publishing_flickr_session_get_type ())
#define PUBLISHING_FLICKR_SESSION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_FLICKR_TYPE_SESSION, PublishingFlickrSession))
#define PUBLISHING_FLICKR_SESSION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_FLICKR_TYPE_SESSION, PublishingFlickrSessionClass))
#define PUBLISHING_FLICKR_IS_SESSION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_FLICKR_TYPE_SESSION))
#define PUBLISHING_FLICKR_IS_SESSION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_FLICKR_TYPE_SESSION))
#define PUBLISHING_FLICKR_SESSION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_FLICKR_TYPE_SESSION, PublishingFlickrSessionClass))

typedef struct _PublishingFlickrSession PublishingFlickrSession;
typedef struct _PublishingFlickrSessionClass PublishingFlickrSessionClass;

#define PUBLISHING_FLICKR_TYPE_PUBLISHING_OPTIONS_PANE (publishing_flickr_publishing_options_pane_get_type ())
#define PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_FLICKR_TYPE_PUBLISHING_OPTIONS_PANE, PublishingFlickrPublishingOptionsPane))
#define PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_FLICKR_TYPE_PUBLISHING_OPTIONS_PANE, PublishingFlickrPublishingOptionsPaneClass))
#define PUBLISHING_FLICKR_IS_PUBLISHING_OPTIONS_PANE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_FLICKR_TYPE_PUBLISHING_OPTIONS_PANE))
#define PUBLISHING_FLICKR_IS_PUBLISHING_OPTIONS_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_FLICKR_TYPE_PUBLISHING_OPTIONS_PANE))
#define PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_FLICKR_TYPE_PUBLISHING_OPTIONS_PANE, PublishingFlickrPublishingOptionsPaneClass))

typedef struct _PublishingFlickrPublishingOptionsPane PublishingFlickrPublishingOptionsPane;
typedef struct _PublishingFlickrPublishingOptionsPaneClass PublishingFlickrPublishingOptionsPaneClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _publishing_rest_support_session_unref0(var) ((var == NULL) ? NULL : (var = (publishing_rest_support_session_unref (var), NULL)))
#define _publishing_flickr_publishing_parameters_unref0(var) ((var == NULL) ? NULL : (var = (publishing_flickr_publishing_parameters_unref (var), NULL)))

#define PUBLISHING_FLICKR_TYPE_PIN_ENTRY_PANE (publishing_flickr_pin_entry_pane_get_type ())
#define PUBLISHING_FLICKR_PIN_ENTRY_PANE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_FLICKR_TYPE_PIN_ENTRY_PANE, PublishingFlickrPinEntryPane))
#define PUBLISHING_FLICKR_PIN_ENTRY_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_FLICKR_TYPE_PIN_ENTRY_PANE, PublishingFlickrPinEntryPaneClass))
#define PUBLISHING_FLICKR_IS_PIN_ENTRY_PANE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_FLICKR_TYPE_PIN_ENTRY_PANE))
#define PUBLISHING_FLICKR_IS_PIN_ENTRY_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_FLICKR_TYPE_PIN_ENTRY_PANE))
#define PUBLISHING_FLICKR_PIN_ENTRY_PANE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_FLICKR_TYPE_PIN_ENTRY_PANE, PublishingFlickrPinEntryPaneClass))

typedef struct _PublishingFlickrPinEntryPane PublishingFlickrPinEntryPane;
typedef struct _PublishingFlickrPinEntryPaneClass PublishingFlickrPinEntryPaneClass;

#define PUBLISHING_FLICKR_TYPE_TRANSACTION (publishing_flickr_transaction_get_type ())
#define PUBLISHING_FLICKR_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_FLICKR_TYPE_TRANSACTION, PublishingFlickrTransaction))
#define PUBLISHING_FLICKR_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_FLICKR_TYPE_TRANSACTION, PublishingFlickrTransactionClass))
#define PUBLISHING_FLICKR_IS_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_FLICKR_TYPE_TRANSACTION))
#define PUBLISHING_FLICKR_IS_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_FLICKR_TYPE_TRANSACTION))
#define PUBLISHING_FLICKR_TRANSACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_FLICKR_TYPE_TRANSACTION, PublishingFlickrTransactionClass))

typedef struct _PublishingFlickrTransaction PublishingFlickrTransaction;
typedef struct _PublishingFlickrTransactionClass PublishingFlickrTransactionClass;

#define PUBLISHING_FLICKR_TYPE_AUTHENTICATION_REQUEST_TRANSACTION (publishing_flickr_authentication_request_transaction_get_type ())
#define PUBLISHING_FLICKR_AUTHENTICATION_REQUEST_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_FLICKR_TYPE_AUTHENTICATION_REQUEST_TRANSACTION, PublishingFlickrAuthenticationRequestTransaction))
#define PUBLISHING_FLICKR_AUTHENTICATION_REQUEST_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_FLICKR_TYPE_AUTHENTICATION_REQUEST_TRANSACTION, PublishingFlickrAuthenticationRequestTransactionClass))
#define PUBLISHING_FLICKR_IS_AUTHENTICATION_REQUEST_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_FLICKR_TYPE_AUTHENTICATION_REQUEST_TRANSACTION))
#define PUBLISHING_FLICKR_IS_AUTHENTICATION_REQUEST_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_FLICKR_TYPE_AUTHENTICATION_REQUEST_TRANSACTION))
#define PUBLISHING_FLICKR_AUTHENTICATION_REQUEST_TRANSACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_FLICKR_TYPE_AUTHENTICATION_REQUEST_TRANSACTION, PublishingFlickrAuthenticationRequestTransactionClass))

typedef struct _PublishingFlickrAuthenticationRequestTransaction PublishingFlickrAuthenticationRequestTransaction;
typedef struct _PublishingFlickrAuthenticationRequestTransactionClass PublishingFlickrAuthenticationRequestTransactionClass;
#define _publishing_rest_support_transaction_unref0(var) ((var == NULL) ? NULL : (var = (publishing_rest_support_transaction_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))

#define PUBLISHING_FLICKR_TYPE_ACCESS_TOKEN_FETCH_TRANSACTION (publishing_flickr_access_token_fetch_transaction_get_type ())
#define PUBLISHING_FLICKR_ACCESS_TOKEN_FETCH_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_FLICKR_TYPE_ACCESS_TOKEN_FETCH_TRANSACTION, PublishingFlickrAccessTokenFetchTransaction))
#define PUBLISHING_FLICKR_ACCESS_TOKEN_FETCH_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_FLICKR_TYPE_ACCESS_TOKEN_FETCH_TRANSACTION, PublishingFlickrAccessTokenFetchTransactionClass))
#define PUBLISHING_FLICKR_IS_ACCESS_TOKEN_FETCH_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_FLICKR_TYPE_ACCESS_TOKEN_FETCH_TRANSACTION))
#define PUBLISHING_FLICKR_IS_ACCESS_TOKEN_FETCH_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_FLICKR_TYPE_ACCESS_TOKEN_FETCH_TRANSACTION))
#define PUBLISHING_FLICKR_ACCESS_TOKEN_FETCH_TRANSACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_FLICKR_TYPE_ACCESS_TOKEN_FETCH_TRANSACTION, PublishingFlickrAccessTokenFetchTransactionClass))

typedef struct _PublishingFlickrAccessTokenFetchTransaction PublishingFlickrAccessTokenFetchTransaction;
typedef struct _PublishingFlickrAccessTokenFetchTransactionClass PublishingFlickrAccessTokenFetchTransactionClass;

#define PUBLISHING_FLICKR_TYPE_ACCOUNT_INFO_FETCH_TRANSACTION (publishing_flickr_account_info_fetch_transaction_get_type ())
#define PUBLISHING_FLICKR_ACCOUNT_INFO_FETCH_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_FLICKR_TYPE_ACCOUNT_INFO_FETCH_TRANSACTION, PublishingFlickrAccountInfoFetchTransaction))
#define PUBLISHING_FLICKR_ACCOUNT_INFO_FETCH_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_FLICKR_TYPE_ACCOUNT_INFO_FETCH_TRANSACTION, PublishingFlickrAccountInfoFetchTransactionClass))
#define PUBLISHING_FLICKR_IS_ACCOUNT_INFO_FETCH_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_FLICKR_TYPE_ACCOUNT_INFO_FETCH_TRANSACTION))
#define PUBLISHING_FLICKR_IS_ACCOUNT_INFO_FETCH_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_FLICKR_TYPE_ACCOUNT_INFO_FETCH_TRANSACTION))
#define PUBLISHING_FLICKR_ACCOUNT_INFO_FETCH_TRANSACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_FLICKR_TYPE_ACCOUNT_INFO_FETCH_TRANSACTION, PublishingFlickrAccountInfoFetchTransactionClass))

typedef struct _PublishingFlickrAccountInfoFetchTransaction PublishingFlickrAccountInfoFetchTransaction;
typedef struct _PublishingFlickrAccountInfoFetchTransactionClass PublishingFlickrAccountInfoFetchTransactionClass;
#define _publishing_rest_support_xml_document_unref0(var) ((var == NULL) ? NULL : (var = (publishing_rest_support_xml_document_unref (var), NULL)))
#define _g_date_time_unref0(var) ((var == NULL) ? NULL : (var = (g_date_time_unref (var), NULL)))

#define PUBLISHING_FLICKR_TYPE_UPLOADER (publishing_flickr_uploader_get_type ())
#define PUBLISHING_FLICKR_UPLOADER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_FLICKR_TYPE_UPLOADER, PublishingFlickrUploader))
#define PUBLISHING_FLICKR_UPLOADER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_FLICKR_TYPE_UPLOADER, PublishingFlickrUploaderClass))
#define PUBLISHING_FLICKR_IS_UPLOADER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_FLICKR_TYPE_UPLOADER))
#define PUBLISHING_FLICKR_IS_UPLOADER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_FLICKR_TYPE_UPLOADER))
#define PUBLISHING_FLICKR_UPLOADER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_FLICKR_TYPE_UPLOADER, PublishingFlickrUploaderClass))

typedef struct _PublishingFlickrUploader PublishingFlickrUploader;
typedef struct _PublishingFlickrUploaderClass PublishingFlickrUploaderClass;
#define _publishing_rest_support_batch_uploader_unref0(var) ((var == NULL) ? NULL : (var = (publishing_rest_support_batch_uploader_unref (var), NULL)))
typedef struct _PublishingFlickrPinEntryPanePrivate PublishingFlickrPinEntryPanePrivate;
#define _g_slist_free0(var) ((var == NULL) ? NULL : (var = (g_slist_free (var), NULL)))
typedef struct _PublishingFlickrTransactionPrivate PublishingFlickrTransactionPrivate;
typedef struct _PublishingFlickrAuthenticationRequestTransactionPrivate PublishingFlickrAuthenticationRequestTransactionPrivate;
typedef struct _PublishingFlickrAccessTokenFetchTransactionPrivate PublishingFlickrAccessTokenFetchTransactionPrivate;
typedef struct _PublishingFlickrAccountInfoFetchTransactionPrivate PublishingFlickrAccountInfoFetchTransactionPrivate;

#define PUBLISHING_FLICKR_TYPE_UPLOAD_TRANSACTION (publishing_flickr_upload_transaction_get_type ())
#define PUBLISHING_FLICKR_UPLOAD_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_FLICKR_TYPE_UPLOAD_TRANSACTION, PublishingFlickrUploadTransaction))
#define PUBLISHING_FLICKR_UPLOAD_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_FLICKR_TYPE_UPLOAD_TRANSACTION, PublishingFlickrUploadTransactionClass))
#define PUBLISHING_FLICKR_IS_UPLOAD_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_FLICKR_TYPE_UPLOAD_TRANSACTION))
#define PUBLISHING_FLICKR_IS_UPLOAD_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_FLICKR_TYPE_UPLOAD_TRANSACTION))
#define PUBLISHING_FLICKR_UPLOAD_TRANSACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_FLICKR_TYPE_UPLOAD_TRANSACTION, PublishingFlickrUploadTransactionClass))

typedef struct _PublishingFlickrUploadTransaction PublishingFlickrUploadTransaction;
typedef struct _PublishingFlickrUploadTransactionClass PublishingFlickrUploadTransactionClass;
typedef struct _PublishingFlickrUploadTransactionPrivate PublishingFlickrUploadTransactionPrivate;
#define _g_hash_table_unref0(var) ((var == NULL) ? NULL : (var = (g_hash_table_unref (var), NULL)))
typedef struct _PublishingFlickrSessionPrivate PublishingFlickrSessionPrivate;
#define _publishing_rest_support_argument_unref0(var) ((var == NULL) ? NULL : (var = (publishing_rest_support_argument_unref (var), NULL)))
typedef struct _PublishingFlickrPublishingOptionsPanePrivate PublishingFlickrPublishingOptionsPanePrivate;

#define PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_TYPE_VISIBILITY_ENTRY (publishing_flickr_publishing_options_pane_visibility_entry_get_type ())
#define PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_VISIBILITY_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_TYPE_VISIBILITY_ENTRY, PublishingFlickrPublishingOptionsPaneVisibilityEntry))
#define PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_VISIBILITY_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_TYPE_VISIBILITY_ENTRY, PublishingFlickrPublishingOptionsPaneVisibilityEntryClass))
#define PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_IS_VISIBILITY_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_TYPE_VISIBILITY_ENTRY))
#define PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_IS_VISIBILITY_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_TYPE_VISIBILITY_ENTRY))
#define PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_VISIBILITY_ENTRY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_TYPE_VISIBILITY_ENTRY, PublishingFlickrPublishingOptionsPaneVisibilityEntryClass))

typedef struct _PublishingFlickrPublishingOptionsPaneVisibilityEntry PublishingFlickrPublishingOptionsPaneVisibilityEntry;
typedef struct _PublishingFlickrPublishingOptionsPaneVisibilityEntryClass PublishingFlickrPublishingOptionsPaneVisibilityEntryClass;

#define PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_TYPE_SIZE_ENTRY (publishing_flickr_publishing_options_pane_size_entry_get_type ())
#define PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_SIZE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_TYPE_SIZE_ENTRY, PublishingFlickrPublishingOptionsPaneSizeEntry))
#define PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_SIZE_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_TYPE_SIZE_ENTRY, PublishingFlickrPublishingOptionsPaneSizeEntryClass))
#define PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_IS_SIZE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_TYPE_SIZE_ENTRY))
#define PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_IS_SIZE_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_TYPE_SIZE_ENTRY))
#define PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_SIZE_ENTRY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_TYPE_SIZE_ENTRY, PublishingFlickrPublishingOptionsPaneSizeEntryClass))

typedef struct _PublishingFlickrPublishingOptionsPaneSizeEntry PublishingFlickrPublishingOptionsPaneSizeEntry;
typedef struct _PublishingFlickrPublishingOptionsPaneSizeEntryClass PublishingFlickrPublishingOptionsPaneSizeEntryClass;
typedef struct _PublishingFlickrPublishingOptionsPaneVisibilityEntryPrivate PublishingFlickrPublishingOptionsPaneVisibilityEntryPrivate;
typedef struct _PublishingFlickrPublishingOptionsPaneSizeEntryPrivate PublishingFlickrPublishingOptionsPaneSizeEntryPrivate;
#define _publishing_flickr_publishing_options_pane_visibility_entry_unref0(var) ((var == NULL) ? NULL : (var = (publishing_flickr_publishing_options_pane_visibility_entry_unref (var), NULL)))
#define _publishing_flickr_publishing_options_pane_size_entry_unref0(var) ((var == NULL) ? NULL : (var = (publishing_flickr_publishing_options_pane_size_entry_unref (var), NULL)))
typedef struct _PublishingFlickrPublishingOptionsPaneParamSpecSizeEntry PublishingFlickrPublishingOptionsPaneParamSpecSizeEntry;
typedef struct _PublishingFlickrPublishingOptionsPaneParamSpecVisibilityEntry PublishingFlickrPublishingOptionsPaneParamSpecVisibilityEntry;
typedef struct _PublishingFlickrUploaderPrivate PublishingFlickrUploaderPrivate;
#define _gexiv2_metadata_free0(var) ((var == NULL) ? NULL : (var = (gexiv2_metadata_free (var), NULL)))
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _FlickrService {
	GObject parent_instance;
	FlickrServicePrivate * priv;
};

struct _FlickrServiceClass {
	GObjectClass parent_class;
};

typedef enum  {
	PUBLISHING_FLICKR_USER_KIND_PRO,
	PUBLISHING_FLICKR_USER_KIND_FREE
} PublishingFlickrUserKind;

struct _PublishingFlickrVisibilitySpecification {
	GTypeInstance parent_instance;
	volatile int ref_count;
	PublishingFlickrVisibilitySpecificationPrivate * priv;
	gint friends_level;
	gint family_level;
	gint everyone_level;
};

struct _PublishingFlickrVisibilitySpecificationClass {
	GTypeClass parent_class;
	void (*finalize) (PublishingFlickrVisibilitySpecification *self);
};

struct _PublishingFlickrParamSpecVisibilitySpecification {
	GParamSpec parent_instance;
};

struct _PublishingFlickrPublishingParameters {
	GTypeInstance parent_instance;
	volatile int ref_count;
	PublishingFlickrPublishingParametersPrivate * priv;
	PublishingFlickrUserKind user_kind;
	gint quota_free_mb;
	gint photo_major_axis_size;
	gchar* username;
	PublishingFlickrVisibilitySpecification* visibility_specification;
};

struct _PublishingFlickrPublishingParametersClass {
	GTypeClass parent_class;
	void (*finalize) (PublishingFlickrPublishingParameters *self);
};

struct _PublishingFlickrParamSpecPublishingParameters {
	GParamSpec parent_instance;
};

struct _PublishingFlickrFlickrPublisher {
	GObject parent_instance;
	PublishingFlickrFlickrPublisherPrivate * priv;
};

struct _PublishingFlickrFlickrPublisherClass {
	GObjectClass parent_class;
};

struct _PublishingFlickrFlickrPublisherPrivate {
	SpitPublishingService* service;
	SpitPublishingPluginHost* host;
	SpitPublishingProgressCallback progress_reporter;
	gpointer progress_reporter_target;
	GDestroyNotify progress_reporter_target_destroy_notify;
	gboolean running;
	gboolean was_started;
	PublishingFlickrSession* session;
	PublishingFlickrPublishingOptionsPane* publishing_options_pane;
	PublishingFlickrPublishingParameters* parameters;
};

struct _PublishingFlickrPinEntryPane {
	GObject parent_instance;
	PublishingFlickrPinEntryPanePrivate * priv;
};

struct _PublishingFlickrPinEntryPaneClass {
	GObjectClass parent_class;
};

struct _PublishingFlickrPinEntryPanePrivate {
	GtkBox* pane_widget;
	GtkButton* continue_button;
	GtkEntry* pin_entry;
	GtkLabel* pin_entry_caption;
	GtkLabel* explanatory_text;
	GtkBuilder* builder;
};

struct _PublishingFlickrTransaction {
	PublishingRESTSupportTransaction parent_instance;
	PublishingFlickrTransactionPrivate * priv;
};

struct _PublishingFlickrTransactionClass {
	PublishingRESTSupportTransactionClass parent_class;
};

struct _PublishingFlickrAuthenticationRequestTransaction {
	PublishingFlickrTransaction parent_instance;
	PublishingFlickrAuthenticationRequestTransactionPrivate * priv;
};

struct _PublishingFlickrAuthenticationRequestTransactionClass {
	PublishingFlickrTransactionClass parent_class;
};

struct _PublishingFlickrAccessTokenFetchTransaction {
	PublishingFlickrTransaction parent_instance;
	PublishingFlickrAccessTokenFetchTransactionPrivate * priv;
};

struct _PublishingFlickrAccessTokenFetchTransactionClass {
	PublishingFlickrTransactionClass parent_class;
};

struct _PublishingFlickrAccountInfoFetchTransaction {
	PublishingFlickrTransaction parent_instance;
	PublishingFlickrAccountInfoFetchTransactionPrivate * priv;
};

struct _PublishingFlickrAccountInfoFetchTransactionClass {
	PublishingFlickrTransactionClass parent_class;
};

struct _PublishingFlickrUploadTransaction {
	PublishingRESTSupportUploadTransaction parent_instance;
	PublishingFlickrUploadTransactionPrivate * priv;
};

struct _PublishingFlickrUploadTransactionClass {
	PublishingRESTSupportUploadTransactionClass parent_class;
};

struct _PublishingFlickrUploadTransactionPrivate {
	PublishingFlickrPublishingParameters* parameters;
	PublishingFlickrSession* session;
	PublishingRESTSupportArgument** auth_header_fields;
	gint auth_header_fields_length1;
	gint _auth_header_fields_size_;
};

struct _PublishingFlickrSession {
	PublishingRESTSupportSession parent_instance;
	PublishingFlickrSessionPrivate * priv;
};

struct _PublishingFlickrSessionClass {
	PublishingRESTSupportSessionClass parent_class;
};

struct _PublishingFlickrSessionPrivate {
	gchar* request_phase_token;
	gchar* request_phase_token_secret;
	gchar* access_phase_token;
	gchar* access_phase_token_secret;
	gchar* username;
};

struct _PublishingFlickrPublishingOptionsPane {
	GObject parent_instance;
	PublishingFlickrPublishingOptionsPanePrivate * priv;
};

struct _PublishingFlickrPublishingOptionsPaneClass {
	GObjectClass parent_class;
};

struct _PublishingFlickrPublishingOptionsPanePrivate {
	GtkBuilder* builder;
	GtkBox* pane_widget;
	GtkLabel* visibility_label;
	GtkLabel* upload_info_label;
	GtkLabel* size_label;
	GtkButton* logout_button;
	GtkButton* publish_button;
	GtkComboBoxText* visibility_combo;
	GtkComboBoxText* size_combo;
	GtkCheckButton* strip_metadata_check;
	PublishingFlickrPublishingOptionsPaneVisibilityEntry** visibilities;
	gint visibilities_length1;
	gint _visibilities_size_;
	PublishingFlickrPublishingOptionsPaneSizeEntry** sizes;
	gint sizes_length1;
	gint _sizes_size_;
	PublishingFlickrPublishingParameters* parameters;
	PublishingFlickrFlickrPublisher* publisher;
	SpitPublishingPublisherMediaType media_type;
};

struct _PublishingFlickrPublishingOptionsPaneVisibilityEntry {
	GTypeInstance parent_instance;
	volatile int ref_count;
	PublishingFlickrPublishingOptionsPaneVisibilityEntryPrivate * priv;
	PublishingFlickrVisibilitySpecification* specification;
	gchar* title;
};

struct _PublishingFlickrPublishingOptionsPaneVisibilityEntryClass {
	GTypeClass parent_class;
	void (*finalize) (PublishingFlickrPublishingOptionsPaneVisibilityEntry *self);
};

struct _PublishingFlickrPublishingOptionsPaneSizeEntry {
	GTypeInstance parent_instance;
	volatile int ref_count;
	PublishingFlickrPublishingOptionsPaneSizeEntryPrivate * priv;
	gchar* title;
	gint size;
};

struct _PublishingFlickrPublishingOptionsPaneSizeEntryClass {
	GTypeClass parent_class;
	void (*finalize) (PublishingFlickrPublishingOptionsPaneSizeEntry *self);
};

struct _PublishingFlickrPublishingOptionsPaneParamSpecSizeEntry {
	GParamSpec parent_instance;
};

struct _PublishingFlickrPublishingOptionsPaneParamSpecVisibilityEntry {
	GParamSpec parent_instance;
};

struct _PublishingFlickrUploader {
	PublishingRESTSupportBatchUploader parent_instance;
	PublishingFlickrUploaderPrivate * priv;
};

struct _PublishingFlickrUploaderClass {
	PublishingRESTSupportBatchUploaderClass parent_class;
};

struct _PublishingFlickrUploaderPrivate {
	PublishingFlickrPublishingParameters* parameters;
	gboolean strip_metadata;
};


static gpointer flickr_service_parent_class = NULL;
static GdkPixbuf** flickr_service_icon_pixbuf_set;
static gint flickr_service_icon_pixbuf_set_length1;
static GdkPixbuf** flickr_service_icon_pixbuf_set = NULL;
static gint flickr_service_icon_pixbuf_set_length1 = 0;
static gint _flickr_service_icon_pixbuf_set_size_ = 0;
static SpitPluggableIface* flickr_service_spit_pluggable_parent_iface = NULL;
static SpitPublishingServiceIface* flickr_service_spit_publishing_service_parent_iface = NULL;
static gpointer publishing_flickr_visibility_specification_parent_class = NULL;
static gpointer publishing_flickr_publishing_parameters_parent_class = NULL;
static gpointer publishing_flickr_flickr_publisher_parent_class = NULL;
static SpitPublishingPublisherIface* publishing_flickr_flickr_publisher_spit_publishing_publisher_parent_iface = NULL;
static gpointer publishing_flickr_pin_entry_pane_parent_class = NULL;
static SpitPublishingDialogPaneIface* publishing_flickr_pin_entry_pane_spit_publishing_dialog_pane_parent_iface = NULL;
static gpointer publishing_flickr_transaction_parent_class = NULL;
static gpointer publishing_flickr_authentication_request_transaction_parent_class = NULL;
static gpointer publishing_flickr_access_token_fetch_transaction_parent_class = NULL;
static gpointer publishing_flickr_account_info_fetch_transaction_parent_class = NULL;
static gpointer publishing_flickr_upload_transaction_parent_class = NULL;
static gpointer publishing_flickr_session_parent_class = NULL;
static gpointer publishing_flickr_publishing_options_pane_parent_class = NULL;
static gpointer publishing_flickr_publishing_options_pane_size_entry_parent_class = NULL;
static gpointer publishing_flickr_publishing_options_pane_visibility_entry_parent_class = NULL;
static SpitPublishingDialogPaneIface* publishing_flickr_publishing_options_pane_spit_publishing_dialog_pane_parent_iface = NULL;
static gpointer publishing_flickr_uploader_parent_class = NULL;

GType flickr_service_get_type (void) G_GNUC_CONST;
enum  {
	FLICKR_SERVICE_DUMMY_PROPERTY
};
#define FLICKR_SERVICE_ICON_FILENAME "flickr.png"
FlickrService* flickr_service_new (GFile* resource_directory);
FlickrService* flickr_service_construct (GType object_type, GFile* resource_directory);
static gint flickr_service_real_get_pluggable_interface (SpitPluggable* base, gint min_host_interface, gint max_host_interface);
static const gchar* flickr_service_real_get_id (SpitPluggable* base);
static const gchar* flickr_service_real_get_pluggable_name (SpitPluggable* base);
static void flickr_service_real_get_info (SpitPluggable* base, SpitPluggableInfo* info);
static GdkPixbuf** _vala_array_dup7 (GdkPixbuf** self, int length);
static void flickr_service_real_activation (SpitPluggable* base, gboolean enabled);
static SpitPublishingPublisher* flickr_service_real_create_publisher (SpitPublishingService* base, SpitPublishingPluginHost* host);
PublishingFlickrFlickrPublisher* publishing_flickr_flickr_publisher_new (SpitPublishingService* service, SpitPublishingPluginHost* host);
PublishingFlickrFlickrPublisher* publishing_flickr_flickr_publisher_construct (GType object_type, SpitPublishingService* service, SpitPublishingPluginHost* host);
GType publishing_flickr_flickr_publisher_get_type (void) G_GNUC_CONST;
static SpitPublishingPublisherMediaType flickr_service_real_get_supported_media (SpitPublishingService* base);
static void flickr_service_finalize (GObject* obj);
#define PUBLISHING_FLICKR_SERVICE_NAME "Flickr"
#define PUBLISHING_FLICKR_SERVICE_WELCOME_MESSAGE _ ("You are not currently logged into Flickr.\n" \
"\n" \
"Click Login to log into Flickr in your Web browser.  You will have to " \
"authorize Shotwell Connect to link to your Flickr account.")
#define PUBLISHING_FLICKR_RESTART_ERROR_MESSAGE _ ("You have already logged in and out of Flickr during this Shotwell sess" \
"ion.\n" \
"To continue publishing to Flickr, quit and restart Shotwell, then try " \
"publishing again.")
#define PUBLISHING_FLICKR_ENDPOINT_URL "https://api.flickr.com/services/rest"
#define PUBLISHING_FLICKR_API_KEY "60dd96d4a2ad04888b09c9e18d82c26f"
#define PUBLISHING_FLICKR_API_SECRET "d0960565e03547c1"
#define PUBLISHING_FLICKR_ORIGINAL_SIZE -1
#define PUBLISHING_FLICKR_EXPIRED_SESSION_ERROR_CODE "98"
#define PUBLISHING_FLICKR_ENCODE_RFC_3986_EXTRA "!*'();:@&=+$,/?%#[] \\"
GType publishing_flickr_user_kind_get_type (void) G_GNUC_CONST;
gpointer publishing_flickr_visibility_specification_ref (gpointer instance);
void publishing_flickr_visibility_specification_unref (gpointer instance);
GParamSpec* publishing_flickr_param_spec_visibility_specification (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void publishing_flickr_value_set_visibility_specification (GValue* value, gpointer v_object);
void publishing_flickr_value_take_visibility_specification (GValue* value, gpointer v_object);
gpointer publishing_flickr_value_get_visibility_specification (const GValue* value);
GType publishing_flickr_visibility_specification_get_type (void) G_GNUC_CONST;
enum  {
	PUBLISHING_FLICKR_VISIBILITY_SPECIFICATION_DUMMY_PROPERTY
};
PublishingFlickrVisibilitySpecification* publishing_flickr_visibility_specification_new (gint friends_level, gint family_level, gint everyone_level);
PublishingFlickrVisibilitySpecification* publishing_flickr_visibility_specification_construct (GType object_type, gint friends_level, gint family_level, gint everyone_level);
static void publishing_flickr_visibility_specification_finalize (PublishingFlickrVisibilitySpecification* obj);
gpointer publishing_flickr_publishing_parameters_ref (gpointer instance);
void publishing_flickr_publishing_parameters_unref (gpointer instance);
GParamSpec* publishing_flickr_param_spec_publishing_parameters (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void publishing_flickr_value_set_publishing_parameters (GValue* value, gpointer v_object);
void publishing_flickr_value_take_publishing_parameters (GValue* value, gpointer v_object);
gpointer publishing_flickr_value_get_publishing_parameters (const GValue* value);
GType publishing_flickr_publishing_parameters_get_type (void) G_GNUC_CONST;
enum  {
	PUBLISHING_FLICKR_PUBLISHING_PARAMETERS_DUMMY_PROPERTY
};
PublishingFlickrPublishingParameters* publishing_flickr_publishing_parameters_new (void);
PublishingFlickrPublishingParameters* publishing_flickr_publishing_parameters_construct (GType object_type);
static void publishing_flickr_publishing_parameters_finalize (PublishingFlickrPublishingParameters* obj);
GType publishing_flickr_session_get_type (void) G_GNUC_CONST;
GType publishing_flickr_publishing_options_pane_get_type (void) G_GNUC_CONST;
#define PUBLISHING_FLICKR_FLICKR_PUBLISHER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_FLICKR_TYPE_FLICKR_PUBLISHER, PublishingFlickrFlickrPublisherPrivate))
enum  {
	PUBLISHING_FLICKR_FLICKR_PUBLISHER_DUMMY_PROPERTY
};
static void publishing_flickr_flickr_publisher_on_session_authenticated (PublishingFlickrFlickrPublisher* self);
static void _publishing_flickr_flickr_publisher_on_session_authenticated_publishing_rest_support_session_authenticated (PublishingRESTSupportSession* _sender, gpointer self);
PublishingFlickrSession* publishing_flickr_session_new (void);
PublishingFlickrSession* publishing_flickr_session_construct (GType object_type);
static void publishing_flickr_flickr_publisher_invalidate_persistent_session (PublishingFlickrFlickrPublisher* self);
static void publishing_flickr_flickr_publisher_set_persistent_access_phase_token (PublishingFlickrFlickrPublisher* self, const gchar* token);
static void publishing_flickr_flickr_publisher_set_persistent_access_phase_token_secret (PublishingFlickrFlickrPublisher* self, const gchar* secret);
static void publishing_flickr_flickr_publisher_set_persistent_access_phase_username (PublishingFlickrFlickrPublisher* self, const gchar* username);
static gboolean publishing_flickr_flickr_publisher_is_persistent_session_valid (PublishingFlickrFlickrPublisher* self);
static gchar* publishing_flickr_flickr_publisher_get_persistent_access_phase_username (PublishingFlickrFlickrPublisher* self);
static gchar* publishing_flickr_flickr_publisher_get_persistent_access_phase_token (PublishingFlickrFlickrPublisher* self);
static gchar* publishing_flickr_flickr_publisher_get_persistent_access_phase_token_secret (PublishingFlickrFlickrPublisher* self);
static gboolean publishing_flickr_flickr_publisher_get_persistent_strip_metadata (PublishingFlickrFlickrPublisher* self);
static void publishing_flickr_flickr_publisher_set_persistent_strip_metadata (PublishingFlickrFlickrPublisher* self, gboolean strip_metadata);
static void publishing_flickr_flickr_publisher_on_welcome_pane_login_clicked (PublishingFlickrFlickrPublisher* self);
static void publishing_flickr_flickr_publisher_do_run_authentication_request_transaction (PublishingFlickrFlickrPublisher* self);
static void publishing_flickr_flickr_publisher_on_auth_request_txn_completed (PublishingFlickrFlickrPublisher* self, PublishingRESTSupportTransaction* txn);
static void _publishing_flickr_flickr_publisher_on_auth_request_txn_completed_publishing_rest_support_transaction_completed (PublishingRESTSupportTransaction* _sender, gpointer self);
static void publishing_flickr_flickr_publisher_on_auth_request_txn_error (PublishingFlickrFlickrPublisher* self, PublishingRESTSupportTransaction* txn, GError* err);
static void _publishing_flickr_flickr_publisher_on_auth_request_txn_error_publishing_rest_support_transaction_network_error (PublishingRESTSupportTransaction* _sender, GError* err, gpointer self);
static void publishing_flickr_flickr_publisher_do_parse_token_info_from_auth_request (PublishingFlickrFlickrPublisher* self, const gchar* response);
static void publishing_flickr_flickr_publisher_on_authentication_token_available (PublishingFlickrFlickrPublisher* self, const gchar* token, const gchar* token_secret);
void publishing_flickr_session_set_request_phase_credentials (PublishingFlickrSession* self, const gchar* token, const gchar* secret);
static void publishing_flickr_flickr_publisher_do_launch_system_browser (PublishingFlickrFlickrPublisher* self, const gchar* token);
static void publishing_flickr_flickr_publisher_on_system_browser_launched (PublishingFlickrFlickrPublisher* self);
static void publishing_flickr_flickr_publisher_do_show_pin_entry_pane (PublishingFlickrFlickrPublisher* self);
GType publishing_flickr_pin_entry_pane_get_type (void) G_GNUC_CONST;
static void publishing_flickr_flickr_publisher_on_pin_entry_proceed (PublishingFlickrFlickrPublisher* self, PublishingFlickrPinEntryPane* sender, const gchar* pin);
static void _publishing_flickr_flickr_publisher_on_pin_entry_proceed_publishing_flickr_pin_entry_pane_proceed (PublishingFlickrPinEntryPane* _sender, PublishingFlickrPinEntryPane* sender, const gchar* authorization_pin, gpointer self);
static void publishing_flickr_flickr_publisher_do_verify_pin (PublishingFlickrFlickrPublisher* self, const gchar* pin);
static void publishing_flickr_flickr_publisher_on_access_token_fetch_txn_completed (PublishingFlickrFlickrPublisher* self, PublishingRESTSupportTransaction* txn);
static void _publishing_flickr_flickr_publisher_on_access_token_fetch_txn_completed_publishing_rest_support_transaction_completed (PublishingRESTSupportTransaction* _sender, gpointer self);
static void publishing_flickr_flickr_publisher_on_access_token_fetch_error (PublishingFlickrFlickrPublisher* self, PublishingRESTSupportTransaction* txn, GError* err);
static void _publishing_flickr_flickr_publisher_on_access_token_fetch_error_publishing_rest_support_transaction_network_error (PublishingRESTSupportTransaction* _sender, GError* err, gpointer self);
static void publishing_flickr_flickr_publisher_do_extract_access_phase_credentials_from_reponse (PublishingFlickrFlickrPublisher* self, const gchar* response);
gchar* publishing_flickr_session_get_username (PublishingFlickrSession* self);
gchar* publishing_flickr_session_get_access_phase_token (PublishingFlickrSession* self);
gchar* publishing_flickr_session_get_access_phase_token_secret (PublishingFlickrSession* self);
static void publishing_flickr_flickr_publisher_do_fetch_account_info (PublishingFlickrFlickrPublisher* self);
static void publishing_flickr_flickr_publisher_on_account_fetch_txn_completed (PublishingFlickrFlickrPublisher* self, PublishingRESTSupportTransaction* txn);
static void _publishing_flickr_flickr_publisher_on_account_fetch_txn_completed_publishing_rest_support_transaction_completed (PublishingRESTSupportTransaction* _sender, gpointer self);
static void publishing_flickr_flickr_publisher_on_account_fetch_txn_error (PublishingFlickrFlickrPublisher* self, PublishingRESTSupportTransaction* txn, GError* err);
static void _publishing_flickr_flickr_publisher_on_account_fetch_txn_error_publishing_rest_support_transaction_network_error (PublishingRESTSupportTransaction* _sender, GError* err, gpointer self);
static void publishing_flickr_flickr_publisher_do_parse_account_info_from_xml (PublishingFlickrFlickrPublisher* self, const gchar* xml);
static void publishing_flickr_flickr_publisher_on_account_info_available (PublishingFlickrFlickrPublisher* self);
static void publishing_flickr_flickr_publisher_do_show_publishing_options_pane (PublishingFlickrFlickrPublisher* self);
static void publishing_flickr_flickr_publisher_on_publishing_options_pane_publish (PublishingFlickrFlickrPublisher* self, gboolean strip_metadata);
static void _publishing_flickr_flickr_publisher_on_publishing_options_pane_publish_publishing_flickr_publishing_options_pane_publish (PublishingFlickrPublishingOptionsPane* _sender, gboolean strip_metadata, gpointer self);
static void publishing_flickr_flickr_publisher_on_publishing_options_pane_logout (PublishingFlickrFlickrPublisher* self);
static void _publishing_flickr_flickr_publisher_on_publishing_options_pane_logout_publishing_flickr_publishing_options_pane_logout (PublishingFlickrPublishingOptionsPane* _sender, gpointer self);
static void publishing_flickr_flickr_publisher_do_publish (PublishingFlickrFlickrPublisher* self, gboolean strip_metadata);
static void publishing_flickr_flickr_publisher_do_logout (PublishingFlickrFlickrPublisher* self);
static void publishing_flickr_flickr_publisher_on_upload_status_updated (PublishingFlickrFlickrPublisher* self, gint file_number, gdouble completed_fraction);
static void publishing_flickr_flickr_publisher_on_upload_complete (PublishingFlickrFlickrPublisher* self, PublishingRESTSupportBatchUploader* uploader, gint num_published);
static void _publishing_flickr_flickr_publisher_on_upload_complete_publishing_rest_support_batch_uploader_upload_complete (PublishingRESTSupportBatchUploader* _sender, gint num_photos_published, gpointer self);
static void publishing_flickr_flickr_publisher_on_upload_error (PublishingFlickrFlickrPublisher* self, PublishingRESTSupportBatchUploader* uploader, GError* err);
static void _publishing_flickr_flickr_publisher_on_upload_error_publishing_rest_support_batch_uploader_upload_error (PublishingRESTSupportBatchUploader* _sender, GError* err, gpointer self);
static void publishing_flickr_flickr_publisher_do_show_success_pane (PublishingFlickrFlickrPublisher* self);
static void publishing_flickr_flickr_publisher_do_show_login_welcome_pane (PublishingFlickrFlickrPublisher* self);
static void _publishing_flickr_flickr_publisher_on_welcome_pane_login_clicked_spit_publishing_login_callback (gpointer self);
GType publishing_flickr_transaction_get_type (void) G_GNUC_CONST;
GType publishing_flickr_authentication_request_transaction_get_type (void) G_GNUC_CONST;
PublishingFlickrAuthenticationRequestTransaction* publishing_flickr_authentication_request_transaction_new (PublishingFlickrSession* session);
PublishingFlickrAuthenticationRequestTransaction* publishing_flickr_authentication_request_transaction_construct (GType object_type, PublishingFlickrSession* session);
PublishingFlickrPinEntryPane* publishing_flickr_pin_entry_pane_new (GtkBuilder* builder);
PublishingFlickrPinEntryPane* publishing_flickr_pin_entry_pane_construct (GType object_type, GtkBuilder* builder);
GType publishing_flickr_access_token_fetch_transaction_get_type (void) G_GNUC_CONST;
PublishingFlickrAccessTokenFetchTransaction* publishing_flickr_access_token_fetch_transaction_new (PublishingFlickrSession* session, const gchar* user_verifier);
PublishingFlickrAccessTokenFetchTransaction* publishing_flickr_access_token_fetch_transaction_construct (GType object_type, PublishingFlickrSession* session, const gchar* user_verifier);
void publishing_flickr_session_set_access_phase_credentials (PublishingFlickrSession* self, const gchar* token, const gchar* secret, const gchar* username);
GType publishing_flickr_account_info_fetch_transaction_get_type (void) G_GNUC_CONST;
PublishingFlickrAccountInfoFetchTransaction* publishing_flickr_account_info_fetch_transaction_new (PublishingFlickrSession* session);
PublishingFlickrAccountInfoFetchTransaction* publishing_flickr_account_info_fetch_transaction_construct (GType object_type, PublishingFlickrSession* session);
PublishingRESTSupportXmlDocument* publishing_flickr_transaction_parse_flickr_response (const gchar* xml, GError** error);
void publishing_flickr_session_deauthenticate (PublishingFlickrSession* self);
static void publishing_flickr_flickr_publisher_attempt_start (PublishingFlickrFlickrPublisher* self);
PublishingFlickrPublishingOptionsPane* publishing_flickr_publishing_options_pane_new (PublishingFlickrFlickrPublisher* publisher, PublishingFlickrPublishingParameters* parameters, SpitPublishingPublisherMediaType media_type, GtkBuilder* builder, gboolean strip_metadata);
PublishingFlickrPublishingOptionsPane* publishing_flickr_publishing_options_pane_construct (GType object_type, PublishingFlickrFlickrPublisher* publisher, PublishingFlickrPublishingParameters* parameters, SpitPublishingPublisherMediaType media_type, GtkBuilder* builder, gboolean strip_metadata);
gint publishing_flickr_flickr_publisher_flickr_date_time_compare_func (SpitPublishingPublishable* a, SpitPublishingPublishable* b);
static gint _publishing_flickr_flickr_publisher_flickr_date_time_compare_func_gcompare_data_func (gconstpointer a, gconstpointer b, gpointer self);
GType publishing_flickr_uploader_get_type (void) G_GNUC_CONST;
PublishingFlickrUploader* publishing_flickr_uploader_new (PublishingFlickrSession* session, SpitPublishingPublishable** publishables, int publishables_length1, PublishingFlickrPublishingParameters* parameters, gboolean strip_metadata);
PublishingFlickrUploader* publishing_flickr_uploader_construct (GType object_type, PublishingFlickrSession* session, SpitPublishingPublishable** publishables, int publishables_length1, PublishingFlickrPublishingParameters* parameters, gboolean strip_metadata);
static void _publishing_flickr_flickr_publisher_on_upload_status_updated_spit_publishing_progress_callback (gint file_number, gdouble fraction_complete, gpointer self);
gint publishing_flickr_flickr_publisher_get_persistent_visibility (PublishingFlickrFlickrPublisher* self);
void publishing_flickr_flickr_publisher_set_persistent_visibility (PublishingFlickrFlickrPublisher* self, gint vis);
gint publishing_flickr_flickr_publisher_get_persistent_default_size (PublishingFlickrFlickrPublisher* self);
void publishing_flickr_flickr_publisher_set_persistent_default_size (PublishingFlickrFlickrPublisher* self, gint size);
static SpitPublishingService* publishing_flickr_flickr_publisher_real_get_service (SpitPublishingPublisher* base);
static gboolean publishing_flickr_flickr_publisher_real_is_running (SpitPublishingPublisher* base);
void publishing_flickr_session_authenticate_from_persistent_credentials (PublishingFlickrSession* self, const gchar* token, const gchar* secret, const gchar* username);
static void publishing_flickr_flickr_publisher_real_start (SpitPublishingPublisher* base);
static void publishing_flickr_flickr_publisher_real_stop (SpitPublishingPublisher* base);
static void publishing_flickr_flickr_publisher_finalize (GObject* obj);
#define PUBLISHING_FLICKR_PIN_ENTRY_PANE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_FLICKR_TYPE_PIN_ENTRY_PANE, PublishingFlickrPinEntryPanePrivate))
enum  {
	PUBLISHING_FLICKR_PIN_ENTRY_PANE_DUMMY_PROPERTY
};
static void publishing_flickr_pin_entry_pane_on_pin_entry_contents_changed (PublishingFlickrPinEntryPane* self);
static void publishing_flickr_pin_entry_pane_on_continue_clicked (PublishingFlickrPinEntryPane* self);
static GtkWidget* publishing_flickr_pin_entry_pane_real_get_widget (SpitPublishingDialogPane* base);
static SpitPublishingDialogPaneGeometryOptions publishing_flickr_pin_entry_pane_real_get_preferred_geometry (SpitPublishingDialogPane* base);
static void publishing_flickr_pin_entry_pane_real_on_pane_installed (SpitPublishingDialogPane* base);
static void _publishing_flickr_pin_entry_pane_on_continue_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self);
static void _publishing_flickr_pin_entry_pane_on_pin_entry_contents_changed_gtk_editable_changed (GtkEditable* _sender, gpointer self);
static void publishing_flickr_pin_entry_pane_real_on_pane_uninstalled (SpitPublishingDialogPane* base);
static void g_cclosure_user_marshal_VOID__OBJECT_STRING (GClosure * closure, GValue * return_value, guint n_param_values, const GValue * param_values, gpointer invocation_hint, gpointer marshal_data);
static void publishing_flickr_pin_entry_pane_finalize (GObject* obj);
enum  {
	PUBLISHING_FLICKR_TRANSACTION_DUMMY_PROPERTY
};
PublishingFlickrTransaction* publishing_flickr_transaction_new (PublishingFlickrSession* session, PublishingRESTSupportHttpMethod method);
PublishingFlickrTransaction* publishing_flickr_transaction_construct (GType object_type, PublishingFlickrSession* session, PublishingRESTSupportHttpMethod method);
gchar* publishing_flickr_session_get_oauth_nonce (PublishingFlickrSession* self);
gchar* publishing_flickr_session_get_oauth_timestamp (PublishingFlickrSession* self);
PublishingFlickrTransaction* publishing_flickr_transaction_new_with_uri (PublishingFlickrSession* session, const gchar* uri, PublishingRESTSupportHttpMethod method);
PublishingFlickrTransaction* publishing_flickr_transaction_construct_with_uri (GType object_type, PublishingFlickrSession* session, const gchar* uri, PublishingRESTSupportHttpMethod method);
static void publishing_flickr_transaction_real_execute (PublishingRESTSupportTransaction* base, GError** error);
void publishing_flickr_session_sign_transaction (PublishingFlickrSession* self, PublishingRESTSupportTransaction* txn);
gchar* publishing_flickr_transaction_validate_xml (PublishingRESTSupportXmlDocument* doc);
static gchar* _publishing_flickr_transaction_validate_xml_publishing_rest_support_xml_document_check_for_error_response (PublishingRESTSupportXmlDocument* doc, gpointer self);
enum  {
	PUBLISHING_FLICKR_AUTHENTICATION_REQUEST_TRANSACTION_DUMMY_PROPERTY
};
enum  {
	PUBLISHING_FLICKR_ACCESS_TOKEN_FETCH_TRANSACTION_DUMMY_PROPERTY
};
gchar* publishing_flickr_session_get_request_phase_token (PublishingFlickrSession* self);
enum  {
	PUBLISHING_FLICKR_ACCOUNT_INFO_FETCH_TRANSACTION_DUMMY_PROPERTY
};
GType publishing_flickr_upload_transaction_get_type (void) G_GNUC_CONST;
#define PUBLISHING_FLICKR_UPLOAD_TRANSACTION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_FLICKR_TYPE_UPLOAD_TRANSACTION, PublishingFlickrUploadTransactionPrivate))
enum  {
	PUBLISHING_FLICKR_UPLOAD_TRANSACTION_DUMMY_PROPERTY
};
PublishingFlickrUploadTransaction* publishing_flickr_upload_transaction_new (PublishingFlickrSession* session, PublishingFlickrPublishingParameters* parameters, SpitPublishingPublishable* publishable);
PublishingFlickrUploadTransaction* publishing_flickr_upload_transaction_construct (GType object_type, PublishingFlickrSession* session, PublishingFlickrPublishingParameters* parameters, SpitPublishingPublishable* publishable);
void publishing_flickr_upload_transaction_add_authorization_header_field (PublishingFlickrUploadTransaction* self, const gchar* key, const gchar* value);
static void _g_free0_ (gpointer var);
static void _vala_array_add18 (PublishingRESTSupportArgument*** array, int* length, int* size, PublishingRESTSupportArgument* value);
PublishingRESTSupportArgument** publishing_flickr_upload_transaction_get_authorization_header_fields (PublishingFlickrUploadTransaction* self, int* result_length1);
static PublishingRESTSupportArgument** _vala_array_dup8 (PublishingRESTSupportArgument** self, int length);
gchar* publishing_flickr_upload_transaction_get_authorization_header_string (PublishingFlickrUploadTransaction* self);
static void publishing_flickr_upload_transaction_real_execute (PublishingRESTSupportTransaction* base, GError** error);
static void publishing_flickr_upload_transaction_finalize (PublishingRESTSupportTransaction* obj);
#define PUBLISHING_FLICKR_SESSION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_FLICKR_TYPE_SESSION, PublishingFlickrSessionPrivate))
enum  {
	PUBLISHING_FLICKR_SESSION_DUMMY_PROPERTY
};
static gboolean publishing_flickr_session_real_is_authenticated (PublishingRESTSupportSession* base);
static void _vala_array_add19 (PublishingRESTSupportArgument*** array, int* length, int* size, PublishingRESTSupportArgument* value);
static void publishing_flickr_session_finalize (PublishingRESTSupportSession* obj);
static gpointer publishing_flickr_publishing_options_pane_visibility_entry_ref (gpointer instance);
static void publishing_flickr_publishing_options_pane_visibility_entry_unref (gpointer instance);
static GParamSpec* publishing_flickr_publishing_options_pane_param_spec_visibility_entry (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) G_GNUC_UNUSED;
static void publishing_flickr_publishing_options_pane_value_set_visibility_entry (GValue* value, gpointer v_object) G_GNUC_UNUSED;
static void publishing_flickr_publishing_options_pane_value_take_visibility_entry (GValue* value, gpointer v_object) G_GNUC_UNUSED;
static gpointer publishing_flickr_publishing_options_pane_value_get_visibility_entry (const GValue* value) G_GNUC_UNUSED;
static GType publishing_flickr_publishing_options_pane_visibility_entry_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
static gpointer publishing_flickr_publishing_options_pane_size_entry_ref (gpointer instance);
static void publishing_flickr_publishing_options_pane_size_entry_unref (gpointer instance);
static GParamSpec* publishing_flickr_publishing_options_pane_param_spec_size_entry (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) G_GNUC_UNUSED;
static void publishing_flickr_publishing_options_pane_value_set_size_entry (GValue* value, gpointer v_object) G_GNUC_UNUSED;
static void publishing_flickr_publishing_options_pane_value_take_size_entry (GValue* value, gpointer v_object) G_GNUC_UNUSED;
static gpointer publishing_flickr_publishing_options_pane_value_get_size_entry (const GValue* value) G_GNUC_UNUSED;
static GType publishing_flickr_publishing_options_pane_size_entry_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
#define PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_FLICKR_TYPE_PUBLISHING_OPTIONS_PANE, PublishingFlickrPublishingOptionsPanePrivate))
enum  {
	PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_DUMMY_PROPERTY
};
static PublishingFlickrPublishingOptionsPaneVisibilityEntry** publishing_flickr_publishing_options_pane_create_visibilities (PublishingFlickrPublishingOptionsPane* self, int* result_length1);
static PublishingFlickrPublishingOptionsPaneSizeEntry** publishing_flickr_publishing_options_pane_create_sizes (PublishingFlickrPublishingOptionsPane* self, int* result_length1);
static void publishing_flickr_publishing_options_pane_populate_visibility_combo (PublishingFlickrPublishingOptionsPane* self);
static void publishing_flickr_publishing_options_pane_on_visibility_changed (PublishingFlickrPublishingOptionsPane* self);
static void _publishing_flickr_publishing_options_pane_on_visibility_changed_gtk_combo_box_changed (GtkComboBox* _sender, gpointer self);
static void publishing_flickr_publishing_options_pane_populate_size_combo (PublishingFlickrPublishingOptionsPane* self);
static void publishing_flickr_publishing_options_pane_on_size_changed (PublishingFlickrPublishingOptionsPane* self);
static void _publishing_flickr_publishing_options_pane_on_size_changed_gtk_combo_box_changed (GtkComboBox* _sender, gpointer self);
static void publishing_flickr_publishing_options_pane_on_logout_clicked (PublishingFlickrPublishingOptionsPane* self);
static void _publishing_flickr_publishing_options_pane_on_logout_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self);
static void publishing_flickr_publishing_options_pane_on_publish_clicked (PublishingFlickrPublishingOptionsPane* self);
static void _publishing_flickr_publishing_options_pane_on_publish_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self);
static PublishingFlickrPublishingOptionsPaneVisibilityEntry* publishing_flickr_publishing_options_pane_visibility_entry_new (const gchar* creator_title, PublishingFlickrVisibilitySpecification* creator_specification);
static PublishingFlickrPublishingOptionsPaneVisibilityEntry* publishing_flickr_publishing_options_pane_visibility_entry_construct (GType object_type, const gchar* creator_title, PublishingFlickrVisibilitySpecification* creator_specification);
static void _vala_array_add20 (PublishingFlickrPublishingOptionsPaneVisibilityEntry*** array, int* length, int* size, PublishingFlickrPublishingOptionsPaneVisibilityEntry* value);
static void _vala_array_add21 (PublishingFlickrPublishingOptionsPaneVisibilityEntry*** array, int* length, int* size, PublishingFlickrPublishingOptionsPaneVisibilityEntry* value);
static void _vala_array_add22 (PublishingFlickrPublishingOptionsPaneVisibilityEntry*** array, int* length, int* size, PublishingFlickrPublishingOptionsPaneVisibilityEntry* value);
static void _vala_array_add23 (PublishingFlickrPublishingOptionsPaneVisibilityEntry*** array, int* length, int* size, PublishingFlickrPublishingOptionsPaneVisibilityEntry* value);
static void _vala_array_add24 (PublishingFlickrPublishingOptionsPaneVisibilityEntry*** array, int* length, int* size, PublishingFlickrPublishingOptionsPaneVisibilityEntry* value);
static PublishingFlickrPublishingOptionsPaneSizeEntry* publishing_flickr_publishing_options_pane_size_entry_new (const gchar* creator_title, gint creator_size);
static PublishingFlickrPublishingOptionsPaneSizeEntry* publishing_flickr_publishing_options_pane_size_entry_construct (GType object_type, const gchar* creator_title, gint creator_size);
static void _vala_array_add25 (PublishingFlickrPublishingOptionsPaneSizeEntry*** array, int* length, int* size, PublishingFlickrPublishingOptionsPaneSizeEntry* value);
static void _vala_array_add26 (PublishingFlickrPublishingOptionsPaneSizeEntry*** array, int* length, int* size, PublishingFlickrPublishingOptionsPaneSizeEntry* value);
static void _vala_array_add27 (PublishingFlickrPublishingOptionsPaneSizeEntry*** array, int* length, int* size, PublishingFlickrPublishingOptionsPaneSizeEntry* value);
static void _vala_array_add28 (PublishingFlickrPublishingOptionsPaneSizeEntry*** array, int* length, int* size, PublishingFlickrPublishingOptionsPaneSizeEntry* value);
static void _vala_array_add29 (PublishingFlickrPublishingOptionsPaneSizeEntry*** array, int* length, int* size, PublishingFlickrPublishingOptionsPaneSizeEntry* value);
void publishing_flickr_publishing_options_pane_notify_publish (PublishingFlickrPublishingOptionsPane* self);
void publishing_flickr_publishing_options_pane_notify_logout (PublishingFlickrPublishingOptionsPane* self);
static GtkWidget* publishing_flickr_publishing_options_pane_real_get_widget (SpitPublishingDialogPane* base);
static SpitPublishingDialogPaneGeometryOptions publishing_flickr_publishing_options_pane_real_get_preferred_geometry (SpitPublishingDialogPane* base);
static void publishing_flickr_publishing_options_pane_real_on_pane_installed (SpitPublishingDialogPane* base);
static void _publishing_flickr_publishing_options_pane_notify_publish_publishing_flickr_publishing_options_pane_publish (PublishingFlickrPublishingOptionsPane* _sender, gboolean strip_metadata, gpointer self);
static void _publishing_flickr_publishing_options_pane_notify_logout_publishing_flickr_publishing_options_pane_logout (PublishingFlickrPublishingOptionsPane* _sender, gpointer self);
static void publishing_flickr_publishing_options_pane_real_on_pane_uninstalled (SpitPublishingDialogPane* base);
enum  {
	PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_SIZE_ENTRY_DUMMY_PROPERTY
};
static void publishing_flickr_publishing_options_pane_size_entry_finalize (PublishingFlickrPublishingOptionsPaneSizeEntry* obj);
enum  {
	PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_VISIBILITY_ENTRY_DUMMY_PROPERTY
};
static void publishing_flickr_publishing_options_pane_visibility_entry_finalize (PublishingFlickrPublishingOptionsPaneVisibilityEntry* obj);
static void publishing_flickr_publishing_options_pane_finalize (GObject* obj);
#define PUBLISHING_FLICKR_UPLOADER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_FLICKR_TYPE_UPLOADER, PublishingFlickrUploaderPrivate))
enum  {
	PUBLISHING_FLICKR_UPLOADER_DUMMY_PROPERTY
};
static void publishing_flickr_uploader_preprocess_publishable (PublishingFlickrUploader* self, SpitPublishingPublishable* publishable);
static void _vala_array_add30 (gchar*** array, int* length, int* size, gchar* value);
static PublishingRESTSupportTransaction* publishing_flickr_uploader_real_create_transaction (PublishingRESTSupportBatchUploader* base, SpitPublishingPublishable* publishable);
static void publishing_flickr_uploader_finalize (PublishingRESTSupportBatchUploader* obj);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
static gint _vala_array_length (gpointer array);


FlickrService* flickr_service_construct (GType object_type, GFile* resource_directory) {
	FlickrService * self = NULL;
	GdkPixbuf** _tmp0_ = NULL;
	gint _tmp0__length1 = 0;
#line 12 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (G_IS_FILE (resource_directory), NULL);
#line 12 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = (FlickrService*) g_object_new (object_type, NULL);
#line 13 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = flickr_service_icon_pixbuf_set;
#line 13 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0__length1 = flickr_service_icon_pixbuf_set_length1;
#line 13 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (_tmp0_ == NULL) {
#line 791 "FlickrPublishing.c"
		gint _tmp1_ = 0;
		GdkPixbuf** _tmp2_ = NULL;
#line 14 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp2_ = resources_load_from_resource (PLUGIN_RESOURCE_PATH "/" FLICKR_SERVICE_ICON_FILENAME, &_tmp1_);
#line 14 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		flickr_service_icon_pixbuf_set = (_vala_array_free (flickr_service_icon_pixbuf_set, flickr_service_icon_pixbuf_set_length1, (GDestroyNotify) g_object_unref), NULL);
#line 14 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		flickr_service_icon_pixbuf_set = _tmp2_;
#line 14 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		flickr_service_icon_pixbuf_set_length1 = _tmp1_;
#line 14 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_flickr_service_icon_pixbuf_set_size_ = flickr_service_icon_pixbuf_set_length1;
#line 804 "FlickrPublishing.c"
	}
#line 12 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return self;
#line 808 "FlickrPublishing.c"
}


FlickrService* flickr_service_new (GFile* resource_directory) {
#line 12 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return flickr_service_construct (TYPE_FLICKR_SERVICE, resource_directory);
#line 815 "FlickrPublishing.c"
}


static gint flickr_service_real_get_pluggable_interface (SpitPluggable* base, gint min_host_interface, gint max_host_interface) {
	FlickrService * self;
	gint result = 0;
	gint _tmp0_ = 0;
	gint _tmp1_ = 0;
	gint _tmp2_ = 0;
#line 18 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_FLICKR_SERVICE, FlickrService);
#line 19 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = min_host_interface;
#line 19 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = max_host_interface;
#line 19 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp2_ = spit_negotiate_interfaces (_tmp0_, _tmp1_, SPIT_PUBLISHING_CURRENT_INTERFACE);
#line 19 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	result = _tmp2_;
#line 19 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return result;
#line 837 "FlickrPublishing.c"
}


static const gchar* flickr_service_real_get_id (SpitPluggable* base) {
	FlickrService * self;
	const gchar* result = NULL;
#line 23 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_FLICKR_SERVICE, FlickrService);
#line 24 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	result = "org.yorba.shotwell.publishing.flickr";
#line 24 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return result;
#line 850 "FlickrPublishing.c"
}


static const gchar* flickr_service_real_get_pluggable_name (SpitPluggable* base) {
	FlickrService * self;
	const gchar* result = NULL;
#line 27 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_FLICKR_SERVICE, FlickrService);
#line 28 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	result = "Flickr";
#line 28 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return result;
#line 863 "FlickrPublishing.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return self ? g_object_ref (self) : NULL;
#line 870 "FlickrPublishing.c"
}


static GdkPixbuf** _vala_array_dup7 (GdkPixbuf** self, int length) {
	GdkPixbuf** result;
	int i;
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	result = g_new0 (GdkPixbuf*, length + 1);
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	for (i = 0; i < length; i++) {
#line 881 "FlickrPublishing.c"
		GdkPixbuf* _tmp0_ = NULL;
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp0_ = _g_object_ref0 (self[i]);
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		result[i] = _tmp0_;
#line 887 "FlickrPublishing.c"
	}
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return result;
#line 891 "FlickrPublishing.c"
}


static void flickr_service_real_get_info (SpitPluggable* base, SpitPluggableInfo* info) {
	FlickrService * self;
	gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
	GdkPixbuf** _tmp8_ = NULL;
	gint _tmp8__length1 = 0;
	GdkPixbuf** _tmp9_ = NULL;
	gint _tmp9__length1 = 0;
#line 31 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_FLICKR_SERVICE, FlickrService);
#line 31 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (info != NULL);
#line 32 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = g_strdup ("Lucas Beeler");
#line 32 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 ((*info).authors);
#line 32 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	(*info).authors = _tmp0_;
#line 33 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = _ ("Copyright 2016 Software Freedom Conservancy Inc.");
#line 33 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp2_ = g_strdup (_tmp1_);
#line 33 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 ((*info).copyright);
#line 33 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	(*info).copyright = _tmp2_;
#line 34 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp3_ = g_strdup (RESOURCES_TRANSLATORS);
#line 34 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 ((*info).translators);
#line 34 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	(*info).translators = _tmp3_;
#line 35 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp4_ = g_strdup (_VERSION);
#line 35 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 ((*info).version);
#line 35 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	(*info).version = _tmp4_;
#line 36 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp5_ = g_strdup (RESOURCES_WEBSITE_NAME);
#line 36 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 ((*info).website_name);
#line 36 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	(*info).website_name = _tmp5_;
#line 37 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp6_ = g_strdup (RESOURCES_WEBSITE_URL);
#line 37 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 ((*info).website_url);
#line 37 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	(*info).website_url = _tmp6_;
#line 38 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	(*info).is_license_wordwrapped = FALSE;
#line 39 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp7_ = g_strdup (RESOURCES_LICENSE);
#line 39 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 ((*info).license);
#line 39 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	(*info).license = _tmp7_;
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp8_ = flickr_service_icon_pixbuf_set;
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp8__length1 = flickr_service_icon_pixbuf_set_length1;
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp9_ = (_tmp8_ != NULL) ? _vala_array_dup7 (_tmp8_, _tmp8__length1) : ((gpointer) _tmp8_);
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp9__length1 = _tmp8__length1;
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	(*info).icons = (_vala_array_free ((*info).icons, (*info).icons_length1, (GDestroyNotify) g_object_unref), NULL);
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	(*info).icons = _tmp9_;
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	(*info).icons_length1 = _tmp9__length1;
#line 973 "FlickrPublishing.c"
}


static void flickr_service_real_activation (SpitPluggable* base, gboolean enabled) {
	FlickrService * self;
#line 43 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_FLICKR_SERVICE, FlickrService);
#line 981 "FlickrPublishing.c"
}


static SpitPublishingPublisher* flickr_service_real_create_publisher (SpitPublishingService* base, SpitPublishingPluginHost* host) {
	FlickrService * self;
	SpitPublishingPublisher* result = NULL;
	SpitPublishingPluginHost* _tmp0_ = NULL;
	PublishingFlickrFlickrPublisher* _tmp1_ = NULL;
#line 46 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_FLICKR_SERVICE, FlickrService);
#line 46 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (SPIT_PUBLISHING_IS_PLUGIN_HOST (host), NULL);
#line 47 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = host;
#line 47 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = publishing_flickr_flickr_publisher_new (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_SERVICE, SpitPublishingService), _tmp0_);
#line 47 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	result = G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher);
#line 47 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return result;
#line 1002 "FlickrPublishing.c"
}


static SpitPublishingPublisherMediaType flickr_service_real_get_supported_media (SpitPublishingService* base) {
	FlickrService * self;
	SpitPublishingPublisherMediaType result = 0;
#line 50 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_FLICKR_SERVICE, FlickrService);
#line 51 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	result = SPIT_PUBLISHING_PUBLISHER_MEDIA_TYPE_PHOTO | SPIT_PUBLISHING_PUBLISHER_MEDIA_TYPE_VIDEO;
#line 51 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return result;
#line 1015 "FlickrPublishing.c"
}


static void flickr_service_class_init (FlickrServiceClass * klass) {
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	flickr_service_parent_class = g_type_class_peek_parent (klass);
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	G_OBJECT_CLASS (klass)->finalize = flickr_service_finalize;
#line 1024 "FlickrPublishing.c"
}


static void flickr_service_spit_pluggable_interface_init (SpitPluggableIface * iface) {
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	flickr_service_spit_pluggable_parent_iface = g_type_interface_peek_parent (iface);
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	iface->get_pluggable_interface = (gint (*)(SpitPluggable*, gint, gint)) flickr_service_real_get_pluggable_interface;
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	iface->get_id = (const gchar* (*)(SpitPluggable*)) flickr_service_real_get_id;
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	iface->get_pluggable_name = (const gchar* (*)(SpitPluggable*)) flickr_service_real_get_pluggable_name;
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	iface->get_info = (void (*)(SpitPluggable*, SpitPluggableInfo*)) flickr_service_real_get_info;
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	iface->activation = (void (*)(SpitPluggable*, gboolean)) flickr_service_real_activation;
#line 1041 "FlickrPublishing.c"
}


static void flickr_service_spit_publishing_service_interface_init (SpitPublishingServiceIface * iface) {
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	flickr_service_spit_publishing_service_parent_iface = g_type_interface_peek_parent (iface);
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	iface->create_publisher = (SpitPublishingPublisher* (*)(SpitPublishingService*, SpitPublishingPluginHost*)) flickr_service_real_create_publisher;
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	iface->get_supported_media = (SpitPublishingPublisherMediaType (*)(SpitPublishingService*)) flickr_service_real_get_supported_media;
#line 1052 "FlickrPublishing.c"
}


static void flickr_service_instance_init (FlickrService * self) {
}


static void flickr_service_finalize (GObject* obj) {
	FlickrService * self;
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_FLICKR_SERVICE, FlickrService);
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	G_OBJECT_CLASS (flickr_service_parent_class)->finalize (obj);
#line 1066 "FlickrPublishing.c"
}


GType flickr_service_get_type (void) {
	static volatile gsize flickr_service_type_id__volatile = 0;
	if (g_once_init_enter (&flickr_service_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (FlickrServiceClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) flickr_service_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (FlickrService), 0, (GInstanceInitFunc) flickr_service_instance_init, NULL };
		static const GInterfaceInfo spit_pluggable_info = { (GInterfaceInitFunc) flickr_service_spit_pluggable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo spit_publishing_service_info = { (GInterfaceInitFunc) flickr_service_spit_publishing_service_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType flickr_service_type_id;
		flickr_service_type_id = g_type_register_static (G_TYPE_OBJECT, "FlickrService", &g_define_type_info, 0);
		g_type_add_interface_static (flickr_service_type_id, SPIT_TYPE_PLUGGABLE, &spit_pluggable_info);
		g_type_add_interface_static (flickr_service_type_id, SPIT_PUBLISHING_TYPE_SERVICE, &spit_publishing_service_info);
		g_once_init_leave (&flickr_service_type_id__volatile, flickr_service_type_id);
	}
	return flickr_service_type_id__volatile;
}


GType publishing_flickr_user_kind_get_type (void) {
	static volatile gsize publishing_flickr_user_kind_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_flickr_user_kind_type_id__volatile)) {
		static const GEnumValue values[] = {{PUBLISHING_FLICKR_USER_KIND_PRO, "PUBLISHING_FLICKR_USER_KIND_PRO", "pro"}, {PUBLISHING_FLICKR_USER_KIND_FREE, "PUBLISHING_FLICKR_USER_KIND_FREE", "free"}, {0, NULL, NULL}};
		GType publishing_flickr_user_kind_type_id;
		publishing_flickr_user_kind_type_id = g_enum_register_static ("PublishingFlickrUserKind", values);
		g_once_init_leave (&publishing_flickr_user_kind_type_id__volatile, publishing_flickr_user_kind_type_id);
	}
	return publishing_flickr_user_kind_type_id__volatile;
}


PublishingFlickrVisibilitySpecification* publishing_flickr_visibility_specification_construct (GType object_type, gint friends_level, gint family_level, gint everyone_level) {
	PublishingFlickrVisibilitySpecification* self = NULL;
	gint _tmp0_ = 0;
	gint _tmp1_ = 0;
	gint _tmp2_ = 0;
#line 80 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = (PublishingFlickrVisibilitySpecification*) g_type_create_instance (object_type);
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = friends_level;
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->friends_level = _tmp0_;
#line 82 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = family_level;
#line 82 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->family_level = _tmp1_;
#line 83 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp2_ = everyone_level;
#line 83 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->everyone_level = _tmp2_;
#line 80 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return self;
#line 1119 "FlickrPublishing.c"
}


PublishingFlickrVisibilitySpecification* publishing_flickr_visibility_specification_new (gint friends_level, gint family_level, gint everyone_level) {
#line 80 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return publishing_flickr_visibility_specification_construct (PUBLISHING_FLICKR_TYPE_VISIBILITY_SPECIFICATION, friends_level, family_level, everyone_level);
#line 1126 "FlickrPublishing.c"
}


static void publishing_flickr_value_visibility_specification_init (GValue* value) {
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	value->data[0].v_pointer = NULL;
#line 1133 "FlickrPublishing.c"
}


static void publishing_flickr_value_visibility_specification_free_value (GValue* value) {
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (value->data[0].v_pointer) {
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		publishing_flickr_visibility_specification_unref (value->data[0].v_pointer);
#line 1142 "FlickrPublishing.c"
	}
}


static void publishing_flickr_value_visibility_specification_copy_value (const GValue* src_value, GValue* dest_value) {
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (src_value->data[0].v_pointer) {
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		dest_value->data[0].v_pointer = publishing_flickr_visibility_specification_ref (src_value->data[0].v_pointer);
#line 1152 "FlickrPublishing.c"
	} else {
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		dest_value->data[0].v_pointer = NULL;
#line 1156 "FlickrPublishing.c"
	}
}


static gpointer publishing_flickr_value_visibility_specification_peek_pointer (const GValue* value) {
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return value->data[0].v_pointer;
#line 1164 "FlickrPublishing.c"
}


static gchar* publishing_flickr_value_visibility_specification_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (collect_values[0].v_pointer) {
#line 1171 "FlickrPublishing.c"
		PublishingFlickrVisibilitySpecification* object;
		object = collect_values[0].v_pointer;
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		if (object->parent_instance.g_class == NULL) {
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 1178 "FlickrPublishing.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 1182 "FlickrPublishing.c"
		}
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		value->data[0].v_pointer = publishing_flickr_visibility_specification_ref (object);
#line 1186 "FlickrPublishing.c"
	} else {
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 1190 "FlickrPublishing.c"
	}
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return NULL;
#line 1194 "FlickrPublishing.c"
}


static gchar* publishing_flickr_value_visibility_specification_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	PublishingFlickrVisibilitySpecification** object_p;
	object_p = collect_values[0].v_pointer;
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (!object_p) {
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 1205 "FlickrPublishing.c"
	}
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (!value->data[0].v_pointer) {
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		*object_p = NULL;
#line 1211 "FlickrPublishing.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		*object_p = value->data[0].v_pointer;
#line 1215 "FlickrPublishing.c"
	} else {
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		*object_p = publishing_flickr_visibility_specification_ref (value->data[0].v_pointer);
#line 1219 "FlickrPublishing.c"
	}
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return NULL;
#line 1223 "FlickrPublishing.c"
}


GParamSpec* publishing_flickr_param_spec_visibility_specification (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
	PublishingFlickrParamSpecVisibilitySpecification* spec;
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (g_type_is_a (object_type, PUBLISHING_FLICKR_TYPE_VISIBILITY_SPECIFICATION), NULL);
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return G_PARAM_SPEC (spec);
#line 1237 "FlickrPublishing.c"
}


gpointer publishing_flickr_value_get_visibility_specification (const GValue* value) {
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_FLICKR_TYPE_VISIBILITY_SPECIFICATION), NULL);
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return value->data[0].v_pointer;
#line 1246 "FlickrPublishing.c"
}


void publishing_flickr_value_set_visibility_specification (GValue* value, gpointer v_object) {
	PublishingFlickrVisibilitySpecification* old;
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_FLICKR_TYPE_VISIBILITY_SPECIFICATION));
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	old = value->data[0].v_pointer;
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (v_object) {
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PUBLISHING_FLICKR_TYPE_VISIBILITY_SPECIFICATION));
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		value->data[0].v_pointer = v_object;
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		publishing_flickr_visibility_specification_ref (value->data[0].v_pointer);
#line 1266 "FlickrPublishing.c"
	} else {
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 1270 "FlickrPublishing.c"
	}
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (old) {
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		publishing_flickr_visibility_specification_unref (old);
#line 1276 "FlickrPublishing.c"
	}
}


void publishing_flickr_value_take_visibility_specification (GValue* value, gpointer v_object) {
	PublishingFlickrVisibilitySpecification* old;
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_FLICKR_TYPE_VISIBILITY_SPECIFICATION));
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	old = value->data[0].v_pointer;
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (v_object) {
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PUBLISHING_FLICKR_TYPE_VISIBILITY_SPECIFICATION));
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		value->data[0].v_pointer = v_object;
#line 1295 "FlickrPublishing.c"
	} else {
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 1299 "FlickrPublishing.c"
	}
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (old) {
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		publishing_flickr_visibility_specification_unref (old);
#line 1305 "FlickrPublishing.c"
	}
}


static void publishing_flickr_visibility_specification_class_init (PublishingFlickrVisibilitySpecificationClass * klass) {
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_visibility_specification_parent_class = g_type_class_peek_parent (klass);
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	((PublishingFlickrVisibilitySpecificationClass *) klass)->finalize = publishing_flickr_visibility_specification_finalize;
#line 1315 "FlickrPublishing.c"
}


static void publishing_flickr_visibility_specification_instance_init (PublishingFlickrVisibilitySpecification * self) {
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->ref_count = 1;
#line 1322 "FlickrPublishing.c"
}


static void publishing_flickr_visibility_specification_finalize (PublishingFlickrVisibilitySpecification* obj) {
	PublishingFlickrVisibilitySpecification * self;
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_FLICKR_TYPE_VISIBILITY_SPECIFICATION, PublishingFlickrVisibilitySpecification);
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_handlers_destroy (self);
#line 1332 "FlickrPublishing.c"
}


GType publishing_flickr_visibility_specification_get_type (void) {
	static volatile gsize publishing_flickr_visibility_specification_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_flickr_visibility_specification_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { publishing_flickr_value_visibility_specification_init, publishing_flickr_value_visibility_specification_free_value, publishing_flickr_value_visibility_specification_copy_value, publishing_flickr_value_visibility_specification_peek_pointer, "p", publishing_flickr_value_visibility_specification_collect_value, "p", publishing_flickr_value_visibility_specification_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (PublishingFlickrVisibilitySpecificationClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_flickr_visibility_specification_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingFlickrVisibilitySpecification), 0, (GInstanceInitFunc) publishing_flickr_visibility_specification_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType publishing_flickr_visibility_specification_type_id;
		publishing_flickr_visibility_specification_type_id = g_type_register_fundamental (g_type_fundamental_next (), "PublishingFlickrVisibilitySpecification", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&publishing_flickr_visibility_specification_type_id__volatile, publishing_flickr_visibility_specification_type_id);
	}
	return publishing_flickr_visibility_specification_type_id__volatile;
}


gpointer publishing_flickr_visibility_specification_ref (gpointer instance) {
	PublishingFlickrVisibilitySpecification* self;
	self = instance;
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_atomic_int_inc (&self->ref_count);
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return instance;
#line 1357 "FlickrPublishing.c"
}


void publishing_flickr_visibility_specification_unref (gpointer instance) {
	PublishingFlickrVisibilitySpecification* self;
	self = instance;
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		PUBLISHING_FLICKR_VISIBILITY_SPECIFICATION_GET_CLASS (self)->finalize (self);
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 1370 "FlickrPublishing.c"
	}
}


PublishingFlickrPublishingParameters* publishing_flickr_publishing_parameters_construct (GType object_type) {
	PublishingFlickrPublishingParameters* self = NULL;
#line 95 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = (PublishingFlickrPublishingParameters*) g_type_create_instance (object_type);
#line 95 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return self;
#line 1381 "FlickrPublishing.c"
}


PublishingFlickrPublishingParameters* publishing_flickr_publishing_parameters_new (void) {
#line 95 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return publishing_flickr_publishing_parameters_construct (PUBLISHING_FLICKR_TYPE_PUBLISHING_PARAMETERS);
#line 1388 "FlickrPublishing.c"
}


static void publishing_flickr_value_publishing_parameters_init (GValue* value) {
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	value->data[0].v_pointer = NULL;
#line 1395 "FlickrPublishing.c"
}


static void publishing_flickr_value_publishing_parameters_free_value (GValue* value) {
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (value->data[0].v_pointer) {
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		publishing_flickr_publishing_parameters_unref (value->data[0].v_pointer);
#line 1404 "FlickrPublishing.c"
	}
}


static void publishing_flickr_value_publishing_parameters_copy_value (const GValue* src_value, GValue* dest_value) {
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (src_value->data[0].v_pointer) {
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		dest_value->data[0].v_pointer = publishing_flickr_publishing_parameters_ref (src_value->data[0].v_pointer);
#line 1414 "FlickrPublishing.c"
	} else {
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		dest_value->data[0].v_pointer = NULL;
#line 1418 "FlickrPublishing.c"
	}
}


static gpointer publishing_flickr_value_publishing_parameters_peek_pointer (const GValue* value) {
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return value->data[0].v_pointer;
#line 1426 "FlickrPublishing.c"
}


static gchar* publishing_flickr_value_publishing_parameters_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (collect_values[0].v_pointer) {
#line 1433 "FlickrPublishing.c"
		PublishingFlickrPublishingParameters* object;
		object = collect_values[0].v_pointer;
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		if (object->parent_instance.g_class == NULL) {
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 1440 "FlickrPublishing.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 1444 "FlickrPublishing.c"
		}
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		value->data[0].v_pointer = publishing_flickr_publishing_parameters_ref (object);
#line 1448 "FlickrPublishing.c"
	} else {
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 1452 "FlickrPublishing.c"
	}
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return NULL;
#line 1456 "FlickrPublishing.c"
}


static gchar* publishing_flickr_value_publishing_parameters_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	PublishingFlickrPublishingParameters** object_p;
	object_p = collect_values[0].v_pointer;
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (!object_p) {
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 1467 "FlickrPublishing.c"
	}
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (!value->data[0].v_pointer) {
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		*object_p = NULL;
#line 1473 "FlickrPublishing.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		*object_p = value->data[0].v_pointer;
#line 1477 "FlickrPublishing.c"
	} else {
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		*object_p = publishing_flickr_publishing_parameters_ref (value->data[0].v_pointer);
#line 1481 "FlickrPublishing.c"
	}
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return NULL;
#line 1485 "FlickrPublishing.c"
}


GParamSpec* publishing_flickr_param_spec_publishing_parameters (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
	PublishingFlickrParamSpecPublishingParameters* spec;
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (g_type_is_a (object_type, PUBLISHING_FLICKR_TYPE_PUBLISHING_PARAMETERS), NULL);
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return G_PARAM_SPEC (spec);
#line 1499 "FlickrPublishing.c"
}


gpointer publishing_flickr_value_get_publishing_parameters (const GValue* value) {
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_FLICKR_TYPE_PUBLISHING_PARAMETERS), NULL);
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return value->data[0].v_pointer;
#line 1508 "FlickrPublishing.c"
}


void publishing_flickr_value_set_publishing_parameters (GValue* value, gpointer v_object) {
	PublishingFlickrPublishingParameters* old;
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_FLICKR_TYPE_PUBLISHING_PARAMETERS));
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	old = value->data[0].v_pointer;
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (v_object) {
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PUBLISHING_FLICKR_TYPE_PUBLISHING_PARAMETERS));
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		value->data[0].v_pointer = v_object;
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		publishing_flickr_publishing_parameters_ref (value->data[0].v_pointer);
#line 1528 "FlickrPublishing.c"
	} else {
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 1532 "FlickrPublishing.c"
	}
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (old) {
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		publishing_flickr_publishing_parameters_unref (old);
#line 1538 "FlickrPublishing.c"
	}
}


void publishing_flickr_value_take_publishing_parameters (GValue* value, gpointer v_object) {
	PublishingFlickrPublishingParameters* old;
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_FLICKR_TYPE_PUBLISHING_PARAMETERS));
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	old = value->data[0].v_pointer;
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (v_object) {
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PUBLISHING_FLICKR_TYPE_PUBLISHING_PARAMETERS));
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		value->data[0].v_pointer = v_object;
#line 1557 "FlickrPublishing.c"
	} else {
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 1561 "FlickrPublishing.c"
	}
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (old) {
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		publishing_flickr_publishing_parameters_unref (old);
#line 1567 "FlickrPublishing.c"
	}
}


static void publishing_flickr_publishing_parameters_class_init (PublishingFlickrPublishingParametersClass * klass) {
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_publishing_parameters_parent_class = g_type_class_peek_parent (klass);
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	((PublishingFlickrPublishingParametersClass *) klass)->finalize = publishing_flickr_publishing_parameters_finalize;
#line 1577 "FlickrPublishing.c"
}


static void publishing_flickr_publishing_parameters_instance_init (PublishingFlickrPublishingParameters * self) {
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->ref_count = 1;
#line 1584 "FlickrPublishing.c"
}


static void publishing_flickr_publishing_parameters_finalize (PublishingFlickrPublishingParameters* obj) {
	PublishingFlickrPublishingParameters * self;
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_FLICKR_TYPE_PUBLISHING_PARAMETERS, PublishingFlickrPublishingParameters);
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_handlers_destroy (self);
#line 92 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (self->username);
#line 93 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_publishing_flickr_visibility_specification_unref0 (self->visibility_specification);
#line 1598 "FlickrPublishing.c"
}


GType publishing_flickr_publishing_parameters_get_type (void) {
	static volatile gsize publishing_flickr_publishing_parameters_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_flickr_publishing_parameters_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { publishing_flickr_value_publishing_parameters_init, publishing_flickr_value_publishing_parameters_free_value, publishing_flickr_value_publishing_parameters_copy_value, publishing_flickr_value_publishing_parameters_peek_pointer, "p", publishing_flickr_value_publishing_parameters_collect_value, "p", publishing_flickr_value_publishing_parameters_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (PublishingFlickrPublishingParametersClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_flickr_publishing_parameters_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingFlickrPublishingParameters), 0, (GInstanceInitFunc) publishing_flickr_publishing_parameters_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType publishing_flickr_publishing_parameters_type_id;
		publishing_flickr_publishing_parameters_type_id = g_type_register_fundamental (g_type_fundamental_next (), "PublishingFlickrPublishingParameters", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&publishing_flickr_publishing_parameters_type_id__volatile, publishing_flickr_publishing_parameters_type_id);
	}
	return publishing_flickr_publishing_parameters_type_id__volatile;
}


gpointer publishing_flickr_publishing_parameters_ref (gpointer instance) {
	PublishingFlickrPublishingParameters* self;
	self = instance;
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_atomic_int_inc (&self->ref_count);
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return instance;
#line 1623 "FlickrPublishing.c"
}


void publishing_flickr_publishing_parameters_unref (gpointer instance) {
	PublishingFlickrPublishingParameters* self;
	self = instance;
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		PUBLISHING_FLICKR_PUBLISHING_PARAMETERS_GET_CLASS (self)->finalize (self);
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 1636 "FlickrPublishing.c"
	}
}


static void _publishing_flickr_flickr_publisher_on_session_authenticated_publishing_rest_support_session_authenticated (PublishingRESTSupportSession* _sender, gpointer self) {
#line 122 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_flickr_publisher_on_session_authenticated ((PublishingFlickrFlickrPublisher*) self);
#line 1644 "FlickrPublishing.c"
}


PublishingFlickrFlickrPublisher* publishing_flickr_flickr_publisher_construct (GType object_type, SpitPublishingService* service, SpitPublishingPluginHost* host) {
	PublishingFlickrFlickrPublisher * self = NULL;
	SpitPublishingService* _tmp0_ = NULL;
	SpitPublishingService* _tmp1_ = NULL;
	SpitPublishingPluginHost* _tmp2_ = NULL;
	SpitPublishingPluginHost* _tmp3_ = NULL;
	PublishingFlickrSession* _tmp4_ = NULL;
	PublishingFlickrPublishingParameters* _tmp5_ = NULL;
	PublishingFlickrSession* _tmp6_ = NULL;
#line 110 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (SPIT_PUBLISHING_IS_SERVICE (service), NULL);
#line 110 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (SPIT_PUBLISHING_IS_PLUGIN_HOST (host), NULL);
#line 110 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = (PublishingFlickrFlickrPublisher*) g_object_new (object_type, NULL);
#line 112 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_debug ("FlickrPublishing.vala:112: FlickrPublisher instantiated.");
#line 113 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = service;
#line 113 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 113 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (self->priv->service);
#line 113 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->service = _tmp1_;
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp2_ = host;
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (self->priv->host);
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->host = _tmp3_;
#line 115 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp4_ = publishing_flickr_session_new ();
#line 115 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_publishing_rest_support_session_unref0 (self->priv->session);
#line 115 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->session = _tmp4_;
#line 116 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp5_ = publishing_flickr_publishing_parameters_new ();
#line 116 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_publishing_flickr_publishing_parameters_unref0 (self->priv->parameters);
#line 116 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->parameters = _tmp5_;
#line 118 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp6_ = self->priv->session;
#line 118 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession), "authenticated", (GCallback) _publishing_flickr_flickr_publisher_on_session_authenticated_publishing_rest_support_session_authenticated, self, 0);
#line 110 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return self;
#line 1699 "FlickrPublishing.c"
}


PublishingFlickrFlickrPublisher* publishing_flickr_flickr_publisher_new (SpitPublishingService* service, SpitPublishingPluginHost* host) {
#line 110 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return publishing_flickr_flickr_publisher_construct (PUBLISHING_FLICKR_TYPE_FLICKR_PUBLISHER, service, host);
#line 1706 "FlickrPublishing.c"
}


static void publishing_flickr_flickr_publisher_invalidate_persistent_session (PublishingFlickrFlickrPublisher* self) {
#line 125 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_FLICKR_PUBLISHER (self));
#line 126 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_flickr_publisher_set_persistent_access_phase_token (self, "");
#line 127 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_flickr_publisher_set_persistent_access_phase_token_secret (self, "");
#line 128 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_flickr_publisher_set_persistent_access_phase_username (self, "");
#line 1719 "FlickrPublishing.c"
}


static gboolean publishing_flickr_flickr_publisher_is_persistent_session_valid (PublishingFlickrFlickrPublisher* self) {
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gboolean _tmp4_ = FALSE;
#line 131 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (PUBLISHING_FLICKR_IS_FLICKR_PUBLISHER (self), FALSE);
#line 132 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp2_ = publishing_flickr_flickr_publisher_get_persistent_access_phase_username (self);
#line 132 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp3_ = _tmp2_;
#line 132 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp4_ = _tmp3_ != NULL;
#line 132 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (_tmp3_);
#line 132 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (_tmp4_) {
#line 1742 "FlickrPublishing.c"
		gchar* _tmp5_ = NULL;
		gchar* _tmp6_ = NULL;
#line 133 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp5_ = publishing_flickr_flickr_publisher_get_persistent_access_phase_token (self);
#line 133 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp6_ = _tmp5_;
#line 133 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp1_ = _tmp6_ != NULL;
#line 133 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_free0 (_tmp6_);
#line 1753 "FlickrPublishing.c"
	} else {
#line 132 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp1_ = FALSE;
#line 1757 "FlickrPublishing.c"
	}
#line 132 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (_tmp1_) {
#line 1761 "FlickrPublishing.c"
		gchar* _tmp7_ = NULL;
		gchar* _tmp8_ = NULL;
#line 134 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp7_ = publishing_flickr_flickr_publisher_get_persistent_access_phase_token_secret (self);
#line 134 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp8_ = _tmp7_;
#line 134 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp0_ = _tmp8_ != NULL;
#line 134 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_free0 (_tmp8_);
#line 1772 "FlickrPublishing.c"
	} else {
#line 132 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp0_ = FALSE;
#line 1776 "FlickrPublishing.c"
	}
#line 132 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	result = _tmp0_;
#line 132 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return result;
#line 1782 "FlickrPublishing.c"
}


static gchar* publishing_flickr_flickr_publisher_get_persistent_access_phase_username (PublishingFlickrFlickrPublisher* self) {
	gchar* result = NULL;
	SpitPublishingPluginHost* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 137 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (PUBLISHING_FLICKR_IS_FLICKR_PUBLISHER (self), NULL);
#line 138 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = self->priv->host;
#line 138 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = spit_host_interface_get_config_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "access_phase_username", NULL);
#line 138 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	result = _tmp1_;
#line 138 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return result;
#line 1800 "FlickrPublishing.c"
}


static void publishing_flickr_flickr_publisher_set_persistent_access_phase_username (PublishingFlickrFlickrPublisher* self, const gchar* username) {
	SpitPublishingPluginHost* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
#line 141 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_FLICKR_PUBLISHER (self));
#line 141 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (username != NULL);
#line 142 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = self->priv->host;
#line 142 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = username;
#line 142 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	spit_host_interface_set_config_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "access_phase_username", _tmp1_);
#line 1817 "FlickrPublishing.c"
}


static gchar* publishing_flickr_flickr_publisher_get_persistent_access_phase_token (PublishingFlickrFlickrPublisher* self) {
	gchar* result = NULL;
	SpitPublishingPluginHost* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 145 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (PUBLISHING_FLICKR_IS_FLICKR_PUBLISHER (self), NULL);
#line 146 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = self->priv->host;
#line 146 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = spit_host_interface_get_config_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "access_phase_token", NULL);
#line 146 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	result = _tmp1_;
#line 146 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return result;
#line 1835 "FlickrPublishing.c"
}


static void publishing_flickr_flickr_publisher_set_persistent_access_phase_token (PublishingFlickrFlickrPublisher* self, const gchar* token) {
	SpitPublishingPluginHost* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
#line 149 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_FLICKR_PUBLISHER (self));
#line 149 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (token != NULL);
#line 150 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = self->priv->host;
#line 150 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = token;
#line 150 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	spit_host_interface_set_config_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "access_phase_token", _tmp1_);
#line 1852 "FlickrPublishing.c"
}


static gchar* publishing_flickr_flickr_publisher_get_persistent_access_phase_token_secret (PublishingFlickrFlickrPublisher* self) {
	gchar* result = NULL;
	SpitPublishingPluginHost* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 153 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (PUBLISHING_FLICKR_IS_FLICKR_PUBLISHER (self), NULL);
#line 154 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = self->priv->host;
#line 154 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = spit_host_interface_get_config_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "access_phase_token_secret", NULL);
#line 154 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	result = _tmp1_;
#line 154 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return result;
#line 1870 "FlickrPublishing.c"
}


static void publishing_flickr_flickr_publisher_set_persistent_access_phase_token_secret (PublishingFlickrFlickrPublisher* self, const gchar* secret) {
	SpitPublishingPluginHost* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
#line 157 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_FLICKR_PUBLISHER (self));
#line 157 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (secret != NULL);
#line 158 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = self->priv->host;
#line 158 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = secret;
#line 158 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	spit_host_interface_set_config_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "access_phase_token_secret", _tmp1_);
#line 1887 "FlickrPublishing.c"
}


static gboolean publishing_flickr_flickr_publisher_get_persistent_strip_metadata (PublishingFlickrFlickrPublisher* self) {
	gboolean result = FALSE;
	SpitPublishingPluginHost* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
#line 161 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (PUBLISHING_FLICKR_IS_FLICKR_PUBLISHER (self), FALSE);
#line 162 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = self->priv->host;
#line 162 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = spit_host_interface_get_config_bool (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "strip_metadata", FALSE);
#line 162 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	result = _tmp1_;
#line 162 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return result;
#line 1905 "FlickrPublishing.c"
}


static void publishing_flickr_flickr_publisher_set_persistent_strip_metadata (PublishingFlickrFlickrPublisher* self, gboolean strip_metadata) {
	SpitPublishingPluginHost* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
#line 165 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_FLICKR_PUBLISHER (self));
#line 166 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = self->priv->host;
#line 166 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = strip_metadata;
#line 166 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	spit_host_interface_set_config_bool (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "strip_metadata", _tmp1_);
#line 1920 "FlickrPublishing.c"
}


static void publishing_flickr_flickr_publisher_on_welcome_pane_login_clicked (PublishingFlickrFlickrPublisher* self) {
	gboolean _tmp0_ = FALSE;
#line 169 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_FLICKR_PUBLISHER (self));
#line 170 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = self->priv->running;
#line 170 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (!_tmp0_) {
#line 171 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		return;
#line 1934 "FlickrPublishing.c"
	}
#line 173 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_debug ("FlickrPublishing.vala:173: EVENT: user clicked 'Login' button in the w" \
"elcome pane");
#line 175 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_flickr_publisher_do_run_authentication_request_transaction (self);
#line 1940 "FlickrPublishing.c"
}


static void _publishing_flickr_flickr_publisher_on_auth_request_txn_completed_publishing_rest_support_transaction_completed (PublishingRESTSupportTransaction* _sender, gpointer self) {
#line 179 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_flickr_publisher_on_auth_request_txn_completed ((PublishingFlickrFlickrPublisher*) self, _sender);
#line 1947 "FlickrPublishing.c"
}


static void _publishing_flickr_flickr_publisher_on_auth_request_txn_error_publishing_rest_support_transaction_network_error (PublishingRESTSupportTransaction* _sender, GError* err, gpointer self) {
#line 180 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_flickr_publisher_on_auth_request_txn_error ((PublishingFlickrFlickrPublisher*) self, _sender, err);
#line 1954 "FlickrPublishing.c"
}


static void publishing_flickr_flickr_publisher_on_auth_request_txn_completed (PublishingFlickrFlickrPublisher* self, PublishingRESTSupportTransaction* txn) {
	PublishingRESTSupportTransaction* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
	PublishingRESTSupportTransaction* _tmp2_ = NULL;
	guint _tmp3_ = 0U;
	gboolean _tmp4_ = FALSE;
	PublishingRESTSupportTransaction* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
	PublishingRESTSupportTransaction* _tmp8_ = NULL;
	gchar* _tmp9_ = NULL;
	gchar* _tmp10_ = NULL;
#line 178 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_FLICKR_PUBLISHER (self));
#line 178 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_TRANSACTION (txn));
#line 179 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = txn;
#line 179 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_parse_name ("completed", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp1_, NULL, FALSE);
#line 179 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_flickr_flickr_publisher_on_auth_request_txn_completed_publishing_rest_support_transaction_completed, self);
#line 180 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp2_ = txn;
#line 180 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_parse_name ("network-error", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp3_, NULL, FALSE);
#line 180 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp2_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _publishing_flickr_flickr_publisher_on_auth_request_txn_error_publishing_rest_support_transaction_network_error, self);
#line 182 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp4_ = spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher));
#line 182 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (!_tmp4_) {
#line 183 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		return;
#line 1992 "FlickrPublishing.c"
	}
#line 185 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp5_ = txn;
#line 185 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp6_ = publishing_rest_support_transaction_get_response (_tmp5_);
#line 185 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp7_ = _tmp6_;
#line 185 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_debug ("FlickrPublishing.vala:185: EVENT: OAuth authentication request transac" \
"tion completed; response = '%s'", _tmp7_);
#line 185 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (_tmp7_);
#line 188 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp8_ = txn;
#line 188 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp9_ = publishing_rest_support_transaction_get_response (_tmp8_);
#line 188 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp10_ = _tmp9_;
#line 188 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_flickr_publisher_do_parse_token_info_from_auth_request (self, _tmp10_);
#line 188 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (_tmp10_);
#line 2014 "FlickrPublishing.c"
}


static void publishing_flickr_flickr_publisher_on_auth_request_txn_error (PublishingFlickrFlickrPublisher* self, PublishingRESTSupportTransaction* txn, GError* err) {
	PublishingRESTSupportTransaction* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
	PublishingRESTSupportTransaction* _tmp2_ = NULL;
	guint _tmp3_ = 0U;
	gboolean _tmp4_ = FALSE;
	SpitPublishingPluginHost* _tmp5_ = NULL;
	GError* _tmp6_ = NULL;
#line 191 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_FLICKR_PUBLISHER (self));
#line 191 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_TRANSACTION (txn));
#line 193 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = txn;
#line 193 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_parse_name ("completed", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp1_, NULL, FALSE);
#line 193 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_flickr_flickr_publisher_on_auth_request_txn_completed_publishing_rest_support_transaction_completed, self);
#line 194 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp2_ = txn;
#line 194 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_parse_name ("network-error", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp3_, NULL, FALSE);
#line 194 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp2_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _publishing_flickr_flickr_publisher_on_auth_request_txn_error_publishing_rest_support_transaction_network_error, self);
#line 196 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp4_ = spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher));
#line 196 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (!_tmp4_) {
#line 197 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		return;
#line 2048 "FlickrPublishing.c"
	}
#line 199 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_debug ("FlickrPublishing.vala:199: EVENT: OAuth authentication request transac" \
"tion caused a network error");
#line 200 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp5_ = self->priv->host;
#line 200 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp6_ = err;
#line 200 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	spit_publishing_plugin_host_post_error (_tmp5_, _tmp6_);
#line 2058 "FlickrPublishing.c"
}


static void publishing_flickr_flickr_publisher_on_authentication_token_available (PublishingFlickrFlickrPublisher* self, const gchar* token, const gchar* token_secret) {
	const gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	PublishingFlickrSession* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
#line 203 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_FLICKR_PUBLISHER (self));
#line 203 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (token != NULL);
#line 203 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (token_secret != NULL);
#line 204 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = token;
#line 204 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = token_secret;
#line 204 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_debug ("FlickrPublishing.vala:204: EVENT: OAuth authentication token (%s) and " \
"token secret (%s) available", _tmp0_, _tmp1_);
#line 207 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp2_ = self->priv->session;
#line 207 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp3_ = token;
#line 207 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp4_ = token_secret;
#line 207 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_session_set_request_phase_credentials (_tmp2_, _tmp3_, _tmp4_);
#line 209 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp5_ = token;
#line 209 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_flickr_publisher_do_launch_system_browser (self, _tmp5_);
#line 2093 "FlickrPublishing.c"
}


static void publishing_flickr_flickr_publisher_on_system_browser_launched (PublishingFlickrFlickrPublisher* self) {
	gboolean _tmp0_ = FALSE;
#line 212 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_FLICKR_PUBLISHER (self));
#line 213 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher));
#line 213 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (!_tmp0_) {
#line 214 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		return;
#line 2107 "FlickrPublishing.c"
	}
#line 216 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_debug ("FlickrPublishing.vala:216: EVENT: system browser launched.");
#line 218 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_flickr_publisher_do_show_pin_entry_pane (self);
#line 2113 "FlickrPublishing.c"
}


static void _publishing_flickr_flickr_publisher_on_pin_entry_proceed_publishing_flickr_pin_entry_pane_proceed (PublishingFlickrPinEntryPane* _sender, PublishingFlickrPinEntryPane* sender, const gchar* authorization_pin, gpointer self) {
#line 222 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_flickr_publisher_on_pin_entry_proceed ((PublishingFlickrFlickrPublisher*) self, sender, authorization_pin);
#line 2120 "FlickrPublishing.c"
}


static void publishing_flickr_flickr_publisher_on_pin_entry_proceed (PublishingFlickrFlickrPublisher* self, PublishingFlickrPinEntryPane* sender, const gchar* pin) {
	PublishingFlickrPinEntryPane* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
	gboolean _tmp2_ = FALSE;
	const gchar* _tmp3_ = NULL;
#line 221 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_FLICKR_PUBLISHER (self));
#line 221 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_PIN_ENTRY_PANE (sender));
#line 221 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (pin != NULL);
#line 222 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = sender;
#line 222 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_parse_name ("proceed", PUBLISHING_FLICKR_TYPE_PIN_ENTRY_PANE, &_tmp1_, NULL, FALSE);
#line 222 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_flickr_flickr_publisher_on_pin_entry_proceed_publishing_flickr_pin_entry_pane_proceed, self);
#line 224 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp2_ = spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher));
#line 224 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (!_tmp2_) {
#line 225 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		return;
#line 2147 "FlickrPublishing.c"
	}
#line 227 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_debug ("FlickrPublishing.vala:227: EVENT: user clicked 'Continue' in PIN entry" \
" pane.");
#line 229 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp3_ = pin;
#line 229 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_flickr_publisher_do_verify_pin (self, _tmp3_);
#line 2155 "FlickrPublishing.c"
}


static void _publishing_flickr_flickr_publisher_on_access_token_fetch_txn_completed_publishing_rest_support_transaction_completed (PublishingRESTSupportTransaction* _sender, gpointer self) {
#line 233 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_flickr_publisher_on_access_token_fetch_txn_completed ((PublishingFlickrFlickrPublisher*) self, _sender);
#line 2162 "FlickrPublishing.c"
}


static void _publishing_flickr_flickr_publisher_on_access_token_fetch_error_publishing_rest_support_transaction_network_error (PublishingRESTSupportTransaction* _sender, GError* err, gpointer self) {
#line 234 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_flickr_publisher_on_access_token_fetch_error ((PublishingFlickrFlickrPublisher*) self, _sender, err);
#line 2169 "FlickrPublishing.c"
}


static void publishing_flickr_flickr_publisher_on_access_token_fetch_txn_completed (PublishingFlickrFlickrPublisher* self, PublishingRESTSupportTransaction* txn) {
	PublishingRESTSupportTransaction* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
	PublishingRESTSupportTransaction* _tmp2_ = NULL;
	guint _tmp3_ = 0U;
	gboolean _tmp4_ = FALSE;
	PublishingRESTSupportTransaction* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
#line 232 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_FLICKR_PUBLISHER (self));
#line 232 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_TRANSACTION (txn));
#line 233 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = txn;
#line 233 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_parse_name ("completed", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp1_, NULL, FALSE);
#line 233 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_flickr_flickr_publisher_on_access_token_fetch_txn_completed_publishing_rest_support_transaction_completed, self);
#line 234 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp2_ = txn;
#line 234 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_parse_name ("network-error", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp3_, NULL, FALSE);
#line 234 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp2_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _publishing_flickr_flickr_publisher_on_access_token_fetch_error_publishing_rest_support_transaction_network_error, self);
#line 236 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp4_ = spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher));
#line 236 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (!_tmp4_) {
#line 237 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		return;
#line 2204 "FlickrPublishing.c"
	}
#line 239 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_debug ("FlickrPublishing.vala:239: EVENT: fetching OAuth access token over the" \
" network succeeded");
#line 241 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp5_ = txn;
#line 241 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp6_ = publishing_rest_support_transaction_get_response (_tmp5_);
#line 241 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp7_ = _tmp6_;
#line 241 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_flickr_publisher_do_extract_access_phase_credentials_from_reponse (self, _tmp7_);
#line 241 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (_tmp7_);
#line 2218 "FlickrPublishing.c"
}


static void publishing_flickr_flickr_publisher_on_access_token_fetch_error (PublishingFlickrFlickrPublisher* self, PublishingRESTSupportTransaction* txn, GError* err) {
	PublishingRESTSupportTransaction* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
	PublishingRESTSupportTransaction* _tmp2_ = NULL;
	guint _tmp3_ = 0U;
	gboolean _tmp4_ = FALSE;
	SpitPublishingPluginHost* _tmp5_ = NULL;
	GError* _tmp6_ = NULL;
#line 244 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_FLICKR_PUBLISHER (self));
#line 244 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_TRANSACTION (txn));
#line 246 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = txn;
#line 246 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_parse_name ("completed", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp1_, NULL, FALSE);
#line 246 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_flickr_flickr_publisher_on_access_token_fetch_txn_completed_publishing_rest_support_transaction_completed, self);
#line 247 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp2_ = txn;
#line 247 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_parse_name ("network-error", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp3_, NULL, FALSE);
#line 247 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp2_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _publishing_flickr_flickr_publisher_on_access_token_fetch_error_publishing_rest_support_transaction_network_error, self);
#line 249 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp4_ = spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher));
#line 249 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (!_tmp4_) {
#line 250 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		return;
#line 2252 "FlickrPublishing.c"
	}
#line 252 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_debug ("FlickrPublishing.vala:252: EVENT: fetching OAuth access token over the" \
" network caused an error.");
#line 254 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp5_ = self->priv->host;
#line 254 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp6_ = err;
#line 254 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	spit_publishing_plugin_host_post_error (_tmp5_, _tmp6_);
#line 2262 "FlickrPublishing.c"
}


static void publishing_flickr_flickr_publisher_on_session_authenticated (PublishingFlickrFlickrPublisher* self) {
	gboolean _tmp0_ = FALSE;
	PublishingFlickrPublishingParameters* _tmp1_ = NULL;
	PublishingFlickrSession* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	PublishingFlickrSession* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	PublishingFlickrSession* _tmp7_ = NULL;
	gchar* _tmp8_ = NULL;
	gchar* _tmp9_ = NULL;
	PublishingFlickrSession* _tmp10_ = NULL;
	gchar* _tmp11_ = NULL;
	gchar* _tmp12_ = NULL;
#line 257 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_FLICKR_PUBLISHER (self));
#line 258 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher));
#line 258 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (!_tmp0_) {
#line 259 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		return;
#line 2288 "FlickrPublishing.c"
	}
#line 261 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_debug ("FlickrPublishing.vala:261: EVENT: a fully authenticated session has be" \
"come available");
#line 263 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = self->priv->parameters;
#line 263 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp2_ = self->priv->session;
#line 263 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp3_ = publishing_flickr_session_get_username (_tmp2_);
#line 263 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (_tmp1_->username);
#line 263 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_->username = _tmp3_;
#line 265 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp4_ = self->priv->session;
#line 265 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp5_ = publishing_flickr_session_get_access_phase_token (_tmp4_);
#line 265 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp6_ = _tmp5_;
#line 265 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_flickr_publisher_set_persistent_access_phase_token (self, _tmp6_);
#line 265 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (_tmp6_);
#line 266 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp7_ = self->priv->session;
#line 266 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp8_ = publishing_flickr_session_get_access_phase_token_secret (_tmp7_);
#line 266 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp9_ = _tmp8_;
#line 266 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_flickr_publisher_set_persistent_access_phase_token_secret (self, _tmp9_);
#line 266 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (_tmp9_);
#line 267 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp10_ = self->priv->session;
#line 267 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp11_ = publishing_flickr_session_get_username (_tmp10_);
#line 267 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp12_ = _tmp11_;
#line 267 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_flickr_publisher_set_persistent_access_phase_username (self, _tmp12_);
#line 267 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (_tmp12_);
#line 269 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_flickr_publisher_do_fetch_account_info (self);
#line 2334 "FlickrPublishing.c"
}


static void _publishing_flickr_flickr_publisher_on_account_fetch_txn_completed_publishing_rest_support_transaction_completed (PublishingRESTSupportTransaction* _sender, gpointer self) {
#line 273 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_flickr_publisher_on_account_fetch_txn_completed ((PublishingFlickrFlickrPublisher*) self, _sender);
#line 2341 "FlickrPublishing.c"
}


static void _publishing_flickr_flickr_publisher_on_account_fetch_txn_error_publishing_rest_support_transaction_network_error (PublishingRESTSupportTransaction* _sender, GError* err, gpointer self) {
#line 274 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_flickr_publisher_on_account_fetch_txn_error ((PublishingFlickrFlickrPublisher*) self, _sender, err);
#line 2348 "FlickrPublishing.c"
}


static void publishing_flickr_flickr_publisher_on_account_fetch_txn_completed (PublishingFlickrFlickrPublisher* self, PublishingRESTSupportTransaction* txn) {
	PublishingRESTSupportTransaction* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
	PublishingRESTSupportTransaction* _tmp2_ = NULL;
	guint _tmp3_ = 0U;
	gboolean _tmp4_ = FALSE;
	PublishingRESTSupportTransaction* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
#line 272 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_FLICKR_PUBLISHER (self));
#line 272 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_TRANSACTION (txn));
#line 273 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = txn;
#line 273 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_parse_name ("completed", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp1_, NULL, FALSE);
#line 273 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_flickr_flickr_publisher_on_account_fetch_txn_completed_publishing_rest_support_transaction_completed, self);
#line 274 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp2_ = txn;
#line 274 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_parse_name ("network-error", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp3_, NULL, FALSE);
#line 274 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp2_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _publishing_flickr_flickr_publisher_on_account_fetch_txn_error_publishing_rest_support_transaction_network_error, self);
#line 276 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp4_ = spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher));
#line 276 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (!_tmp4_) {
#line 277 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		return;
#line 2383 "FlickrPublishing.c"
	}
#line 279 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_debug ("FlickrPublishing.vala:279: EVENT: account fetch transaction response r" \
"eceived over the network");
#line 280 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp5_ = txn;
#line 280 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp6_ = publishing_rest_support_transaction_get_response (_tmp5_);
#line 280 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp7_ = _tmp6_;
#line 280 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_flickr_publisher_do_parse_account_info_from_xml (self, _tmp7_);
#line 280 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (_tmp7_);
#line 2397 "FlickrPublishing.c"
}


static void publishing_flickr_flickr_publisher_on_account_fetch_txn_error (PublishingFlickrFlickrPublisher* self, PublishingRESTSupportTransaction* txn, GError* err) {
	PublishingRESTSupportTransaction* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
	PublishingRESTSupportTransaction* _tmp2_ = NULL;
	guint _tmp3_ = 0U;
	gboolean _tmp4_ = FALSE;
	SpitPublishingPluginHost* _tmp5_ = NULL;
	GError* _tmp6_ = NULL;
#line 283 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_FLICKR_PUBLISHER (self));
#line 283 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_TRANSACTION (txn));
#line 285 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = txn;
#line 285 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_parse_name ("completed", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp1_, NULL, FALSE);
#line 285 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_flickr_flickr_publisher_on_account_fetch_txn_completed_publishing_rest_support_transaction_completed, self);
#line 286 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp2_ = txn;
#line 286 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_parse_name ("network-error", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp3_, NULL, FALSE);
#line 286 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp2_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _publishing_flickr_flickr_publisher_on_account_fetch_txn_error_publishing_rest_support_transaction_network_error, self);
#line 288 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp4_ = spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher));
#line 288 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (!_tmp4_) {
#line 289 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		return;
#line 2431 "FlickrPublishing.c"
	}
#line 291 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_debug ("FlickrPublishing.vala:291: EVENT: account fetch transaction caused a n" \
"etwork error");
#line 292 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp5_ = self->priv->host;
#line 292 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp6_ = err;
#line 292 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	spit_publishing_plugin_host_post_error (_tmp5_, _tmp6_);
#line 2441 "FlickrPublishing.c"
}


static void publishing_flickr_flickr_publisher_on_account_info_available (PublishingFlickrFlickrPublisher* self) {
	gboolean _tmp0_ = FALSE;
#line 295 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_FLICKR_PUBLISHER (self));
#line 296 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher));
#line 296 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (!_tmp0_) {
#line 297 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		return;
#line 2455 "FlickrPublishing.c"
	}
#line 299 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_debug ("FlickrPublishing.vala:299: EVENT: account information has become avail" \
"able");
#line 300 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_flickr_publisher_do_show_publishing_options_pane (self);
#line 2461 "FlickrPublishing.c"
}


static void _publishing_flickr_flickr_publisher_on_publishing_options_pane_publish_publishing_flickr_publishing_options_pane_publish (PublishingFlickrPublishingOptionsPane* _sender, gboolean strip_metadata, gpointer self) {
#line 304 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_flickr_publisher_on_publishing_options_pane_publish ((PublishingFlickrFlickrPublisher*) self, strip_metadata);
#line 2468 "FlickrPublishing.c"
}


static void _publishing_flickr_flickr_publisher_on_publishing_options_pane_logout_publishing_flickr_publishing_options_pane_logout (PublishingFlickrPublishingOptionsPane* _sender, gpointer self) {
#line 305 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_flickr_publisher_on_publishing_options_pane_logout ((PublishingFlickrFlickrPublisher*) self);
#line 2475 "FlickrPublishing.c"
}


static void publishing_flickr_flickr_publisher_on_publishing_options_pane_publish (PublishingFlickrFlickrPublisher* self, gboolean strip_metadata) {
	PublishingFlickrPublishingOptionsPane* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
	PublishingFlickrPublishingOptionsPane* _tmp2_ = NULL;
	guint _tmp3_ = 0U;
	gboolean _tmp4_ = FALSE;
	gboolean _tmp5_ = FALSE;
#line 303 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_FLICKR_PUBLISHER (self));
#line 304 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = self->priv->publishing_options_pane;
#line 304 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_parse_name ("publish", PUBLISHING_FLICKR_TYPE_PUBLISHING_OPTIONS_PANE, &_tmp1_, NULL, FALSE);
#line 304 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_flickr_flickr_publisher_on_publishing_options_pane_publish_publishing_flickr_publishing_options_pane_publish, self);
#line 305 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp2_ = self->priv->publishing_options_pane;
#line 305 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_parse_name ("logout", PUBLISHING_FLICKR_TYPE_PUBLISHING_OPTIONS_PANE, &_tmp3_, NULL, FALSE);
#line 305 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp2_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _publishing_flickr_flickr_publisher_on_publishing_options_pane_logout_publishing_flickr_publishing_options_pane_logout, self);
#line 307 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp4_ = spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher));
#line 307 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (!_tmp4_) {
#line 308 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		return;
#line 2506 "FlickrPublishing.c"
	}
#line 310 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_debug ("FlickrPublishing.vala:310: EVENT: user clicked the 'Publish' button in" \
" the publishing options pane");
#line 311 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp5_ = strip_metadata;
#line 311 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_flickr_publisher_do_publish (self, _tmp5_);
#line 2514 "FlickrPublishing.c"
}


static void publishing_flickr_flickr_publisher_on_publishing_options_pane_logout (PublishingFlickrFlickrPublisher* self) {
	PublishingFlickrPublishingOptionsPane* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
	PublishingFlickrPublishingOptionsPane* _tmp2_ = NULL;
	guint _tmp3_ = 0U;
	gboolean _tmp4_ = FALSE;
#line 314 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_FLICKR_PUBLISHER (self));
#line 315 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = self->priv->publishing_options_pane;
#line 315 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_parse_name ("publish", PUBLISHING_FLICKR_TYPE_PUBLISHING_OPTIONS_PANE, &_tmp1_, NULL, FALSE);
#line 315 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_flickr_flickr_publisher_on_publishing_options_pane_publish_publishing_flickr_publishing_options_pane_publish, self);
#line 316 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp2_ = self->priv->publishing_options_pane;
#line 316 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_parse_name ("logout", PUBLISHING_FLICKR_TYPE_PUBLISHING_OPTIONS_PANE, &_tmp3_, NULL, FALSE);
#line 316 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp2_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _publishing_flickr_flickr_publisher_on_publishing_options_pane_logout_publishing_flickr_publishing_options_pane_logout, self);
#line 318 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp4_ = spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher));
#line 318 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (!_tmp4_) {
#line 319 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		return;
#line 2544 "FlickrPublishing.c"
	}
#line 321 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_debug ("FlickrPublishing.vala:321: EVENT: user clicked the 'Logout' button in " \
"the publishing options pane");
#line 323 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_flickr_publisher_do_logout (self);
#line 2550 "FlickrPublishing.c"
}


static void publishing_flickr_flickr_publisher_on_upload_status_updated (PublishingFlickrFlickrPublisher* self, gint file_number, gdouble completed_fraction) {
	gboolean _tmp0_ = FALSE;
	gdouble _tmp1_ = 0.0;
	SpitPublishingProgressCallback _tmp2_ = NULL;
	void* _tmp2__target = NULL;
	SpitPublishingProgressCallback _tmp3_ = NULL;
	void* _tmp3__target = NULL;
	gint _tmp4_ = 0;
	gdouble _tmp5_ = 0.0;
#line 326 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_FLICKR_PUBLISHER (self));
#line 327 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher));
#line 327 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (!_tmp0_) {
#line 328 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		return;
#line 2571 "FlickrPublishing.c"
	}
#line 330 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = completed_fraction;
#line 330 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_debug ("FlickrPublishing.vala:330: EVENT: uploader reports upload %.2f percent" \
" complete.", 100.0 * _tmp1_);
#line 332 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp2_ = self->priv->progress_reporter;
#line 332 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp2__target = self->priv->progress_reporter_target;
#line 332 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_vala_assert (_tmp2_ != NULL, "progress_reporter != null");
#line 334 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp3_ = self->priv->progress_reporter;
#line 334 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp3__target = self->priv->progress_reporter_target;
#line 334 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp4_ = file_number;
#line 334 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp5_ = completed_fraction;
#line 334 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp3_ (_tmp4_, _tmp5_, _tmp3__target);
#line 2593 "FlickrPublishing.c"
}


static void _publishing_flickr_flickr_publisher_on_upload_complete_publishing_rest_support_batch_uploader_upload_complete (PublishingRESTSupportBatchUploader* _sender, gint num_photos_published, gpointer self) {
#line 344 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_flickr_publisher_on_upload_complete ((PublishingFlickrFlickrPublisher*) self, _sender, num_photos_published);
#line 2600 "FlickrPublishing.c"
}


static void _publishing_flickr_flickr_publisher_on_upload_error_publishing_rest_support_batch_uploader_upload_error (PublishingRESTSupportBatchUploader* _sender, GError* err, gpointer self) {
#line 345 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_flickr_publisher_on_upload_error ((PublishingFlickrFlickrPublisher*) self, _sender, err);
#line 2607 "FlickrPublishing.c"
}


static void publishing_flickr_flickr_publisher_on_upload_complete (PublishingFlickrFlickrPublisher* self, PublishingRESTSupportBatchUploader* uploader, gint num_published) {
	gboolean _tmp0_ = FALSE;
	gint _tmp1_ = 0;
	PublishingRESTSupportBatchUploader* _tmp2_ = NULL;
	guint _tmp3_ = 0U;
	PublishingRESTSupportBatchUploader* _tmp4_ = NULL;
	guint _tmp5_ = 0U;
#line 337 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_FLICKR_PUBLISHER (self));
#line 337 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_BATCH_UPLOADER (uploader));
#line 339 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher));
#line 339 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (!_tmp0_) {
#line 340 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		return;
#line 2628 "FlickrPublishing.c"
	}
#line 342 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = num_published;
#line 342 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_debug ("FlickrPublishing.vala:342: EVENT: uploader reports upload complete; %d" \
" items published.", _tmp1_);
#line 344 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp2_ = uploader;
#line 344 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_parse_name ("upload-complete", PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, &_tmp3_, NULL, FALSE);
#line 344 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp2_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _publishing_flickr_flickr_publisher_on_upload_complete_publishing_rest_support_batch_uploader_upload_complete, self);
#line 345 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp4_ = uploader;
#line 345 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_parse_name ("upload-error", PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, &_tmp5_, NULL, FALSE);
#line 345 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp4_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp5_, 0, NULL, (GCallback) _publishing_flickr_flickr_publisher_on_upload_error_publishing_rest_support_batch_uploader_upload_error, self);
#line 347 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_flickr_publisher_do_show_success_pane (self);
#line 2648 "FlickrPublishing.c"
}


static void publishing_flickr_flickr_publisher_on_upload_error (PublishingFlickrFlickrPublisher* self, PublishingRESTSupportBatchUploader* uploader, GError* err) {
	gboolean _tmp0_ = FALSE;
	GError* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	PublishingRESTSupportBatchUploader* _tmp3_ = NULL;
	guint _tmp4_ = 0U;
	PublishingRESTSupportBatchUploader* _tmp5_ = NULL;
	guint _tmp6_ = 0U;
	SpitPublishingPluginHost* _tmp7_ = NULL;
	GError* _tmp8_ = NULL;
#line 350 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_FLICKR_PUBLISHER (self));
#line 350 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_BATCH_UPLOADER (uploader));
#line 352 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher));
#line 352 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (!_tmp0_) {
#line 353 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		return;
#line 2672 "FlickrPublishing.c"
	}
#line 355 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = err;
#line 355 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp2_ = _tmp1_->message;
#line 355 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_debug ("FlickrPublishing.vala:355: EVENT: uploader reports upload error = '%s'" \
".", _tmp2_);
#line 357 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp3_ = uploader;
#line 357 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_parse_name ("upload-complete", PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, &_tmp4_, NULL, FALSE);
#line 357 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp3_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp4_, 0, NULL, (GCallback) _publishing_flickr_flickr_publisher_on_upload_complete_publishing_rest_support_batch_uploader_upload_complete, self);
#line 358 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp5_ = uploader;
#line 358 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_parse_name ("upload-error", PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, &_tmp6_, NULL, FALSE);
#line 358 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp5_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp6_, 0, NULL, (GCallback) _publishing_flickr_flickr_publisher_on_upload_error_publishing_rest_support_batch_uploader_upload_error, self);
#line 360 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp7_ = self->priv->host;
#line 360 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp8_ = err;
#line 360 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	spit_publishing_plugin_host_post_error (_tmp7_, _tmp8_);
#line 2698 "FlickrPublishing.c"
}


static void _publishing_flickr_flickr_publisher_on_welcome_pane_login_clicked_spit_publishing_login_callback (gpointer self) {
#line 367 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_flickr_publisher_on_welcome_pane_login_clicked ((PublishingFlickrFlickrPublisher*) self);
#line 2705 "FlickrPublishing.c"
}


static void publishing_flickr_flickr_publisher_do_show_login_welcome_pane (PublishingFlickrFlickrPublisher* self) {
	SpitPublishingPluginHost* _tmp0_ = NULL;
	SpitPublishingPluginHost* _tmp1_ = NULL;
#line 363 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_FLICKR_PUBLISHER (self));
#line 364 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_debug ("FlickrPublishing.vala:364: ACTION: installing login welcome pane");
#line 366 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = self->priv->host;
#line 366 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	spit_publishing_plugin_host_set_service_locked (_tmp0_, FALSE);
#line 367 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = self->priv->host;
#line 367 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	spit_publishing_plugin_host_install_welcome_pane (_tmp1_, PUBLISHING_FLICKR_SERVICE_WELCOME_MESSAGE, _publishing_flickr_flickr_publisher_on_welcome_pane_login_clicked_spit_publishing_login_callback, self);
#line 2724 "FlickrPublishing.c"
}


static void publishing_flickr_flickr_publisher_do_run_authentication_request_transaction (PublishingFlickrFlickrPublisher* self) {
	SpitPublishingPluginHost* _tmp0_ = NULL;
	SpitPublishingPluginHost* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	PublishingFlickrAuthenticationRequestTransaction* txn = NULL;
	PublishingFlickrSession* _tmp3_ = NULL;
	PublishingFlickrAuthenticationRequestTransaction* _tmp4_ = NULL;
	GError * _inner_error_ = NULL;
#line 370 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_FLICKR_PUBLISHER (self));
#line 371 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_debug ("FlickrPublishing.vala:371: ACTION: running authentication request tran" \
"saction");
#line 373 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = self->priv->host;
#line 373 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	spit_publishing_plugin_host_set_service_locked (_tmp0_, TRUE);
#line 374 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = self->priv->host;
#line 374 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp2_ = _ ("Preparing for login...");
#line 374 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	spit_publishing_plugin_host_install_static_message_pane (_tmp1_, _tmp2_, SPIT_PUBLISHING_PLUGIN_HOST_BUTTON_MODE_CANCEL);
#line 376 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp3_ = self->priv->session;
#line 376 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp4_ = publishing_flickr_authentication_request_transaction_new (_tmp3_);
#line 376 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	txn = _tmp4_;
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (txn, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "completed", (GCallback) _publishing_flickr_flickr_publisher_on_auth_request_txn_completed_publishing_rest_support_transaction_completed, self, 0);
#line 378 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (txn, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "network-error", (GCallback) _publishing_flickr_flickr_publisher_on_auth_request_txn_error_publishing_rest_support_transaction_network_error, self, 0);
#line 2760 "FlickrPublishing.c"
	{
#line 381 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		publishing_rest_support_transaction_execute (G_TYPE_CHECK_INSTANCE_CAST (txn, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), &_inner_error_);
#line 381 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 381 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 2768 "FlickrPublishing.c"
				goto __catch16_spit_publishing_publishing_error;
			}
#line 381 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_publishing_rest_support_transaction_unref0 (txn);
#line 381 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 381 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			g_clear_error (&_inner_error_);
#line 381 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			return;
#line 2779 "FlickrPublishing.c"
		}
	}
	goto __finally16;
	__catch16_spit_publishing_publishing_error:
	{
		GError* err = NULL;
		SpitPublishingPluginHost* _tmp5_ = NULL;
		GError* _tmp6_ = NULL;
#line 380 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		err = _inner_error_;
#line 380 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_inner_error_ = NULL;
#line 383 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp5_ = self->priv->host;
#line 383 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp6_ = err;
#line 383 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		spit_publishing_plugin_host_post_error (_tmp5_, _tmp6_);
#line 380 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_error_free0 (err);
#line 2800 "FlickrPublishing.c"
	}
	__finally16:
#line 380 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 380 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_publishing_rest_support_transaction_unref0 (txn);
#line 380 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 380 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_clear_error (&_inner_error_);
#line 380 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		return;
#line 2813 "FlickrPublishing.c"
	}
#line 370 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_publishing_rest_support_transaction_unref0 (txn);
#line 2817 "FlickrPublishing.c"
}


static void publishing_flickr_flickr_publisher_do_parse_token_info_from_auth_request (PublishingFlickrFlickrPublisher* self, const gchar* response) {
	const gchar* _tmp0_ = NULL;
	gchar* oauth_token = NULL;
	gchar* oauth_token_secret = NULL;
	gchar** key_value_pairs = NULL;
	const gchar* _tmp1_ = NULL;
	gchar** _tmp2_ = NULL;
	gchar** _tmp3_ = NULL;
	gint key_value_pairs_length1 = 0;
	gint _key_value_pairs_size_ = 0;
	gchar** _tmp4_ = NULL;
	gint _tmp4__length1 = 0;
	gboolean _tmp24_ = FALSE;
	const gchar* _tmp25_ = NULL;
	const gchar* _tmp31_ = NULL;
	const gchar* _tmp32_ = NULL;
#line 387 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_FLICKR_PUBLISHER (self));
#line 387 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (response != NULL);
#line 388 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = response;
#line 388 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_debug ("FlickrPublishing.vala:388: ACTION: parsing authorization request respo" \
"nse '%s' into token and secret", _tmp0_);
#line 390 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	oauth_token = NULL;
#line 391 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	oauth_token_secret = NULL;
#line 393 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = response;
#line 393 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp3_ = _tmp2_ = g_strsplit (_tmp1_, "&", 0);
#line 393 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	key_value_pairs = _tmp3_;
#line 393 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	key_value_pairs_length1 = _vala_array_length (_tmp2_);
#line 393 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_key_value_pairs_size_ = key_value_pairs_length1;
#line 394 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp4_ = key_value_pairs;
#line 394 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp4__length1 = key_value_pairs_length1;
#line 2863 "FlickrPublishing.c"
	{
		gchar** pair_collection = NULL;
		gint pair_collection_length1 = 0;
		gint _pair_collection_size_ = 0;
		gint pair_it = 0;
#line 394 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		pair_collection = _tmp4_;
#line 394 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		pair_collection_length1 = _tmp4__length1;
#line 394 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		for (pair_it = 0; pair_it < _tmp4__length1; pair_it = pair_it + 1) {
#line 2875 "FlickrPublishing.c"
			gchar* _tmp5_ = NULL;
			gchar* pair = NULL;
#line 394 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_tmp5_ = g_strdup (pair_collection[pair_it]);
#line 394 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			pair = _tmp5_;
#line 2882 "FlickrPublishing.c"
			{
				gchar** split_pair = NULL;
				const gchar* _tmp6_ = NULL;
				gchar** _tmp7_ = NULL;
				gchar** _tmp8_ = NULL;
				gint split_pair_length1 = 0;
				gint _split_pair_size_ = 0;
				gchar** _tmp9_ = NULL;
				gint _tmp9__length1 = 0;
				gchar** _tmp14_ = NULL;
				gint _tmp14__length1 = 0;
				const gchar* _tmp15_ = NULL;
#line 395 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp6_ = pair;
#line 395 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp8_ = _tmp7_ = g_strsplit (_tmp6_, "=", 0);
#line 395 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				split_pair = _tmp8_;
#line 395 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				split_pair_length1 = _vala_array_length (_tmp7_);
#line 395 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_split_pair_size_ = split_pair_length1;
#line 397 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp9_ = split_pair;
#line 397 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp9__length1 = split_pair_length1;
#line 397 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				if (_tmp9__length1 != 2) {
#line 2911 "FlickrPublishing.c"
					SpitPublishingPluginHost* _tmp10_ = NULL;
					const gchar* _tmp11_ = NULL;
					GError* _tmp12_ = NULL;
					GError* _tmp13_ = NULL;
#line 398 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
					_tmp10_ = self->priv->host;
#line 398 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
					_tmp11_ = response;
#line 398 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
					_tmp12_ = g_error_new (SPIT_PUBLISHING_PUBLISHING_ERROR, SPIT_PUBLISHING_PUBLISHING_ERROR_MALFORMED_RESPONSE, "'%s' isn't a valid response to an OAuth authentication request", _tmp11_);
#line 398 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
					_tmp13_ = _tmp12_;
#line 398 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
					spit_publishing_plugin_host_post_error (_tmp10_, _tmp13_);
#line 398 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
					_g_error_free0 (_tmp13_);
#line 2928 "FlickrPublishing.c"
				}
#line 401 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp14_ = split_pair;
#line 401 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp14__length1 = split_pair_length1;
#line 401 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp15_ = _tmp14_[0];
#line 401 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				if (g_strcmp0 (_tmp15_, "oauth_token") == 0) {
#line 2938 "FlickrPublishing.c"
					gchar** _tmp16_ = NULL;
					gint _tmp16__length1 = 0;
					const gchar* _tmp17_ = NULL;
					gchar* _tmp18_ = NULL;
#line 402 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
					_tmp16_ = split_pair;
#line 402 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
					_tmp16__length1 = split_pair_length1;
#line 402 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
					_tmp17_ = _tmp16_[1];
#line 402 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
					_tmp18_ = g_strdup (_tmp17_);
#line 402 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
					_g_free0 (oauth_token);
#line 402 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
					oauth_token = _tmp18_;
#line 2955 "FlickrPublishing.c"
				} else {
					gchar** _tmp19_ = NULL;
					gint _tmp19__length1 = 0;
					const gchar* _tmp20_ = NULL;
#line 403 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
					_tmp19_ = split_pair;
#line 403 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
					_tmp19__length1 = split_pair_length1;
#line 403 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
					_tmp20_ = _tmp19_[0];
#line 403 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
					if (g_strcmp0 (_tmp20_, "oauth_token_secret") == 0) {
#line 2968 "FlickrPublishing.c"
						gchar** _tmp21_ = NULL;
						gint _tmp21__length1 = 0;
						const gchar* _tmp22_ = NULL;
						gchar* _tmp23_ = NULL;
#line 404 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
						_tmp21_ = split_pair;
#line 404 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
						_tmp21__length1 = split_pair_length1;
#line 404 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
						_tmp22_ = _tmp21_[1];
#line 404 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
						_tmp23_ = g_strdup (_tmp22_);
#line 404 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
						_g_free0 (oauth_token_secret);
#line 404 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
						oauth_token_secret = _tmp23_;
#line 2985 "FlickrPublishing.c"
					}
				}
#line 394 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				split_pair = (_vala_array_free (split_pair, split_pair_length1, (GDestroyNotify) g_free), NULL);
#line 394 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_g_free0 (pair);
#line 2992 "FlickrPublishing.c"
			}
		}
	}
#line 407 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp25_ = oauth_token;
#line 407 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (_tmp25_ == NULL) {
#line 407 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp24_ = TRUE;
#line 3002 "FlickrPublishing.c"
	} else {
		const gchar* _tmp26_ = NULL;
#line 407 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp26_ = oauth_token_secret;
#line 407 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp24_ = _tmp26_ == NULL;
#line 3009 "FlickrPublishing.c"
	}
#line 407 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (_tmp24_) {
#line 3013 "FlickrPublishing.c"
		SpitPublishingPluginHost* _tmp27_ = NULL;
		const gchar* _tmp28_ = NULL;
		GError* _tmp29_ = NULL;
		GError* _tmp30_ = NULL;
#line 408 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp27_ = self->priv->host;
#line 408 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp28_ = response;
#line 408 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp29_ = g_error_new (SPIT_PUBLISHING_PUBLISHING_ERROR, SPIT_PUBLISHING_PUBLISHING_ERROR_MALFORMED_RESPONSE, "'%s' isn't a valid response to an OAuth authentication request", _tmp28_);
#line 408 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp30_ = _tmp29_;
#line 408 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		spit_publishing_plugin_host_post_error (_tmp27_, _tmp30_);
#line 408 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_error_free0 (_tmp30_);
#line 3030 "FlickrPublishing.c"
	}
#line 412 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp31_ = oauth_token;
#line 412 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp32_ = oauth_token_secret;
#line 412 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_flickr_publisher_on_authentication_token_available (self, _tmp31_, _tmp32_);
#line 387 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	key_value_pairs = (_vala_array_free (key_value_pairs, key_value_pairs_length1, (GDestroyNotify) g_free), NULL);
#line 387 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (oauth_token_secret);
#line 387 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (oauth_token);
#line 3044 "FlickrPublishing.c"
}


static void publishing_flickr_flickr_publisher_do_launch_system_browser (PublishingFlickrFlickrPublisher* self, const gchar* token) {
	gchar* login_uri = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
	GError * _inner_error_ = NULL;
#line 415 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_FLICKR_PUBLISHER (self));
#line 415 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (token != NULL);
#line 416 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = token;
#line 416 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = g_strconcat ("https://www.flickr.com/services/oauth/authorize?oauth_token=", _tmp0_, NULL);
#line 416 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp2_ = _tmp1_;
#line 416 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp3_ = g_strconcat (_tmp2_, "&perms=write", NULL);
#line 416 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp4_ = _tmp3_;
#line 416 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (_tmp2_);
#line 416 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	login_uri = _tmp4_;
#line 419 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp5_ = login_uri;
#line 419 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_debug ("FlickrPublishing.vala:419: ACTION: launching system browser with uri =" \
" '%s'", _tmp5_);
#line 3079 "FlickrPublishing.c"
	{
		const gchar* _tmp6_ = NULL;
		gchar* _tmp7_ = NULL;
		gchar* _tmp8_ = NULL;
#line 422 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp6_ = login_uri;
#line 422 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp7_ = g_strconcat ("xdg-open ", _tmp6_, NULL);
#line 422 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp8_ = _tmp7_;
#line 422 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_spawn_command_line_async (_tmp8_, &_inner_error_);
#line 422 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_free0 (_tmp8_);
#line 422 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 422 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			if (_inner_error_->domain == G_SPAWN_ERROR) {
#line 3098 "FlickrPublishing.c"
				goto __catch17_g_spawn_error;
			}
#line 422 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_g_free0 (login_uri);
#line 422 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 422 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			g_clear_error (&_inner_error_);
#line 422 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			return;
#line 3109 "FlickrPublishing.c"
		}
	}
	goto __finally17;
	__catch17_g_spawn_error:
	{
		GError* e = NULL;
		SpitPublishingPluginHost* _tmp9_ = NULL;
		GError* _tmp10_ = NULL;
		GError* _tmp11_ = NULL;
#line 421 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		e = _inner_error_;
#line 421 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_inner_error_ = NULL;
#line 424 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp9_ = self->priv->host;
#line 424 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp10_ = g_error_new_literal (SPIT_PUBLISHING_PUBLISHING_ERROR, SPIT_PUBLISHING_PUBLISHING_ERROR_LOCAL_FILE_ERROR, "couldn't launch system web browser to complete Flickr login");
#line 424 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp11_ = _tmp10_;
#line 424 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		spit_publishing_plugin_host_post_error (_tmp9_, _tmp11_);
#line 424 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_error_free0 (_tmp11_);
#line 426 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_error_free0 (e);
#line 426 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_free0 (login_uri);
#line 426 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		return;
#line 3139 "FlickrPublishing.c"
	}
	__finally17:
#line 421 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 421 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_free0 (login_uri);
#line 421 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 421 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_clear_error (&_inner_error_);
#line 421 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		return;
#line 3152 "FlickrPublishing.c"
	}
#line 429 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_flickr_publisher_on_system_browser_launched (self);
#line 415 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (login_uri);
#line 3158 "FlickrPublishing.c"
}


static void publishing_flickr_flickr_publisher_do_show_pin_entry_pane (PublishingFlickrFlickrPublisher* self) {
	GtkBuilder* builder = NULL;
	GtkBuilder* _tmp0_ = NULL;
	PublishingFlickrPinEntryPane* pin_entry_pane = NULL;
	GtkBuilder* _tmp8_ = NULL;
	PublishingFlickrPinEntryPane* _tmp9_ = NULL;
	PublishingFlickrPinEntryPane* _tmp10_ = NULL;
	SpitPublishingPluginHost* _tmp11_ = NULL;
	PublishingFlickrPinEntryPane* _tmp12_ = NULL;
	GError * _inner_error_ = NULL;
#line 432 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_FLICKR_PUBLISHER (self));
#line 433 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_debug ("FlickrPublishing.vala:433: ACTION: showing PIN entry pane");
#line 435 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = gtk_builder_new ();
#line 435 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	builder = _tmp0_;
#line 3180 "FlickrPublishing.c"
	{
		GtkBuilder* _tmp1_ = NULL;
#line 438 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp1_ = builder;
#line 438 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		gtk_builder_add_from_resource (_tmp1_, PLUGIN_RESOURCE_PATH "/" "flickr_pin_entry_pane.ui", &_inner_error_);
#line 438 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3189 "FlickrPublishing.c"
			goto __catch18_g_error;
		}
	}
	goto __finally18;
	__catch18_g_error:
	{
		GError* e = NULL;
		GError* _tmp2_ = NULL;
		const gchar* _tmp3_ = NULL;
		SpitPublishingPluginHost* _tmp4_ = NULL;
		const gchar* _tmp5_ = NULL;
		GError* _tmp6_ = NULL;
		GError* _tmp7_ = NULL;
#line 437 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		e = _inner_error_;
#line 437 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_inner_error_ = NULL;
#line 441 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp2_ = e;
#line 441 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp3_ = _tmp2_->message;
#line 441 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_warning ("FlickrPublishing.vala:441: Could not parse UI file! Error: %s.", _tmp3_);
#line 442 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp4_ = self->priv->host;
#line 442 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp5_ = _ ("A file required for publishing is unavailable. Publishing to Flickr ca" \
"n't continue.");
#line 442 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp6_ = g_error_new_literal (SPIT_PUBLISHING_PUBLISHING_ERROR, SPIT_PUBLISHING_PUBLISHING_ERROR_LOCAL_FILE_ERROR, _tmp5_);
#line 442 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp7_ = _tmp6_;
#line 442 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		spit_publishing_plugin_host_post_error (_tmp4_, _tmp7_);
#line 442 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_error_free0 (_tmp7_);
#line 445 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_error_free0 (e);
#line 445 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_object_unref0 (builder);
#line 445 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		return;
#line 3231 "FlickrPublishing.c"
	}
	__finally18:
#line 437 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 437 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_object_unref0 (builder);
#line 437 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 437 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_clear_error (&_inner_error_);
#line 437 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		return;
#line 3244 "FlickrPublishing.c"
	}
#line 448 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp8_ = builder;
#line 448 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp9_ = publishing_flickr_pin_entry_pane_new (_tmp8_);
#line 448 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	pin_entry_pane = _tmp9_;
#line 449 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp10_ = pin_entry_pane;
#line 449 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_connect_object (_tmp10_, "proceed", (GCallback) _publishing_flickr_flickr_publisher_on_pin_entry_proceed_publishing_flickr_pin_entry_pane_proceed, self, 0);
#line 450 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp11_ = self->priv->host;
#line 450 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp12_ = pin_entry_pane;
#line 450 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	spit_publishing_plugin_host_install_dialog_pane (_tmp11_, G_TYPE_CHECK_INSTANCE_CAST (_tmp12_, SPIT_PUBLISHING_TYPE_DIALOG_PANE, SpitPublishingDialogPane), SPIT_PUBLISHING_PLUGIN_HOST_BUTTON_MODE_CANCEL);
#line 432 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (pin_entry_pane);
#line 432 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (builder);
#line 3266 "FlickrPublishing.c"
}


static void publishing_flickr_flickr_publisher_do_verify_pin (PublishingFlickrFlickrPublisher* self, const gchar* pin) {
	const gchar* _tmp0_ = NULL;
	SpitPublishingPluginHost* _tmp1_ = NULL;
	SpitPublishingPluginHost* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	PublishingFlickrAccessTokenFetchTransaction* txn = NULL;
	PublishingFlickrSession* _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
	PublishingFlickrAccessTokenFetchTransaction* _tmp6_ = NULL;
	GError * _inner_error_ = NULL;
#line 453 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_FLICKR_PUBLISHER (self));
#line 453 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (pin != NULL);
#line 454 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = pin;
#line 454 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_debug ("FlickrPublishing.vala:454: ACTION: validating authorization PIN %s", _tmp0_);
#line 456 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = self->priv->host;
#line 456 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	spit_publishing_plugin_host_set_service_locked (_tmp1_, TRUE);
#line 457 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp2_ = self->priv->host;
#line 457 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp3_ = _ ("Verifying authorization...");
#line 457 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	spit_publishing_plugin_host_install_static_message_pane (_tmp2_, _tmp3_, SPIT_PUBLISHING_PLUGIN_HOST_BUTTON_MODE_CANCEL);
#line 459 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp4_ = self->priv->session;
#line 459 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp5_ = pin;
#line 459 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp6_ = publishing_flickr_access_token_fetch_transaction_new (_tmp4_, _tmp5_);
#line 459 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	txn = _tmp6_;
#line 460 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (txn, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "completed", (GCallback) _publishing_flickr_flickr_publisher_on_access_token_fetch_txn_completed_publishing_rest_support_transaction_completed, self, 0);
#line 461 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (txn, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "network-error", (GCallback) _publishing_flickr_flickr_publisher_on_access_token_fetch_error_publishing_rest_support_transaction_network_error, self, 0);
#line 3310 "FlickrPublishing.c"
	{
#line 464 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		publishing_rest_support_transaction_execute (G_TYPE_CHECK_INSTANCE_CAST (txn, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), &_inner_error_);
#line 464 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 464 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 3318 "FlickrPublishing.c"
				goto __catch19_spit_publishing_publishing_error;
			}
#line 464 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_publishing_rest_support_transaction_unref0 (txn);
#line 464 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 464 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			g_clear_error (&_inner_error_);
#line 464 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			return;
#line 3329 "FlickrPublishing.c"
		}
	}
	goto __finally19;
	__catch19_spit_publishing_publishing_error:
	{
		GError* err = NULL;
		SpitPublishingPluginHost* _tmp7_ = NULL;
		GError* _tmp8_ = NULL;
#line 463 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		err = _inner_error_;
#line 463 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_inner_error_ = NULL;
#line 466 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp7_ = self->priv->host;
#line 466 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp8_ = err;
#line 466 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		spit_publishing_plugin_host_post_error (_tmp7_, _tmp8_);
#line 463 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_error_free0 (err);
#line 3350 "FlickrPublishing.c"
	}
	__finally19:
#line 463 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 463 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_publishing_rest_support_transaction_unref0 (txn);
#line 463 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 463 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_clear_error (&_inner_error_);
#line 463 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		return;
#line 3363 "FlickrPublishing.c"
	}
#line 453 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_publishing_rest_support_transaction_unref0 (txn);
#line 3367 "FlickrPublishing.c"
}


static void publishing_flickr_flickr_publisher_do_extract_access_phase_credentials_from_reponse (PublishingFlickrFlickrPublisher* self, const gchar* response) {
	const gchar* _tmp0_ = NULL;
	gchar** key_value_pairs = NULL;
	const gchar* _tmp1_ = NULL;
	gchar** _tmp2_ = NULL;
	gchar** _tmp3_ = NULL;
	gint key_value_pairs_length1 = 0;
	gint _key_value_pairs_size_ = 0;
	gchar* token = NULL;
	gchar* token_secret = NULL;
	gchar* username = NULL;
	gchar** _tmp4_ = NULL;
	gint _tmp4__length1 = 0;
	const gchar* _tmp25_ = NULL;
	const gchar* _tmp26_ = NULL;
	const gchar* _tmp27_ = NULL;
	gboolean _tmp28_ = FALSE;
	gboolean _tmp29_ = FALSE;
	const gchar* _tmp30_ = NULL;
	PublishingFlickrSession* _tmp36_ = NULL;
	const gchar* _tmp37_ = NULL;
	const gchar* _tmp38_ = NULL;
	const gchar* _tmp39_ = NULL;
#line 470 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_FLICKR_PUBLISHER (self));
#line 470 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (response != NULL);
#line 471 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = response;
#line 471 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_debug ("FlickrPublishing.vala:471: ACTION: extracting access phase credentials" \
" from '%s'", _tmp0_);
#line 473 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = response;
#line 473 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp3_ = _tmp2_ = g_strsplit (_tmp1_, "&", 0);
#line 473 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	key_value_pairs = _tmp3_;
#line 473 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	key_value_pairs_length1 = _vala_array_length (_tmp2_);
#line 473 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_key_value_pairs_size_ = key_value_pairs_length1;
#line 475 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	token = NULL;
#line 476 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	token_secret = NULL;
#line 477 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	username = NULL;
#line 478 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp4_ = key_value_pairs;
#line 478 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp4__length1 = key_value_pairs_length1;
#line 3422 "FlickrPublishing.c"
	{
		gchar** key_value_pair_collection = NULL;
		gint key_value_pair_collection_length1 = 0;
		gint _key_value_pair_collection_size_ = 0;
		gint key_value_pair_it = 0;
#line 478 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		key_value_pair_collection = _tmp4_;
#line 478 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		key_value_pair_collection_length1 = _tmp4__length1;
#line 478 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		for (key_value_pair_it = 0; key_value_pair_it < _tmp4__length1; key_value_pair_it = key_value_pair_it + 1) {
#line 3434 "FlickrPublishing.c"
			gchar* _tmp5_ = NULL;
			gchar* key_value_pair = NULL;
#line 478 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_tmp5_ = g_strdup (key_value_pair_collection[key_value_pair_it]);
#line 478 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			key_value_pair = _tmp5_;
#line 3441 "FlickrPublishing.c"
			{
				gchar** split_pair = NULL;
				const gchar* _tmp6_ = NULL;
				gchar** _tmp7_ = NULL;
				gchar** _tmp8_ = NULL;
				gint split_pair_length1 = 0;
				gint _split_pair_size_ = 0;
				gchar** _tmp9_ = NULL;
				gint _tmp9__length1 = 0;
				gchar* key = NULL;
				gchar** _tmp10_ = NULL;
				gint _tmp10__length1 = 0;
				const gchar* _tmp11_ = NULL;
				gchar* _tmp12_ = NULL;
				gchar* value = NULL;
				gchar** _tmp13_ = NULL;
				gint _tmp13__length1 = 0;
				const gchar* _tmp14_ = NULL;
				gchar* _tmp15_ = NULL;
				const gchar* _tmp16_ = NULL;
#line 479 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp6_ = key_value_pair;
#line 479 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp8_ = _tmp7_ = g_strsplit (_tmp6_, "=", 0);
#line 479 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				split_pair = _tmp8_;
#line 479 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				split_pair_length1 = _vala_array_length (_tmp7_);
#line 479 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_split_pair_size_ = split_pair_length1;
#line 481 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp9_ = split_pair;
#line 481 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp9__length1 = split_pair_length1;
#line 481 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				if (_tmp9__length1 != 2) {
#line 482 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
					split_pair = (_vala_array_free (split_pair, split_pair_length1, (GDestroyNotify) g_free), NULL);
#line 482 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
					_g_free0 (key_value_pair);
#line 482 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
					continue;
#line 3484 "FlickrPublishing.c"
				}
#line 484 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp10_ = split_pair;
#line 484 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp10__length1 = split_pair_length1;
#line 484 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp11_ = _tmp10_[0];
#line 484 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp12_ = g_strdup (_tmp11_);
#line 484 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				key = _tmp12_;
#line 485 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp13_ = split_pair;
#line 485 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp13__length1 = split_pair_length1;
#line 485 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp14_ = _tmp13_[1];
#line 485 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp15_ = g_strdup (_tmp14_);
#line 485 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				value = _tmp15_;
#line 487 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp16_ = key;
#line 487 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				if (g_strcmp0 (_tmp16_, "oauth_token") == 0) {
#line 3510 "FlickrPublishing.c"
					const gchar* _tmp17_ = NULL;
					gchar* _tmp18_ = NULL;
#line 488 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
					_tmp17_ = value;
#line 488 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
					_tmp18_ = g_strdup (_tmp17_);
#line 488 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
					_g_free0 (token);
#line 488 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
					token = _tmp18_;
#line 3521 "FlickrPublishing.c"
				} else {
					const gchar* _tmp19_ = NULL;
#line 489 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
					_tmp19_ = key;
#line 489 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
					if (g_strcmp0 (_tmp19_, "oauth_token_secret") == 0) {
#line 3528 "FlickrPublishing.c"
						const gchar* _tmp20_ = NULL;
						gchar* _tmp21_ = NULL;
#line 490 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
						_tmp20_ = value;
#line 490 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
						_tmp21_ = g_strdup (_tmp20_);
#line 490 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
						_g_free0 (token_secret);
#line 490 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
						token_secret = _tmp21_;
#line 3539 "FlickrPublishing.c"
					} else {
						const gchar* _tmp22_ = NULL;
#line 491 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
						_tmp22_ = key;
#line 491 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
						if (g_strcmp0 (_tmp22_, "username") == 0) {
#line 3546 "FlickrPublishing.c"
							const gchar* _tmp23_ = NULL;
							gchar* _tmp24_ = NULL;
#line 492 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
							_tmp23_ = value;
#line 492 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
							_tmp24_ = g_strdup (_tmp23_);
#line 492 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
							_g_free0 (username);
#line 492 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
							username = _tmp24_;
#line 3557 "FlickrPublishing.c"
						}
					}
				}
#line 478 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_g_free0 (value);
#line 478 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_g_free0 (key);
#line 478 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				split_pair = (_vala_array_free (split_pair, split_pair_length1, (GDestroyNotify) g_free), NULL);
#line 478 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_g_free0 (key_value_pair);
#line 3569 "FlickrPublishing.c"
			}
		}
	}
#line 495 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp25_ = token;
#line 495 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp26_ = token_secret;
#line 495 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp27_ = username;
#line 495 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_debug ("FlickrPublishing.vala:495: access phase credentials: { token = '%s'; t" \
"oken_secret = '%s'; username = '%s' }", _tmp25_, _tmp26_, _tmp27_);
#line 498 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp30_ = token;
#line 498 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (_tmp30_ == NULL) {
#line 498 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp29_ = TRUE;
#line 3587 "FlickrPublishing.c"
	} else {
		const gchar* _tmp31_ = NULL;
#line 498 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp31_ = token_secret;
#line 498 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp29_ = _tmp31_ == NULL;
#line 3594 "FlickrPublishing.c"
	}
#line 498 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (_tmp29_) {
#line 498 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp28_ = TRUE;
#line 3600 "FlickrPublishing.c"
	} else {
		const gchar* _tmp32_ = NULL;
#line 498 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp32_ = username;
#line 498 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp28_ = _tmp32_ == NULL;
#line 3607 "FlickrPublishing.c"
	}
#line 498 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (_tmp28_) {
#line 3611 "FlickrPublishing.c"
		SpitPublishingPluginHost* _tmp33_ = NULL;
		GError* _tmp34_ = NULL;
		GError* _tmp35_ = NULL;
#line 499 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp33_ = self->priv->host;
#line 499 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp34_ = g_error_new_literal (SPIT_PUBLISHING_PUBLISHING_ERROR, SPIT_PUBLISHING_PUBLISHING_ERROR_MALFORMED_RESPONSE, "expected " "access phase credentials to contain token, token secret, and username " \
"but at " "least one of these is absent");
#line 499 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp35_ = _tmp34_;
#line 499 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		spit_publishing_plugin_host_post_error (_tmp33_, _tmp35_);
#line 499 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_error_free0 (_tmp35_);
#line 3625 "FlickrPublishing.c"
	}
#line 503 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp36_ = self->priv->session;
#line 503 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp37_ = token;
#line 503 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp38_ = token_secret;
#line 503 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp39_ = username;
#line 503 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_session_set_access_phase_credentials (_tmp36_, _tmp37_, _tmp38_, _tmp39_);
#line 470 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (username);
#line 470 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (token_secret);
#line 470 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (token);
#line 470 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	key_value_pairs = (_vala_array_free (key_value_pairs, key_value_pairs_length1, (GDestroyNotify) g_free), NULL);
#line 3645 "FlickrPublishing.c"
}


static void publishing_flickr_flickr_publisher_do_fetch_account_info (PublishingFlickrFlickrPublisher* self) {
	SpitPublishingPluginHost* _tmp0_ = NULL;
	SpitPublishingPluginHost* _tmp1_ = NULL;
	PublishingFlickrAccountInfoFetchTransaction* txn = NULL;
	PublishingFlickrSession* _tmp2_ = NULL;
	PublishingFlickrAccountInfoFetchTransaction* _tmp3_ = NULL;
	GError * _inner_error_ = NULL;
#line 506 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_FLICKR_PUBLISHER (self));
#line 507 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_debug ("FlickrPublishing.vala:507: ACTION: running network transaction to fetc" \
"h account information");
#line 509 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = self->priv->host;
#line 509 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	spit_publishing_plugin_host_set_service_locked (_tmp0_, TRUE);
#line 510 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = self->priv->host;
#line 510 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	spit_publishing_plugin_host_install_account_fetch_wait_pane (_tmp1_);
#line 512 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp2_ = self->priv->session;
#line 512 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp3_ = publishing_flickr_account_info_fetch_transaction_new (_tmp2_);
#line 512 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	txn = _tmp3_;
#line 513 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (txn, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "completed", (GCallback) _publishing_flickr_flickr_publisher_on_account_fetch_txn_completed_publishing_rest_support_transaction_completed, self, 0);
#line 514 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (txn, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "network-error", (GCallback) _publishing_flickr_flickr_publisher_on_account_fetch_txn_error_publishing_rest_support_transaction_network_error, self, 0);
#line 3678 "FlickrPublishing.c"
	{
#line 517 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		publishing_rest_support_transaction_execute (G_TYPE_CHECK_INSTANCE_CAST (txn, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), &_inner_error_);
#line 517 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 517 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 3686 "FlickrPublishing.c"
				goto __catch20_spit_publishing_publishing_error;
			}
#line 517 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_publishing_rest_support_transaction_unref0 (txn);
#line 517 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 517 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			g_clear_error (&_inner_error_);
#line 517 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			return;
#line 3697 "FlickrPublishing.c"
		}
	}
	goto __finally20;
	__catch20_spit_publishing_publishing_error:
	{
		GError* err = NULL;
		SpitPublishingPluginHost* _tmp4_ = NULL;
		GError* _tmp5_ = NULL;
#line 516 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		err = _inner_error_;
#line 516 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_inner_error_ = NULL;
#line 519 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp4_ = self->priv->host;
#line 519 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp5_ = err;
#line 519 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		spit_publishing_plugin_host_post_error (_tmp4_, _tmp5_);
#line 516 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_error_free0 (err);
#line 3718 "FlickrPublishing.c"
	}
	__finally20:
#line 516 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 516 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_publishing_rest_support_transaction_unref0 (txn);
#line 516 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 516 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_clear_error (&_inner_error_);
#line 516 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		return;
#line 3731 "FlickrPublishing.c"
	}
#line 506 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_publishing_rest_support_transaction_unref0 (txn);
#line 3735 "FlickrPublishing.c"
}


static void publishing_flickr_flickr_publisher_do_parse_account_info_from_xml (PublishingFlickrFlickrPublisher* self, const gchar* xml) {
	const gchar* _tmp0_ = NULL;
	GError * _inner_error_ = NULL;
#line 523 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_FLICKR_PUBLISHER (self));
#line 523 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (xml != NULL);
#line 524 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = xml;
#line 524 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_debug ("FlickrPublishing.vala:524: ACTION: parsing account information from xm" \
"l = '%s'", _tmp0_);
#line 3750 "FlickrPublishing.c"
	{
		PublishingRESTSupportXmlDocument* response_doc = NULL;
		const gchar* _tmp1_ = NULL;
		PublishingRESTSupportXmlDocument* _tmp2_ = NULL;
		xmlNode* root_node = NULL;
		PublishingRESTSupportXmlDocument* _tmp3_ = NULL;
		xmlNode* _tmp4_ = NULL;
		xmlNode* user_node = NULL;
		PublishingRESTSupportXmlDocument* _tmp5_ = NULL;
		xmlNode* _tmp6_ = NULL;
		xmlNode* _tmp7_ = NULL;
		gchar* is_pro_str = NULL;
		PublishingRESTSupportXmlDocument* _tmp8_ = NULL;
		xmlNode* _tmp9_ = NULL;
		gchar* _tmp10_ = NULL;
		xmlNode* bandwidth_node = NULL;
		PublishingRESTSupportXmlDocument* _tmp11_ = NULL;
		xmlNode* _tmp12_ = NULL;
		xmlNode* _tmp13_ = NULL;
		gchar* remaining_kb_str = NULL;
		PublishingRESTSupportXmlDocument* _tmp14_ = NULL;
		xmlNode* _tmp15_ = NULL;
		gchar* _tmp16_ = NULL;
		PublishingFlickrUserKind user_kind = 0;
		const gchar* _tmp17_ = NULL;
		gint quota_mb_left = 0;
		const gchar* _tmp20_ = NULL;
		gint _tmp21_ = 0;
		PublishingFlickrPublishingParameters* _tmp22_ = NULL;
		gint _tmp23_ = 0;
		PublishingFlickrPublishingParameters* _tmp24_ = NULL;
		PublishingFlickrUserKind _tmp25_ = 0;
#line 526 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp1_ = xml;
#line 526 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp2_ = publishing_flickr_transaction_parse_flickr_response (_tmp1_, &_inner_error_);
#line 526 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		response_doc = _tmp2_;
#line 526 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 526 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 3793 "FlickrPublishing.c"
				goto __catch21_spit_publishing_publishing_error;
			}
#line 526 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 526 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			g_clear_error (&_inner_error_);
#line 526 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			return;
#line 3802 "FlickrPublishing.c"
		}
#line 527 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp3_ = response_doc;
#line 527 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp4_ = publishing_rest_support_xml_document_get_root_node (_tmp3_);
#line 527 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		root_node = _tmp4_;
#line 529 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp5_ = response_doc;
#line 529 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp6_ = root_node;
#line 529 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp7_ = publishing_rest_support_xml_document_get_named_child (_tmp5_, _tmp6_, "user", &_inner_error_);
#line 529 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		user_node = _tmp7_;
#line 529 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 529 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_publishing_rest_support_xml_document_unref0 (response_doc);
#line 529 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 3824 "FlickrPublishing.c"
				goto __catch21_spit_publishing_publishing_error;
			}
#line 529 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_publishing_rest_support_xml_document_unref0 (response_doc);
#line 529 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 529 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			g_clear_error (&_inner_error_);
#line 529 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			return;
#line 3835 "FlickrPublishing.c"
		}
#line 531 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp8_ = response_doc;
#line 531 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp9_ = user_node;
#line 531 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp10_ = publishing_rest_support_xml_document_get_property_value (_tmp8_, _tmp9_, "ispro", &_inner_error_);
#line 531 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		is_pro_str = _tmp10_;
#line 531 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 531 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_publishing_rest_support_xml_document_unref0 (response_doc);
#line 531 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 3851 "FlickrPublishing.c"
				goto __catch21_spit_publishing_publishing_error;
			}
#line 531 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_publishing_rest_support_xml_document_unref0 (response_doc);
#line 531 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 531 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			g_clear_error (&_inner_error_);
#line 531 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			return;
#line 3862 "FlickrPublishing.c"
		}
#line 533 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp11_ = response_doc;
#line 533 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp12_ = user_node;
#line 533 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp13_ = publishing_rest_support_xml_document_get_named_child (_tmp11_, _tmp12_, "bandwidth", &_inner_error_);
#line 533 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		bandwidth_node = _tmp13_;
#line 533 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 533 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_g_free0 (is_pro_str);
#line 533 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_publishing_rest_support_xml_document_unref0 (response_doc);
#line 533 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 3880 "FlickrPublishing.c"
				goto __catch21_spit_publishing_publishing_error;
			}
#line 533 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_g_free0 (is_pro_str);
#line 533 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_publishing_rest_support_xml_document_unref0 (response_doc);
#line 533 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 533 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			g_clear_error (&_inner_error_);
#line 533 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			return;
#line 3893 "FlickrPublishing.c"
		}
#line 535 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp14_ = response_doc;
#line 535 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp15_ = bandwidth_node;
#line 535 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp16_ = publishing_rest_support_xml_document_get_property_value (_tmp14_, _tmp15_, "remainingkb", &_inner_error_);
#line 535 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		remaining_kb_str = _tmp16_;
#line 535 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 535 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_g_free0 (is_pro_str);
#line 535 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_publishing_rest_support_xml_document_unref0 (response_doc);
#line 535 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 3911 "FlickrPublishing.c"
				goto __catch21_spit_publishing_publishing_error;
			}
#line 535 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_g_free0 (is_pro_str);
#line 535 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_publishing_rest_support_xml_document_unref0 (response_doc);
#line 535 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 535 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			g_clear_error (&_inner_error_);
#line 535 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			return;
#line 3924 "FlickrPublishing.c"
		}
#line 538 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp17_ = is_pro_str;
#line 538 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		if (g_strcmp0 (_tmp17_, "0") == 0) {
#line 539 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			user_kind = PUBLISHING_FLICKR_USER_KIND_FREE;
#line 3932 "FlickrPublishing.c"
		} else {
			const gchar* _tmp18_ = NULL;
#line 540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_tmp18_ = is_pro_str;
#line 540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			if (g_strcmp0 (_tmp18_, "1") == 0) {
#line 541 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				user_kind = PUBLISHING_FLICKR_USER_KIND_PRO;
#line 3941 "FlickrPublishing.c"
			} else {
				GError* _tmp19_ = NULL;
#line 543 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp19_ = g_error_new_literal (SPIT_PUBLISHING_PUBLISHING_ERROR, SPIT_PUBLISHING_PUBLISHING_ERROR_MALFORMED_RESPONSE, "Unable to determine if user has free or pro account");
#line 543 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_inner_error_ = _tmp19_;
#line 543 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_g_free0 (remaining_kb_str);
#line 543 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_g_free0 (is_pro_str);
#line 543 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_publishing_rest_support_xml_document_unref0 (response_doc);
#line 543 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 3956 "FlickrPublishing.c"
					goto __catch21_spit_publishing_publishing_error;
				}
#line 543 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_g_free0 (remaining_kb_str);
#line 543 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_g_free0 (is_pro_str);
#line 543 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_publishing_rest_support_xml_document_unref0 (response_doc);
#line 543 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 543 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				g_clear_error (&_inner_error_);
#line 543 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				return;
#line 3971 "FlickrPublishing.c"
			}
		}
#line 546 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp20_ = remaining_kb_str;
#line 546 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp21_ = atoi (_tmp20_);
#line 546 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		quota_mb_left = _tmp21_ / 1024;
#line 548 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp22_ = self->priv->parameters;
#line 548 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp23_ = quota_mb_left;
#line 548 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp22_->quota_free_mb = _tmp23_;
#line 549 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp24_ = self->priv->parameters;
#line 549 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp25_ = user_kind;
#line 549 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp24_->user_kind = _tmp25_;
#line 525 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_free0 (remaining_kb_str);
#line 525 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_free0 (is_pro_str);
#line 525 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_publishing_rest_support_xml_document_unref0 (response_doc);
#line 3998 "FlickrPublishing.c"
	}
	goto __finally21;
	__catch21_spit_publishing_publishing_error:
	{
		GError* err = NULL;
		GError* _tmp26_ = NULL;
		SpitPublishingPluginHost* _tmp27_ = NULL;
		GError* _tmp28_ = NULL;
#line 525 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		err = _inner_error_;
#line 525 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_inner_error_ = NULL;
#line 555 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp26_ = err;
#line 555 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		if (g_error_matches (_tmp26_, SPIT_PUBLISHING_PUBLISHING_ERROR, SPIT_PUBLISHING_PUBLISHING_ERROR_EXPIRED_SESSION)) {
#line 556 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			publishing_flickr_flickr_publisher_do_logout (self);
#line 557 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_g_error_free0 (err);
#line 557 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			return;
#line 4021 "FlickrPublishing.c"
		}
#line 560 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp27_ = self->priv->host;
#line 560 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp28_ = err;
#line 560 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		spit_publishing_plugin_host_post_error (_tmp27_, _tmp28_);
#line 561 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_error_free0 (err);
#line 561 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		return;
#line 4033 "FlickrPublishing.c"
	}
	__finally21:
#line 525 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 525 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 525 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_clear_error (&_inner_error_);
#line 525 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		return;
#line 4044 "FlickrPublishing.c"
	}
#line 564 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_flickr_publisher_on_account_info_available (self);
#line 4048 "FlickrPublishing.c"
}


static void publishing_flickr_flickr_publisher_do_logout (PublishingFlickrFlickrPublisher* self) {
	PublishingFlickrSession* _tmp0_ = NULL;
#line 567 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_FLICKR_PUBLISHER (self));
#line 568 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_debug ("FlickrPublishing.vala:568: ACTION: logging user out, deauthenticating " \
"session, and erasing stored credentials");
#line 570 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = self->priv->session;
#line 570 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_session_deauthenticate (_tmp0_);
#line 571 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_flickr_publisher_invalidate_persistent_session (self);
#line 573 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->running = FALSE;
#line 575 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_flickr_publisher_attempt_start (self);
#line 4068 "FlickrPublishing.c"
}


static void publishing_flickr_flickr_publisher_do_show_publishing_options_pane (PublishingFlickrFlickrPublisher* self) {
	SpitPublishingPluginHost* _tmp0_ = NULL;
	GtkBuilder* builder = NULL;
	GtkBuilder* _tmp1_ = NULL;
	PublishingFlickrPublishingParameters* _tmp9_ = NULL;
	SpitPublishingPluginHost* _tmp10_ = NULL;
	SpitPublishingPublisherMediaType _tmp11_ = 0;
	GtkBuilder* _tmp12_ = NULL;
	gboolean _tmp13_ = FALSE;
	PublishingFlickrPublishingOptionsPane* _tmp14_ = NULL;
	PublishingFlickrPublishingOptionsPane* _tmp15_ = NULL;
	PublishingFlickrPublishingOptionsPane* _tmp16_ = NULL;
	SpitPublishingPluginHost* _tmp17_ = NULL;
	PublishingFlickrPublishingOptionsPane* _tmp18_ = NULL;
	GError * _inner_error_ = NULL;
#line 578 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_FLICKR_PUBLISHER (self));
#line 579 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_debug ("FlickrPublishing.vala:579: ACTION: displaying publishing options pane");
#line 581 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = self->priv->host;
#line 581 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	spit_publishing_plugin_host_set_service_locked (_tmp0_, FALSE);
#line 583 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = gtk_builder_new ();
#line 583 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	builder = _tmp1_;
#line 4099 "FlickrPublishing.c"
	{
		GtkBuilder* _tmp2_ = NULL;
#line 588 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp2_ = builder;
#line 588 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		gtk_builder_add_from_resource (_tmp2_, PLUGIN_RESOURCE_PATH "/" "flickr_publishing_options_pane.ui", &_inner_error_);
#line 588 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 4108 "FlickrPublishing.c"
			goto __catch22_g_error;
		}
	}
	goto __finally22;
	__catch22_g_error:
	{
		GError* e = NULL;
		GError* _tmp3_ = NULL;
		const gchar* _tmp4_ = NULL;
		SpitPublishingPluginHost* _tmp5_ = NULL;
		const gchar* _tmp6_ = NULL;
		GError* _tmp7_ = NULL;
		GError* _tmp8_ = NULL;
#line 585 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		e = _inner_error_;
#line 585 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_inner_error_ = NULL;
#line 591 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp3_ = e;
#line 591 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp4_ = _tmp3_->message;
#line 591 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_warning ("FlickrPublishing.vala:591: Could not parse UI file! Error: %s.", _tmp4_);
#line 592 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp5_ = self->priv->host;
#line 592 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp6_ = _ ("A file required for publishing is unavailable. Publishing to Flickr ca" \
"n't continue.");
#line 592 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp7_ = g_error_new_literal (SPIT_PUBLISHING_PUBLISHING_ERROR, SPIT_PUBLISHING_PUBLISHING_ERROR_LOCAL_FILE_ERROR, _tmp6_);
#line 592 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp8_ = _tmp7_;
#line 592 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		spit_publishing_plugin_host_post_error (_tmp5_, _tmp8_);
#line 592 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_error_free0 (_tmp8_);
#line 595 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_error_free0 (e);
#line 595 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_object_unref0 (builder);
#line 595 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		return;
#line 4150 "FlickrPublishing.c"
	}
	__finally22:
#line 585 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 585 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_object_unref0 (builder);
#line 585 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 585 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_clear_error (&_inner_error_);
#line 585 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		return;
#line 4163 "FlickrPublishing.c"
	}
#line 598 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp9_ = self->priv->parameters;
#line 598 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp10_ = self->priv->host;
#line 598 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp11_ = spit_publishing_plugin_host_get_publishable_media_type (_tmp10_);
#line 598 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp12_ = builder;
#line 598 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp13_ = publishing_flickr_flickr_publisher_get_persistent_strip_metadata (self);
#line 598 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp14_ = publishing_flickr_publishing_options_pane_new (self, _tmp9_, _tmp11_, _tmp12_, _tmp13_);
#line 598 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (self->priv->publishing_options_pane);
#line 598 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->publishing_options_pane = _tmp14_;
#line 600 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp15_ = self->priv->publishing_options_pane;
#line 600 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_connect_object (_tmp15_, "publish", (GCallback) _publishing_flickr_flickr_publisher_on_publishing_options_pane_publish_publishing_flickr_publishing_options_pane_publish, self, 0);
#line 601 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp16_ = self->priv->publishing_options_pane;
#line 601 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_connect_object (_tmp16_, "logout", (GCallback) _publishing_flickr_flickr_publisher_on_publishing_options_pane_logout_publishing_flickr_publishing_options_pane_logout, self, 0);
#line 602 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp17_ = self->priv->host;
#line 602 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp18_ = self->priv->publishing_options_pane;
#line 602 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	spit_publishing_plugin_host_install_dialog_pane (_tmp17_, G_TYPE_CHECK_INSTANCE_CAST (_tmp18_, SPIT_PUBLISHING_TYPE_DIALOG_PANE, SpitPublishingDialogPane), SPIT_PUBLISHING_PLUGIN_HOST_BUTTON_MODE_CANCEL);
#line 578 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (builder);
#line 4197 "FlickrPublishing.c"
}


gint publishing_flickr_flickr_publisher_flickr_date_time_compare_func (SpitPublishingPublishable* a, SpitPublishingPublishable* b) {
	gint result = 0;
	SpitPublishingPublishable* _tmp0_ = NULL;
	GDateTime* _tmp1_ = NULL;
	GDateTime* _tmp2_ = NULL;
	SpitPublishingPublishable* _tmp3_ = NULL;
	GDateTime* _tmp4_ = NULL;
	GDateTime* _tmp5_ = NULL;
	gint _tmp6_ = 0;
	gint _tmp7_ = 0;
#line 605 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (SPIT_PUBLISHING_IS_PUBLISHABLE (a), 0);
#line 605 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (SPIT_PUBLISHING_IS_PUBLISHABLE (b), 0);
#line 607 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = a;
#line 607 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = spit_publishing_publishable_get_exposure_date_time (_tmp0_);
#line 607 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp2_ = _tmp1_;
#line 607 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp3_ = b;
#line 607 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp4_ = spit_publishing_publishable_get_exposure_date_time (_tmp3_);
#line 607 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp5_ = _tmp4_;
#line 607 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp6_ = g_date_time_compare (_tmp2_, _tmp5_);
#line 607 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp7_ = _tmp6_;
#line 607 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_date_time_unref0 (_tmp5_);
#line 607 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_date_time_unref0 (_tmp2_);
#line 607 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	result = _tmp7_;
#line 607 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return result;
#line 4239 "FlickrPublishing.c"
}


static gint _publishing_flickr_flickr_publisher_flickr_date_time_compare_func_gcompare_data_func (gconstpointer a, gconstpointer b, gpointer self) {
	gint result;
	result = publishing_flickr_flickr_publisher_flickr_date_time_compare_func ((SpitPublishingPublishable*) a, (SpitPublishingPublishable*) b);
#line 631 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return result;
#line 4248 "FlickrPublishing.c"
}


static void _publishing_flickr_flickr_publisher_on_upload_status_updated_spit_publishing_progress_callback (gint file_number, gdouble fraction_complete, gpointer self) {
#line 636 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_flickr_publisher_on_upload_status_updated ((PublishingFlickrFlickrPublisher*) self, file_number, fraction_complete);
#line 4255 "FlickrPublishing.c"
}


static void publishing_flickr_flickr_publisher_do_publish (PublishingFlickrFlickrPublisher* self, gboolean strip_metadata) {
	gboolean _tmp0_ = FALSE;
	SpitPublishingPluginHost* _tmp1_ = NULL;
	SpitPublishingPluginHost* _tmp2_ = NULL;
	PublishingFlickrPublishingParameters* _tmp3_ = NULL;
	gint _tmp4_ = 0;
	gboolean _tmp5_ = FALSE;
	void* _tmp6_ = NULL;
	GDestroyNotify _tmp7_ = NULL;
	SpitPublishingProgressCallback _tmp8_ = NULL;
	gboolean _tmp9_ = FALSE;
	SpitPublishingPublishable** publishables = NULL;
	SpitPublishingPluginHost* _tmp10_ = NULL;
	gint _tmp11_ = 0;
	SpitPublishingPublishable** _tmp12_ = NULL;
	gint publishables_length1 = 0;
	gint _publishables_size_ = 0;
	GeeArrayList* sorted_list = NULL;
	GeeArrayList* _tmp13_ = NULL;
	SpitPublishingPublishable** _tmp14_ = NULL;
	gint _tmp14__length1 = 0;
	GeeArrayList* _tmp18_ = NULL;
	PublishingFlickrUploader* uploader = NULL;
	PublishingFlickrSession* _tmp19_ = NULL;
	GeeArrayList* _tmp20_ = NULL;
	gint _tmp21_ = 0;
	gpointer* _tmp22_ = NULL;
	SpitPublishingPublishable** _tmp23_ = NULL;
	gint _tmp23__length1 = 0;
	PublishingFlickrPublishingParameters* _tmp24_ = NULL;
	gboolean _tmp25_ = FALSE;
	PublishingFlickrUploader* _tmp26_ = NULL;
	PublishingFlickrUploader* _tmp27_ = NULL;
	PublishingFlickrUploader* _tmp28_ = NULL;
	PublishingFlickrUploader* _tmp29_ = NULL;
	PublishingFlickrUploader* _tmp30_ = NULL;
#line 610 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_FLICKR_PUBLISHER (self));
#line 611 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = strip_metadata;
#line 611 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_flickr_publisher_set_persistent_strip_metadata (self, _tmp0_);
#line 612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_debug ("FlickrPublishing.vala:612: ACTION: uploading media items to remote ser" \
"ver.");
#line 614 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = self->priv->host;
#line 614 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	spit_publishing_plugin_host_set_service_locked (_tmp1_, TRUE);
#line 615 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp2_ = self->priv->host;
#line 615 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp3_ = self->priv->parameters;
#line 615 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp4_ = _tmp3_->photo_major_axis_size;
#line 615 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp5_ = strip_metadata;
#line 615 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp8_ = spit_publishing_plugin_host_serialize_publishables (_tmp2_, _tmp4_, _tmp5_, &_tmp6_, &_tmp7_);
#line 615 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	(self->priv->progress_reporter_target_destroy_notify == NULL) ? NULL : (self->priv->progress_reporter_target_destroy_notify (self->priv->progress_reporter_target), NULL);
#line 615 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->progress_reporter = NULL;
#line 615 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->progress_reporter_target = NULL;
#line 615 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->progress_reporter_target_destroy_notify = NULL;
#line 615 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->progress_reporter = _tmp8_;
#line 615 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->progress_reporter_target = _tmp6_;
#line 615 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->progress_reporter_target_destroy_notify = _tmp7_;
#line 621 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp9_ = spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher));
#line 621 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (!_tmp9_) {
#line 622 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		return;
#line 4337 "FlickrPublishing.c"
	}
#line 625 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp10_ = self->priv->host;
#line 625 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp12_ = spit_publishing_plugin_host_get_publishables (_tmp10_, &_tmp11_);
#line 625 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishables = _tmp12_;
#line 625 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishables_length1 = _tmp11_;
#line 625 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_publishables_size_ = publishables_length1;
#line 626 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp13_ = gee_array_list_new (SPIT_PUBLISHING_TYPE_PUBLISHABLE, (GBoxedCopyFunc) g_object_ref, g_object_unref, NULL, NULL, NULL);
#line 626 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	sorted_list = _tmp13_;
#line 628 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp14_ = publishables;
#line 628 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp14__length1 = publishables_length1;
#line 4357 "FlickrPublishing.c"
	{
		SpitPublishingPublishable** p_collection = NULL;
		gint p_collection_length1 = 0;
		gint _p_collection_size_ = 0;
		gint p_it = 0;
#line 628 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		p_collection = _tmp14_;
#line 628 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		p_collection_length1 = _tmp14__length1;
#line 628 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		for (p_it = 0; p_it < _tmp14__length1; p_it = p_it + 1) {
#line 4369 "FlickrPublishing.c"
			SpitPublishingPublishable* _tmp15_ = NULL;
			SpitPublishingPublishable* p = NULL;
#line 628 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_tmp15_ = _g_object_ref0 (p_collection[p_it]);
#line 628 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			p = _tmp15_;
#line 4376 "FlickrPublishing.c"
			{
				GeeArrayList* _tmp16_ = NULL;
				SpitPublishingPublishable* _tmp17_ = NULL;
#line 629 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp16_ = sorted_list;
#line 629 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp17_ = p;
#line 629 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				gee_abstract_collection_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp16_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection), _tmp17_);
#line 628 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_g_object_unref0 (p);
#line 4388 "FlickrPublishing.c"
			}
		}
	}
#line 631 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp18_ = sorted_list;
#line 631 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	gee_list_sort (G_TYPE_CHECK_INSTANCE_CAST (_tmp18_, GEE_TYPE_LIST, GeeList), _publishing_flickr_flickr_publisher_flickr_date_time_compare_func_gcompare_data_func, NULL, NULL);
#line 633 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp19_ = self->priv->session;
#line 633 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp20_ = sorted_list;
#line 633 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp22_ = gee_collection_to_array (G_TYPE_CHECK_INSTANCE_CAST (_tmp20_, GEE_TYPE_COLLECTION, GeeCollection), &_tmp21_);
#line 633 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp23_ = _tmp22_;
#line 633 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp23__length1 = _tmp21_;
#line 633 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp24_ = self->priv->parameters;
#line 633 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp25_ = strip_metadata;
#line 633 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp26_ = publishing_flickr_uploader_new (_tmp19_, _tmp23_, _tmp21_, _tmp24_, _tmp25_);
#line 633 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp27_ = _tmp26_;
#line 633 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp23_ = (_vala_array_free (_tmp23_, _tmp23__length1, (GDestroyNotify) g_object_unref), NULL);
#line 633 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	uploader = _tmp27_;
#line 634 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp28_ = uploader;
#line 634 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp28_, PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, PublishingRESTSupportBatchUploader), "upload-complete", (GCallback) _publishing_flickr_flickr_publisher_on_upload_complete_publishing_rest_support_batch_uploader_upload_complete, self, 0);
#line 635 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp29_ = uploader;
#line 635 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp29_, PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, PublishingRESTSupportBatchUploader), "upload-error", (GCallback) _publishing_flickr_flickr_publisher_on_upload_error_publishing_rest_support_batch_uploader_upload_error, self, 0);
#line 636 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp30_ = uploader;
#line 636 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_rest_support_batch_uploader_upload (G_TYPE_CHECK_INSTANCE_CAST (_tmp30_, PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, PublishingRESTSupportBatchUploader), _publishing_flickr_flickr_publisher_on_upload_status_updated_spit_publishing_progress_callback, self);
#line 610 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_publishing_rest_support_batch_uploader_unref0 (uploader);
#line 610 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (sorted_list);
#line 610 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishables = (_vala_array_free (publishables, publishables_length1, (GDestroyNotify) g_object_unref), NULL);
#line 4436 "FlickrPublishing.c"
}


static void publishing_flickr_flickr_publisher_do_show_success_pane (PublishingFlickrFlickrPublisher* self) {
	SpitPublishingPluginHost* _tmp0_ = NULL;
	SpitPublishingPluginHost* _tmp1_ = NULL;
#line 639 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_FLICKR_PUBLISHER (self));
#line 640 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_debug ("FlickrPublishing.vala:640: ACTION: showing success pane.");
#line 642 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = self->priv->host;
#line 642 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	spit_publishing_plugin_host_set_service_locked (_tmp0_, FALSE);
#line 643 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = self->priv->host;
#line 643 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	spit_publishing_plugin_host_install_success_pane (_tmp1_);
#line 4455 "FlickrPublishing.c"
}


gint publishing_flickr_flickr_publisher_get_persistent_visibility (PublishingFlickrFlickrPublisher* self) {
	gint result = 0;
	SpitPublishingPluginHost* _tmp0_ = NULL;
	gint _tmp1_ = 0;
#line 646 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (PUBLISHING_FLICKR_IS_FLICKR_PUBLISHER (self), 0);
#line 647 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = self->priv->host;
#line 647 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = spit_host_interface_get_config_int (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "visibility", 0);
#line 647 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	result = _tmp1_;
#line 647 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return result;
#line 4473 "FlickrPublishing.c"
}


void publishing_flickr_flickr_publisher_set_persistent_visibility (PublishingFlickrFlickrPublisher* self, gint vis) {
	SpitPublishingPluginHost* _tmp0_ = NULL;
	gint _tmp1_ = 0;
#line 650 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_FLICKR_PUBLISHER (self));
#line 651 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = self->priv->host;
#line 651 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = vis;
#line 651 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	spit_host_interface_set_config_int (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "visibility", _tmp1_);
#line 4488 "FlickrPublishing.c"
}


gint publishing_flickr_flickr_publisher_get_persistent_default_size (PublishingFlickrFlickrPublisher* self) {
	gint result = 0;
	SpitPublishingPluginHost* _tmp0_ = NULL;
	gint _tmp1_ = 0;
#line 654 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (PUBLISHING_FLICKR_IS_FLICKR_PUBLISHER (self), 0);
#line 655 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = self->priv->host;
#line 655 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = spit_host_interface_get_config_int (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "default_size", 1);
#line 655 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	result = _tmp1_;
#line 655 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return result;
#line 4506 "FlickrPublishing.c"
}


void publishing_flickr_flickr_publisher_set_persistent_default_size (PublishingFlickrFlickrPublisher* self, gint size) {
	SpitPublishingPluginHost* _tmp0_ = NULL;
	gint _tmp1_ = 0;
#line 658 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_FLICKR_PUBLISHER (self));
#line 659 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = self->priv->host;
#line 659 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = size;
#line 659 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	spit_host_interface_set_config_int (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "default_size", _tmp1_);
#line 4521 "FlickrPublishing.c"
}


static SpitPublishingService* publishing_flickr_flickr_publisher_real_get_service (SpitPublishingPublisher* base) {
	PublishingFlickrFlickrPublisher * self;
	SpitPublishingService* result = NULL;
	SpitPublishingService* _tmp0_ = NULL;
	SpitPublishingService* _tmp1_ = NULL;
#line 662 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_FLICKR_TYPE_FLICKR_PUBLISHER, PublishingFlickrFlickrPublisher);
#line 663 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = self->priv->service;
#line 663 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 663 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	result = _tmp1_;
#line 663 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return result;
#line 4540 "FlickrPublishing.c"
}


static gboolean publishing_flickr_flickr_publisher_real_is_running (SpitPublishingPublisher* base) {
	PublishingFlickrFlickrPublisher * self;
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
#line 666 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_FLICKR_TYPE_FLICKR_PUBLISHER, PublishingFlickrFlickrPublisher);
#line 667 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = self->priv->running;
#line 667 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	result = _tmp0_;
#line 667 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return result;
#line 4556 "FlickrPublishing.c"
}


static void publishing_flickr_flickr_publisher_attempt_start (PublishingFlickrFlickrPublisher* self) {
	gboolean _tmp0_ = FALSE;
#line 672 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_FLICKR_PUBLISHER (self));
#line 673 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->running = TRUE;
#line 674 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->was_started = TRUE;
#line 676 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = publishing_flickr_flickr_publisher_is_persistent_session_valid (self);
#line 676 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (_tmp0_) {
#line 4572 "FlickrPublishing.c"
		PublishingFlickrSession* _tmp1_ = NULL;
		gchar* _tmp2_ = NULL;
		gchar* _tmp3_ = NULL;
		gchar* _tmp4_ = NULL;
		gchar* _tmp5_ = NULL;
		gchar* _tmp6_ = NULL;
		gchar* _tmp7_ = NULL;
#line 677 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_debug ("FlickrPublishing.vala:677: attempt start: a persistent session is avai" \
"lable; using it");
#line 679 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp1_ = self->priv->session;
#line 679 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp2_ = publishing_flickr_flickr_publisher_get_persistent_access_phase_token (self);
#line 679 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp3_ = _tmp2_;
#line 679 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp4_ = publishing_flickr_flickr_publisher_get_persistent_access_phase_token_secret (self);
#line 679 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp5_ = _tmp4_;
#line 679 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp6_ = publishing_flickr_flickr_publisher_get_persistent_access_phase_username (self);
#line 679 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp7_ = _tmp6_;
#line 679 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		publishing_flickr_session_authenticate_from_persistent_credentials (_tmp1_, _tmp3_, _tmp5_, _tmp7_);
#line 679 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_free0 (_tmp7_);
#line 679 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_free0 (_tmp5_);
#line 679 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_free0 (_tmp3_);
#line 4604 "FlickrPublishing.c"
	} else {
#line 682 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_debug ("FlickrPublishing.vala:682: attempt start: no persistent session availa" \
"ble; showing login welcome pane");
#line 684 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		publishing_flickr_flickr_publisher_do_show_login_welcome_pane (self);
#line 4610 "FlickrPublishing.c"
	}
}


static void publishing_flickr_flickr_publisher_real_start (SpitPublishingPublisher* base) {
	PublishingFlickrFlickrPublisher * self;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
#line 688 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_FLICKR_TYPE_FLICKR_PUBLISHER, PublishingFlickrFlickrPublisher);
#line 689 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher));
#line 689 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (_tmp0_) {
#line 690 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		return;
#line 4627 "FlickrPublishing.c"
	}
#line 692 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = self->priv->was_started;
#line 692 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (_tmp1_) {
#line 693 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_error ("FlickrPublishing.vala:693: FlickrPublisher: start( ): can't start; thi" \
"s publisher is not restartable.");
#line 4635 "FlickrPublishing.c"
	}
#line 695 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_debug ("FlickrPublishing.vala:695: FlickrPublisher: starting interaction.");
#line 697 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_flickr_publisher_attempt_start (self);
#line 4641 "FlickrPublishing.c"
}


static void publishing_flickr_flickr_publisher_real_stop (SpitPublishingPublisher* base) {
	PublishingFlickrFlickrPublisher * self;
	PublishingFlickrSession* _tmp0_ = NULL;
#line 700 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_FLICKR_TYPE_FLICKR_PUBLISHER, PublishingFlickrFlickrPublisher);
#line 701 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_debug ("FlickrPublishing.vala:701: FlickrPublisher: stop( ) invoked.");
#line 703 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = self->priv->session;
#line 703 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (_tmp0_ != NULL) {
#line 4656 "FlickrPublishing.c"
		PublishingFlickrSession* _tmp1_ = NULL;
#line 704 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp1_ = self->priv->session;
#line 704 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		publishing_rest_support_session_stop_transactions (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession));
#line 4662 "FlickrPublishing.c"
	}
#line 706 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->running = FALSE;
#line 4666 "FlickrPublishing.c"
}


static void publishing_flickr_flickr_publisher_class_init (PublishingFlickrFlickrPublisherClass * klass) {
#line 99 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_flickr_publisher_parent_class = g_type_class_peek_parent (klass);
#line 99 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_type_class_add_private (klass, sizeof (PublishingFlickrFlickrPublisherPrivate));
#line 99 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	G_OBJECT_CLASS (klass)->finalize = publishing_flickr_flickr_publisher_finalize;
#line 4677 "FlickrPublishing.c"
}


static void publishing_flickr_flickr_publisher_spit_publishing_publisher_interface_init (SpitPublishingPublisherIface * iface) {
#line 99 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_flickr_publisher_spit_publishing_publisher_parent_iface = g_type_interface_peek_parent (iface);
#line 99 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	iface->get_service = (SpitPublishingService* (*)(SpitPublishingPublisher*)) publishing_flickr_flickr_publisher_real_get_service;
#line 99 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	iface->is_running = (gboolean (*)(SpitPublishingPublisher*)) publishing_flickr_flickr_publisher_real_is_running;
#line 99 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	iface->start = (void (*)(SpitPublishingPublisher*)) publishing_flickr_flickr_publisher_real_start;
#line 99 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	iface->stop = (void (*)(SpitPublishingPublisher*)) publishing_flickr_flickr_publisher_real_stop;
#line 4692 "FlickrPublishing.c"
}


static void publishing_flickr_flickr_publisher_instance_init (PublishingFlickrFlickrPublisher * self) {
#line 99 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv = PUBLISHING_FLICKR_FLICKR_PUBLISHER_GET_PRIVATE (self);
#line 102 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->progress_reporter = NULL;
#line 103 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->running = FALSE;
#line 104 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->was_started = FALSE;
#line 105 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->session = NULL;
#line 106 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->publishing_options_pane = NULL;
#line 108 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->parameters = NULL;
#line 4711 "FlickrPublishing.c"
}


static void publishing_flickr_flickr_publisher_finalize (GObject* obj) {
	PublishingFlickrFlickrPublisher * self;
	PublishingFlickrSession* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
#line 99 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_FLICKR_TYPE_FLICKR_PUBLISHER, PublishingFlickrFlickrPublisher);
#line 122 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = self->priv->session;
#line 122 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_parse_name ("authenticated", PUBLISHING_REST_SUPPORT_TYPE_SESSION, &_tmp1_, NULL, FALSE);
#line 122 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_handlers_disconnect_matched (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession), G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_flickr_flickr_publisher_on_session_authenticated_publishing_rest_support_session_authenticated, self);
#line 100 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (self->priv->service);
#line 101 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (self->priv->host);
#line 102 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	(self->priv->progress_reporter_target_destroy_notify == NULL) ? NULL : (self->priv->progress_reporter_target_destroy_notify (self->priv->progress_reporter_target), NULL);
#line 102 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->progress_reporter = NULL;
#line 102 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->progress_reporter_target = NULL;
#line 102 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->progress_reporter_target_destroy_notify = NULL;
#line 105 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_publishing_rest_support_session_unref0 (self->priv->session);
#line 106 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (self->priv->publishing_options_pane);
#line 108 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_publishing_flickr_publishing_parameters_unref0 (self->priv->parameters);
#line 99 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	G_OBJECT_CLASS (publishing_flickr_flickr_publisher_parent_class)->finalize (obj);
#line 4747 "FlickrPublishing.c"
}


GType publishing_flickr_flickr_publisher_get_type (void) {
	static volatile gsize publishing_flickr_flickr_publisher_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_flickr_flickr_publisher_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingFlickrFlickrPublisherClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_flickr_flickr_publisher_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingFlickrFlickrPublisher), 0, (GInstanceInitFunc) publishing_flickr_flickr_publisher_instance_init, NULL };
		static const GInterfaceInfo spit_publishing_publisher_info = { (GInterfaceInitFunc) publishing_flickr_flickr_publisher_spit_publishing_publisher_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType publishing_flickr_flickr_publisher_type_id;
		publishing_flickr_flickr_publisher_type_id = g_type_register_static (G_TYPE_OBJECT, "PublishingFlickrFlickrPublisher", &g_define_type_info, 0);
		g_type_add_interface_static (publishing_flickr_flickr_publisher_type_id, SPIT_PUBLISHING_TYPE_PUBLISHER, &spit_publishing_publisher_info);
		g_once_init_leave (&publishing_flickr_flickr_publisher_type_id__volatile, publishing_flickr_flickr_publisher_type_id);
	}
	return publishing_flickr_flickr_publisher_type_id__volatile;
}


PublishingFlickrPinEntryPane* publishing_flickr_pin_entry_pane_construct (GType object_type, GtkBuilder* builder) {
	PublishingFlickrPinEntryPane * self = NULL;
	GtkBuilder* _tmp0_ = NULL;
	GtkBuilder* _tmp1_ = NULL;
	GtkBuilder* _tmp2_ = NULL;
	GtkBuilder* _tmp3_ = NULL;
	GSList* _tmp4_ = NULL;
	GSList* _tmp5_ = NULL;
	guint _tmp6_ = 0U;
	GtkBuilder* _tmp7_ = NULL;
	GObject* _tmp8_ = NULL;
	GtkLabel* _tmp9_ = NULL;
	GtkBuilder* _tmp10_ = NULL;
	GObject* _tmp11_ = NULL;
	GtkLabel* _tmp12_ = NULL;
	GtkBuilder* _tmp13_ = NULL;
	GObject* _tmp14_ = NULL;
	GtkEntry* _tmp15_ = NULL;
	GtkBuilder* _tmp16_ = NULL;
	GObject* _tmp17_ = NULL;
	GtkButton* _tmp18_ = NULL;
	GtkBuilder* _tmp19_ = NULL;
	GObject* _tmp20_ = NULL;
	GtkBox* _tmp21_ = NULL;
	GtkBox* _tmp22_ = NULL;
#line 720 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (GTK_IS_BUILDER (builder), NULL);
#line 720 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = (PublishingFlickrPinEntryPane*) g_object_new (object_type, NULL);
#line 721 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = builder;
#line 721 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 721 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (self->priv->builder);
#line 721 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->builder = _tmp1_;
#line 722 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp2_ = builder;
#line 722 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_vala_assert (_tmp2_ != NULL, "builder != null");
#line 723 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp3_ = builder;
#line 723 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp4_ = gtk_builder_get_objects (_tmp3_);
#line 723 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp5_ = _tmp4_;
#line 723 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp6_ = g_slist_length (_tmp5_);
#line 723 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_vala_assert (_tmp6_ > ((guint) 0), "builder.get_objects().length() > 0");
#line 723 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_slist_free0 (_tmp5_);
#line 725 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp7_ = builder;
#line 725 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp8_ = gtk_builder_get_object (_tmp7_, "explanatory_text");
#line 725 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp9_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp8_, gtk_label_get_type ()) ? ((GtkLabel*) _tmp8_) : NULL);
#line 725 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (self->priv->explanatory_text);
#line 725 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->explanatory_text = _tmp9_;
#line 726 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp10_ = builder;
#line 726 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp11_ = gtk_builder_get_object (_tmp10_, "pin_entry_caption");
#line 726 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp12_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp11_, gtk_label_get_type ()) ? ((GtkLabel*) _tmp11_) : NULL);
#line 726 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (self->priv->pin_entry_caption);
#line 726 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->pin_entry_caption = _tmp12_;
#line 727 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp13_ = builder;
#line 727 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp14_ = gtk_builder_get_object (_tmp13_, "pin_entry");
#line 727 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp15_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp14_, gtk_entry_get_type ()) ? ((GtkEntry*) _tmp14_) : NULL);
#line 727 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (self->priv->pin_entry);
#line 727 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->pin_entry = _tmp15_;
#line 728 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp16_ = builder;
#line 728 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp17_ = gtk_builder_get_object (_tmp16_, "continue_button");
#line 728 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp18_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp17_, gtk_button_get_type ()) ? ((GtkButton*) _tmp17_) : NULL);
#line 728 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (self->priv->continue_button);
#line 728 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->continue_button = _tmp18_;
#line 730 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp19_ = builder;
#line 730 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp20_ = gtk_builder_get_object (_tmp19_, "pane_widget");
#line 730 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp21_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp20_, gtk_box_get_type ()) ? ((GtkBox*) _tmp20_) : NULL);
#line 730 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (self->priv->pane_widget);
#line 730 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->pane_widget = _tmp21_;
#line 732 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp22_ = self->priv->pane_widget;
#line 732 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	gtk_widget_show_all (G_TYPE_CHECK_INSTANCE_CAST (_tmp22_, gtk_widget_get_type (), GtkWidget));
#line 734 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_pin_entry_pane_on_pin_entry_contents_changed (self);
#line 720 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return self;
#line 4876 "FlickrPublishing.c"
}


PublishingFlickrPinEntryPane* publishing_flickr_pin_entry_pane_new (GtkBuilder* builder) {
#line 720 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return publishing_flickr_pin_entry_pane_construct (PUBLISHING_FLICKR_TYPE_PIN_ENTRY_PANE, builder);
#line 4883 "FlickrPublishing.c"
}


static void publishing_flickr_pin_entry_pane_on_continue_clicked (PublishingFlickrPinEntryPane* self) {
	GtkEntry* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
#line 737 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_PIN_ENTRY_PANE (self));
#line 738 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = self->priv->pin_entry;
#line 738 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = gtk_entry_get_text (_tmp0_);
#line 738 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_emit_by_name (self, "proceed", self, _tmp1_);
#line 4898 "FlickrPublishing.c"
}


static void publishing_flickr_pin_entry_pane_on_pin_entry_contents_changed (PublishingFlickrPinEntryPane* self) {
	GtkButton* _tmp0_ = NULL;
	GtkEntry* _tmp1_ = NULL;
	guint _tmp2_ = 0U;
	guint _tmp3_ = 0U;
#line 741 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_PIN_ENTRY_PANE (self));
#line 742 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = self->priv->continue_button;
#line 742 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = self->priv->pin_entry;
#line 742 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp2_ = gtk_entry_get_text_length (_tmp1_);
#line 742 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp3_ = _tmp2_;
#line 742 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_widget_get_type (), GtkWidget), _tmp3_ > ((guint) 0));
#line 4919 "FlickrPublishing.c"
}


static GtkWidget* publishing_flickr_pin_entry_pane_real_get_widget (SpitPublishingDialogPane* base) {
	PublishingFlickrPinEntryPane * self;
	GtkWidget* result = NULL;
	GtkBox* _tmp0_ = NULL;
	GtkWidget* _tmp1_ = NULL;
#line 745 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_FLICKR_TYPE_PIN_ENTRY_PANE, PublishingFlickrPinEntryPane);
#line 746 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = self->priv->pane_widget;
#line 746 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_widget_get_type (), GtkWidget));
#line 746 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	result = _tmp1_;
#line 746 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return result;
#line 4938 "FlickrPublishing.c"
}


static SpitPublishingDialogPaneGeometryOptions publishing_flickr_pin_entry_pane_real_get_preferred_geometry (SpitPublishingDialogPane* base) {
	PublishingFlickrPinEntryPane * self;
	SpitPublishingDialogPaneGeometryOptions result = 0;
#line 749 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_FLICKR_TYPE_PIN_ENTRY_PANE, PublishingFlickrPinEntryPane);
#line 750 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	result = SPIT_PUBLISHING_DIALOG_PANE_GEOMETRY_OPTIONS_NONE;
#line 750 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return result;
#line 4951 "FlickrPublishing.c"
}


static void _publishing_flickr_pin_entry_pane_on_continue_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 754 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_pin_entry_pane_on_continue_clicked ((PublishingFlickrPinEntryPane*) self);
#line 4958 "FlickrPublishing.c"
}


static void _publishing_flickr_pin_entry_pane_on_pin_entry_contents_changed_gtk_editable_changed (GtkEditable* _sender, gpointer self) {
#line 755 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_pin_entry_pane_on_pin_entry_contents_changed ((PublishingFlickrPinEntryPane*) self);
#line 4965 "FlickrPublishing.c"
}


static void publishing_flickr_pin_entry_pane_real_on_pane_installed (SpitPublishingDialogPane* base) {
	PublishingFlickrPinEntryPane * self;
	GtkButton* _tmp0_ = NULL;
	GtkEntry* _tmp1_ = NULL;
#line 753 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_FLICKR_TYPE_PIN_ENTRY_PANE, PublishingFlickrPinEntryPane);
#line 754 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = self->priv->continue_button;
#line 754 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_connect_object (_tmp0_, "clicked", (GCallback) _publishing_flickr_pin_entry_pane_on_continue_clicked_gtk_button_clicked, self, 0);
#line 755 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = self->priv->pin_entry;
#line 755 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, GTK_TYPE_EDITABLE, GtkEditable), "changed", (GCallback) _publishing_flickr_pin_entry_pane_on_pin_entry_contents_changed_gtk_editable_changed, self, 0);
#line 4983 "FlickrPublishing.c"
}


static void publishing_flickr_pin_entry_pane_real_on_pane_uninstalled (SpitPublishingDialogPane* base) {
	PublishingFlickrPinEntryPane * self;
	GtkButton* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
	GtkEntry* _tmp2_ = NULL;
	guint _tmp3_ = 0U;
#line 758 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_FLICKR_TYPE_PIN_ENTRY_PANE, PublishingFlickrPinEntryPane);
#line 759 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = self->priv->continue_button;
#line 759 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_parse_name ("clicked", gtk_button_get_type (), &_tmp1_, NULL, FALSE);
#line 759 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_flickr_pin_entry_pane_on_continue_clicked_gtk_button_clicked, self);
#line 760 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp2_ = self->priv->pin_entry;
#line 760 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_parse_name ("changed", GTK_TYPE_EDITABLE, &_tmp3_, NULL, FALSE);
#line 760 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_handlers_disconnect_matched (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, GTK_TYPE_EDITABLE, GtkEditable), G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _publishing_flickr_pin_entry_pane_on_pin_entry_contents_changed_gtk_editable_changed, self);
#line 5007 "FlickrPublishing.c"
}


static void g_cclosure_user_marshal_VOID__OBJECT_STRING (GClosure * closure, GValue * return_value, guint n_param_values, const GValue * param_values, gpointer invocation_hint, gpointer marshal_data) {
	typedef void (*GMarshalFunc_VOID__OBJECT_STRING) (gpointer data1, gpointer arg_1, const char* arg_2, gpointer data2);
	register GMarshalFunc_VOID__OBJECT_STRING callback;
	register GCClosure * cc;
	register gpointer data1;
	register gpointer data2;
	cc = (GCClosure *) closure;
#line 710 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (n_param_values == 3);
#line 710 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (G_CCLOSURE_SWAP_DATA (closure)) {
#line 710 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		data1 = closure->data;
#line 710 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		data2 = param_values->data[0].v_pointer;
#line 5026 "FlickrPublishing.c"
	} else {
#line 710 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		data1 = param_values->data[0].v_pointer;
#line 710 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		data2 = closure->data;
#line 5032 "FlickrPublishing.c"
	}
#line 710 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	callback = (GMarshalFunc_VOID__OBJECT_STRING) (marshal_data ? marshal_data : cc->callback);
#line 710 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	callback (data1, g_value_get_object (param_values + 1), g_value_get_string (param_values + 2), data2);
#line 5038 "FlickrPublishing.c"
}


static void publishing_flickr_pin_entry_pane_class_init (PublishingFlickrPinEntryPaneClass * klass) {
#line 710 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_pin_entry_pane_parent_class = g_type_class_peek_parent (klass);
#line 710 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_type_class_add_private (klass, sizeof (PublishingFlickrPinEntryPanePrivate));
#line 710 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	G_OBJECT_CLASS (klass)->finalize = publishing_flickr_pin_entry_pane_finalize;
#line 710 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_new ("proceed", PUBLISHING_FLICKR_TYPE_PIN_ENTRY_PANE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_user_marshal_VOID__OBJECT_STRING, G_TYPE_NONE, 2, PUBLISHING_FLICKR_TYPE_PIN_ENTRY_PANE, G_TYPE_STRING);
#line 5051 "FlickrPublishing.c"
}


static void publishing_flickr_pin_entry_pane_spit_publishing_dialog_pane_interface_init (SpitPublishingDialogPaneIface * iface) {
#line 710 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_pin_entry_pane_spit_publishing_dialog_pane_parent_iface = g_type_interface_peek_parent (iface);
#line 710 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	iface->get_widget = (GtkWidget* (*)(SpitPublishingDialogPane*)) publishing_flickr_pin_entry_pane_real_get_widget;
#line 710 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	iface->get_preferred_geometry = (SpitPublishingDialogPaneGeometryOptions (*)(SpitPublishingDialogPane*)) publishing_flickr_pin_entry_pane_real_get_preferred_geometry;
#line 710 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	iface->on_pane_installed = (void (*)(SpitPublishingDialogPane*)) publishing_flickr_pin_entry_pane_real_on_pane_installed;
#line 710 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	iface->on_pane_uninstalled = (void (*)(SpitPublishingDialogPane*)) publishing_flickr_pin_entry_pane_real_on_pane_uninstalled;
#line 5066 "FlickrPublishing.c"
}


static void publishing_flickr_pin_entry_pane_instance_init (PublishingFlickrPinEntryPane * self) {
#line 710 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv = PUBLISHING_FLICKR_PIN_ENTRY_PANE_GET_PRIVATE (self);
#line 711 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->pane_widget = NULL;
#line 712 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->continue_button = NULL;
#line 713 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->pin_entry = NULL;
#line 714 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->pin_entry_caption = NULL;
#line 715 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->explanatory_text = NULL;
#line 716 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->builder = NULL;
#line 5085 "FlickrPublishing.c"
}


static void publishing_flickr_pin_entry_pane_finalize (GObject* obj) {
	PublishingFlickrPinEntryPane * self;
#line 710 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_FLICKR_TYPE_PIN_ENTRY_PANE, PublishingFlickrPinEntryPane);
#line 711 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (self->priv->pane_widget);
#line 712 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (self->priv->continue_button);
#line 713 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (self->priv->pin_entry);
#line 714 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (self->priv->pin_entry_caption);
#line 715 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (self->priv->explanatory_text);
#line 716 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (self->priv->builder);
#line 710 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	G_OBJECT_CLASS (publishing_flickr_pin_entry_pane_parent_class)->finalize (obj);
#line 5107 "FlickrPublishing.c"
}


GType publishing_flickr_pin_entry_pane_get_type (void) {
	static volatile gsize publishing_flickr_pin_entry_pane_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_flickr_pin_entry_pane_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingFlickrPinEntryPaneClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_flickr_pin_entry_pane_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingFlickrPinEntryPane), 0, (GInstanceInitFunc) publishing_flickr_pin_entry_pane_instance_init, NULL };
		static const GInterfaceInfo spit_publishing_dialog_pane_info = { (GInterfaceInitFunc) publishing_flickr_pin_entry_pane_spit_publishing_dialog_pane_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType publishing_flickr_pin_entry_pane_type_id;
		publishing_flickr_pin_entry_pane_type_id = g_type_register_static (G_TYPE_OBJECT, "PublishingFlickrPinEntryPane", &g_define_type_info, 0);
		g_type_add_interface_static (publishing_flickr_pin_entry_pane_type_id, SPIT_PUBLISHING_TYPE_DIALOG_PANE, &spit_publishing_dialog_pane_info);
		g_once_init_leave (&publishing_flickr_pin_entry_pane_type_id__volatile, publishing_flickr_pin_entry_pane_type_id);
	}
	return publishing_flickr_pin_entry_pane_type_id__volatile;
}


PublishingFlickrTransaction* publishing_flickr_transaction_construct (GType object_type, PublishingFlickrSession* session, PublishingRESTSupportHttpMethod method) {
	PublishingFlickrTransaction* self = NULL;
	PublishingFlickrSession* _tmp0_ = NULL;
	PublishingRESTSupportHttpMethod _tmp1_ = 0;
	PublishingFlickrSession* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	PublishingFlickrSession* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
#line 765 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (PUBLISHING_FLICKR_IS_SESSION (session), NULL);
#line 767 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = session;
#line 767 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = method;
#line 767 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = (PublishingFlickrTransaction*) publishing_rest_support_transaction_construct (object_type, G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession), _tmp1_);
#line 769 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp2_ = session;
#line 769 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp3_ = publishing_flickr_session_get_oauth_nonce (_tmp2_);
#line 769 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp4_ = _tmp3_;
#line 769 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "oauth_nonce", _tmp4_);
#line 769 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (_tmp4_);
#line 770 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "oauth_signature_method", "HMAC-SHA1");
#line 771 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "oauth_version", "1.0");
#line 772 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "oauth_callback", "oob");
#line 773 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp5_ = session;
#line 773 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp6_ = publishing_flickr_session_get_oauth_timestamp (_tmp5_);
#line 773 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp7_ = _tmp6_;
#line 773 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "oauth_timestamp", _tmp7_);
#line 773 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (_tmp7_);
#line 774 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "oauth_consumer_key", PUBLISHING_FLICKR_API_KEY);
#line 765 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return self;
#line 5173 "FlickrPublishing.c"
}


PublishingFlickrTransaction* publishing_flickr_transaction_new (PublishingFlickrSession* session, PublishingRESTSupportHttpMethod method) {
#line 765 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return publishing_flickr_transaction_construct (PUBLISHING_FLICKR_TYPE_TRANSACTION, session, method);
#line 5180 "FlickrPublishing.c"
}


PublishingFlickrTransaction* publishing_flickr_transaction_construct_with_uri (GType object_type, PublishingFlickrSession* session, const gchar* uri, PublishingRESTSupportHttpMethod method) {
	PublishingFlickrTransaction* self = NULL;
	PublishingFlickrSession* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	PublishingRESTSupportHttpMethod _tmp2_ = 0;
	PublishingFlickrSession* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	PublishingFlickrSession* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
	gchar* _tmp8_ = NULL;
#line 777 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (PUBLISHING_FLICKR_IS_SESSION (session), NULL);
#line 777 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (uri != NULL, NULL);
#line 779 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = session;
#line 779 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = uri;
#line 779 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp2_ = method;
#line 779 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = (PublishingFlickrTransaction*) publishing_rest_support_transaction_construct_with_endpoint_url (object_type, G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession), _tmp1_, _tmp2_);
#line 781 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp3_ = session;
#line 781 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp4_ = publishing_flickr_session_get_oauth_nonce (_tmp3_);
#line 781 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp5_ = _tmp4_;
#line 781 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "oauth_nonce", _tmp5_);
#line 781 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (_tmp5_);
#line 782 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "oauth_signature_method", "HMAC-SHA1");
#line 783 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "oauth_version", "1.0");
#line 784 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "oauth_callback", "oob");
#line 785 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp6_ = session;
#line 785 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp7_ = publishing_flickr_session_get_oauth_timestamp (_tmp6_);
#line 785 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp8_ = _tmp7_;
#line 785 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "oauth_timestamp", _tmp8_);
#line 785 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (_tmp8_);
#line 786 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "oauth_consumer_key", PUBLISHING_FLICKR_API_KEY);
#line 777 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return self;
#line 5237 "FlickrPublishing.c"
}


PublishingFlickrTransaction* publishing_flickr_transaction_new_with_uri (PublishingFlickrSession* session, const gchar* uri, PublishingRESTSupportHttpMethod method) {
#line 777 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return publishing_flickr_transaction_construct_with_uri (PUBLISHING_FLICKR_TYPE_TRANSACTION, session, uri, method);
#line 5244 "FlickrPublishing.c"
}


static void publishing_flickr_transaction_real_execute (PublishingRESTSupportTransaction* base, GError** error) {
	PublishingFlickrTransaction * self;
	PublishingRESTSupportSession* _tmp0_ = NULL;
	PublishingFlickrSession* _tmp1_ = NULL;
	GError * _inner_error_ = NULL;
#line 789 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_FLICKR_TYPE_TRANSACTION, PublishingFlickrTransaction);
#line 790 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = publishing_rest_support_transaction_get_parent_session (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction));
#line 790 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, PUBLISHING_FLICKR_TYPE_SESSION, PublishingFlickrSession);
#line 790 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_session_sign_transaction (_tmp1_, G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction));
#line 790 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_publishing_rest_support_session_unref0 (_tmp1_);
#line 792 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	PUBLISHING_REST_SUPPORT_TRANSACTION_CLASS (publishing_flickr_transaction_parent_class)->execute (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), &_inner_error_);
#line 792 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 792 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 792 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			g_propagate_error (error, _inner_error_);
#line 792 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			return;
#line 5273 "FlickrPublishing.c"
		} else {
#line 792 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 792 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			g_clear_error (&_inner_error_);
#line 792 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			return;
#line 5281 "FlickrPublishing.c"
		}
	}
}


gchar* publishing_flickr_transaction_validate_xml (PublishingRESTSupportXmlDocument* doc) {
	gchar* result = NULL;
	xmlNode* root = NULL;
	PublishingRESTSupportXmlDocument* _tmp0_ = NULL;
	xmlNode* _tmp1_ = NULL;
	gchar* status = NULL;
	xmlNode* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	const gchar* _tmp6_ = NULL;
	xmlNode* errcode = NULL;
	xmlNode* _tmp12_ = NULL;
	gchar* _tmp13_ = NULL;
	gchar* _tmp14_ = NULL;
	xmlNode* _tmp15_ = NULL;
	gchar* _tmp16_ = NULL;
	gchar* _tmp17_ = NULL;
	gchar* _tmp18_ = NULL;
	gchar* _tmp19_ = NULL;
	GError * _inner_error_ = NULL;
#line 795 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (PUBLISHING_REST_SUPPORT_IS_XML_DOCUMENT (doc), NULL);
#line 796 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = doc;
#line 796 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = publishing_rest_support_xml_document_get_root_node (_tmp0_);
#line 796 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	root = _tmp1_;
#line 797 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp2_ = root;
#line 797 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp3_ = (gchar*) xmlGetProp (_tmp2_, (xmlChar*) "stat");
#line 797 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	status = _tmp3_;
#line 800 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp4_ = status;
#line 800 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (_tmp4_ == NULL) {
#line 5325 "FlickrPublishing.c"
		gchar* _tmp5_ = NULL;
#line 801 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp5_ = g_strdup ("No status property in root node");
#line 801 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		result = _tmp5_;
#line 801 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_free0 (status);
#line 801 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		return result;
#line 5335 "FlickrPublishing.c"
	}
#line 803 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp6_ = status;
#line 803 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (g_strcmp0 (_tmp6_, "ok") == 0) {
#line 804 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		result = NULL;
#line 804 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_free0 (status);
#line 804 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		return result;
#line 5347 "FlickrPublishing.c"
	}
	{
		xmlNode* _tmp7_ = NULL;
		PublishingRESTSupportXmlDocument* _tmp8_ = NULL;
		xmlNode* _tmp9_ = NULL;
		xmlNode* _tmp10_ = NULL;
#line 808 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp8_ = doc;
#line 808 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp9_ = root;
#line 808 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp10_ = publishing_rest_support_xml_document_get_named_child (_tmp8_, _tmp9_, "err", &_inner_error_);
#line 808 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp7_ = _tmp10_;
#line 808 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 808 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 5366 "FlickrPublishing.c"
				goto __catch23_spit_publishing_publishing_error;
			}
#line 808 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_g_free0 (status);
#line 808 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 808 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			g_clear_error (&_inner_error_);
#line 808 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			return NULL;
#line 5377 "FlickrPublishing.c"
		}
#line 808 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		errcode = _tmp7_;
#line 5381 "FlickrPublishing.c"
	}
	goto __finally23;
	__catch23_spit_publishing_publishing_error:
	{
		GError* err = NULL;
		gchar* _tmp11_ = NULL;
#line 807 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		err = _inner_error_;
#line 807 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_inner_error_ = NULL;
#line 810 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp11_ = g_strdup ("No error code specified");
#line 810 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		result = _tmp11_;
#line 810 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_error_free0 (err);
#line 810 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_free0 (status);
#line 810 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		return result;
#line 5402 "FlickrPublishing.c"
	}
	__finally23:
#line 807 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 807 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_free0 (status);
#line 807 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 807 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_clear_error (&_inner_error_);
#line 807 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		return NULL;
#line 5415 "FlickrPublishing.c"
	}
#line 816 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp12_ = errcode;
#line 816 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp13_ = (gchar*) xmlGetProp (_tmp12_, (xmlChar*) "msg");
#line 816 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp14_ = _tmp13_;
#line 816 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp15_ = errcode;
#line 816 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp16_ = (gchar*) xmlGetProp (_tmp15_, (xmlChar*) "code");
#line 816 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp17_ = _tmp16_;
#line 816 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp18_ = g_strdup_printf ("%s (error code %s)", _tmp14_, _tmp17_);
#line 816 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp19_ = _tmp18_;
#line 816 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (_tmp17_);
#line 816 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (_tmp14_);
#line 816 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	result = _tmp19_;
#line 816 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (status);
#line 816 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return result;
#line 5443 "FlickrPublishing.c"
}


static gchar* _publishing_flickr_transaction_validate_xml_publishing_rest_support_xml_document_check_for_error_response (PublishingRESTSupportXmlDocument* doc, gpointer self) {
	gchar* result;
	result = publishing_flickr_transaction_validate_xml (doc);
#line 831 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return result;
#line 5452 "FlickrPublishing.c"
}


static gboolean string_contains (const gchar* self, const gchar* needle) {
	gboolean result = FALSE;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 1376 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, FALSE);
#line 1376 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	g_return_val_if_fail (needle != NULL, FALSE);
#line 1377 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp0_ = needle;
#line 1377 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp1_ = strstr ((gchar*) self, (gchar*) _tmp0_);
#line 1377 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	result = _tmp1_ != NULL;
#line 1377 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	return result;
#line 5472 "FlickrPublishing.c"
}


static gpointer _g_error_copy0 (gpointer self) {
#line 836 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return self ? g_error_copy (self) : NULL;
#line 5479 "FlickrPublishing.c"
}


PublishingRESTSupportXmlDocument* publishing_flickr_transaction_parse_flickr_response (const gchar* xml, GError** error) {
	PublishingRESTSupportXmlDocument* result = NULL;
	PublishingRESTSupportXmlDocument* _result_ = NULL;
	GError * _inner_error_ = NULL;
#line 826 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (xml != NULL, NULL);
#line 828 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_result_ = NULL;
#line 5491 "FlickrPublishing.c"
	{
		PublishingRESTSupportXmlDocument* _tmp0_ = NULL;
		const gchar* _tmp1_ = NULL;
		PublishingRESTSupportXmlDocument* _tmp2_ = NULL;
		PublishingRESTSupportXmlDocument* _tmp3_ = NULL;
#line 831 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp1_ = xml;
#line 831 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp2_ = publishing_rest_support_xml_document_parse_string (_tmp1_, _publishing_flickr_transaction_validate_xml_publishing_rest_support_xml_document_check_for_error_response, NULL, &_inner_error_);
#line 831 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp0_ = _tmp2_;
#line 831 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 831 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 5507 "FlickrPublishing.c"
				goto __catch24_spit_publishing_publishing_error;
			}
#line 831 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_publishing_rest_support_xml_document_unref0 (_result_);
#line 831 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 831 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			g_clear_error (&_inner_error_);
#line 831 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			return NULL;
#line 5518 "FlickrPublishing.c"
		}
#line 831 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp3_ = _tmp0_;
#line 831 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp0_ = NULL;
#line 831 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_publishing_rest_support_xml_document_unref0 (_result_);
#line 831 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_result_ = _tmp3_;
#line 830 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_publishing_rest_support_xml_document_unref0 (_tmp0_);
#line 5530 "FlickrPublishing.c"
	}
	goto __finally24;
	__catch24_spit_publishing_publishing_error:
	{
		GError* e = NULL;
		GError* _tmp4_ = NULL;
		const gchar* _tmp5_ = NULL;
		gchar* _tmp6_ = NULL;
		gchar* _tmp7_ = NULL;
		gboolean _tmp8_ = FALSE;
		gboolean _tmp9_ = FALSE;
#line 830 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		e = _inner_error_;
#line 830 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_inner_error_ = NULL;
#line 833 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp4_ = e;
#line 833 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp5_ = _tmp4_->message;
#line 833 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp6_ = g_strdup_printf ("(error code %s)", PUBLISHING_FLICKR_EXPIRED_SESSION_ERROR_CODE);
#line 833 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp7_ = _tmp6_;
#line 833 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp8_ = string_contains (_tmp5_, _tmp7_);
#line 833 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp9_ = _tmp8_;
#line 833 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_free0 (_tmp7_);
#line 833 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		if (_tmp9_) {
#line 5562 "FlickrPublishing.c"
			GError* _tmp10_ = NULL;
			const gchar* _tmp11_ = NULL;
			GError* _tmp12_ = NULL;
#line 834 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_tmp10_ = e;
#line 834 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_tmp11_ = _tmp10_->message;
#line 834 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_tmp12_ = g_error_new_literal (SPIT_PUBLISHING_PUBLISHING_ERROR, SPIT_PUBLISHING_PUBLISHING_ERROR_EXPIRED_SESSION, _tmp11_);
#line 834 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_inner_error_ = _tmp12_;
#line 834 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_g_error_free0 (e);
#line 5576 "FlickrPublishing.c"
			goto __finally24;
		} else {
			GError* _tmp13_ = NULL;
			GError* _tmp14_ = NULL;
#line 836 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_tmp13_ = e;
#line 836 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_tmp14_ = _g_error_copy0 (_tmp13_);
#line 836 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_inner_error_ = _tmp14_;
#line 836 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_g_error_free0 (e);
#line 5589 "FlickrPublishing.c"
			goto __finally24;
		}
#line 830 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_error_free0 (e);
#line 5594 "FlickrPublishing.c"
	}
	__finally24:
#line 830 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 830 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 830 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			g_propagate_error (error, _inner_error_);
#line 830 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_publishing_rest_support_xml_document_unref0 (_result_);
#line 830 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			return NULL;
#line 5607 "FlickrPublishing.c"
		} else {
#line 830 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_publishing_rest_support_xml_document_unref0 (_result_);
#line 830 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 830 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			g_clear_error (&_inner_error_);
#line 830 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			return NULL;
#line 5617 "FlickrPublishing.c"
		}
	}
#line 840 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	result = _result_;
#line 840 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return result;
#line 5624 "FlickrPublishing.c"
}


static void publishing_flickr_transaction_class_init (PublishingFlickrTransactionClass * klass) {
#line 764 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_transaction_parent_class = g_type_class_peek_parent (klass);
#line 764 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	((PublishingRESTSupportTransactionClass *) klass)->execute = publishing_flickr_transaction_real_execute;
#line 5633 "FlickrPublishing.c"
}


static void publishing_flickr_transaction_instance_init (PublishingFlickrTransaction * self) {
}


GType publishing_flickr_transaction_get_type (void) {
	static volatile gsize publishing_flickr_transaction_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_flickr_transaction_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingFlickrTransactionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_flickr_transaction_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingFlickrTransaction), 0, (GInstanceInitFunc) publishing_flickr_transaction_instance_init, NULL };
		GType publishing_flickr_transaction_type_id;
		publishing_flickr_transaction_type_id = g_type_register_static (PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, "PublishingFlickrTransaction", &g_define_type_info, 0);
		g_once_init_leave (&publishing_flickr_transaction_type_id__volatile, publishing_flickr_transaction_type_id);
	}
	return publishing_flickr_transaction_type_id__volatile;
}


PublishingFlickrAuthenticationRequestTransaction* publishing_flickr_authentication_request_transaction_construct (GType object_type, PublishingFlickrSession* session) {
	PublishingFlickrAuthenticationRequestTransaction* self = NULL;
	PublishingFlickrSession* _tmp0_ = NULL;
#line 845 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (PUBLISHING_FLICKR_IS_SESSION (session), NULL);
#line 846 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = session;
#line 846 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = (PublishingFlickrAuthenticationRequestTransaction*) publishing_flickr_transaction_construct_with_uri (object_type, _tmp0_, "https://www.flickr.com/services/oauth/request_token", PUBLISHING_REST_SUPPORT_HTTP_METHOD_GET);
#line 845 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return self;
#line 5664 "FlickrPublishing.c"
}


PublishingFlickrAuthenticationRequestTransaction* publishing_flickr_authentication_request_transaction_new (PublishingFlickrSession* session) {
#line 845 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return publishing_flickr_authentication_request_transaction_construct (PUBLISHING_FLICKR_TYPE_AUTHENTICATION_REQUEST_TRANSACTION, session);
#line 5671 "FlickrPublishing.c"
}


static void publishing_flickr_authentication_request_transaction_class_init (PublishingFlickrAuthenticationRequestTransactionClass * klass) {
#line 844 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_authentication_request_transaction_parent_class = g_type_class_peek_parent (klass);
#line 5678 "FlickrPublishing.c"
}


static void publishing_flickr_authentication_request_transaction_instance_init (PublishingFlickrAuthenticationRequestTransaction * self) {
}


GType publishing_flickr_authentication_request_transaction_get_type (void) {
	static volatile gsize publishing_flickr_authentication_request_transaction_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_flickr_authentication_request_transaction_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingFlickrAuthenticationRequestTransactionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_flickr_authentication_request_transaction_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingFlickrAuthenticationRequestTransaction), 0, (GInstanceInitFunc) publishing_flickr_authentication_request_transaction_instance_init, NULL };
		GType publishing_flickr_authentication_request_transaction_type_id;
		publishing_flickr_authentication_request_transaction_type_id = g_type_register_static (PUBLISHING_FLICKR_TYPE_TRANSACTION, "PublishingFlickrAuthenticationRequestTransaction", &g_define_type_info, 0);
		g_once_init_leave (&publishing_flickr_authentication_request_transaction_type_id__volatile, publishing_flickr_authentication_request_transaction_type_id);
	}
	return publishing_flickr_authentication_request_transaction_type_id__volatile;
}


PublishingFlickrAccessTokenFetchTransaction* publishing_flickr_access_token_fetch_transaction_construct (GType object_type, PublishingFlickrSession* session, const gchar* user_verifier) {
	PublishingFlickrAccessTokenFetchTransaction* self = NULL;
	PublishingFlickrSession* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	PublishingFlickrSession* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
#line 852 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (PUBLISHING_FLICKR_IS_SESSION (session), NULL);
#line 852 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (user_verifier != NULL, NULL);
#line 853 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = session;
#line 853 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = (PublishingFlickrAccessTokenFetchTransaction*) publishing_flickr_transaction_construct_with_uri (object_type, _tmp0_, "https://www.flickr.com/services/oauth/access_token", PUBLISHING_REST_SUPPORT_HTTP_METHOD_GET);
#line 855 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = user_verifier;
#line 855 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "oauth_verifier", _tmp1_);
#line 856 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp2_ = session;
#line 856 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp3_ = publishing_flickr_session_get_request_phase_token (_tmp2_);
#line 856 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp4_ = _tmp3_;
#line 856 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "oauth_token", _tmp4_);
#line 856 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (_tmp4_);
#line 852 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return self;
#line 5729 "FlickrPublishing.c"
}


PublishingFlickrAccessTokenFetchTransaction* publishing_flickr_access_token_fetch_transaction_new (PublishingFlickrSession* session, const gchar* user_verifier) {
#line 852 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return publishing_flickr_access_token_fetch_transaction_construct (PUBLISHING_FLICKR_TYPE_ACCESS_TOKEN_FETCH_TRANSACTION, session, user_verifier);
#line 5736 "FlickrPublishing.c"
}


static void publishing_flickr_access_token_fetch_transaction_class_init (PublishingFlickrAccessTokenFetchTransactionClass * klass) {
#line 851 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_access_token_fetch_transaction_parent_class = g_type_class_peek_parent (klass);
#line 5743 "FlickrPublishing.c"
}


static void publishing_flickr_access_token_fetch_transaction_instance_init (PublishingFlickrAccessTokenFetchTransaction * self) {
}


GType publishing_flickr_access_token_fetch_transaction_get_type (void) {
	static volatile gsize publishing_flickr_access_token_fetch_transaction_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_flickr_access_token_fetch_transaction_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingFlickrAccessTokenFetchTransactionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_flickr_access_token_fetch_transaction_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingFlickrAccessTokenFetchTransaction), 0, (GInstanceInitFunc) publishing_flickr_access_token_fetch_transaction_instance_init, NULL };
		GType publishing_flickr_access_token_fetch_transaction_type_id;
		publishing_flickr_access_token_fetch_transaction_type_id = g_type_register_static (PUBLISHING_FLICKR_TYPE_TRANSACTION, "PublishingFlickrAccessTokenFetchTransaction", &g_define_type_info, 0);
		g_once_init_leave (&publishing_flickr_access_token_fetch_transaction_type_id__volatile, publishing_flickr_access_token_fetch_transaction_type_id);
	}
	return publishing_flickr_access_token_fetch_transaction_type_id__volatile;
}


PublishingFlickrAccountInfoFetchTransaction* publishing_flickr_account_info_fetch_transaction_construct (GType object_type, PublishingFlickrSession* session) {
	PublishingFlickrAccountInfoFetchTransaction* self = NULL;
	PublishingFlickrSession* _tmp0_ = NULL;
	PublishingFlickrSession* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (PUBLISHING_FLICKR_IS_SESSION (session), NULL);
#line 862 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = session;
#line 862 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = (PublishingFlickrAccountInfoFetchTransaction*) publishing_flickr_transaction_construct (object_type, _tmp0_, PUBLISHING_REST_SUPPORT_HTTP_METHOD_GET);
#line 863 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "method", "flickr.people.getUploadStatus");
#line 864 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = session;
#line 864 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp2_ = publishing_flickr_session_get_access_phase_token (_tmp1_);
#line 864 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp3_ = _tmp2_;
#line 864 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "oauth_token", _tmp3_);
#line 864 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (_tmp3_);
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return self;
#line 5789 "FlickrPublishing.c"
}


PublishingFlickrAccountInfoFetchTransaction* publishing_flickr_account_info_fetch_transaction_new (PublishingFlickrSession* session) {
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return publishing_flickr_account_info_fetch_transaction_construct (PUBLISHING_FLICKR_TYPE_ACCOUNT_INFO_FETCH_TRANSACTION, session);
#line 5796 "FlickrPublishing.c"
}


static void publishing_flickr_account_info_fetch_transaction_class_init (PublishingFlickrAccountInfoFetchTransactionClass * klass) {
#line 860 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_account_info_fetch_transaction_parent_class = g_type_class_peek_parent (klass);
#line 5803 "FlickrPublishing.c"
}


static void publishing_flickr_account_info_fetch_transaction_instance_init (PublishingFlickrAccountInfoFetchTransaction * self) {
}


GType publishing_flickr_account_info_fetch_transaction_get_type (void) {
	static volatile gsize publishing_flickr_account_info_fetch_transaction_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_flickr_account_info_fetch_transaction_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingFlickrAccountInfoFetchTransactionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_flickr_account_info_fetch_transaction_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingFlickrAccountInfoFetchTransaction), 0, (GInstanceInitFunc) publishing_flickr_account_info_fetch_transaction_instance_init, NULL };
		GType publishing_flickr_account_info_fetch_transaction_type_id;
		publishing_flickr_account_info_fetch_transaction_type_id = g_type_register_static (PUBLISHING_FLICKR_TYPE_TRANSACTION, "PublishingFlickrAccountInfoFetchTransaction", &g_define_type_info, 0);
		g_once_init_leave (&publishing_flickr_account_info_fetch_transaction_type_id__volatile, publishing_flickr_account_info_fetch_transaction_type_id);
	}
	return publishing_flickr_account_info_fetch_transaction_type_id__volatile;
}


static gpointer _publishing_flickr_publishing_parameters_ref0 (gpointer self) {
#line 877 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return self ? publishing_flickr_publishing_parameters_ref (self) : NULL;
#line 5826 "FlickrPublishing.c"
}


static gpointer _publishing_rest_support_session_ref0 (gpointer self) {
#line 878 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return self ? publishing_rest_support_session_ref (self) : NULL;
#line 5833 "FlickrPublishing.c"
}


static void _g_free0_ (gpointer var) {
#line 893 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	var = (g_free (var), NULL);
#line 5840 "FlickrPublishing.c"
}


PublishingFlickrUploadTransaction* publishing_flickr_upload_transaction_construct (GType object_type, PublishingFlickrSession* session, PublishingFlickrPublishingParameters* parameters, SpitPublishingPublishable* publishable) {
	PublishingFlickrUploadTransaction* self = NULL;
	PublishingFlickrSession* _tmp0_ = NULL;
	SpitPublishingPublishable* _tmp1_ = NULL;
	PublishingFlickrPublishingParameters* _tmp2_ = NULL;
	PublishingFlickrPublishingParameters* _tmp3_ = NULL;
	PublishingFlickrSession* _tmp4_ = NULL;
	PublishingFlickrSession* _tmp5_ = NULL;
	PublishingRESTSupportArgument** _tmp6_ = NULL;
	PublishingFlickrSession* _tmp7_ = NULL;
	gchar* _tmp8_ = NULL;
	gchar* _tmp9_ = NULL;
	PublishingFlickrSession* _tmp10_ = NULL;
	gchar* _tmp11_ = NULL;
	gchar* _tmp12_ = NULL;
	PublishingFlickrSession* _tmp13_ = NULL;
	gchar* _tmp14_ = NULL;
	gchar* _tmp15_ = NULL;
	PublishingFlickrPublishingParameters* _tmp16_ = NULL;
	PublishingFlickrVisibilitySpecification* _tmp17_ = NULL;
	gint _tmp18_ = 0;
	gchar* _tmp19_ = NULL;
	gchar* _tmp20_ = NULL;
	PublishingFlickrPublishingParameters* _tmp21_ = NULL;
	PublishingFlickrVisibilitySpecification* _tmp22_ = NULL;
	gint _tmp23_ = 0;
	gchar* _tmp24_ = NULL;
	gchar* _tmp25_ = NULL;
	PublishingFlickrPublishingParameters* _tmp26_ = NULL;
	PublishingFlickrVisibilitySpecification* _tmp27_ = NULL;
	gint _tmp28_ = 0;
	gchar* _tmp29_ = NULL;
	gchar* _tmp30_ = NULL;
	GHashTable* disposition_table = NULL;
	GHashFunc _tmp31_ = NULL;
	GEqualFunc _tmp32_ = NULL;
	GHashTable* _tmp33_ = NULL;
	gchar* filename = NULL;
	SpitPublishingPublishable* _tmp34_ = NULL;
	gchar* _tmp35_ = NULL;
	gboolean _tmp36_ = FALSE;
	const gchar* _tmp37_ = NULL;
	GHashTable* _tmp41_ = NULL;
	gchar* _tmp42_ = NULL;
	SpitPublishingPublishable* _tmp43_ = NULL;
	gchar* _tmp44_ = NULL;
	gchar* _tmp45_ = NULL;
	gchar* _tmp46_ = NULL;
	GHashTable* _tmp47_ = NULL;
	gchar* _tmp48_ = NULL;
	gchar* _tmp49_ = NULL;
	GHashTable* _tmp50_ = NULL;
#line 873 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (PUBLISHING_FLICKR_IS_SESSION (session), NULL);
#line 873 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (PUBLISHING_FLICKR_IS_PUBLISHING_PARAMETERS (parameters), NULL);
#line 873 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (SPIT_PUBLISHING_IS_PUBLISHABLE (publishable), NULL);
#line 875 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = session;
#line 875 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = publishable;
#line 875 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = (PublishingFlickrUploadTransaction*) publishing_rest_support_upload_transaction_construct_with_endpoint_url (object_type, G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession), _tmp1_, "https://api.flickr.com/services/upload");
#line 877 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp2_ = parameters;
#line 877 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp3_ = _publishing_flickr_publishing_parameters_ref0 (_tmp2_);
#line 877 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_publishing_flickr_publishing_parameters_unref0 (self->priv->parameters);
#line 877 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->parameters = _tmp3_;
#line 878 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp4_ = session;
#line 878 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp5_ = _publishing_rest_support_session_ref0 (_tmp4_);
#line 878 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_publishing_rest_support_session_unref0 (self->priv->session);
#line 878 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->session = _tmp5_;
#line 879 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp6_ = g_new0 (PublishingRESTSupportArgument*, 0 + 1);
#line 879 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->auth_header_fields = (_vala_array_free (self->priv->auth_header_fields, self->priv->auth_header_fields_length1, (GDestroyNotify) publishing_rest_support_argument_unref), NULL);
#line 879 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->auth_header_fields = _tmp6_;
#line 879 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->auth_header_fields_length1 = 0;
#line 879 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->_auth_header_fields_size_ = self->priv->auth_header_fields_length1;
#line 881 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp7_ = session;
#line 881 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp8_ = publishing_flickr_session_get_oauth_nonce (_tmp7_);
#line 881 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp9_ = _tmp8_;
#line 881 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_upload_transaction_add_authorization_header_field (self, "oauth_nonce", _tmp9_);
#line 881 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (_tmp9_);
#line 882 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_upload_transaction_add_authorization_header_field (self, "oauth_signature_method", "HMAC-SHA1");
#line 883 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_upload_transaction_add_authorization_header_field (self, "oauth_version", "1.0");
#line 884 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_upload_transaction_add_authorization_header_field (self, "oauth_callback", "oob");
#line 885 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp10_ = session;
#line 885 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp11_ = publishing_flickr_session_get_oauth_timestamp (_tmp10_);
#line 885 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp12_ = _tmp11_;
#line 885 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_upload_transaction_add_authorization_header_field (self, "oauth_timestamp", _tmp12_);
#line 885 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (_tmp12_);
#line 886 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_upload_transaction_add_authorization_header_field (self, "oauth_consumer_key", PUBLISHING_FLICKR_API_KEY);
#line 887 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp13_ = session;
#line 887 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp14_ = publishing_flickr_session_get_access_phase_token (_tmp13_);
#line 887 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp15_ = _tmp14_;
#line 887 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_upload_transaction_add_authorization_header_field (self, "oauth_token", _tmp15_);
#line 887 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (_tmp15_);
#line 889 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp16_ = parameters;
#line 889 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp17_ = _tmp16_->visibility_specification;
#line 889 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp18_ = _tmp17_->everyone_level;
#line 889 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp19_ = g_strdup_printf ("%d", _tmp18_);
#line 889 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp20_ = _tmp19_;
#line 889 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "is_public", _tmp20_);
#line 889 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (_tmp20_);
#line 890 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp21_ = parameters;
#line 890 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp22_ = _tmp21_->visibility_specification;
#line 890 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp23_ = _tmp22_->friends_level;
#line 890 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp24_ = g_strdup_printf ("%d", _tmp23_);
#line 890 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp25_ = _tmp24_;
#line 890 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "is_friend", _tmp25_);
#line 890 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (_tmp25_);
#line 891 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp26_ = parameters;
#line 891 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp27_ = _tmp26_->visibility_specification;
#line 891 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp28_ = _tmp27_->family_level;
#line 891 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp29_ = g_strdup_printf ("%d", _tmp28_);
#line 891 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp30_ = _tmp29_;
#line 891 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "is_family", _tmp30_);
#line 891 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (_tmp30_);
#line 893 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp31_ = g_str_hash;
#line 893 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp32_ = g_str_equal;
#line 893 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp33_ = g_hash_table_new_full (_tmp31_, _tmp32_, _g_free0_, _g_free0_);
#line 893 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	disposition_table = _tmp33_;
#line 895 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp34_ = publishable;
#line 895 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp35_ = spit_publishing_publishable_get_publishing_name (_tmp34_);
#line 895 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	filename = _tmp35_;
#line 896 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp37_ = filename;
#line 896 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (_tmp37_ == NULL) {
#line 896 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp36_ = TRUE;
#line 6034 "FlickrPublishing.c"
	} else {
		const gchar* _tmp38_ = NULL;
#line 896 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp38_ = filename;
#line 896 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp36_ = g_strcmp0 (_tmp38_, "") == 0;
#line 6041 "FlickrPublishing.c"
	}
#line 896 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (_tmp36_) {
#line 6045 "FlickrPublishing.c"
		SpitPublishingPublishable* _tmp39_ = NULL;
		gchar* _tmp40_ = NULL;
#line 897 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp39_ = publishable;
#line 897 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp40_ = spit_publishing_publishable_get_param_string (_tmp39_, SPIT_PUBLISHING_PUBLISHABLE_PARAM_STRING_BASENAME);
#line 897 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_free0 (filename);
#line 897 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		filename = _tmp40_;
#line 6056 "FlickrPublishing.c"
	}
#line 901 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp41_ = disposition_table;
#line 901 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp42_ = g_strdup ("filename");
#line 901 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp43_ = publishable;
#line 901 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp44_ = spit_publishing_publishable_get_param_string (_tmp43_, SPIT_PUBLISHING_PUBLISHABLE_PARAM_STRING_BASENAME);
#line 901 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp45_ = _tmp44_;
#line 901 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp46_ = soup_uri_encode (_tmp45_, NULL);
#line 901 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_hash_table_insert (_tmp41_, _tmp42_, _tmp46_);
#line 901 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (_tmp45_);
#line 904 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp47_ = disposition_table;
#line 904 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp48_ = g_strdup ("name");
#line 904 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp49_ = g_strdup ("photo");
#line 904 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_hash_table_insert (_tmp47_, _tmp48_, _tmp49_);
#line 906 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp50_ = disposition_table;
#line 906 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_rest_support_upload_transaction_set_binary_disposition_table (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_UPLOAD_TRANSACTION, PublishingRESTSupportUploadTransaction), _tmp50_);
#line 873 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (filename);
#line 873 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_hash_table_unref0 (disposition_table);
#line 873 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return self;
#line 6092 "FlickrPublishing.c"
}


PublishingFlickrUploadTransaction* publishing_flickr_upload_transaction_new (PublishingFlickrSession* session, PublishingFlickrPublishingParameters* parameters, SpitPublishingPublishable* publishable) {
#line 873 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return publishing_flickr_upload_transaction_construct (PUBLISHING_FLICKR_TYPE_UPLOAD_TRANSACTION, session, parameters, publishable);
#line 6099 "FlickrPublishing.c"
}


static void _vala_array_add18 (PublishingRESTSupportArgument*** array, int* length, int* size, PublishingRESTSupportArgument* value) {
#line 910 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if ((*length) == (*size)) {
#line 910 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 910 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		*array = g_renew (PublishingRESTSupportArgument*, *array, (*size) + 1);
#line 6110 "FlickrPublishing.c"
	}
#line 910 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	(*array)[(*length)++] = value;
#line 910 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	(*array)[*length] = NULL;
#line 6116 "FlickrPublishing.c"
}


void publishing_flickr_upload_transaction_add_authorization_header_field (PublishingFlickrUploadTransaction* self, const gchar* key, const gchar* value) {
	PublishingRESTSupportArgument** _tmp0_ = NULL;
	gint _tmp0__length1 = 0;
	const gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	PublishingRESTSupportArgument* _tmp3_ = NULL;
#line 909 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_UPLOAD_TRANSACTION (self));
#line 909 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (key != NULL);
#line 909 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (value != NULL);
#line 910 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = self->priv->auth_header_fields;
#line 910 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0__length1 = self->priv->auth_header_fields_length1;
#line 910 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = key;
#line 910 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp2_ = value;
#line 910 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp3_ = publishing_rest_support_argument_new (_tmp1_, _tmp2_);
#line 910 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_vala_array_add18 (&self->priv->auth_header_fields, &self->priv->auth_header_fields_length1, &self->priv->_auth_header_fields_size_, _tmp3_);
#line 6144 "FlickrPublishing.c"
}


static gpointer _publishing_rest_support_argument_ref0 (gpointer self) {
#line 914 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return self ? publishing_rest_support_argument_ref (self) : NULL;
#line 6151 "FlickrPublishing.c"
}


static PublishingRESTSupportArgument** _vala_array_dup8 (PublishingRESTSupportArgument** self, int length) {
	PublishingRESTSupportArgument** result;
	int i;
#line 914 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	result = g_new0 (PublishingRESTSupportArgument*, length + 1);
#line 914 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	for (i = 0; i < length; i++) {
#line 6162 "FlickrPublishing.c"
		PublishingRESTSupportArgument* _tmp0_ = NULL;
#line 914 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp0_ = _publishing_rest_support_argument_ref0 (self[i]);
#line 914 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		result[i] = _tmp0_;
#line 6168 "FlickrPublishing.c"
	}
#line 914 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return result;
#line 6172 "FlickrPublishing.c"
}


PublishingRESTSupportArgument** publishing_flickr_upload_transaction_get_authorization_header_fields (PublishingFlickrUploadTransaction* self, int* result_length1) {
	PublishingRESTSupportArgument** result = NULL;
	PublishingRESTSupportArgument** _tmp0_ = NULL;
	gint _tmp0__length1 = 0;
	PublishingRESTSupportArgument** _tmp1_ = NULL;
	gint _tmp1__length1 = 0;
	PublishingRESTSupportArgument** _tmp2_ = NULL;
	gint _tmp2__length1 = 0;
#line 913 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (PUBLISHING_FLICKR_IS_UPLOAD_TRANSACTION (self), NULL);
#line 914 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = self->priv->auth_header_fields;
#line 914 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0__length1 = self->priv->auth_header_fields_length1;
#line 914 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = (_tmp0_ != NULL) ? _vala_array_dup8 (_tmp0_, _tmp0__length1) : ((gpointer) _tmp0_);
#line 914 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1__length1 = _tmp0__length1;
#line 914 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp2_ = _tmp1_;
#line 914 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp2__length1 = _tmp1__length1;
#line 914 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (result_length1) {
#line 914 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		*result_length1 = _tmp2__length1;
#line 6202 "FlickrPublishing.c"
	}
#line 914 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	result = _tmp2_;
#line 914 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return result;
#line 6208 "FlickrPublishing.c"
}


gchar* publishing_flickr_upload_transaction_get_authorization_header_string (PublishingFlickrUploadTransaction* self) {
	gchar* result = NULL;
	gchar* _result_ = NULL;
	gchar* _tmp0_ = NULL;
#line 917 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (PUBLISHING_FLICKR_IS_UPLOAD_TRANSACTION (self), NULL);
#line 918 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = g_strdup ("OAuth ");
#line 918 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_result_ = _tmp0_;
#line 6222 "FlickrPublishing.c"
	{
		gint i = 0;
#line 920 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		i = 0;
#line 6227 "FlickrPublishing.c"
		{
			gboolean _tmp1_ = FALSE;
#line 920 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_tmp1_ = TRUE;
#line 920 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			while (TRUE) {
#line 6234 "FlickrPublishing.c"
				gint _tmp3_ = 0;
				PublishingRESTSupportArgument** _tmp4_ = NULL;
				gint _tmp4__length1 = 0;
				const gchar* _tmp5_ = NULL;
				PublishingRESTSupportArgument** _tmp6_ = NULL;
				gint _tmp6__length1 = 0;
				gint _tmp7_ = 0;
				PublishingRESTSupportArgument* _tmp8_ = NULL;
				const gchar* _tmp9_ = NULL;
				gchar* _tmp10_ = NULL;
				const gchar* _tmp11_ = NULL;
				gchar* _tmp12_ = NULL;
				const gchar* _tmp13_ = NULL;
				PublishingRESTSupportArgument** _tmp14_ = NULL;
				gint _tmp14__length1 = 0;
				gint _tmp15_ = 0;
				PublishingRESTSupportArgument* _tmp16_ = NULL;
				const gchar* _tmp17_ = NULL;
				gchar* _tmp18_ = NULL;
				gchar* _tmp19_ = NULL;
				gchar* _tmp20_ = NULL;
				gchar* _tmp21_ = NULL;
				gchar* _tmp22_ = NULL;
				gint _tmp23_ = 0;
				PublishingRESTSupportArgument** _tmp24_ = NULL;
				gint _tmp24__length1 = 0;
#line 920 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				if (!_tmp1_) {
#line 6263 "FlickrPublishing.c"
					gint _tmp2_ = 0;
#line 920 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
					_tmp2_ = i;
#line 920 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
					i = _tmp2_ + 1;
#line 6269 "FlickrPublishing.c"
				}
#line 920 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp1_ = FALSE;
#line 920 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp3_ = i;
#line 920 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp4_ = self->priv->auth_header_fields;
#line 920 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp4__length1 = self->priv->auth_header_fields_length1;
#line 920 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				if (!(_tmp3_ < _tmp4__length1)) {
#line 920 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
					break;
#line 6283 "FlickrPublishing.c"
				}
#line 921 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp5_ = _result_;
#line 921 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp6_ = self->priv->auth_header_fields;
#line 921 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp6__length1 = self->priv->auth_header_fields_length1;
#line 921 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp7_ = i;
#line 921 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp8_ = _tmp6_[_tmp7_];
#line 921 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp9_ = _tmp8_->key;
#line 921 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp10_ = g_strconcat (_tmp5_, _tmp9_, NULL);
#line 921 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_g_free0 (_result_);
#line 921 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_result_ = _tmp10_;
#line 922 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp11_ = _result_;
#line 922 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp12_ = g_strconcat (_tmp11_, "=", NULL);
#line 922 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_g_free0 (_result_);
#line 922 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_result_ = _tmp12_;
#line 923 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp13_ = _result_;
#line 923 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp14_ = self->priv->auth_header_fields;
#line 923 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp14__length1 = self->priv->auth_header_fields_length1;
#line 923 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp15_ = i;
#line 923 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp16_ = _tmp14_[_tmp15_];
#line 923 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp17_ = _tmp16_->value;
#line 923 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp18_ = g_strconcat ("\"", _tmp17_, NULL);
#line 923 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp19_ = _tmp18_;
#line 923 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp20_ = g_strconcat (_tmp19_, "\"", NULL);
#line 923 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp21_ = _tmp20_;
#line 923 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp22_ = g_strconcat (_tmp13_, _tmp21_, NULL);
#line 923 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_g_free0 (_result_);
#line 923 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_result_ = _tmp22_;
#line 923 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_g_free0 (_tmp21_);
#line 923 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_g_free0 (_tmp19_);
#line 925 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp23_ = i;
#line 925 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp24_ = self->priv->auth_header_fields;
#line 925 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp24__length1 = self->priv->auth_header_fields_length1;
#line 925 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				if (_tmp23_ < (_tmp24__length1 - 1)) {
#line 6349 "FlickrPublishing.c"
					const gchar* _tmp25_ = NULL;
					gchar* _tmp26_ = NULL;
#line 926 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
					_tmp25_ = _result_;
#line 926 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
					_tmp26_ = g_strconcat (_tmp25_, ", ", NULL);
#line 926 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
					_g_free0 (_result_);
#line 926 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
					_result_ = _tmp26_;
#line 6360 "FlickrPublishing.c"
				}
			}
		}
	}
#line 929 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	result = _result_;
#line 929 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return result;
#line 6369 "FlickrPublishing.c"
}


static void publishing_flickr_upload_transaction_real_execute (PublishingRESTSupportTransaction* base, GError** error) {
	PublishingFlickrUploadTransaction * self;
	PublishingFlickrSession* _tmp0_ = NULL;
	gchar* authorization_header = NULL;
	gchar* _tmp1_ = NULL;
	GError * _inner_error_ = NULL;
#line 932 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_FLICKR_TYPE_UPLOAD_TRANSACTION, PublishingFlickrUploadTransaction);
#line 933 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = self->priv->session;
#line 933 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_session_sign_transaction (_tmp0_, G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction));
#line 935 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = publishing_flickr_upload_transaction_get_authorization_header_string (self);
#line 935 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	authorization_header = _tmp1_;
#line 937 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_debug ("FlickrPublishing.vala:937: executing upload transaction: authorization" \
" header string = '%s'", authorization_header);
#line 939 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_rest_support_transaction_add_header (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "Authorization", authorization_header);
#line 941 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	PUBLISHING_REST_SUPPORT_TRANSACTION_CLASS (publishing_flickr_upload_transaction_parent_class)->execute (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_UPLOAD_TRANSACTION, PublishingRESTSupportUploadTransaction), PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), &_inner_error_);
#line 941 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 941 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 941 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			g_propagate_error (error, _inner_error_);
#line 941 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_g_free0 (authorization_header);
#line 941 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			return;
#line 6405 "FlickrPublishing.c"
		} else {
#line 941 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_g_free0 (authorization_header);
#line 941 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 941 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			g_clear_error (&_inner_error_);
#line 941 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			return;
#line 6415 "FlickrPublishing.c"
		}
	}
#line 932 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (authorization_header);
#line 6420 "FlickrPublishing.c"
}


static void publishing_flickr_upload_transaction_class_init (PublishingFlickrUploadTransactionClass * klass) {
#line 868 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_upload_transaction_parent_class = g_type_class_peek_parent (klass);
#line 868 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	((PublishingRESTSupportTransactionClass *) klass)->finalize = publishing_flickr_upload_transaction_finalize;
#line 868 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_type_class_add_private (klass, sizeof (PublishingFlickrUploadTransactionPrivate));
#line 868 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	((PublishingRESTSupportTransactionClass *) klass)->execute = publishing_flickr_upload_transaction_real_execute;
#line 6433 "FlickrPublishing.c"
}


static void publishing_flickr_upload_transaction_instance_init (PublishingFlickrUploadTransaction * self) {
#line 868 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv = PUBLISHING_FLICKR_UPLOAD_TRANSACTION_GET_PRIVATE (self);
#line 6440 "FlickrPublishing.c"
}


static void publishing_flickr_upload_transaction_finalize (PublishingRESTSupportTransaction* obj) {
	PublishingFlickrUploadTransaction * self;
#line 868 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_FLICKR_TYPE_UPLOAD_TRANSACTION, PublishingFlickrUploadTransaction);
#line 869 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_publishing_flickr_publishing_parameters_unref0 (self->priv->parameters);
#line 870 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_publishing_rest_support_session_unref0 (self->priv->session);
#line 871 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->auth_header_fields = (_vala_array_free (self->priv->auth_header_fields, self->priv->auth_header_fields_length1, (GDestroyNotify) publishing_rest_support_argument_unref), NULL);
#line 868 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	PUBLISHING_REST_SUPPORT_TRANSACTION_CLASS (publishing_flickr_upload_transaction_parent_class)->finalize (obj);
#line 6456 "FlickrPublishing.c"
}


GType publishing_flickr_upload_transaction_get_type (void) {
	static volatile gsize publishing_flickr_upload_transaction_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_flickr_upload_transaction_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingFlickrUploadTransactionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_flickr_upload_transaction_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingFlickrUploadTransaction), 0, (GInstanceInitFunc) publishing_flickr_upload_transaction_instance_init, NULL };
		GType publishing_flickr_upload_transaction_type_id;
		publishing_flickr_upload_transaction_type_id = g_type_register_static (PUBLISHING_REST_SUPPORT_TYPE_UPLOAD_TRANSACTION, "PublishingFlickrUploadTransaction", &g_define_type_info, 0);
		g_once_init_leave (&publishing_flickr_upload_transaction_type_id__volatile, publishing_flickr_upload_transaction_type_id);
	}
	return publishing_flickr_upload_transaction_type_id__volatile;
}


PublishingFlickrSession* publishing_flickr_session_construct (GType object_type) {
	PublishingFlickrSession* self = NULL;
#line 953 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = (PublishingFlickrSession*) publishing_rest_support_session_construct (object_type, PUBLISHING_FLICKR_ENDPOINT_URL);
#line 952 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return self;
#line 6478 "FlickrPublishing.c"
}


PublishingFlickrSession* publishing_flickr_session_new (void) {
#line 952 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return publishing_flickr_session_construct (PUBLISHING_FLICKR_TYPE_SESSION);
#line 6485 "FlickrPublishing.c"
}


static gboolean publishing_flickr_session_real_is_authenticated (PublishingRESTSupportSession* base) {
	PublishingFlickrSession * self;
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	const gchar* _tmp2_ = NULL;
#line 956 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_FLICKR_TYPE_SESSION, PublishingFlickrSession);
#line 957 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp2_ = self->priv->access_phase_token;
#line 957 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (_tmp2_ != NULL) {
#line 6501 "FlickrPublishing.c"
		const gchar* _tmp3_ = NULL;
#line 957 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp3_ = self->priv->access_phase_token_secret;
#line 957 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp1_ = _tmp3_ != NULL;
#line 6507 "FlickrPublishing.c"
	} else {
#line 957 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp1_ = FALSE;
#line 6511 "FlickrPublishing.c"
	}
#line 957 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (_tmp1_) {
#line 6515 "FlickrPublishing.c"
		const gchar* _tmp4_ = NULL;
#line 958 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp4_ = self->priv->username;
#line 958 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp0_ = _tmp4_ != NULL;
#line 6521 "FlickrPublishing.c"
	} else {
#line 957 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp0_ = FALSE;
#line 6525 "FlickrPublishing.c"
	}
#line 957 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	result = _tmp0_;
#line 957 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return result;
#line 6531 "FlickrPublishing.c"
}


void publishing_flickr_session_authenticate_from_persistent_credentials (PublishingFlickrSession* self, const gchar* token, const gchar* secret, const gchar* username) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
#line 961 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_SESSION (self));
#line 961 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (token != NULL);
#line 961 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (secret != NULL);
#line 961 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (username != NULL);
#line 963 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = token;
#line 963 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 963 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (self->priv->access_phase_token);
#line 963 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->access_phase_token = _tmp1_;
#line 964 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp2_ = secret;
#line 964 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp3_ = g_strdup (_tmp2_);
#line 964 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (self->priv->access_phase_token_secret);
#line 964 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->access_phase_token_secret = _tmp3_;
#line 965 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp4_ = username;
#line 965 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp5_ = g_strdup (_tmp4_);
#line 965 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (self->priv->username);
#line 965 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->username = _tmp5_;
#line 967 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_emit_by_name (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession), "authenticated");
#line 6576 "FlickrPublishing.c"
}


void publishing_flickr_session_deauthenticate (PublishingFlickrSession* self) {
#line 970 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_SESSION (self));
#line 971 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (self->priv->access_phase_token);
#line 971 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->access_phase_token = NULL;
#line 972 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (self->priv->access_phase_token_secret);
#line 972 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->access_phase_token_secret = NULL;
#line 973 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (self->priv->username);
#line 973 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->username = NULL;
#line 6595 "FlickrPublishing.c"
}


static gpointer _publishing_rest_support_transaction_ref0 (gpointer self) {
#line 984 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return self ? publishing_rest_support_transaction_ref (self) : NULL;
#line 6602 "FlickrPublishing.c"
}


static void _vala_array_add19 (PublishingRESTSupportArgument*** array, int* length, int* size, PublishingRESTSupportArgument* value) {
#line 993 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if ((*length) == (*size)) {
#line 993 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 993 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		*array = g_renew (PublishingRESTSupportArgument*, *array, (*size) + 1);
#line 6613 "FlickrPublishing.c"
	}
#line 993 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	(*array)[(*length)++] = value;
#line 993 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	(*array)[*length] = NULL;
#line 6619 "FlickrPublishing.c"
}


void publishing_flickr_session_sign_transaction (PublishingFlickrSession* self, PublishingRESTSupportTransaction* txn) {
	gchar* http_method = NULL;
	PublishingRESTSupportTransaction* _tmp0_ = NULL;
	PublishingRESTSupportHttpMethod _tmp1_ = 0;
	gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	PublishingRESTSupportArgument** base_string_arguments = NULL;
	PublishingRESTSupportTransaction* _tmp6_ = NULL;
	gint _tmp7_ = 0;
	PublishingRESTSupportArgument** _tmp8_ = NULL;
	gint base_string_arguments_length1 = 0;
	gint _base_string_arguments_size_ = 0;
	PublishingFlickrUploadTransaction* upload_txn = NULL;
	PublishingRESTSupportTransaction* _tmp9_ = NULL;
	PublishingFlickrUploadTransaction* _tmp10_ = NULL;
	PublishingFlickrUploadTransaction* _tmp11_ = NULL;
	PublishingRESTSupportArgument** sorted_args = NULL;
	PublishingRESTSupportArgument** _tmp20_ = NULL;
	gint _tmp20__length1 = 0;
	gint _tmp21_ = 0;
	PublishingRESTSupportArgument** _tmp22_ = NULL;
	gint sorted_args_length1 = 0;
	gint _sorted_args_size_ = 0;
	gchar* arguments_string = NULL;
	gchar* _tmp23_ = NULL;
	gchar* signing_key = NULL;
	const gchar* _tmp46_ = NULL;
	gchar* signature_base_string = NULL;
	const gchar* _tmp53_ = NULL;
	gchar* _tmp54_ = NULL;
	gchar* _tmp55_ = NULL;
	PublishingRESTSupportTransaction* _tmp56_ = NULL;
	gchar* _tmp57_ = NULL;
	gchar* _tmp58_ = NULL;
	gchar* _tmp59_ = NULL;
	gchar* _tmp60_ = NULL;
	gchar* _tmp61_ = NULL;
	gchar* _tmp62_ = NULL;
	gchar* _tmp63_ = NULL;
	gchar* _tmp64_ = NULL;
	const gchar* _tmp65_ = NULL;
	gchar* _tmp66_ = NULL;
	gchar* _tmp67_ = NULL;
	gchar* _tmp68_ = NULL;
	gchar* _tmp69_ = NULL;
	const gchar* _tmp70_ = NULL;
	const gchar* _tmp71_ = NULL;
	gchar* signature = NULL;
	const gchar* _tmp72_ = NULL;
	const gchar* _tmp73_ = NULL;
	gchar* _tmp74_ = NULL;
	const gchar* _tmp75_ = NULL;
	gchar* _tmp76_ = NULL;
	const gchar* _tmp77_ = NULL;
	PublishingFlickrUploadTransaction* _tmp78_ = NULL;
#line 976 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_SESSION (self));
#line 976 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_TRANSACTION (txn));
#line 977 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = txn;
#line 977 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = publishing_rest_support_transaction_get_method (_tmp0_);
#line 977 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp2_ = publishing_rest_support_http_method_to_string (_tmp1_);
#line 977 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	http_method = _tmp2_;
#line 979 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_debug ("FlickrPublishing.vala:979: signing transaction with parameters:");
#line 980 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp3_ = http_method;
#line 980 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp4_ = g_strconcat ("HTTP method = ", _tmp3_, NULL);
#line 980 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp5_ = _tmp4_;
#line 980 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_debug ("FlickrPublishing.vala:980: %s", _tmp5_);
#line 980 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (_tmp5_);
#line 982 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp6_ = txn;
#line 982 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp8_ = publishing_rest_support_transaction_get_arguments (_tmp6_, &_tmp7_);
#line 982 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	base_string_arguments = _tmp8_;
#line 982 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	base_string_arguments_length1 = _tmp7_;
#line 982 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_base_string_arguments_size_ = base_string_arguments_length1;
#line 984 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp9_ = txn;
#line 984 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp10_ = _publishing_rest_support_transaction_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp9_, PUBLISHING_FLICKR_TYPE_UPLOAD_TRANSACTION) ? ((PublishingFlickrUploadTransaction*) _tmp9_) : NULL);
#line 984 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	upload_txn = _tmp10_;
#line 985 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp11_ = upload_txn;
#line 985 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (_tmp11_ != NULL) {
#line 6724 "FlickrPublishing.c"
		PublishingRESTSupportArgument** auth_header_args = NULL;
		PublishingFlickrUploadTransaction* _tmp12_ = NULL;
		gint _tmp13_ = 0;
		PublishingRESTSupportArgument** _tmp14_ = NULL;
		gint auth_header_args_length1 = 0;
		gint _auth_header_args_size_ = 0;
		PublishingRESTSupportArgument** _tmp15_ = NULL;
		gint _tmp15__length1 = 0;
#line 986 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_debug ("FlickrPublishing.vala:986: %s", "this transaction is an UploadTransaction; including Authorization head" \
"er " "fields in signature base string");
#line 989 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp12_ = upload_txn;
#line 989 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp14_ = publishing_flickr_upload_transaction_get_authorization_header_fields (_tmp12_, &_tmp13_);
#line 989 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		auth_header_args = _tmp14_;
#line 989 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		auth_header_args_length1 = _tmp13_;
#line 989 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_auth_header_args_size_ = auth_header_args_length1;
#line 992 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp15_ = auth_header_args;
#line 992 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp15__length1 = auth_header_args_length1;
#line 6749 "FlickrPublishing.c"
		{
			PublishingRESTSupportArgument** arg_collection = NULL;
			gint arg_collection_length1 = 0;
			gint _arg_collection_size_ = 0;
			gint arg_it = 0;
#line 992 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			arg_collection = _tmp15_;
#line 992 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			arg_collection_length1 = _tmp15__length1;
#line 992 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			for (arg_it = 0; arg_it < _tmp15__length1; arg_it = arg_it + 1) {
#line 6761 "FlickrPublishing.c"
				PublishingRESTSupportArgument* _tmp16_ = NULL;
				PublishingRESTSupportArgument* arg = NULL;
#line 992 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp16_ = _publishing_rest_support_argument_ref0 (arg_collection[arg_it]);
#line 992 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				arg = _tmp16_;
#line 6768 "FlickrPublishing.c"
				{
					PublishingRESTSupportArgument** _tmp17_ = NULL;
					gint _tmp17__length1 = 0;
					PublishingRESTSupportArgument* _tmp18_ = NULL;
					PublishingRESTSupportArgument* _tmp19_ = NULL;
#line 993 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
					_tmp17_ = base_string_arguments;
#line 993 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
					_tmp17__length1 = base_string_arguments_length1;
#line 993 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
					_tmp18_ = arg;
#line 993 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
					_tmp19_ = _publishing_rest_support_argument_ref0 (_tmp18_);
#line 993 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
					_vala_array_add19 (&base_string_arguments, &base_string_arguments_length1, &_base_string_arguments_size_, _tmp19_);
#line 992 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
					_publishing_rest_support_argument_unref0 (arg);
#line 6786 "FlickrPublishing.c"
				}
			}
		}
#line 985 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		auth_header_args = (_vala_array_free (auth_header_args, auth_header_args_length1, (GDestroyNotify) publishing_rest_support_argument_unref), NULL);
#line 6792 "FlickrPublishing.c"
	}
#line 996 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp20_ = base_string_arguments;
#line 996 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp20__length1 = base_string_arguments_length1;
#line 996 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp22_ = publishing_rest_support_argument_sort (_tmp20_, _tmp20__length1, &_tmp21_);
#line 996 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	sorted_args = _tmp22_;
#line 996 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	sorted_args_length1 = _tmp21_;
#line 996 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_sorted_args_size_ = sorted_args_length1;
#line 999 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp23_ = g_strdup ("");
#line 999 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	arguments_string = _tmp23_;
#line 6810 "FlickrPublishing.c"
	{
		gint i = 0;
#line 1000 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		i = 0;
#line 6815 "FlickrPublishing.c"
		{
			gboolean _tmp24_ = FALSE;
#line 1000 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_tmp24_ = TRUE;
#line 1000 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			while (TRUE) {
#line 6822 "FlickrPublishing.c"
				gint _tmp26_ = 0;
				PublishingRESTSupportArgument** _tmp27_ = NULL;
				gint _tmp27__length1 = 0;
				const gchar* _tmp28_ = NULL;
				PublishingRESTSupportArgument** _tmp29_ = NULL;
				gint _tmp29__length1 = 0;
				gint _tmp30_ = 0;
				PublishingRESTSupportArgument* _tmp31_ = NULL;
				const gchar* _tmp32_ = NULL;
				gchar* _tmp33_ = NULL;
				gchar* _tmp34_ = NULL;
				PublishingRESTSupportArgument** _tmp35_ = NULL;
				gint _tmp35__length1 = 0;
				gint _tmp36_ = 0;
				PublishingRESTSupportArgument* _tmp37_ = NULL;
				const gchar* _tmp38_ = NULL;
				gchar* _tmp39_ = NULL;
				gchar* _tmp40_ = NULL;
				gchar* _tmp41_ = NULL;
				gint _tmp42_ = 0;
				PublishingRESTSupportArgument** _tmp43_ = NULL;
				gint _tmp43__length1 = 0;
#line 1000 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				if (!_tmp24_) {
#line 6847 "FlickrPublishing.c"
					gint _tmp25_ = 0;
#line 1000 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
					_tmp25_ = i;
#line 1000 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
					i = _tmp25_ + 1;
#line 6853 "FlickrPublishing.c"
				}
#line 1000 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp24_ = FALSE;
#line 1000 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp26_ = i;
#line 1000 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp27_ = sorted_args;
#line 1000 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp27__length1 = sorted_args_length1;
#line 1000 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				if (!(_tmp26_ < _tmp27__length1)) {
#line 1000 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
					break;
#line 6867 "FlickrPublishing.c"
				}
#line 1001 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp28_ = arguments_string;
#line 1001 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp29_ = sorted_args;
#line 1001 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp29__length1 = sorted_args_length1;
#line 1001 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp30_ = i;
#line 1001 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp31_ = _tmp29_[_tmp30_];
#line 1001 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp32_ = _tmp31_->key;
#line 1001 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp33_ = g_strconcat (_tmp32_, "=", NULL);
#line 1001 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp34_ = _tmp33_;
#line 1001 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp35_ = sorted_args;
#line 1001 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp35__length1 = sorted_args_length1;
#line 1001 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp36_ = i;
#line 1001 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp37_ = _tmp35_[_tmp36_];
#line 1001 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp38_ = _tmp37_->value;
#line 1001 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp39_ = g_strconcat (_tmp34_, _tmp38_, NULL);
#line 1001 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp40_ = _tmp39_;
#line 1001 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp41_ = g_strconcat (_tmp28_, _tmp40_, NULL);
#line 1001 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_g_free0 (arguments_string);
#line 1001 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				arguments_string = _tmp41_;
#line 1001 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_g_free0 (_tmp40_);
#line 1001 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_g_free0 (_tmp34_);
#line 1002 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp42_ = i;
#line 1002 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp43_ = sorted_args;
#line 1002 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp43__length1 = sorted_args_length1;
#line 1002 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				if (_tmp42_ < (_tmp43__length1 - 1)) {
#line 6917 "FlickrPublishing.c"
					const gchar* _tmp44_ = NULL;
					gchar* _tmp45_ = NULL;
#line 1003 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
					_tmp44_ = arguments_string;
#line 1003 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
					_tmp45_ = g_strconcat (_tmp44_, "&", NULL);
#line 1003 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
					_g_free0 (arguments_string);
#line 1003 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
					arguments_string = _tmp45_;
#line 6928 "FlickrPublishing.c"
				}
			}
		}
	}
#line 1006 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	signing_key = NULL;
#line 1007 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp46_ = self->priv->access_phase_token_secret;
#line 1007 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (_tmp46_ != NULL) {
#line 6939 "FlickrPublishing.c"
		const gchar* _tmp47_ = NULL;
		gchar* _tmp48_ = NULL;
#line 1008 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_debug ("FlickrPublishing.vala:1008: access phase token secret available; using" \
" it as signing key");
#line 1010 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp47_ = self->priv->access_phase_token_secret;
#line 1010 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp48_ = g_strconcat (PUBLISHING_FLICKR_API_SECRET "&", _tmp47_, NULL);
#line 1010 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_free0 (signing_key);
#line 1010 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		signing_key = _tmp48_;
#line 6952 "FlickrPublishing.c"
	} else {
		const gchar* _tmp49_ = NULL;
#line 1011 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp49_ = self->priv->request_phase_token_secret;
#line 1011 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		if (_tmp49_ != NULL) {
#line 6959 "FlickrPublishing.c"
			const gchar* _tmp50_ = NULL;
			gchar* _tmp51_ = NULL;
#line 1012 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			g_debug ("FlickrPublishing.vala:1012: request phase token secret available; usin" \
"g it as signing key");
#line 1014 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_tmp50_ = self->priv->request_phase_token_secret;
#line 1014 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_tmp51_ = g_strconcat (PUBLISHING_FLICKR_API_SECRET "&", _tmp50_, NULL);
#line 1014 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_g_free0 (signing_key);
#line 1014 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			signing_key = _tmp51_;
#line 6972 "FlickrPublishing.c"
		} else {
			gchar* _tmp52_ = NULL;
#line 1016 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			g_debug ("FlickrPublishing.vala:1016: %s", "neither access phase nor request phase token secrets available; using " \
"API " "key as signing key");
#line 1019 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_tmp52_ = g_strdup (PUBLISHING_FLICKR_API_SECRET "&");
#line 1019 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_g_free0 (signing_key);
#line 1019 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			signing_key = _tmp52_;
#line 6983 "FlickrPublishing.c"
		}
	}
#line 1022 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp53_ = http_method;
#line 1022 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp54_ = g_strconcat (_tmp53_, "&", NULL);
#line 1022 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp55_ = _tmp54_;
#line 1022 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp56_ = txn;
#line 1022 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp57_ = publishing_rest_support_transaction_get_endpoint_url (_tmp56_);
#line 1022 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp58_ = _tmp57_;
#line 1022 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp59_ = soup_uri_encode (_tmp58_, PUBLISHING_FLICKR_ENCODE_RFC_3986_EXTRA);
#line 1022 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp60_ = _tmp59_;
#line 1022 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp61_ = g_strconcat (_tmp55_, _tmp60_, NULL);
#line 1022 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp62_ = _tmp61_;
#line 1022 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp63_ = g_strconcat (_tmp62_, "&", NULL);
#line 1022 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp64_ = _tmp63_;
#line 1022 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp65_ = arguments_string;
#line 1022 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp66_ = soup_uri_encode (_tmp65_, PUBLISHING_FLICKR_ENCODE_RFC_3986_EXTRA);
#line 1022 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp67_ = _tmp66_;
#line 1022 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp68_ = g_strconcat (_tmp64_, _tmp67_, NULL);
#line 1022 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp69_ = _tmp68_;
#line 1022 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (_tmp67_);
#line 1022 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (_tmp64_);
#line 1022 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (_tmp62_);
#line 1022 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (_tmp60_);
#line 1022 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (_tmp58_);
#line 1022 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (_tmp55_);
#line 1022 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	signature_base_string = _tmp69_;
#line 1026 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp70_ = signature_base_string;
#line 1026 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_debug ("FlickrPublishing.vala:1026: signature base string = '%s'", _tmp70_);
#line 1028 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp71_ = signing_key;
#line 1028 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_debug ("FlickrPublishing.vala:1028: signing key = '%s'", _tmp71_);
#line 1031 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp72_ = signing_key;
#line 1031 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp73_ = signature_base_string;
#line 1031 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp74_ = publishing_rest_support_hmac_sha1 (_tmp72_, _tmp73_);
#line 1031 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	signature = _tmp74_;
#line 1032 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp75_ = signature;
#line 1032 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp76_ = soup_uri_encode (_tmp75_, PUBLISHING_FLICKR_ENCODE_RFC_3986_EXTRA);
#line 1032 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (signature);
#line 1032 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	signature = _tmp76_;
#line 1034 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp77_ = signature;
#line 1034 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_debug ("FlickrPublishing.vala:1034: signature = '%s'", _tmp77_);
#line 1036 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp78_ = upload_txn;
#line 1036 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (_tmp78_ != NULL) {
#line 7066 "FlickrPublishing.c"
		PublishingFlickrUploadTransaction* _tmp79_ = NULL;
		const gchar* _tmp80_ = NULL;
#line 1037 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp79_ = upload_txn;
#line 1037 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp80_ = signature;
#line 1037 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		publishing_flickr_upload_transaction_add_authorization_header_field (_tmp79_, "oauth_signature", _tmp80_);
#line 7075 "FlickrPublishing.c"
	} else {
		PublishingRESTSupportTransaction* _tmp81_ = NULL;
		const gchar* _tmp82_ = NULL;
#line 1039 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp81_ = txn;
#line 1039 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp82_ = signature;
#line 1039 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		publishing_rest_support_transaction_add_argument (_tmp81_, "oauth_signature", _tmp82_);
#line 7085 "FlickrPublishing.c"
	}
#line 976 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (signature);
#line 976 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (signature_base_string);
#line 976 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (signing_key);
#line 976 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (arguments_string);
#line 976 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	sorted_args = (_vala_array_free (sorted_args, sorted_args_length1, (GDestroyNotify) publishing_rest_support_argument_unref), NULL);
#line 976 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_publishing_rest_support_transaction_unref0 (upload_txn);
#line 976 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	base_string_arguments = (_vala_array_free (base_string_arguments, base_string_arguments_length1, (GDestroyNotify) publishing_rest_support_argument_unref), NULL);
#line 976 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (http_method);
#line 7103 "FlickrPublishing.c"
}


void publishing_flickr_session_set_request_phase_credentials (PublishingFlickrSession* self, const gchar* token, const gchar* secret) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
#line 1042 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_SESSION (self));
#line 1042 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (token != NULL);
#line 1042 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (secret != NULL);
#line 1043 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = token;
#line 1043 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 1043 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (self->priv->request_phase_token);
#line 1043 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->request_phase_token = _tmp1_;
#line 1044 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp2_ = secret;
#line 1044 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp3_ = g_strdup (_tmp2_);
#line 1044 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (self->priv->request_phase_token_secret);
#line 1044 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->request_phase_token_secret = _tmp3_;
#line 7134 "FlickrPublishing.c"
}


void publishing_flickr_session_set_access_phase_credentials (PublishingFlickrSession* self, const gchar* token, const gchar* secret, const gchar* username) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
#line 1047 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_SESSION (self));
#line 1047 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (token != NULL);
#line 1047 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (secret != NULL);
#line 1047 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (username != NULL);
#line 1048 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = token;
#line 1048 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 1048 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (self->priv->access_phase_token);
#line 1048 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->access_phase_token = _tmp1_;
#line 1049 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp2_ = secret;
#line 1049 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp3_ = g_strdup (_tmp2_);
#line 1049 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (self->priv->access_phase_token_secret);
#line 1049 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->access_phase_token_secret = _tmp3_;
#line 1050 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp4_ = username;
#line 1050 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp5_ = g_strdup (_tmp4_);
#line 1050 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (self->priv->username);
#line 1050 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->username = _tmp5_;
#line 1052 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_emit_by_name (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession), "authenticated");
#line 7179 "FlickrPublishing.c"
}


gchar* publishing_flickr_session_get_oauth_nonce (PublishingFlickrSession* self) {
	gchar* result = NULL;
	GTimeVal currtime = {0};
	GTimeVal _tmp0_ = {0};
	glong _tmp1_ = 0L;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	GTimeVal _tmp4_ = {0};
	glong _tmp5_ = 0L;
	gchar* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
	gchar* _tmp8_ = NULL;
	gchar* _tmp9_ = NULL;
	gchar* _tmp10_ = NULL;
	gchar* _tmp11_ = NULL;
#line 1055 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (PUBLISHING_FLICKR_IS_SESSION (self), NULL);
#line 1056 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_get_current_time (&currtime);
#line 1057 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_get_current_time (&currtime);
#line 1059 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = currtime;
#line 1059 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = _tmp0_.tv_sec;
#line 1059 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp2_ = g_strdup_printf ("%li", _tmp1_);
#line 1059 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp3_ = _tmp2_;
#line 1059 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp4_ = currtime;
#line 1059 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp5_ = _tmp4_.tv_usec;
#line 1059 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp6_ = g_strdup_printf ("%li", _tmp5_);
#line 1059 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp7_ = _tmp6_;
#line 1059 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp8_ = g_strconcat (_tmp3_, _tmp7_, NULL);
#line 1059 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp9_ = _tmp8_;
#line 1059 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp10_ = g_compute_checksum_for_string (G_CHECKSUM_MD5, _tmp9_, (gsize) -1);
#line 1059 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp11_ = _tmp10_;
#line 1059 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (_tmp9_);
#line 1059 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (_tmp7_);
#line 1059 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (_tmp3_);
#line 1059 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	result = _tmp11_;
#line 1059 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return result;
#line 7238 "FlickrPublishing.c"
}


static glong string_strnlen (gchar* str, glong maxlen) {
	glong result = 0L;
	gchar* end = NULL;
	gchar* _tmp0_ = NULL;
	glong _tmp1_ = 0L;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
#line 1295 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp0_ = str;
#line 1295 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp1_ = maxlen;
#line 1295 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp2_ = memchr (_tmp0_, 0, (gsize) _tmp1_);
#line 1295 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	end = _tmp2_;
#line 1296 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp3_ = end;
#line 1296 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	if (_tmp3_ == NULL) {
#line 7261 "FlickrPublishing.c"
		glong _tmp4_ = 0L;
#line 1297 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp4_ = maxlen;
#line 1297 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		result = _tmp4_;
#line 1297 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		return result;
#line 7269 "FlickrPublishing.c"
	} else {
		gchar* _tmp5_ = NULL;
		gchar* _tmp6_ = NULL;
#line 1299 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp5_ = end;
#line 1299 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp6_ = str;
#line 1299 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		result = (glong) (_tmp5_ - _tmp6_);
#line 1299 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		return result;
#line 7281 "FlickrPublishing.c"
	}
}


static gchar* string_substring (const gchar* self, glong offset, glong len) {
	gchar* result = NULL;
	glong string_length = 0L;
	gboolean _tmp0_ = FALSE;
	glong _tmp1_ = 0L;
	glong _tmp8_ = 0L;
	glong _tmp14_ = 0L;
	glong _tmp17_ = 0L;
	glong _tmp18_ = 0L;
	glong _tmp19_ = 0L;
	glong _tmp20_ = 0L;
	glong _tmp21_ = 0L;
	gchar* _tmp22_ = NULL;
#line 1306 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1308 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp1_ = offset;
#line 1308 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	if (_tmp1_ >= ((glong) 0)) {
#line 7305 "FlickrPublishing.c"
		glong _tmp2_ = 0L;
#line 1308 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp2_ = len;
#line 1308 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp0_ = _tmp2_ >= ((glong) 0);
#line 7311 "FlickrPublishing.c"
	} else {
#line 1308 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp0_ = FALSE;
#line 7315 "FlickrPublishing.c"
	}
#line 1308 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	if (_tmp0_) {
#line 7319 "FlickrPublishing.c"
		glong _tmp3_ = 0L;
		glong _tmp4_ = 0L;
		glong _tmp5_ = 0L;
#line 1310 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp3_ = offset;
#line 1310 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp4_ = len;
#line 1310 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp5_ = string_strnlen ((gchar*) self, _tmp3_ + _tmp4_);
#line 1310 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		string_length = _tmp5_;
#line 7331 "FlickrPublishing.c"
	} else {
		gint _tmp6_ = 0;
		gint _tmp7_ = 0;
#line 1312 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp6_ = strlen (self);
#line 1312 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp7_ = _tmp6_;
#line 1312 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		string_length = (glong) _tmp7_;
#line 7341 "FlickrPublishing.c"
	}
#line 1315 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp8_ = offset;
#line 1315 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	if (_tmp8_ < ((glong) 0)) {
#line 7347 "FlickrPublishing.c"
		glong _tmp9_ = 0L;
		glong _tmp10_ = 0L;
		glong _tmp11_ = 0L;
#line 1316 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp9_ = string_length;
#line 1316 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp10_ = offset;
#line 1316 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		offset = _tmp9_ + _tmp10_;
#line 1317 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp11_ = offset;
#line 1317 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		g_return_val_if_fail (_tmp11_ >= ((glong) 0), NULL);
#line 7361 "FlickrPublishing.c"
	} else {
		glong _tmp12_ = 0L;
		glong _tmp13_ = 0L;
#line 1319 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp12_ = offset;
#line 1319 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp13_ = string_length;
#line 1319 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		g_return_val_if_fail (_tmp12_ <= _tmp13_, NULL);
#line 7371 "FlickrPublishing.c"
	}
#line 1321 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp14_ = len;
#line 1321 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	if (_tmp14_ < ((glong) 0)) {
#line 7377 "FlickrPublishing.c"
		glong _tmp15_ = 0L;
		glong _tmp16_ = 0L;
#line 1322 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp15_ = string_length;
#line 1322 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		_tmp16_ = offset;
#line 1322 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
		len = _tmp15_ - _tmp16_;
#line 7386 "FlickrPublishing.c"
	}
#line 1324 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp17_ = offset;
#line 1324 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp18_ = len;
#line 1324 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp19_ = string_length;
#line 1324 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	g_return_val_if_fail ((_tmp17_ + _tmp18_) <= _tmp19_, NULL);
#line 1325 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp20_ = offset;
#line 1325 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp21_ = len;
#line 1325 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	_tmp22_ = g_strndup (((gchar*) self) + _tmp20_, (gsize) _tmp21_);
#line 1325 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	result = _tmp22_;
#line 1325 "/usr/share/vala-0.32/vapi/glib-2.0.vapi"
	return result;
#line 7406 "FlickrPublishing.c"
}


gchar* publishing_flickr_session_get_oauth_timestamp (PublishingFlickrSession* self) {
	gchar* result = NULL;
	gint64 _tmp0_ = 0LL;
	gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
#line 1063 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (PUBLISHING_FLICKR_IS_SESSION (self), NULL);
#line 1064 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = g_get_real_time ();
#line 1064 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = g_strdup_printf ("%" G_GINT64_FORMAT, _tmp0_);
#line 1064 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp2_ = _tmp1_;
#line 1064 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp3_ = string_substring (_tmp2_, (glong) 0, (glong) 10);
#line 1064 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp4_ = _tmp3_;
#line 1064 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (_tmp2_);
#line 1064 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	result = _tmp4_;
#line 1064 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return result;
#line 7435 "FlickrPublishing.c"
}


gchar* publishing_flickr_session_get_request_phase_token (PublishingFlickrSession* self) {
	gchar* result = NULL;
	const gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
#line 1067 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (PUBLISHING_FLICKR_IS_SESSION (self), NULL);
#line 1068 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = self->priv->request_phase_token;
#line 1068 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_vala_assert (_tmp0_ != NULL, "request_phase_token != null");
#line 1069 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = self->priv->request_phase_token;
#line 1069 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp2_ = g_strdup (_tmp1_);
#line 1069 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	result = _tmp2_;
#line 1069 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return result;
#line 7458 "FlickrPublishing.c"
}


gchar* publishing_flickr_session_get_access_phase_token (PublishingFlickrSession* self) {
	gchar* result = NULL;
	const gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
#line 1072 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (PUBLISHING_FLICKR_IS_SESSION (self), NULL);
#line 1073 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = self->priv->access_phase_token;
#line 1073 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_vala_assert (_tmp0_ != NULL, "access_phase_token != null");
#line 1074 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = self->priv->access_phase_token;
#line 1074 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp2_ = g_strdup (_tmp1_);
#line 1074 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	result = _tmp2_;
#line 1074 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return result;
#line 7481 "FlickrPublishing.c"
}


gchar* publishing_flickr_session_get_access_phase_token_secret (PublishingFlickrSession* self) {
	gchar* result = NULL;
	const gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
#line 1077 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (PUBLISHING_FLICKR_IS_SESSION (self), NULL);
#line 1078 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = self->priv->access_phase_token_secret;
#line 1078 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_vala_assert (_tmp0_ != NULL, "access_phase_token_secret != null");
#line 1079 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = self->priv->access_phase_token_secret;
#line 1079 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp2_ = g_strdup (_tmp1_);
#line 1079 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	result = _tmp2_;
#line 1079 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return result;
#line 7504 "FlickrPublishing.c"
}


gchar* publishing_flickr_session_get_username (PublishingFlickrSession* self) {
	gchar* result = NULL;
	gboolean _tmp0_ = FALSE;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
#line 1082 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (PUBLISHING_FLICKR_IS_SESSION (self), NULL);
#line 1083 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = publishing_rest_support_session_is_authenticated (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession));
#line 1083 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_vala_assert (_tmp0_, "is_authenticated()");
#line 1084 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = self->priv->username;
#line 1084 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp2_ = g_strdup (_tmp1_);
#line 1084 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	result = _tmp2_;
#line 1084 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return result;
#line 7527 "FlickrPublishing.c"
}


static void publishing_flickr_session_class_init (PublishingFlickrSessionClass * klass) {
#line 945 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_session_parent_class = g_type_class_peek_parent (klass);
#line 945 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	((PublishingRESTSupportSessionClass *) klass)->finalize = publishing_flickr_session_finalize;
#line 945 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_type_class_add_private (klass, sizeof (PublishingFlickrSessionPrivate));
#line 945 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	((PublishingRESTSupportSessionClass *) klass)->is_authenticated = publishing_flickr_session_real_is_authenticated;
#line 7540 "FlickrPublishing.c"
}


static void publishing_flickr_session_instance_init (PublishingFlickrSession * self) {
#line 945 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv = PUBLISHING_FLICKR_SESSION_GET_PRIVATE (self);
#line 946 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->request_phase_token = NULL;
#line 947 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->request_phase_token_secret = NULL;
#line 948 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->access_phase_token = NULL;
#line 949 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->access_phase_token_secret = NULL;
#line 950 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->username = NULL;
#line 7557 "FlickrPublishing.c"
}


static void publishing_flickr_session_finalize (PublishingRESTSupportSession* obj) {
	PublishingFlickrSession * self;
#line 945 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_FLICKR_TYPE_SESSION, PublishingFlickrSession);
#line 946 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (self->priv->request_phase_token);
#line 947 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (self->priv->request_phase_token_secret);
#line 948 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (self->priv->access_phase_token);
#line 949 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (self->priv->access_phase_token_secret);
#line 950 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (self->priv->username);
#line 945 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	PUBLISHING_REST_SUPPORT_SESSION_CLASS (publishing_flickr_session_parent_class)->finalize (obj);
#line 7577 "FlickrPublishing.c"
}


GType publishing_flickr_session_get_type (void) {
	static volatile gsize publishing_flickr_session_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_flickr_session_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingFlickrSessionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_flickr_session_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingFlickrSession), 0, (GInstanceInitFunc) publishing_flickr_session_instance_init, NULL };
		GType publishing_flickr_session_type_id;
		publishing_flickr_session_type_id = g_type_register_static (PUBLISHING_REST_SUPPORT_TYPE_SESSION, "PublishingFlickrSession", &g_define_type_info, 0);
		g_once_init_leave (&publishing_flickr_session_type_id__volatile, publishing_flickr_session_type_id);
	}
	return publishing_flickr_session_type_id__volatile;
}


static void _publishing_flickr_publishing_options_pane_on_visibility_changed_gtk_combo_box_changed (GtkComboBox* _sender, gpointer self) {
#line 1175 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_publishing_options_pane_on_visibility_changed ((PublishingFlickrPublishingOptionsPane*) self);
#line 7596 "FlickrPublishing.c"
}


static void _publishing_flickr_publishing_options_pane_on_size_changed_gtk_combo_box_changed (GtkComboBox* _sender, gpointer self) {
#line 1179 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_publishing_options_pane_on_size_changed ((PublishingFlickrPublishingOptionsPane*) self);
#line 7603 "FlickrPublishing.c"
}


static void _publishing_flickr_publishing_options_pane_on_logout_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 1188 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_publishing_options_pane_on_logout_clicked ((PublishingFlickrPublishingOptionsPane*) self);
#line 7610 "FlickrPublishing.c"
}


static void _publishing_flickr_publishing_options_pane_on_publish_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 1189 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_publishing_options_pane_on_publish_clicked ((PublishingFlickrPublishingOptionsPane*) self);
#line 7617 "FlickrPublishing.c"
}


PublishingFlickrPublishingOptionsPane* publishing_flickr_publishing_options_pane_construct (GType object_type, PublishingFlickrFlickrPublisher* publisher, PublishingFlickrPublishingParameters* parameters, SpitPublishingPublisherMediaType media_type, GtkBuilder* builder, gboolean strip_metadata) {
	PublishingFlickrPublishingOptionsPane * self = NULL;
	GtkBuilder* _tmp0_ = NULL;
	GtkBuilder* _tmp1_ = NULL;
	GtkBuilder* _tmp2_ = NULL;
	GtkBuilder* _tmp3_ = NULL;
	GSList* _tmp4_ = NULL;
	GSList* _tmp5_ = NULL;
	guint _tmp6_ = 0U;
	GtkBuilder* _tmp7_ = NULL;
	GObject* _tmp8_ = NULL;
	GtkBox* _tmp9_ = NULL;
	GtkBuilder* _tmp10_ = NULL;
	GObject* _tmp11_ = NULL;
	GtkLabel* _tmp12_ = NULL;
	GtkBuilder* _tmp13_ = NULL;
	GObject* _tmp14_ = NULL;
	GtkLabel* _tmp15_ = NULL;
	GtkBuilder* _tmp16_ = NULL;
	GObject* _tmp17_ = NULL;
	GtkButton* _tmp18_ = NULL;
	GtkBuilder* _tmp19_ = NULL;
	GObject* _tmp20_ = NULL;
	GtkButton* _tmp21_ = NULL;
	GtkBuilder* _tmp22_ = NULL;
	GObject* _tmp23_ = NULL;
	GtkComboBoxText* _tmp24_ = NULL;
	GtkBuilder* _tmp25_ = NULL;
	GObject* _tmp26_ = NULL;
	GtkComboBoxText* _tmp27_ = NULL;
	GtkBuilder* _tmp28_ = NULL;
	GObject* _tmp29_ = NULL;
	GtkLabel* _tmp30_ = NULL;
	GtkBuilder* _tmp31_ = NULL;
	GObject* _tmp32_ = NULL;
	GtkCheckButton* _tmp33_ = NULL;
	PublishingFlickrPublishingParameters* _tmp34_ = NULL;
	PublishingFlickrPublishingParameters* _tmp35_ = NULL;
	PublishingFlickrFlickrPublisher* _tmp36_ = NULL;
	PublishingFlickrFlickrPublisher* _tmp37_ = NULL;
	SpitPublishingPublisherMediaType _tmp38_ = 0;
	gint _tmp39_ = 0;
	PublishingFlickrPublishingOptionsPaneVisibilityEntry** _tmp40_ = NULL;
	gint _tmp41_ = 0;
	PublishingFlickrPublishingOptionsPaneSizeEntry** _tmp42_ = NULL;
	gchar* upload_label_text = NULL;
	const gchar* _tmp43_ = NULL;
	PublishingFlickrPublishingParameters* _tmp44_ = NULL;
	const gchar* _tmp45_ = NULL;
	gchar* _tmp46_ = NULL;
	PublishingFlickrPublishingParameters* _tmp47_ = NULL;
	PublishingFlickrUserKind _tmp48_ = 0;
	GtkLabel* _tmp61_ = NULL;
	const gchar* _tmp62_ = NULL;
	gchar* visibility_label_text = NULL;
	const gchar* _tmp63_ = NULL;
	gchar* _tmp64_ = NULL;
	SpitPublishingPublisherMediaType _tmp65_ = 0;
	GtkLabel* _tmp71_ = NULL;
	const gchar* _tmp72_ = NULL;
	GtkComboBoxText* _tmp73_ = NULL;
	SpitPublishingPublisherMediaType _tmp74_ = 0;
	GtkCheckButton* _tmp78_ = NULL;
	gboolean _tmp79_ = FALSE;
	GtkButton* _tmp80_ = NULL;
	GtkButton* _tmp81_ = NULL;
#line 1128 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (PUBLISHING_FLICKR_IS_FLICKR_PUBLISHER (publisher), NULL);
#line 1128 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (PUBLISHING_FLICKR_IS_PUBLISHING_PARAMETERS (parameters), NULL);
#line 1128 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (GTK_IS_BUILDER (builder), NULL);
#line 1128 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = (PublishingFlickrPublishingOptionsPane*) g_object_new (object_type, NULL);
#line 1130 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = builder;
#line 1130 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 1130 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (self->priv->builder);
#line 1130 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->builder = _tmp1_;
#line 1131 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp2_ = builder;
#line 1131 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_vala_assert (_tmp2_ != NULL, "builder != null");
#line 1132 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp3_ = builder;
#line 1132 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp4_ = gtk_builder_get_objects (_tmp3_);
#line 1132 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp5_ = _tmp4_;
#line 1132 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp6_ = g_slist_length (_tmp5_);
#line 1132 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_vala_assert (_tmp6_ > ((guint) 0), "builder.get_objects().length() > 0");
#line 1132 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_slist_free0 (_tmp5_);
#line 1135 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp7_ = self->priv->builder;
#line 1135 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp8_ = gtk_builder_get_object (_tmp7_, "flickr_pane");
#line 1135 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp9_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, gtk_box_get_type (), GtkBox));
#line 1135 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (self->priv->pane_widget);
#line 1135 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->pane_widget = _tmp9_;
#line 1136 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp10_ = self->priv->builder;
#line 1136 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp11_ = gtk_builder_get_object (_tmp10_, "visibility_label");
#line 1136 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp12_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp11_, gtk_label_get_type (), GtkLabel));
#line 1136 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (self->priv->visibility_label);
#line 1136 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->visibility_label = _tmp12_;
#line 1137 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp13_ = self->priv->builder;
#line 1137 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp14_ = gtk_builder_get_object (_tmp13_, "upload_info_label");
#line 1137 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp15_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp14_, gtk_label_get_type (), GtkLabel));
#line 1137 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (self->priv->upload_info_label);
#line 1137 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->upload_info_label = _tmp15_;
#line 1138 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp16_ = self->priv->builder;
#line 1138 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp17_ = gtk_builder_get_object (_tmp16_, "logout_button");
#line 1138 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp18_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp17_, gtk_button_get_type (), GtkButton));
#line 1138 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (self->priv->logout_button);
#line 1138 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->logout_button = _tmp18_;
#line 1139 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp19_ = self->priv->builder;
#line 1139 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp20_ = gtk_builder_get_object (_tmp19_, "publish_button");
#line 1139 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp21_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp20_, gtk_button_get_type (), GtkButton));
#line 1139 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (self->priv->publish_button);
#line 1139 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->publish_button = _tmp21_;
#line 1140 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp22_ = self->priv->builder;
#line 1140 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp23_ = gtk_builder_get_object (_tmp22_, "visibility_combo");
#line 1140 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp24_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp23_, gtk_combo_box_text_get_type (), GtkComboBoxText));
#line 1140 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (self->priv->visibility_combo);
#line 1140 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->visibility_combo = _tmp24_;
#line 1141 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp25_ = self->priv->builder;
#line 1141 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp26_ = gtk_builder_get_object (_tmp25_, "size_combo");
#line 1141 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp27_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp26_, gtk_combo_box_text_get_type (), GtkComboBoxText));
#line 1141 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (self->priv->size_combo);
#line 1141 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->size_combo = _tmp27_;
#line 1142 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp28_ = self->priv->builder;
#line 1142 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp29_ = gtk_builder_get_object (_tmp28_, "size_label");
#line 1142 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp30_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp29_, gtk_label_get_type (), GtkLabel));
#line 1142 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (self->priv->size_label);
#line 1142 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->size_label = _tmp30_;
#line 1143 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp31_ = self->priv->builder;
#line 1143 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp32_ = gtk_builder_get_object (_tmp31_, "strip_metadata_check");
#line 1143 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp33_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp32_, gtk_check_button_get_type (), GtkCheckButton));
#line 1143 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (self->priv->strip_metadata_check);
#line 1143 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->strip_metadata_check = _tmp33_;
#line 1145 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp34_ = parameters;
#line 1145 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp35_ = _publishing_flickr_publishing_parameters_ref0 (_tmp34_);
#line 1145 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_publishing_flickr_publishing_parameters_unref0 (self->priv->parameters);
#line 1145 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->parameters = _tmp35_;
#line 1146 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp36_ = publisher;
#line 1146 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp37_ = _g_object_ref0 (_tmp36_);
#line 1146 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (self->priv->publisher);
#line 1146 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->publisher = _tmp37_;
#line 1147 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp38_ = media_type;
#line 1147 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->media_type = _tmp38_;
#line 1149 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp40_ = publishing_flickr_publishing_options_pane_create_visibilities (self, &_tmp39_);
#line 1149 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->visibilities = (_vala_array_free (self->priv->visibilities, self->priv->visibilities_length1, (GDestroyNotify) publishing_flickr_publishing_options_pane_visibility_entry_unref), NULL);
#line 1149 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->visibilities = _tmp40_;
#line 1149 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->visibilities_length1 = _tmp39_;
#line 1149 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->_visibilities_size_ = self->priv->visibilities_length1;
#line 1150 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp42_ = publishing_flickr_publishing_options_pane_create_sizes (self, &_tmp41_);
#line 1150 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->sizes = (_vala_array_free (self->priv->sizes, self->priv->sizes_length1, (GDestroyNotify) publishing_flickr_publishing_options_pane_size_entry_unref), NULL);
#line 1150 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->sizes = _tmp42_;
#line 1150 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->sizes_length1 = _tmp41_;
#line 1150 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->_sizes_size_ = self->priv->sizes_length1;
#line 1152 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp43_ = _ ("You are logged into Flickr as %s.\n\n");
#line 1152 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp44_ = parameters;
#line 1152 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp45_ = _tmp44_->username;
#line 1152 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp46_ = g_strdup_printf (_tmp43_, _tmp45_);
#line 1152 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	upload_label_text = _tmp46_;
#line 1153 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp47_ = parameters;
#line 1153 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp48_ = _tmp47_->user_kind;
#line 1153 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (_tmp48_ == PUBLISHING_FLICKR_USER_KIND_FREE) {
#line 7865 "FlickrPublishing.c"
		const gchar* _tmp49_ = NULL;
		PublishingFlickrPublishingParameters* _tmp50_ = NULL;
		gint _tmp51_ = 0;
		const gchar* _tmp52_ = NULL;
		PublishingFlickrPublishingParameters* _tmp53_ = NULL;
		gint _tmp54_ = 0;
		gchar* _tmp55_ = NULL;
		gchar* _tmp56_ = NULL;
		gchar* _tmp57_ = NULL;
#line 1154 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp49_ = upload_label_text;
#line 1154 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp50_ = parameters;
#line 1154 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp51_ = _tmp50_->quota_free_mb;
#line 1154 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp52_ = ngettext ("Your free Flickr account limits how much data you can upload per month" \
".\n" \
"This month you have %d megabyte remaining in your upload quota.", "Your free Flickr account limits how much data you can upload per month" \
".\n" \
"This month you have %d megabytes remaining in your upload quota.", (gulong) _tmp51_);
#line 1154 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp53_ = parameters;
#line 1154 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp54_ = _tmp53_->quota_free_mb;
#line 1154 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp55_ = g_strdup_printf (_tmp52_, _tmp54_);
#line 1154 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp56_ = _tmp55_;
#line 1154 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp57_ = g_strconcat (_tmp49_, _tmp56_, NULL);
#line 1154 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_free0 (upload_label_text);
#line 1154 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		upload_label_text = _tmp57_;
#line 1154 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_free0 (_tmp56_);
#line 7899 "FlickrPublishing.c"
	} else {
		const gchar* _tmp58_ = NULL;
		const gchar* _tmp59_ = NULL;
		gchar* _tmp60_ = NULL;
#line 1159 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp58_ = upload_label_text;
#line 1159 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp59_ = _ ("Your Flickr Pro account entitles you to unlimited uploads.");
#line 1159 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp60_ = g_strconcat (_tmp58_, _tmp59_, NULL);
#line 1159 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_free0 (upload_label_text);
#line 1159 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		upload_label_text = _tmp60_;
#line 7914 "FlickrPublishing.c"
	}
#line 1162 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp61_ = self->priv->upload_info_label;
#line 1162 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp62_ = upload_label_text;
#line 1162 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	gtk_label_set_label (_tmp61_, _tmp62_);
#line 1164 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp63_ = _ ("Photos _visible to:");
#line 1164 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp64_ = g_strdup (_tmp63_);
#line 1164 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	visibility_label_text = _tmp64_;
#line 1165 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp65_ = media_type;
#line 1165 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (_tmp65_ == SPIT_PUBLISHING_PUBLISHER_MEDIA_TYPE_VIDEO) {
#line 7932 "FlickrPublishing.c"
		const gchar* _tmp66_ = NULL;
		gchar* _tmp67_ = NULL;
#line 1166 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp66_ = _ ("Videos _visible to:");
#line 1166 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp67_ = g_strdup (_tmp66_);
#line 1166 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_free0 (visibility_label_text);
#line 1166 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		visibility_label_text = _tmp67_;
#line 7943 "FlickrPublishing.c"
	} else {
		SpitPublishingPublisherMediaType _tmp68_ = 0;
#line 1167 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp68_ = media_type;
#line 1167 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		if (_tmp68_ == (SPIT_PUBLISHING_PUBLISHER_MEDIA_TYPE_PHOTO | SPIT_PUBLISHING_PUBLISHER_MEDIA_TYPE_VIDEO)) {
#line 7950 "FlickrPublishing.c"
			const gchar* _tmp69_ = NULL;
			gchar* _tmp70_ = NULL;
#line 1169 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_tmp69_ = _ ("Photos and videos _visible to:");
#line 1169 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_tmp70_ = g_strdup (_tmp69_);
#line 1169 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_g_free0 (visibility_label_text);
#line 1169 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			visibility_label_text = _tmp70_;
#line 7961 "FlickrPublishing.c"
		}
	}
#line 1172 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp71_ = self->priv->visibility_label;
#line 1172 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp72_ = visibility_label_text;
#line 1172 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	gtk_label_set_label (_tmp71_, _tmp72_);
#line 1174 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_publishing_options_pane_populate_visibility_combo (self);
#line 1175 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp73_ = self->priv->visibility_combo;
#line 1175 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp73_, gtk_combo_box_get_type (), GtkComboBox), "changed", (GCallback) _publishing_flickr_publishing_options_pane_on_visibility_changed_gtk_combo_box_changed, self, 0);
#line 1177 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp74_ = media_type;
#line 1177 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (_tmp74_ != SPIT_PUBLISHING_PUBLISHER_MEDIA_TYPE_VIDEO) {
#line 7980 "FlickrPublishing.c"
		GtkComboBoxText* _tmp75_ = NULL;
#line 1178 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		publishing_flickr_publishing_options_pane_populate_size_combo (self);
#line 1179 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp75_ = self->priv->size_combo;
#line 1179 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp75_, gtk_combo_box_get_type (), GtkComboBox), "changed", (GCallback) _publishing_flickr_publishing_options_pane_on_size_changed_gtk_combo_box_changed, self, 0);
#line 7988 "FlickrPublishing.c"
	} else {
		GtkComboBoxText* _tmp76_ = NULL;
		GtkLabel* _tmp77_ = NULL;
#line 1182 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp76_ = self->priv->size_combo;
#line 1182 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp76_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 1183 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp77_ = self->priv->size_label;
#line 1183 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp77_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 8000 "FlickrPublishing.c"
	}
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp78_ = self->priv->strip_metadata_check;
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp79_ = strip_metadata;
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	gtk_toggle_button_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp78_, gtk_toggle_button_get_type (), GtkToggleButton), _tmp79_);
#line 1188 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp80_ = self->priv->logout_button;
#line 1188 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_connect_object (_tmp80_, "clicked", (GCallback) _publishing_flickr_publishing_options_pane_on_logout_clicked_gtk_button_clicked, self, 0);
#line 1189 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp81_ = self->priv->publish_button;
#line 1189 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_connect_object (_tmp81_, "clicked", (GCallback) _publishing_flickr_publishing_options_pane_on_publish_clicked_gtk_button_clicked, self, 0);
#line 1128 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (visibility_label_text);
#line 1128 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (upload_label_text);
#line 1128 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return self;
#line 8022 "FlickrPublishing.c"
}


PublishingFlickrPublishingOptionsPane* publishing_flickr_publishing_options_pane_new (PublishingFlickrFlickrPublisher* publisher, PublishingFlickrPublishingParameters* parameters, SpitPublishingPublisherMediaType media_type, GtkBuilder* builder, gboolean strip_metadata) {
#line 1128 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return publishing_flickr_publishing_options_pane_construct (PUBLISHING_FLICKR_TYPE_PUBLISHING_OPTIONS_PANE, publisher, parameters, media_type, builder, strip_metadata);
#line 8029 "FlickrPublishing.c"
}


static void publishing_flickr_publishing_options_pane_on_logout_clicked (PublishingFlickrPublishingOptionsPane* self) {
#line 1192 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_PUBLISHING_OPTIONS_PANE (self));
#line 1193 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_emit_by_name (self, "logout");
#line 8038 "FlickrPublishing.c"
}


static gpointer _publishing_flickr_visibility_specification_ref0 (gpointer self) {
#line 1197 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return self ? publishing_flickr_visibility_specification_ref (self) : NULL;
#line 8045 "FlickrPublishing.c"
}


static void publishing_flickr_publishing_options_pane_on_publish_clicked (PublishingFlickrPublishingOptionsPane* self) {
	PublishingFlickrPublishingParameters* _tmp0_ = NULL;
	PublishingFlickrPublishingOptionsPaneVisibilityEntry** _tmp1_ = NULL;
	gint _tmp1__length1 = 0;
	GtkComboBoxText* _tmp2_ = NULL;
	gint _tmp3_ = 0;
	PublishingFlickrPublishingOptionsPaneVisibilityEntry* _tmp4_ = NULL;
	PublishingFlickrVisibilitySpecification* _tmp5_ = NULL;
	PublishingFlickrVisibilitySpecification* _tmp6_ = NULL;
	SpitPublishingPublisherMediaType _tmp7_ = 0;
	GtkCheckButton* _tmp14_ = NULL;
	gboolean _tmp15_ = FALSE;
#line 1196 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_PUBLISHING_OPTIONS_PANE (self));
#line 1197 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = self->priv->parameters;
#line 1197 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = self->priv->visibilities;
#line 1197 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1__length1 = self->priv->visibilities_length1;
#line 1197 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp2_ = self->priv->visibility_combo;
#line 1197 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp3_ = gtk_combo_box_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, gtk_combo_box_get_type (), GtkComboBox));
#line 1197 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp4_ = _tmp1_[_tmp3_];
#line 1197 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp5_ = _tmp4_->specification;
#line 1197 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp6_ = _publishing_flickr_visibility_specification_ref0 (_tmp5_);
#line 1197 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_publishing_flickr_visibility_specification_unref0 (_tmp0_->visibility_specification);
#line 1197 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_->visibility_specification = _tmp6_;
#line 1200 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp7_ = self->priv->media_type;
#line 1200 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if ((_tmp7_ & SPIT_PUBLISHING_PUBLISHER_MEDIA_TYPE_PHOTO) != 0) {
#line 8087 "FlickrPublishing.c"
		PublishingFlickrPublishingParameters* _tmp8_ = NULL;
		PublishingFlickrPublishingOptionsPaneSizeEntry** _tmp9_ = NULL;
		gint _tmp9__length1 = 0;
		GtkComboBoxText* _tmp10_ = NULL;
		gint _tmp11_ = 0;
		PublishingFlickrPublishingOptionsPaneSizeEntry* _tmp12_ = NULL;
		gint _tmp13_ = 0;
#line 1201 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp8_ = self->priv->parameters;
#line 1201 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp9_ = self->priv->sizes;
#line 1201 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp9__length1 = self->priv->sizes_length1;
#line 1201 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp10_ = self->priv->size_combo;
#line 1201 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp11_ = gtk_combo_box_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, gtk_combo_box_get_type (), GtkComboBox));
#line 1201 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp12_ = _tmp9_[_tmp11_];
#line 1201 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp13_ = _tmp12_->size;
#line 1201 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp8_->photo_major_axis_size = _tmp13_;
#line 8111 "FlickrPublishing.c"
	}
#line 1203 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp14_ = self->priv->strip_metadata_check;
#line 1203 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp15_ = gtk_toggle_button_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp14_, gtk_toggle_button_get_type (), GtkToggleButton));
#line 1203 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_emit_by_name (self, "publish", _tmp15_);
#line 8119 "FlickrPublishing.c"
}


static void _vala_array_add20 (PublishingFlickrPublishingOptionsPaneVisibilityEntry*** array, int* length, int* size, PublishingFlickrPublishingOptionsPaneVisibilityEntry* value) {
#line 1209 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if ((*length) == (*size)) {
#line 1209 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 1209 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		*array = g_renew (PublishingFlickrPublishingOptionsPaneVisibilityEntry*, *array, (*size) + 1);
#line 8130 "FlickrPublishing.c"
	}
#line 1209 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	(*array)[(*length)++] = value;
#line 1209 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	(*array)[*length] = NULL;
#line 8136 "FlickrPublishing.c"
}


static void _vala_array_add21 (PublishingFlickrPublishingOptionsPaneVisibilityEntry*** array, int* length, int* size, PublishingFlickrPublishingOptionsPaneVisibilityEntry* value) {
#line 1210 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if ((*length) == (*size)) {
#line 1210 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 1210 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		*array = g_renew (PublishingFlickrPublishingOptionsPaneVisibilityEntry*, *array, (*size) + 1);
#line 8147 "FlickrPublishing.c"
	}
#line 1210 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	(*array)[(*length)++] = value;
#line 1210 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	(*array)[*length] = NULL;
#line 8153 "FlickrPublishing.c"
}


static void _vala_array_add22 (PublishingFlickrPublishingOptionsPaneVisibilityEntry*** array, int* length, int* size, PublishingFlickrPublishingOptionsPaneVisibilityEntry* value) {
#line 1211 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if ((*length) == (*size)) {
#line 1211 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 1211 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		*array = g_renew (PublishingFlickrPublishingOptionsPaneVisibilityEntry*, *array, (*size) + 1);
#line 8164 "FlickrPublishing.c"
	}
#line 1211 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	(*array)[(*length)++] = value;
#line 1211 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	(*array)[*length] = NULL;
#line 8170 "FlickrPublishing.c"
}


static void _vala_array_add23 (PublishingFlickrPublishingOptionsPaneVisibilityEntry*** array, int* length, int* size, PublishingFlickrPublishingOptionsPaneVisibilityEntry* value) {
#line 1212 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if ((*length) == (*size)) {
#line 1212 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 1212 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		*array = g_renew (PublishingFlickrPublishingOptionsPaneVisibilityEntry*, *array, (*size) + 1);
#line 8181 "FlickrPublishing.c"
	}
#line 1212 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	(*array)[(*length)++] = value;
#line 1212 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	(*array)[*length] = NULL;
#line 8187 "FlickrPublishing.c"
}


static void _vala_array_add24 (PublishingFlickrPublishingOptionsPaneVisibilityEntry*** array, int* length, int* size, PublishingFlickrPublishingOptionsPaneVisibilityEntry* value) {
#line 1213 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if ((*length) == (*size)) {
#line 1213 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 1213 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		*array = g_renew (PublishingFlickrPublishingOptionsPaneVisibilityEntry*, *array, (*size) + 1);
#line 8198 "FlickrPublishing.c"
	}
#line 1213 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	(*array)[(*length)++] = value;
#line 1213 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	(*array)[*length] = NULL;
#line 8204 "FlickrPublishing.c"
}


static PublishingFlickrPublishingOptionsPaneVisibilityEntry** publishing_flickr_publishing_options_pane_create_visibilities (PublishingFlickrPublishingOptionsPane* self, int* result_length1) {
	PublishingFlickrPublishingOptionsPaneVisibilityEntry** result = NULL;
	PublishingFlickrPublishingOptionsPaneVisibilityEntry** _result_ = NULL;
	PublishingFlickrPublishingOptionsPaneVisibilityEntry** _tmp0_ = NULL;
	gint _result__length1 = 0;
	gint __result__size_ = 0;
	PublishingFlickrPublishingOptionsPaneVisibilityEntry** _tmp1_ = NULL;
	gint _tmp1__length1 = 0;
	const gchar* _tmp2_ = NULL;
	PublishingFlickrVisibilitySpecification* _tmp3_ = NULL;
	PublishingFlickrVisibilitySpecification* _tmp4_ = NULL;
	PublishingFlickrPublishingOptionsPaneVisibilityEntry* _tmp5_ = NULL;
	PublishingFlickrPublishingOptionsPaneVisibilityEntry** _tmp6_ = NULL;
	gint _tmp6__length1 = 0;
	const gchar* _tmp7_ = NULL;
	PublishingFlickrVisibilitySpecification* _tmp8_ = NULL;
	PublishingFlickrVisibilitySpecification* _tmp9_ = NULL;
	PublishingFlickrPublishingOptionsPaneVisibilityEntry* _tmp10_ = NULL;
	PublishingFlickrPublishingOptionsPaneVisibilityEntry** _tmp11_ = NULL;
	gint _tmp11__length1 = 0;
	const gchar* _tmp12_ = NULL;
	PublishingFlickrVisibilitySpecification* _tmp13_ = NULL;
	PublishingFlickrVisibilitySpecification* _tmp14_ = NULL;
	PublishingFlickrPublishingOptionsPaneVisibilityEntry* _tmp15_ = NULL;
	PublishingFlickrPublishingOptionsPaneVisibilityEntry** _tmp16_ = NULL;
	gint _tmp16__length1 = 0;
	const gchar* _tmp17_ = NULL;
	PublishingFlickrVisibilitySpecification* _tmp18_ = NULL;
	PublishingFlickrVisibilitySpecification* _tmp19_ = NULL;
	PublishingFlickrPublishingOptionsPaneVisibilityEntry* _tmp20_ = NULL;
	PublishingFlickrPublishingOptionsPaneVisibilityEntry** _tmp21_ = NULL;
	gint _tmp21__length1 = 0;
	const gchar* _tmp22_ = NULL;
	PublishingFlickrVisibilitySpecification* _tmp23_ = NULL;
	PublishingFlickrVisibilitySpecification* _tmp24_ = NULL;
	PublishingFlickrPublishingOptionsPaneVisibilityEntry* _tmp25_ = NULL;
	PublishingFlickrPublishingOptionsPaneVisibilityEntry** _tmp26_ = NULL;
	gint _tmp26__length1 = 0;
#line 1206 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (PUBLISHING_FLICKR_IS_PUBLISHING_OPTIONS_PANE (self), NULL);
#line 1207 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = g_new0 (PublishingFlickrPublishingOptionsPaneVisibilityEntry*, 0 + 1);
#line 1207 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_result_ = _tmp0_;
#line 1207 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_result__length1 = 0;
#line 1207 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	__result__size_ = _result__length1;
#line 1209 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = _result_;
#line 1209 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1__length1 = _result__length1;
#line 1209 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp2_ = _ ("Everyone");
#line 1209 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp3_ = publishing_flickr_visibility_specification_new (1, 1, 1);
#line 1209 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp4_ = _tmp3_;
#line 1209 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp5_ = publishing_flickr_publishing_options_pane_visibility_entry_new (_tmp2_, _tmp4_);
#line 1209 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_vala_array_add20 (&_result_, &_result__length1, &__result__size_, _tmp5_);
#line 1209 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_publishing_flickr_visibility_specification_unref0 (_tmp4_);
#line 1210 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp6_ = _result_;
#line 1210 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp6__length1 = _result__length1;
#line 1210 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp7_ = _ ("Friends & family only");
#line 1210 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp8_ = publishing_flickr_visibility_specification_new (1, 1, 0);
#line 1210 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp9_ = _tmp8_;
#line 1210 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp10_ = publishing_flickr_publishing_options_pane_visibility_entry_new (_tmp7_, _tmp9_);
#line 1210 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_vala_array_add21 (&_result_, &_result__length1, &__result__size_, _tmp10_);
#line 1210 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_publishing_flickr_visibility_specification_unref0 (_tmp9_);
#line 1211 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp11_ = _result_;
#line 1211 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp11__length1 = _result__length1;
#line 1211 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp12_ = _ ("Family only");
#line 1211 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp13_ = publishing_flickr_visibility_specification_new (0, 1, 0);
#line 1211 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp14_ = _tmp13_;
#line 1211 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp15_ = publishing_flickr_publishing_options_pane_visibility_entry_new (_tmp12_, _tmp14_);
#line 1211 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_vala_array_add22 (&_result_, &_result__length1, &__result__size_, _tmp15_);
#line 1211 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_publishing_flickr_visibility_specification_unref0 (_tmp14_);
#line 1212 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp16_ = _result_;
#line 1212 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp16__length1 = _result__length1;
#line 1212 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp17_ = _ ("Friends only");
#line 1212 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp18_ = publishing_flickr_visibility_specification_new (1, 0, 0);
#line 1212 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp19_ = _tmp18_;
#line 1212 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp20_ = publishing_flickr_publishing_options_pane_visibility_entry_new (_tmp17_, _tmp19_);
#line 1212 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_vala_array_add23 (&_result_, &_result__length1, &__result__size_, _tmp20_);
#line 1212 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_publishing_flickr_visibility_specification_unref0 (_tmp19_);
#line 1213 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp21_ = _result_;
#line 1213 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp21__length1 = _result__length1;
#line 1213 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp22_ = _ ("Just me");
#line 1213 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp23_ = publishing_flickr_visibility_specification_new (0, 0, 0);
#line 1213 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp24_ = _tmp23_;
#line 1213 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp25_ = publishing_flickr_publishing_options_pane_visibility_entry_new (_tmp22_, _tmp24_);
#line 1213 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_vala_array_add24 (&_result_, &_result__length1, &__result__size_, _tmp25_);
#line 1213 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_publishing_flickr_visibility_specification_unref0 (_tmp24_);
#line 1215 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp26_ = _result_;
#line 1215 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp26__length1 = _result__length1;
#line 1215 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (result_length1) {
#line 1215 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		*result_length1 = _tmp26__length1;
#line 8344 "FlickrPublishing.c"
	}
#line 1215 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	result = _tmp26_;
#line 1215 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return result;
#line 8350 "FlickrPublishing.c"
}


static gpointer _publishing_flickr_publishing_options_pane_visibility_entry_ref0 (gpointer self) {
#line 1222 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return self ? publishing_flickr_publishing_options_pane_visibility_entry_ref (self) : NULL;
#line 8357 "FlickrPublishing.c"
}


static void publishing_flickr_publishing_options_pane_populate_visibility_combo (PublishingFlickrPublishingOptionsPane* self) {
	PublishingFlickrPublishingOptionsPaneVisibilityEntry** _tmp0_ = NULL;
	gint _tmp0__length1 = 0;
	PublishingFlickrPublishingOptionsPaneVisibilityEntry** _tmp3_ = NULL;
	gint _tmp3__length1 = 0;
	GtkComboBoxText* _tmp8_ = NULL;
	PublishingFlickrFlickrPublisher* _tmp9_ = NULL;
	gint _tmp10_ = 0;
#line 1218 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_PUBLISHING_OPTIONS_PANE (self));
#line 1219 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = self->priv->visibilities;
#line 1219 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0__length1 = self->priv->visibilities_length1;
#line 1219 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (_tmp0_ == NULL) {
#line 8377 "FlickrPublishing.c"
		gint _tmp1_ = 0;
		PublishingFlickrPublishingOptionsPaneVisibilityEntry** _tmp2_ = NULL;
#line 1220 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp2_ = publishing_flickr_publishing_options_pane_create_visibilities (self, &_tmp1_);
#line 1220 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		self->priv->visibilities = (_vala_array_free (self->priv->visibilities, self->priv->visibilities_length1, (GDestroyNotify) publishing_flickr_publishing_options_pane_visibility_entry_unref), NULL);
#line 1220 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		self->priv->visibilities = _tmp2_;
#line 1220 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		self->priv->visibilities_length1 = _tmp1_;
#line 1220 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		self->priv->_visibilities_size_ = self->priv->visibilities_length1;
#line 8390 "FlickrPublishing.c"
	}
#line 1222 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp3_ = self->priv->visibilities;
#line 1222 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp3__length1 = self->priv->visibilities_length1;
#line 8396 "FlickrPublishing.c"
	{
		PublishingFlickrPublishingOptionsPaneVisibilityEntry** v_collection = NULL;
		gint v_collection_length1 = 0;
		gint _v_collection_size_ = 0;
		gint v_it = 0;
#line 1222 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		v_collection = _tmp3_;
#line 1222 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		v_collection_length1 = _tmp3__length1;
#line 1222 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		for (v_it = 0; v_it < _tmp3__length1; v_it = v_it + 1) {
#line 8408 "FlickrPublishing.c"
			PublishingFlickrPublishingOptionsPaneVisibilityEntry* _tmp4_ = NULL;
			PublishingFlickrPublishingOptionsPaneVisibilityEntry* v = NULL;
#line 1222 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_tmp4_ = _publishing_flickr_publishing_options_pane_visibility_entry_ref0 (v_collection[v_it]);
#line 1222 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			v = _tmp4_;
#line 8415 "FlickrPublishing.c"
			{
				GtkComboBoxText* _tmp5_ = NULL;
				PublishingFlickrPublishingOptionsPaneVisibilityEntry* _tmp6_ = NULL;
				const gchar* _tmp7_ = NULL;
#line 1223 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp5_ = self->priv->visibility_combo;
#line 1223 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp6_ = v;
#line 1223 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp7_ = _tmp6_->title;
#line 1223 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				gtk_combo_box_text_append_text (_tmp5_, _tmp7_);
#line 1222 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_publishing_flickr_publishing_options_pane_visibility_entry_unref0 (v);
#line 8430 "FlickrPublishing.c"
			}
		}
	}
#line 1225 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp8_ = self->priv->visibility_combo;
#line 1225 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp9_ = self->priv->publisher;
#line 1225 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp10_ = publishing_flickr_flickr_publisher_get_persistent_visibility (_tmp9_);
#line 1225 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	gtk_combo_box_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, gtk_combo_box_get_type (), GtkComboBox), _tmp10_);
#line 8442 "FlickrPublishing.c"
}


static void _vala_array_add25 (PublishingFlickrPublishingOptionsPaneSizeEntry*** array, int* length, int* size, PublishingFlickrPublishingOptionsPaneSizeEntry* value) {
#line 1231 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if ((*length) == (*size)) {
#line 1231 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 1231 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		*array = g_renew (PublishingFlickrPublishingOptionsPaneSizeEntry*, *array, (*size) + 1);
#line 8453 "FlickrPublishing.c"
	}
#line 1231 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	(*array)[(*length)++] = value;
#line 1231 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	(*array)[*length] = NULL;
#line 8459 "FlickrPublishing.c"
}


static void _vala_array_add26 (PublishingFlickrPublishingOptionsPaneSizeEntry*** array, int* length, int* size, PublishingFlickrPublishingOptionsPaneSizeEntry* value) {
#line 1232 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if ((*length) == (*size)) {
#line 1232 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 1232 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		*array = g_renew (PublishingFlickrPublishingOptionsPaneSizeEntry*, *array, (*size) + 1);
#line 8470 "FlickrPublishing.c"
	}
#line 1232 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	(*array)[(*length)++] = value;
#line 1232 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	(*array)[*length] = NULL;
#line 8476 "FlickrPublishing.c"
}


static void _vala_array_add27 (PublishingFlickrPublishingOptionsPaneSizeEntry*** array, int* length, int* size, PublishingFlickrPublishingOptionsPaneSizeEntry* value) {
#line 1233 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if ((*length) == (*size)) {
#line 1233 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 1233 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		*array = g_renew (PublishingFlickrPublishingOptionsPaneSizeEntry*, *array, (*size) + 1);
#line 8487 "FlickrPublishing.c"
	}
#line 1233 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	(*array)[(*length)++] = value;
#line 1233 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	(*array)[*length] = NULL;
#line 8493 "FlickrPublishing.c"
}


static void _vala_array_add28 (PublishingFlickrPublishingOptionsPaneSizeEntry*** array, int* length, int* size, PublishingFlickrPublishingOptionsPaneSizeEntry* value) {
#line 1234 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if ((*length) == (*size)) {
#line 1234 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 1234 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		*array = g_renew (PublishingFlickrPublishingOptionsPaneSizeEntry*, *array, (*size) + 1);
#line 8504 "FlickrPublishing.c"
	}
#line 1234 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	(*array)[(*length)++] = value;
#line 1234 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	(*array)[*length] = NULL;
#line 8510 "FlickrPublishing.c"
}


static void _vala_array_add29 (PublishingFlickrPublishingOptionsPaneSizeEntry*** array, int* length, int* size, PublishingFlickrPublishingOptionsPaneSizeEntry* value) {
#line 1235 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if ((*length) == (*size)) {
#line 1235 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 1235 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		*array = g_renew (PublishingFlickrPublishingOptionsPaneSizeEntry*, *array, (*size) + 1);
#line 8521 "FlickrPublishing.c"
	}
#line 1235 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	(*array)[(*length)++] = value;
#line 1235 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	(*array)[*length] = NULL;
#line 8527 "FlickrPublishing.c"
}


static PublishingFlickrPublishingOptionsPaneSizeEntry** publishing_flickr_publishing_options_pane_create_sizes (PublishingFlickrPublishingOptionsPane* self, int* result_length1) {
	PublishingFlickrPublishingOptionsPaneSizeEntry** result = NULL;
	PublishingFlickrPublishingOptionsPaneSizeEntry** _result_ = NULL;
	PublishingFlickrPublishingOptionsPaneSizeEntry** _tmp0_ = NULL;
	gint _result__length1 = 0;
	gint __result__size_ = 0;
	PublishingFlickrPublishingOptionsPaneSizeEntry** _tmp1_ = NULL;
	gint _tmp1__length1 = 0;
	const gchar* _tmp2_ = NULL;
	PublishingFlickrPublishingOptionsPaneSizeEntry* _tmp3_ = NULL;
	PublishingFlickrPublishingOptionsPaneSizeEntry** _tmp4_ = NULL;
	gint _tmp4__length1 = 0;
	const gchar* _tmp5_ = NULL;
	PublishingFlickrPublishingOptionsPaneSizeEntry* _tmp6_ = NULL;
	PublishingFlickrPublishingOptionsPaneSizeEntry** _tmp7_ = NULL;
	gint _tmp7__length1 = 0;
	const gchar* _tmp8_ = NULL;
	PublishingFlickrPublishingOptionsPaneSizeEntry* _tmp9_ = NULL;
	PublishingFlickrPublishingOptionsPaneSizeEntry** _tmp10_ = NULL;
	gint _tmp10__length1 = 0;
	const gchar* _tmp11_ = NULL;
	PublishingFlickrPublishingOptionsPaneSizeEntry* _tmp12_ = NULL;
	PublishingFlickrPublishingOptionsPaneSizeEntry** _tmp13_ = NULL;
	gint _tmp13__length1 = 0;
	const gchar* _tmp14_ = NULL;
	PublishingFlickrPublishingOptionsPaneSizeEntry* _tmp15_ = NULL;
	PublishingFlickrPublishingOptionsPaneSizeEntry** _tmp16_ = NULL;
	gint _tmp16__length1 = 0;
#line 1228 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (PUBLISHING_FLICKR_IS_PUBLISHING_OPTIONS_PANE (self), NULL);
#line 1229 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = g_new0 (PublishingFlickrPublishingOptionsPaneSizeEntry*, 0 + 1);
#line 1229 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_result_ = _tmp0_;
#line 1229 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_result__length1 = 0;
#line 1229 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	__result__size_ = _result__length1;
#line 1231 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = _result_;
#line 1231 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1__length1 = _result__length1;
#line 1231 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp2_ = _ ("500 x 375 pixels");
#line 1231 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp3_ = publishing_flickr_publishing_options_pane_size_entry_new (_tmp2_, 500);
#line 1231 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_vala_array_add25 (&_result_, &_result__length1, &__result__size_, _tmp3_);
#line 1232 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp4_ = _result_;
#line 1232 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp4__length1 = _result__length1;
#line 1232 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp5_ = _ ("1024 x 768 pixels");
#line 1232 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp6_ = publishing_flickr_publishing_options_pane_size_entry_new (_tmp5_, 1024);
#line 1232 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_vala_array_add26 (&_result_, &_result__length1, &__result__size_, _tmp6_);
#line 1233 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp7_ = _result_;
#line 1233 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp7__length1 = _result__length1;
#line 1233 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp8_ = _ ("2048 x 1536 pixels");
#line 1233 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp9_ = publishing_flickr_publishing_options_pane_size_entry_new (_tmp8_, 2048);
#line 1233 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_vala_array_add27 (&_result_, &_result__length1, &__result__size_, _tmp9_);
#line 1234 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp10_ = _result_;
#line 1234 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp10__length1 = _result__length1;
#line 1234 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp11_ = _ ("4096 x 3072 pixels");
#line 1234 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp12_ = publishing_flickr_publishing_options_pane_size_entry_new (_tmp11_, 4096);
#line 1234 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_vala_array_add28 (&_result_, &_result__length1, &__result__size_, _tmp12_);
#line 1235 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp13_ = _result_;
#line 1235 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp13__length1 = _result__length1;
#line 1235 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp14_ = _ ("Original size");
#line 1235 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp15_ = publishing_flickr_publishing_options_pane_size_entry_new (_tmp14_, PUBLISHING_FLICKR_ORIGINAL_SIZE);
#line 1235 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_vala_array_add29 (&_result_, &_result__length1, &__result__size_, _tmp15_);
#line 1237 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp16_ = _result_;
#line 1237 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp16__length1 = _result__length1;
#line 1237 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (result_length1) {
#line 1237 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		*result_length1 = _tmp16__length1;
#line 8627 "FlickrPublishing.c"
	}
#line 1237 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	result = _tmp16_;
#line 1237 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return result;
#line 8633 "FlickrPublishing.c"
}


static gpointer _publishing_flickr_publishing_options_pane_size_entry_ref0 (gpointer self) {
#line 1244 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return self ? publishing_flickr_publishing_options_pane_size_entry_ref (self) : NULL;
#line 8640 "FlickrPublishing.c"
}


static void publishing_flickr_publishing_options_pane_populate_size_combo (PublishingFlickrPublishingOptionsPane* self) {
	PublishingFlickrPublishingOptionsPaneSizeEntry** _tmp0_ = NULL;
	gint _tmp0__length1 = 0;
	PublishingFlickrPublishingOptionsPaneSizeEntry** _tmp3_ = NULL;
	gint _tmp3__length1 = 0;
	GtkComboBoxText* _tmp8_ = NULL;
	PublishingFlickrFlickrPublisher* _tmp9_ = NULL;
	gint _tmp10_ = 0;
#line 1240 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_PUBLISHING_OPTIONS_PANE (self));
#line 1241 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = self->priv->sizes;
#line 1241 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0__length1 = self->priv->sizes_length1;
#line 1241 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (_tmp0_ == NULL) {
#line 8660 "FlickrPublishing.c"
		gint _tmp1_ = 0;
		PublishingFlickrPublishingOptionsPaneSizeEntry** _tmp2_ = NULL;
#line 1242 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp2_ = publishing_flickr_publishing_options_pane_create_sizes (self, &_tmp1_);
#line 1242 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		self->priv->sizes = (_vala_array_free (self->priv->sizes, self->priv->sizes_length1, (GDestroyNotify) publishing_flickr_publishing_options_pane_size_entry_unref), NULL);
#line 1242 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		self->priv->sizes = _tmp2_;
#line 1242 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		self->priv->sizes_length1 = _tmp1_;
#line 1242 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		self->priv->_sizes_size_ = self->priv->sizes_length1;
#line 8673 "FlickrPublishing.c"
	}
#line 1244 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp3_ = self->priv->sizes;
#line 1244 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp3__length1 = self->priv->sizes_length1;
#line 8679 "FlickrPublishing.c"
	{
		PublishingFlickrPublishingOptionsPaneSizeEntry** e_collection = NULL;
		gint e_collection_length1 = 0;
		gint _e_collection_size_ = 0;
		gint e_it = 0;
#line 1244 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		e_collection = _tmp3_;
#line 1244 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		e_collection_length1 = _tmp3__length1;
#line 1244 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		for (e_it = 0; e_it < _tmp3__length1; e_it = e_it + 1) {
#line 8691 "FlickrPublishing.c"
			PublishingFlickrPublishingOptionsPaneSizeEntry* _tmp4_ = NULL;
			PublishingFlickrPublishingOptionsPaneSizeEntry* e = NULL;
#line 1244 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_tmp4_ = _publishing_flickr_publishing_options_pane_size_entry_ref0 (e_collection[e_it]);
#line 1244 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			e = _tmp4_;
#line 8698 "FlickrPublishing.c"
			{
				GtkComboBoxText* _tmp5_ = NULL;
				PublishingFlickrPublishingOptionsPaneSizeEntry* _tmp6_ = NULL;
				const gchar* _tmp7_ = NULL;
#line 1245 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp5_ = self->priv->size_combo;
#line 1245 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp6_ = e;
#line 1245 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp7_ = _tmp6_->title;
#line 1245 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				gtk_combo_box_text_append_text (_tmp5_, _tmp7_);
#line 1244 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_publishing_flickr_publishing_options_pane_size_entry_unref0 (e);
#line 8713 "FlickrPublishing.c"
			}
		}
	}
#line 1247 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp8_ = self->priv->size_combo;
#line 1247 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp9_ = self->priv->publisher;
#line 1247 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp10_ = publishing_flickr_flickr_publisher_get_persistent_default_size (_tmp9_);
#line 1247 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	gtk_combo_box_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, gtk_combo_box_get_type (), GtkComboBox), _tmp10_);
#line 8725 "FlickrPublishing.c"
}


static void publishing_flickr_publishing_options_pane_on_size_changed (PublishingFlickrPublishingOptionsPane* self) {
	PublishingFlickrFlickrPublisher* _tmp0_ = NULL;
	GtkComboBoxText* _tmp1_ = NULL;
	gint _tmp2_ = 0;
#line 1250 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_PUBLISHING_OPTIONS_PANE (self));
#line 1251 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = self->priv->publisher;
#line 1251 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = self->priv->size_combo;
#line 1251 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp2_ = gtk_combo_box_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, gtk_combo_box_get_type (), GtkComboBox));
#line 1251 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_flickr_publisher_set_persistent_default_size (_tmp0_, _tmp2_);
#line 8743 "FlickrPublishing.c"
}


static void publishing_flickr_publishing_options_pane_on_visibility_changed (PublishingFlickrPublishingOptionsPane* self) {
	PublishingFlickrFlickrPublisher* _tmp0_ = NULL;
	GtkComboBoxText* _tmp1_ = NULL;
	gint _tmp2_ = 0;
#line 1254 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_PUBLISHING_OPTIONS_PANE (self));
#line 1255 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = self->priv->publisher;
#line 1255 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = self->priv->visibility_combo;
#line 1255 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp2_ = gtk_combo_box_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, gtk_combo_box_get_type (), GtkComboBox));
#line 1255 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_flickr_publisher_set_persistent_visibility (_tmp0_, _tmp2_);
#line 8761 "FlickrPublishing.c"
}


void publishing_flickr_publishing_options_pane_notify_publish (PublishingFlickrPublishingOptionsPane* self) {
	GtkCheckButton* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
#line 1258 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_PUBLISHING_OPTIONS_PANE (self));
#line 1259 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = self->priv->strip_metadata_check;
#line 1259 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = gtk_toggle_button_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_toggle_button_get_type (), GtkToggleButton));
#line 1259 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_emit_by_name (self, "publish", _tmp1_);
#line 8776 "FlickrPublishing.c"
}


void publishing_flickr_publishing_options_pane_notify_logout (PublishingFlickrPublishingOptionsPane* self) {
#line 1262 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_PUBLISHING_OPTIONS_PANE (self));
#line 1263 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_emit_by_name (self, "logout");
#line 8785 "FlickrPublishing.c"
}


static GtkWidget* publishing_flickr_publishing_options_pane_real_get_widget (SpitPublishingDialogPane* base) {
	PublishingFlickrPublishingOptionsPane * self;
	GtkWidget* result = NULL;
	GtkBox* _tmp0_ = NULL;
	GtkWidget* _tmp1_ = NULL;
#line 1266 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_FLICKR_TYPE_PUBLISHING_OPTIONS_PANE, PublishingFlickrPublishingOptionsPane);
#line 1267 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = self->priv->pane_widget;
#line 1267 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_widget_get_type (), GtkWidget));
#line 1267 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	result = _tmp1_;
#line 1267 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return result;
#line 8804 "FlickrPublishing.c"
}


static SpitPublishingDialogPaneGeometryOptions publishing_flickr_publishing_options_pane_real_get_preferred_geometry (SpitPublishingDialogPane* base) {
	PublishingFlickrPublishingOptionsPane * self;
	SpitPublishingDialogPaneGeometryOptions result = 0;
#line 1270 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_FLICKR_TYPE_PUBLISHING_OPTIONS_PANE, PublishingFlickrPublishingOptionsPane);
#line 1271 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	result = SPIT_PUBLISHING_DIALOG_PANE_GEOMETRY_OPTIONS_NONE;
#line 1271 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return result;
#line 8817 "FlickrPublishing.c"
}


static void _publishing_flickr_publishing_options_pane_notify_publish_publishing_flickr_publishing_options_pane_publish (PublishingFlickrPublishingOptionsPane* _sender, gboolean strip_metadata, gpointer self) {
#line 1275 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_publishing_options_pane_notify_publish ((PublishingFlickrPublishingOptionsPane*) self);
#line 8824 "FlickrPublishing.c"
}


static void _publishing_flickr_publishing_options_pane_notify_logout_publishing_flickr_publishing_options_pane_logout (PublishingFlickrPublishingOptionsPane* _sender, gpointer self) {
#line 1276 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_publishing_options_pane_notify_logout ((PublishingFlickrPublishingOptionsPane*) self);
#line 8831 "FlickrPublishing.c"
}


static void publishing_flickr_publishing_options_pane_real_on_pane_installed (SpitPublishingDialogPane* base) {
	PublishingFlickrPublishingOptionsPane * self;
#line 1274 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_FLICKR_TYPE_PUBLISHING_OPTIONS_PANE, PublishingFlickrPublishingOptionsPane);
#line 1275 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_connect_object (self, "publish", (GCallback) _publishing_flickr_publishing_options_pane_notify_publish_publishing_flickr_publishing_options_pane_publish, self, 0);
#line 1276 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_connect_object (self, "logout", (GCallback) _publishing_flickr_publishing_options_pane_notify_logout_publishing_flickr_publishing_options_pane_logout, self, 0);
#line 8843 "FlickrPublishing.c"
}


static void publishing_flickr_publishing_options_pane_real_on_pane_uninstalled (SpitPublishingDialogPane* base) {
	PublishingFlickrPublishingOptionsPane * self;
	guint _tmp0_ = 0U;
	guint _tmp1_ = 0U;
#line 1279 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_FLICKR_TYPE_PUBLISHING_OPTIONS_PANE, PublishingFlickrPublishingOptionsPane);
#line 1280 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_parse_name ("publish", PUBLISHING_FLICKR_TYPE_PUBLISHING_OPTIONS_PANE, &_tmp0_, NULL, FALSE);
#line 1280 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_handlers_disconnect_matched (self, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp0_, 0, NULL, (GCallback) _publishing_flickr_publishing_options_pane_notify_publish_publishing_flickr_publishing_options_pane_publish, self);
#line 1281 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_parse_name ("logout", PUBLISHING_FLICKR_TYPE_PUBLISHING_OPTIONS_PANE, &_tmp1_, NULL, FALSE);
#line 1281 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_handlers_disconnect_matched (self, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_flickr_publishing_options_pane_notify_logout_publishing_flickr_publishing_options_pane_logout, self);
#line 8861 "FlickrPublishing.c"
}


static PublishingFlickrPublishingOptionsPaneSizeEntry* publishing_flickr_publishing_options_pane_size_entry_construct (GType object_type, const gchar* creator_title, gint creator_size) {
	PublishingFlickrPublishingOptionsPaneSizeEntry* self = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	gint _tmp2_ = 0;
#line 1093 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (creator_title != NULL, NULL);
#line 1093 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = (PublishingFlickrPublishingOptionsPaneSizeEntry*) g_type_create_instance (object_type);
#line 1094 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = creator_title;
#line 1094 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 1094 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (self->title);
#line 1094 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->title = _tmp1_;
#line 1095 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp2_ = creator_size;
#line 1095 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->size = _tmp2_;
#line 1093 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return self;
#line 8888 "FlickrPublishing.c"
}


static PublishingFlickrPublishingOptionsPaneSizeEntry* publishing_flickr_publishing_options_pane_size_entry_new (const gchar* creator_title, gint creator_size) {
#line 1093 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return publishing_flickr_publishing_options_pane_size_entry_construct (PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_TYPE_SIZE_ENTRY, creator_title, creator_size);
#line 8895 "FlickrPublishing.c"
}


static void publishing_flickr_publishing_options_pane_value_size_entry_init (GValue* value) {
#line 1089 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	value->data[0].v_pointer = NULL;
#line 8902 "FlickrPublishing.c"
}


static void publishing_flickr_publishing_options_pane_value_size_entry_free_value (GValue* value) {
#line 1089 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (value->data[0].v_pointer) {
#line 1089 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		publishing_flickr_publishing_options_pane_size_entry_unref (value->data[0].v_pointer);
#line 8911 "FlickrPublishing.c"
	}
}


static void publishing_flickr_publishing_options_pane_value_size_entry_copy_value (const GValue* src_value, GValue* dest_value) {
#line 1089 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (src_value->data[0].v_pointer) {
#line 1089 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		dest_value->data[0].v_pointer = publishing_flickr_publishing_options_pane_size_entry_ref (src_value->data[0].v_pointer);
#line 8921 "FlickrPublishing.c"
	} else {
#line 1089 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		dest_value->data[0].v_pointer = NULL;
#line 8925 "FlickrPublishing.c"
	}
}


static gpointer publishing_flickr_publishing_options_pane_value_size_entry_peek_pointer (const GValue* value) {
#line 1089 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return value->data[0].v_pointer;
#line 8933 "FlickrPublishing.c"
}


static gchar* publishing_flickr_publishing_options_pane_value_size_entry_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
#line 1089 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (collect_values[0].v_pointer) {
#line 8940 "FlickrPublishing.c"
		PublishingFlickrPublishingOptionsPaneSizeEntry* object;
		object = collect_values[0].v_pointer;
#line 1089 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		if (object->parent_instance.g_class == NULL) {
#line 1089 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 8947 "FlickrPublishing.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 1089 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 8951 "FlickrPublishing.c"
		}
#line 1089 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		value->data[0].v_pointer = publishing_flickr_publishing_options_pane_size_entry_ref (object);
#line 8955 "FlickrPublishing.c"
	} else {
#line 1089 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 8959 "FlickrPublishing.c"
	}
#line 1089 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return NULL;
#line 8963 "FlickrPublishing.c"
}


static gchar* publishing_flickr_publishing_options_pane_value_size_entry_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	PublishingFlickrPublishingOptionsPaneSizeEntry** object_p;
	object_p = collect_values[0].v_pointer;
#line 1089 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (!object_p) {
#line 1089 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 8974 "FlickrPublishing.c"
	}
#line 1089 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (!value->data[0].v_pointer) {
#line 1089 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		*object_p = NULL;
#line 8980 "FlickrPublishing.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 1089 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		*object_p = value->data[0].v_pointer;
#line 8984 "FlickrPublishing.c"
	} else {
#line 1089 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		*object_p = publishing_flickr_publishing_options_pane_size_entry_ref (value->data[0].v_pointer);
#line 8988 "FlickrPublishing.c"
	}
#line 1089 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return NULL;
#line 8992 "FlickrPublishing.c"
}


static GParamSpec* publishing_flickr_publishing_options_pane_param_spec_size_entry (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
	PublishingFlickrPublishingOptionsPaneParamSpecSizeEntry* spec;
#line 1089 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (g_type_is_a (object_type, PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_TYPE_SIZE_ENTRY), NULL);
#line 1089 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 1089 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 1089 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return G_PARAM_SPEC (spec);
#line 9006 "FlickrPublishing.c"
}


static gpointer publishing_flickr_publishing_options_pane_value_get_size_entry (const GValue* value) {
#line 1089 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_TYPE_SIZE_ENTRY), NULL);
#line 1089 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return value->data[0].v_pointer;
#line 9015 "FlickrPublishing.c"
}


static void publishing_flickr_publishing_options_pane_value_set_size_entry (GValue* value, gpointer v_object) {
	PublishingFlickrPublishingOptionsPaneSizeEntry* old;
#line 1089 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_TYPE_SIZE_ENTRY));
#line 1089 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	old = value->data[0].v_pointer;
#line 1089 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (v_object) {
#line 1089 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_TYPE_SIZE_ENTRY));
#line 1089 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 1089 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		value->data[0].v_pointer = v_object;
#line 1089 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		publishing_flickr_publishing_options_pane_size_entry_ref (value->data[0].v_pointer);
#line 9035 "FlickrPublishing.c"
	} else {
#line 1089 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 9039 "FlickrPublishing.c"
	}
#line 1089 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (old) {
#line 1089 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		publishing_flickr_publishing_options_pane_size_entry_unref (old);
#line 9045 "FlickrPublishing.c"
	}
}


static void publishing_flickr_publishing_options_pane_value_take_size_entry (GValue* value, gpointer v_object) {
	PublishingFlickrPublishingOptionsPaneSizeEntry* old;
#line 1089 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_TYPE_SIZE_ENTRY));
#line 1089 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	old = value->data[0].v_pointer;
#line 1089 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (v_object) {
#line 1089 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_TYPE_SIZE_ENTRY));
#line 1089 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 1089 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		value->data[0].v_pointer = v_object;
#line 9064 "FlickrPublishing.c"
	} else {
#line 1089 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 9068 "FlickrPublishing.c"
	}
#line 1089 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (old) {
#line 1089 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		publishing_flickr_publishing_options_pane_size_entry_unref (old);
#line 9074 "FlickrPublishing.c"
	}
}


static void publishing_flickr_publishing_options_pane_size_entry_class_init (PublishingFlickrPublishingOptionsPaneSizeEntryClass * klass) {
#line 1089 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_publishing_options_pane_size_entry_parent_class = g_type_class_peek_parent (klass);
#line 1089 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	((PublishingFlickrPublishingOptionsPaneSizeEntryClass *) klass)->finalize = publishing_flickr_publishing_options_pane_size_entry_finalize;
#line 9084 "FlickrPublishing.c"
}


static void publishing_flickr_publishing_options_pane_size_entry_instance_init (PublishingFlickrPublishingOptionsPaneSizeEntry * self) {
#line 1089 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->ref_count = 1;
#line 9091 "FlickrPublishing.c"
}


static void publishing_flickr_publishing_options_pane_size_entry_finalize (PublishingFlickrPublishingOptionsPaneSizeEntry* obj) {
	PublishingFlickrPublishingOptionsPaneSizeEntry * self;
#line 1089 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_TYPE_SIZE_ENTRY, PublishingFlickrPublishingOptionsPaneSizeEntry);
#line 1089 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_handlers_destroy (self);
#line 1090 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (self->title);
#line 9103 "FlickrPublishing.c"
}


static GType publishing_flickr_publishing_options_pane_size_entry_get_type (void) {
	static volatile gsize publishing_flickr_publishing_options_pane_size_entry_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_flickr_publishing_options_pane_size_entry_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { publishing_flickr_publishing_options_pane_value_size_entry_init, publishing_flickr_publishing_options_pane_value_size_entry_free_value, publishing_flickr_publishing_options_pane_value_size_entry_copy_value, publishing_flickr_publishing_options_pane_value_size_entry_peek_pointer, "p", publishing_flickr_publishing_options_pane_value_size_entry_collect_value, "p", publishing_flickr_publishing_options_pane_value_size_entry_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (PublishingFlickrPublishingOptionsPaneSizeEntryClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_flickr_publishing_options_pane_size_entry_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingFlickrPublishingOptionsPaneSizeEntry), 0, (GInstanceInitFunc) publishing_flickr_publishing_options_pane_size_entry_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType publishing_flickr_publishing_options_pane_size_entry_type_id;
		publishing_flickr_publishing_options_pane_size_entry_type_id = g_type_register_fundamental (g_type_fundamental_next (), "PublishingFlickrPublishingOptionsPaneSizeEntry", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&publishing_flickr_publishing_options_pane_size_entry_type_id__volatile, publishing_flickr_publishing_options_pane_size_entry_type_id);
	}
	return publishing_flickr_publishing_options_pane_size_entry_type_id__volatile;
}


static gpointer publishing_flickr_publishing_options_pane_size_entry_ref (gpointer instance) {
	PublishingFlickrPublishingOptionsPaneSizeEntry* self;
	self = instance;
#line 1089 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_atomic_int_inc (&self->ref_count);
#line 1089 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return instance;
#line 9128 "FlickrPublishing.c"
}


static void publishing_flickr_publishing_options_pane_size_entry_unref (gpointer instance) {
	PublishingFlickrPublishingOptionsPaneSizeEntry* self;
	self = instance;
#line 1089 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 1089 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_SIZE_ENTRY_GET_CLASS (self)->finalize (self);
#line 1089 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 9141 "FlickrPublishing.c"
	}
}


static PublishingFlickrPublishingOptionsPaneVisibilityEntry* publishing_flickr_publishing_options_pane_visibility_entry_construct (GType object_type, const gchar* creator_title, PublishingFlickrVisibilitySpecification* creator_specification) {
	PublishingFlickrPublishingOptionsPaneVisibilityEntry* self = NULL;
	PublishingFlickrVisibilitySpecification* _tmp0_ = NULL;
	PublishingFlickrVisibilitySpecification* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
#line 1103 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (creator_title != NULL, NULL);
#line 1103 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (PUBLISHING_FLICKR_IS_VISIBILITY_SPECIFICATION (creator_specification), NULL);
#line 1103 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = (PublishingFlickrPublishingOptionsPaneVisibilityEntry*) g_type_create_instance (object_type);
#line 1104 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = creator_specification;
#line 1104 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = _publishing_flickr_visibility_specification_ref0 (_tmp0_);
#line 1104 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_publishing_flickr_visibility_specification_unref0 (self->specification);
#line 1104 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->specification = _tmp1_;
#line 1105 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp2_ = creator_title;
#line 1105 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp3_ = g_strdup (_tmp2_);
#line 1105 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (self->title);
#line 1105 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->title = _tmp3_;
#line 1103 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return self;
#line 9176 "FlickrPublishing.c"
}


static PublishingFlickrPublishingOptionsPaneVisibilityEntry* publishing_flickr_publishing_options_pane_visibility_entry_new (const gchar* creator_title, PublishingFlickrVisibilitySpecification* creator_specification) {
#line 1103 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return publishing_flickr_publishing_options_pane_visibility_entry_construct (PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_TYPE_VISIBILITY_ENTRY, creator_title, creator_specification);
#line 9183 "FlickrPublishing.c"
}


static void publishing_flickr_publishing_options_pane_value_visibility_entry_init (GValue* value) {
#line 1099 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	value->data[0].v_pointer = NULL;
#line 9190 "FlickrPublishing.c"
}


static void publishing_flickr_publishing_options_pane_value_visibility_entry_free_value (GValue* value) {
#line 1099 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (value->data[0].v_pointer) {
#line 1099 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		publishing_flickr_publishing_options_pane_visibility_entry_unref (value->data[0].v_pointer);
#line 9199 "FlickrPublishing.c"
	}
}


static void publishing_flickr_publishing_options_pane_value_visibility_entry_copy_value (const GValue* src_value, GValue* dest_value) {
#line 1099 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (src_value->data[0].v_pointer) {
#line 1099 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		dest_value->data[0].v_pointer = publishing_flickr_publishing_options_pane_visibility_entry_ref (src_value->data[0].v_pointer);
#line 9209 "FlickrPublishing.c"
	} else {
#line 1099 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		dest_value->data[0].v_pointer = NULL;
#line 9213 "FlickrPublishing.c"
	}
}


static gpointer publishing_flickr_publishing_options_pane_value_visibility_entry_peek_pointer (const GValue* value) {
#line 1099 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return value->data[0].v_pointer;
#line 9221 "FlickrPublishing.c"
}


static gchar* publishing_flickr_publishing_options_pane_value_visibility_entry_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
#line 1099 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (collect_values[0].v_pointer) {
#line 9228 "FlickrPublishing.c"
		PublishingFlickrPublishingOptionsPaneVisibilityEntry* object;
		object = collect_values[0].v_pointer;
#line 1099 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		if (object->parent_instance.g_class == NULL) {
#line 1099 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 9235 "FlickrPublishing.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 1099 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 9239 "FlickrPublishing.c"
		}
#line 1099 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		value->data[0].v_pointer = publishing_flickr_publishing_options_pane_visibility_entry_ref (object);
#line 9243 "FlickrPublishing.c"
	} else {
#line 1099 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 9247 "FlickrPublishing.c"
	}
#line 1099 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return NULL;
#line 9251 "FlickrPublishing.c"
}


static gchar* publishing_flickr_publishing_options_pane_value_visibility_entry_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	PublishingFlickrPublishingOptionsPaneVisibilityEntry** object_p;
	object_p = collect_values[0].v_pointer;
#line 1099 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (!object_p) {
#line 1099 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 9262 "FlickrPublishing.c"
	}
#line 1099 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (!value->data[0].v_pointer) {
#line 1099 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		*object_p = NULL;
#line 9268 "FlickrPublishing.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 1099 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		*object_p = value->data[0].v_pointer;
#line 9272 "FlickrPublishing.c"
	} else {
#line 1099 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		*object_p = publishing_flickr_publishing_options_pane_visibility_entry_ref (value->data[0].v_pointer);
#line 9276 "FlickrPublishing.c"
	}
#line 1099 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return NULL;
#line 9280 "FlickrPublishing.c"
}


static GParamSpec* publishing_flickr_publishing_options_pane_param_spec_visibility_entry (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
	PublishingFlickrPublishingOptionsPaneParamSpecVisibilityEntry* spec;
#line 1099 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (g_type_is_a (object_type, PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_TYPE_VISIBILITY_ENTRY), NULL);
#line 1099 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 1099 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 1099 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return G_PARAM_SPEC (spec);
#line 9294 "FlickrPublishing.c"
}


static gpointer publishing_flickr_publishing_options_pane_value_get_visibility_entry (const GValue* value) {
#line 1099 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_TYPE_VISIBILITY_ENTRY), NULL);
#line 1099 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return value->data[0].v_pointer;
#line 9303 "FlickrPublishing.c"
}


static void publishing_flickr_publishing_options_pane_value_set_visibility_entry (GValue* value, gpointer v_object) {
	PublishingFlickrPublishingOptionsPaneVisibilityEntry* old;
#line 1099 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_TYPE_VISIBILITY_ENTRY));
#line 1099 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	old = value->data[0].v_pointer;
#line 1099 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (v_object) {
#line 1099 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_TYPE_VISIBILITY_ENTRY));
#line 1099 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 1099 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		value->data[0].v_pointer = v_object;
#line 1099 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		publishing_flickr_publishing_options_pane_visibility_entry_ref (value->data[0].v_pointer);
#line 9323 "FlickrPublishing.c"
	} else {
#line 1099 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 9327 "FlickrPublishing.c"
	}
#line 1099 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (old) {
#line 1099 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		publishing_flickr_publishing_options_pane_visibility_entry_unref (old);
#line 9333 "FlickrPublishing.c"
	}
}


static void publishing_flickr_publishing_options_pane_value_take_visibility_entry (GValue* value, gpointer v_object) {
	PublishingFlickrPublishingOptionsPaneVisibilityEntry* old;
#line 1099 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_TYPE_VISIBILITY_ENTRY));
#line 1099 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	old = value->data[0].v_pointer;
#line 1099 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (v_object) {
#line 1099 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_TYPE_VISIBILITY_ENTRY));
#line 1099 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 1099 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		value->data[0].v_pointer = v_object;
#line 9352 "FlickrPublishing.c"
	} else {
#line 1099 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 9356 "FlickrPublishing.c"
	}
#line 1099 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (old) {
#line 1099 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		publishing_flickr_publishing_options_pane_visibility_entry_unref (old);
#line 9362 "FlickrPublishing.c"
	}
}


static void publishing_flickr_publishing_options_pane_visibility_entry_class_init (PublishingFlickrPublishingOptionsPaneVisibilityEntryClass * klass) {
#line 1099 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_publishing_options_pane_visibility_entry_parent_class = g_type_class_peek_parent (klass);
#line 1099 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	((PublishingFlickrPublishingOptionsPaneVisibilityEntryClass *) klass)->finalize = publishing_flickr_publishing_options_pane_visibility_entry_finalize;
#line 9372 "FlickrPublishing.c"
}


static void publishing_flickr_publishing_options_pane_visibility_entry_instance_init (PublishingFlickrPublishingOptionsPaneVisibilityEntry * self) {
#line 1099 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->ref_count = 1;
#line 9379 "FlickrPublishing.c"
}


static void publishing_flickr_publishing_options_pane_visibility_entry_finalize (PublishingFlickrPublishingOptionsPaneVisibilityEntry* obj) {
	PublishingFlickrPublishingOptionsPaneVisibilityEntry * self;
#line 1099 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_TYPE_VISIBILITY_ENTRY, PublishingFlickrPublishingOptionsPaneVisibilityEntry);
#line 1099 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_handlers_destroy (self);
#line 1100 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_publishing_flickr_visibility_specification_unref0 (self->specification);
#line 1101 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (self->title);
#line 9393 "FlickrPublishing.c"
}


static GType publishing_flickr_publishing_options_pane_visibility_entry_get_type (void) {
	static volatile gsize publishing_flickr_publishing_options_pane_visibility_entry_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_flickr_publishing_options_pane_visibility_entry_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { publishing_flickr_publishing_options_pane_value_visibility_entry_init, publishing_flickr_publishing_options_pane_value_visibility_entry_free_value, publishing_flickr_publishing_options_pane_value_visibility_entry_copy_value, publishing_flickr_publishing_options_pane_value_visibility_entry_peek_pointer, "p", publishing_flickr_publishing_options_pane_value_visibility_entry_collect_value, "p", publishing_flickr_publishing_options_pane_value_visibility_entry_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (PublishingFlickrPublishingOptionsPaneVisibilityEntryClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_flickr_publishing_options_pane_visibility_entry_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingFlickrPublishingOptionsPaneVisibilityEntry), 0, (GInstanceInitFunc) publishing_flickr_publishing_options_pane_visibility_entry_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType publishing_flickr_publishing_options_pane_visibility_entry_type_id;
		publishing_flickr_publishing_options_pane_visibility_entry_type_id = g_type_register_fundamental (g_type_fundamental_next (), "PublishingFlickrPublishingOptionsPaneVisibilityEntry", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&publishing_flickr_publishing_options_pane_visibility_entry_type_id__volatile, publishing_flickr_publishing_options_pane_visibility_entry_type_id);
	}
	return publishing_flickr_publishing_options_pane_visibility_entry_type_id__volatile;
}


static gpointer publishing_flickr_publishing_options_pane_visibility_entry_ref (gpointer instance) {
	PublishingFlickrPublishingOptionsPaneVisibilityEntry* self;
	self = instance;
#line 1099 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_atomic_int_inc (&self->ref_count);
#line 1099 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return instance;
#line 9418 "FlickrPublishing.c"
}


static void publishing_flickr_publishing_options_pane_visibility_entry_unref (gpointer instance) {
	PublishingFlickrPublishingOptionsPaneVisibilityEntry* self;
	self = instance;
#line 1099 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 1099 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_VISIBILITY_ENTRY_GET_CLASS (self)->finalize (self);
#line 1099 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 9431 "FlickrPublishing.c"
	}
}


static void publishing_flickr_publishing_options_pane_class_init (PublishingFlickrPublishingOptionsPaneClass * klass) {
#line 1088 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_publishing_options_pane_parent_class = g_type_class_peek_parent (klass);
#line 1088 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_type_class_add_private (klass, sizeof (PublishingFlickrPublishingOptionsPanePrivate));
#line 1088 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	G_OBJECT_CLASS (klass)->finalize = publishing_flickr_publishing_options_pane_finalize;
#line 1088 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_new ("publish", PUBLISHING_FLICKR_TYPE_PUBLISHING_OPTIONS_PANE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__BOOLEAN, G_TYPE_NONE, 1, G_TYPE_BOOLEAN);
#line 1088 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_new ("logout", PUBLISHING_FLICKR_TYPE_PUBLISHING_OPTIONS_PANE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
#line 9447 "FlickrPublishing.c"
}


static void publishing_flickr_publishing_options_pane_spit_publishing_dialog_pane_interface_init (SpitPublishingDialogPaneIface * iface) {
#line 1088 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_publishing_options_pane_spit_publishing_dialog_pane_parent_iface = g_type_interface_peek_parent (iface);
#line 1088 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	iface->get_widget = (GtkWidget* (*)(SpitPublishingDialogPane*)) publishing_flickr_publishing_options_pane_real_get_widget;
#line 1088 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	iface->get_preferred_geometry = (SpitPublishingDialogPaneGeometryOptions (*)(SpitPublishingDialogPane*)) publishing_flickr_publishing_options_pane_real_get_preferred_geometry;
#line 1088 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	iface->on_pane_installed = (void (*)(SpitPublishingDialogPane*)) publishing_flickr_publishing_options_pane_real_on_pane_installed;
#line 1088 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	iface->on_pane_uninstalled = (void (*)(SpitPublishingDialogPane*)) publishing_flickr_publishing_options_pane_real_on_pane_uninstalled;
#line 9462 "FlickrPublishing.c"
}


static void publishing_flickr_publishing_options_pane_instance_init (PublishingFlickrPublishingOptionsPane * self) {
#line 1088 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv = PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_GET_PRIVATE (self);
#line 1110 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->pane_widget = NULL;
#line 1111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->visibility_label = NULL;
#line 1112 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->upload_info_label = NULL;
#line 1113 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->size_label = NULL;
#line 1114 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->logout_button = NULL;
#line 1115 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->publish_button = NULL;
#line 1116 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->visibility_combo = NULL;
#line 1117 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->size_combo = NULL;
#line 1118 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->strip_metadata_check = NULL;
#line 1119 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->visibilities = NULL;
#line 1119 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->visibilities_length1 = 0;
#line 1119 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->_visibilities_size_ = self->priv->visibilities_length1;
#line 1120 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->sizes = NULL;
#line 1120 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->sizes_length1 = 0;
#line 1120 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->_sizes_size_ = self->priv->sizes_length1;
#line 1121 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->parameters = NULL;
#line 1122 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->publisher = NULL;
#line 9503 "FlickrPublishing.c"
}


static void publishing_flickr_publishing_options_pane_finalize (GObject* obj) {
	PublishingFlickrPublishingOptionsPane * self;
#line 1088 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_FLICKR_TYPE_PUBLISHING_OPTIONS_PANE, PublishingFlickrPublishingOptionsPane);
#line 1109 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (self->priv->builder);
#line 1110 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (self->priv->pane_widget);
#line 1111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (self->priv->visibility_label);
#line 1112 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (self->priv->upload_info_label);
#line 1113 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (self->priv->size_label);
#line 1114 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (self->priv->logout_button);
#line 1115 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (self->priv->publish_button);
#line 1116 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (self->priv->visibility_combo);
#line 1117 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (self->priv->size_combo);
#line 1118 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (self->priv->strip_metadata_check);
#line 1119 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->visibilities = (_vala_array_free (self->priv->visibilities, self->priv->visibilities_length1, (GDestroyNotify) publishing_flickr_publishing_options_pane_visibility_entry_unref), NULL);
#line 1120 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->sizes = (_vala_array_free (self->priv->sizes, self->priv->sizes_length1, (GDestroyNotify) publishing_flickr_publishing_options_pane_size_entry_unref), NULL);
#line 1121 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_publishing_flickr_publishing_parameters_unref0 (self->priv->parameters);
#line 1122 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (self->priv->publisher);
#line 1088 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	G_OBJECT_CLASS (publishing_flickr_publishing_options_pane_parent_class)->finalize (obj);
#line 9541 "FlickrPublishing.c"
}


GType publishing_flickr_publishing_options_pane_get_type (void) {
	static volatile gsize publishing_flickr_publishing_options_pane_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_flickr_publishing_options_pane_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingFlickrPublishingOptionsPaneClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_flickr_publishing_options_pane_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingFlickrPublishingOptionsPane), 0, (GInstanceInitFunc) publishing_flickr_publishing_options_pane_instance_init, NULL };
		static const GInterfaceInfo spit_publishing_dialog_pane_info = { (GInterfaceInitFunc) publishing_flickr_publishing_options_pane_spit_publishing_dialog_pane_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType publishing_flickr_publishing_options_pane_type_id;
		publishing_flickr_publishing_options_pane_type_id = g_type_register_static (G_TYPE_OBJECT, "PublishingFlickrPublishingOptionsPane", &g_define_type_info, 0);
		g_type_add_interface_static (publishing_flickr_publishing_options_pane_type_id, SPIT_PUBLISHING_TYPE_DIALOG_PANE, &spit_publishing_dialog_pane_info);
		g_once_init_leave (&publishing_flickr_publishing_options_pane_type_id__volatile, publishing_flickr_publishing_options_pane_type_id);
	}
	return publishing_flickr_publishing_options_pane_type_id__volatile;
}


PublishingFlickrUploader* publishing_flickr_uploader_construct (GType object_type, PublishingFlickrSession* session, SpitPublishingPublishable** publishables, int publishables_length1, PublishingFlickrPublishingParameters* parameters, gboolean strip_metadata) {
	PublishingFlickrUploader* self = NULL;
	PublishingFlickrSession* _tmp0_ = NULL;
	SpitPublishingPublishable** _tmp1_ = NULL;
	gint _tmp1__length1 = 0;
	PublishingFlickrPublishingParameters* _tmp2_ = NULL;
	PublishingFlickrPublishingParameters* _tmp3_ = NULL;
	gboolean _tmp4_ = FALSE;
#line 1289 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (PUBLISHING_FLICKR_IS_SESSION (session), NULL);
#line 1289 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (PUBLISHING_FLICKR_IS_PUBLISHING_PARAMETERS (parameters), NULL);
#line 1291 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = session;
#line 1291 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = publishables;
#line 1291 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1__length1 = publishables_length1;
#line 1291 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = (PublishingFlickrUploader*) publishing_rest_support_batch_uploader_construct (object_type, G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession), _tmp1_, _tmp1__length1);
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp2_ = parameters;
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp3_ = _publishing_flickr_publishing_parameters_ref0 (_tmp2_);
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_publishing_flickr_publishing_parameters_unref0 (self->priv->parameters);
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->parameters = _tmp3_;
#line 1294 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp4_ = strip_metadata;
#line 1294 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->strip_metadata = _tmp4_;
#line 1289 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return self;
#line 9593 "FlickrPublishing.c"
}


PublishingFlickrUploader* publishing_flickr_uploader_new (PublishingFlickrSession* session, SpitPublishingPublishable** publishables, int publishables_length1, PublishingFlickrPublishingParameters* parameters, gboolean strip_metadata) {
#line 1289 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return publishing_flickr_uploader_construct (PUBLISHING_FLICKR_TYPE_UPLOADER, session, publishables, publishables_length1, parameters, strip_metadata);
#line 9600 "FlickrPublishing.c"
}


static void _vala_array_add30 (gchar*** array, int* length, int* size, gchar* value) {
#line 1343 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if ((*length) == (*size)) {
#line 1343 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 1343 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		*array = g_renew (gchar*, *array, (*size) + 1);
#line 9611 "FlickrPublishing.c"
	}
#line 1343 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	(*array)[(*length)++] = value;
#line 1343 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	(*array)[*length] = NULL;
#line 9617 "FlickrPublishing.c"
}


static void publishing_flickr_uploader_preprocess_publishable (PublishingFlickrUploader* self, SpitPublishingPublishable* publishable) {
	SpitPublishingPublishable* _tmp0_ = NULL;
	SpitPublishingPublisherMediaType _tmp1_ = 0;
	GExiv2Metadata* publishable_metadata = NULL;
	GExiv2Metadata* _tmp2_ = NULL;
	GExiv2Metadata* _tmp14_ = NULL;
	gboolean _tmp15_ = FALSE;
	GExiv2Metadata* _tmp16_ = NULL;
	gboolean _tmp17_ = FALSE;
	GExiv2Metadata* _tmp24_ = NULL;
	gboolean _tmp25_ = FALSE;
	GExiv2Metadata* _tmp32_ = NULL;
	gboolean _tmp33_ = FALSE;
	GError * _inner_error_ = NULL;
#line 1297 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_UPLOADER (self));
#line 1297 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (SPIT_PUBLISHING_IS_PUBLISHABLE (publishable));
#line 1298 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = publishable;
#line 1298 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = spit_publishing_publishable_get_media_type (_tmp0_);
#line 1298 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (_tmp1_ != SPIT_PUBLISHING_PUBLISHER_MEDIA_TYPE_PHOTO) {
#line 1299 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		return;
#line 9647 "FlickrPublishing.c"
	}
#line 1301 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp2_ = gexiv2_metadata_new ();
#line 1301 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishable_metadata = _tmp2_;
#line 9653 "FlickrPublishing.c"
	{
		GExiv2Metadata* _tmp3_ = NULL;
		SpitPublishingPublishable* _tmp4_ = NULL;
		GFile* _tmp5_ = NULL;
		GFile* _tmp6_ = NULL;
		gchar* _tmp7_ = NULL;
		gchar* _tmp8_ = NULL;
#line 1303 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp3_ = publishable_metadata;
#line 1303 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp4_ = publishable;
#line 1303 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp5_ = spit_publishing_publishable_get_serialized_file (_tmp4_);
#line 1303 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp6_ = _tmp5_;
#line 1303 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp7_ = g_file_get_path (_tmp6_);
#line 1303 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp8_ = _tmp7_;
#line 1303 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		gexiv2_metadata_open_path (_tmp3_, _tmp8_, &_inner_error_);
#line 1303 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_free0 (_tmp8_);
#line 1303 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_object_unref0 (_tmp6_);
#line 1303 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 9681 "FlickrPublishing.c"
			goto __catch25_g_error;
		}
	}
	goto __finally25;
	__catch25_g_error:
	{
		GError* err = NULL;
		SpitPublishingPublishable* _tmp9_ = NULL;
		GFile* _tmp10_ = NULL;
		GFile* _tmp11_ = NULL;
		gchar* _tmp12_ = NULL;
		gchar* _tmp13_ = NULL;
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		err = _inner_error_;
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_inner_error_ = NULL;
#line 1305 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp9_ = publishable;
#line 1305 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp10_ = spit_publishing_publishable_get_serialized_file (_tmp9_);
#line 1305 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp11_ = _tmp10_;
#line 1305 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp12_ = g_file_get_path (_tmp11_);
#line 1305 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp13_ = _tmp12_;
#line 1305 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_warning ("FlickrPublishing.vala:1305: couldn't read metadata from file '%s' for " \
"upload preprocessing.", _tmp13_);
#line 1305 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_free0 (_tmp13_);
#line 1305 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_object_unref0 (_tmp11_);
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_error_free0 (err);
#line 9716 "FlickrPublishing.c"
	}
	__finally25:
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_gexiv2_metadata_free0 (publishable_metadata);
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_clear_error (&_inner_error_);
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		return;
#line 9729 "FlickrPublishing.c"
	}
#line 1313 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp14_ = publishable_metadata;
#line 1313 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp15_ = gexiv2_metadata_has_iptc (_tmp14_);
#line 1313 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (!_tmp15_) {
#line 1314 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_gexiv2_metadata_free0 (publishable_metadata);
#line 1314 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		return;
#line 9741 "FlickrPublishing.c"
	}
#line 1316 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp16_ = publishable_metadata;
#line 1316 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp17_ = gexiv2_metadata_has_tag (_tmp16_, "Iptc.Application2.Caption");
#line 1316 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (_tmp17_) {
#line 9749 "FlickrPublishing.c"
		GExiv2Metadata* _tmp18_ = NULL;
		GExiv2Metadata* _tmp19_ = NULL;
		gchar* _tmp20_ = NULL;
		gchar* _tmp21_ = NULL;
		gchar* _tmp22_ = NULL;
		gchar* _tmp23_ = NULL;
#line 1317 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp18_ = publishable_metadata;
#line 1317 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp19_ = publishable_metadata;
#line 1317 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp20_ = gexiv2_metadata_get_tag_string (_tmp19_, "Iptc.Application2.Caption");
#line 1317 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp21_ = _tmp20_;
#line 1317 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp22_ = publishing_rest_support_asciify_string (_tmp21_);
#line 1317 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp23_ = _tmp22_;
#line 1317 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		gexiv2_metadata_set_tag_string (_tmp18_, "Iptc.Application2.Caption", _tmp23_);
#line 1317 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_free0 (_tmp23_);
#line 1317 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_free0 (_tmp21_);
#line 9774 "FlickrPublishing.c"
	}
#line 1321 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp24_ = publishable_metadata;
#line 1321 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp25_ = gexiv2_metadata_has_tag (_tmp24_, "Iptc.Application2.Headline");
#line 1321 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (_tmp25_) {
#line 9782 "FlickrPublishing.c"
		GExiv2Metadata* _tmp26_ = NULL;
		GExiv2Metadata* _tmp27_ = NULL;
		gchar* _tmp28_ = NULL;
		gchar* _tmp29_ = NULL;
		gchar* _tmp30_ = NULL;
		gchar* _tmp31_ = NULL;
#line 1322 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp26_ = publishable_metadata;
#line 1322 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp27_ = publishable_metadata;
#line 1322 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp28_ = gexiv2_metadata_get_tag_string (_tmp27_, "Iptc.Application2.Headline");
#line 1322 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp29_ = _tmp28_;
#line 1322 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp30_ = publishing_rest_support_asciify_string (_tmp29_);
#line 1322 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp31_ = _tmp30_;
#line 1322 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		gexiv2_metadata_set_tag_string (_tmp26_, "Iptc.Application2.Headline", _tmp31_);
#line 1322 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_free0 (_tmp31_);
#line 1322 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_free0 (_tmp29_);
#line 9807 "FlickrPublishing.c"
	}
#line 1326 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp32_ = publishable_metadata;
#line 1326 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp33_ = gexiv2_metadata_has_tag (_tmp32_, "Iptc.Application2.Keywords");
#line 1326 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (_tmp33_) {
#line 9815 "FlickrPublishing.c"
		GeeSet* keyword_set = NULL;
		GeeHashSet* _tmp34_ = NULL;
		gchar** iptc_keywords = NULL;
		GExiv2Metadata* _tmp35_ = NULL;
		gchar** _tmp36_ = NULL;
		gchar** _tmp37_ = NULL;
		gint iptc_keywords_length1 = 0;
		gint _iptc_keywords_size_ = 0;
		gchar** _tmp38_ = NULL;
		gint _tmp38__length1 = 0;
		gchar** xmp_keywords = NULL;
		GExiv2Metadata* _tmp43_ = NULL;
		gchar** _tmp44_ = NULL;
		gchar** _tmp45_ = NULL;
		gint xmp_keywords_length1 = 0;
		gint _xmp_keywords_size_ = 0;
		gchar** _tmp46_ = NULL;
		gint _tmp46__length1 = 0;
		gchar** all_keywords = NULL;
		GeeSet* _tmp51_ = NULL;
		gint _tmp52_ = 0;
		gpointer* _tmp53_ = NULL;
		gint all_keywords_length1 = 0;
		gint _all_keywords_size_ = 0;
		gchar** _tmp54_ = NULL;
		gint _tmp54__length1 = 0;
		gchar** no_keywords = NULL;
		gchar** _tmp55_ = NULL;
		gint no_keywords_length1 = 0;
		gint _no_keywords_size_ = 0;
		gchar** _tmp56_ = NULL;
		gint _tmp56__length1 = 0;
		gchar* _tmp57_ = NULL;
		GExiv2Metadata* _tmp58_ = NULL;
		gchar** _tmp59_ = NULL;
		gint _tmp59__length1 = 0;
		GExiv2Metadata* _tmp60_ = NULL;
		gchar** _tmp61_ = NULL;
		gint _tmp61__length1 = 0;
#line 1327 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp34_ = gee_hash_set_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL, NULL, NULL, NULL);
#line 1327 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		keyword_set = G_TYPE_CHECK_INSTANCE_CAST (_tmp34_, GEE_TYPE_SET, GeeSet);
#line 1328 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp35_ = publishable_metadata;
#line 1328 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp37_ = _tmp36_ = gexiv2_metadata_get_tag_multiple (_tmp35_, "Iptc.Application2.Keywords");
#line 1328 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		iptc_keywords = _tmp37_;
#line 1328 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		iptc_keywords_length1 = _vala_array_length (_tmp36_);
#line 1328 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_iptc_keywords_size_ = iptc_keywords_length1;
#line 1329 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp38_ = iptc_keywords;
#line 1329 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp38__length1 = iptc_keywords_length1;
#line 1329 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		if (_tmp38_ != NULL) {
#line 9875 "FlickrPublishing.c"
			gchar** _tmp39_ = NULL;
			gint _tmp39__length1 = 0;
#line 1330 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_tmp39_ = iptc_keywords;
#line 1330 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_tmp39__length1 = iptc_keywords_length1;
#line 9882 "FlickrPublishing.c"
			{
				gchar** keyword_collection = NULL;
				gint keyword_collection_length1 = 0;
				gint _keyword_collection_size_ = 0;
				gint keyword_it = 0;
#line 1330 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				keyword_collection = _tmp39_;
#line 1330 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				keyword_collection_length1 = _tmp39__length1;
#line 1330 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				for (keyword_it = 0; keyword_it < _tmp39__length1; keyword_it = keyword_it + 1) {
#line 9894 "FlickrPublishing.c"
					gchar* _tmp40_ = NULL;
					gchar* keyword = NULL;
#line 1330 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
					_tmp40_ = g_strdup (keyword_collection[keyword_it]);
#line 1330 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
					keyword = _tmp40_;
#line 9901 "FlickrPublishing.c"
					{
						GeeSet* _tmp41_ = NULL;
						const gchar* _tmp42_ = NULL;
#line 1331 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
						_tmp41_ = keyword_set;
#line 1331 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
						_tmp42_ = keyword;
#line 1331 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
						gee_collection_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp41_, GEE_TYPE_COLLECTION, GeeCollection), _tmp42_);
#line 1330 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
						_g_free0 (keyword);
#line 9913 "FlickrPublishing.c"
					}
				}
			}
		}
#line 1333 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp43_ = publishable_metadata;
#line 1333 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp45_ = _tmp44_ = gexiv2_metadata_get_tag_multiple (_tmp43_, "Xmp.dc.subject");
#line 1333 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		xmp_keywords = _tmp45_;
#line 1333 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		xmp_keywords_length1 = _vala_array_length (_tmp44_);
#line 1333 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_xmp_keywords_size_ = xmp_keywords_length1;
#line 1334 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp46_ = xmp_keywords;
#line 1334 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp46__length1 = xmp_keywords_length1;
#line 1334 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		if (_tmp46_ != NULL) {
#line 9934 "FlickrPublishing.c"
			gchar** _tmp47_ = NULL;
			gint _tmp47__length1 = 0;
#line 1335 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_tmp47_ = xmp_keywords;
#line 1335 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_tmp47__length1 = xmp_keywords_length1;
#line 9941 "FlickrPublishing.c"
			{
				gchar** keyword_collection = NULL;
				gint keyword_collection_length1 = 0;
				gint _keyword_collection_size_ = 0;
				gint keyword_it = 0;
#line 1335 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				keyword_collection = _tmp47_;
#line 1335 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				keyword_collection_length1 = _tmp47__length1;
#line 1335 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				for (keyword_it = 0; keyword_it < _tmp47__length1; keyword_it = keyword_it + 1) {
#line 9953 "FlickrPublishing.c"
					gchar* _tmp48_ = NULL;
					gchar* keyword = NULL;
#line 1335 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
					_tmp48_ = g_strdup (keyword_collection[keyword_it]);
#line 1335 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
					keyword = _tmp48_;
#line 9960 "FlickrPublishing.c"
					{
						GeeSet* _tmp49_ = NULL;
						const gchar* _tmp50_ = NULL;
#line 1336 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
						_tmp49_ = keyword_set;
#line 1336 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
						_tmp50_ = keyword;
#line 1336 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
						gee_collection_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp49_, GEE_TYPE_COLLECTION, GeeCollection), _tmp50_);
#line 1335 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
						_g_free0 (keyword);
#line 9972 "FlickrPublishing.c"
					}
				}
			}
		}
#line 1338 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp51_ = keyword_set;
#line 1338 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp53_ = gee_collection_to_array (G_TYPE_CHECK_INSTANCE_CAST (_tmp51_, GEE_TYPE_COLLECTION, GeeCollection), &_tmp52_);
#line 1338 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		all_keywords = _tmp53_;
#line 1338 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		all_keywords_length1 = _tmp52_;
#line 1338 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_all_keywords_size_ = all_keywords_length1;
#line 1343 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp54_ = all_keywords;
#line 1343 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp54__length1 = all_keywords_length1;
#line 1343 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_vala_array_add30 (&all_keywords, &all_keywords_length1, &_all_keywords_size_, NULL);
#line 1345 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp55_ = g_new0 (gchar*, 1 + 1);
#line 1345 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		no_keywords = _tmp55_;
#line 1345 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		no_keywords_length1 = 1;
#line 1345 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_no_keywords_size_ = no_keywords_length1;
#line 1350 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp56_ = no_keywords;
#line 1350 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp56__length1 = no_keywords_length1;
#line 1350 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_free0 (_tmp56_[0]);
#line 1350 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp56_[0] = NULL;
#line 1350 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp57_ = _tmp56_[0];
#line 1352 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp58_ = publishable_metadata;
#line 1352 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp59_ = all_keywords;
#line 1352 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp59__length1 = all_keywords_length1;
#line 1352 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		gexiv2_metadata_set_tag_multiple (_tmp58_, "Xmp.dc.subject", _tmp59_);
#line 1353 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp60_ = publishable_metadata;
#line 1353 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp61_ = no_keywords;
#line 1353 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp61__length1 = no_keywords_length1;
#line 1353 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		gexiv2_metadata_set_tag_multiple (_tmp60_, "Iptc.Application2.Keywords", _tmp61_);
#line 10027 "FlickrPublishing.c"
		{
			GExiv2Metadata* _tmp62_ = NULL;
			SpitPublishingPublishable* _tmp63_ = NULL;
			GFile* _tmp64_ = NULL;
			GFile* _tmp65_ = NULL;
			gchar* _tmp66_ = NULL;
			gchar* _tmp67_ = NULL;
#line 1356 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_tmp62_ = publishable_metadata;
#line 1356 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_tmp63_ = publishable;
#line 1356 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_tmp64_ = spit_publishing_publishable_get_serialized_file (_tmp63_);
#line 1356 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_tmp65_ = _tmp64_;
#line 1356 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_tmp66_ = g_file_get_path (_tmp65_);
#line 1356 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_tmp67_ = _tmp66_;
#line 1356 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			gexiv2_metadata_save_file (_tmp62_, _tmp67_, &_inner_error_);
#line 1356 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_g_free0 (_tmp67_);
#line 1356 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_g_object_unref0 (_tmp65_);
#line 1356 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 10055 "FlickrPublishing.c"
				goto __catch26_g_error;
			}
		}
		goto __finally26;
		__catch26_g_error:
		{
			GError* err = NULL;
			SpitPublishingPublishable* _tmp68_ = NULL;
			GFile* _tmp69_ = NULL;
			GFile* _tmp70_ = NULL;
			gchar* _tmp71_ = NULL;
			gchar* _tmp72_ = NULL;
#line 1355 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			err = _inner_error_;
#line 1355 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_inner_error_ = NULL;
#line 1358 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_tmp68_ = publishable;
#line 1358 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_tmp69_ = spit_publishing_publishable_get_serialized_file (_tmp68_);
#line 1358 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_tmp70_ = _tmp69_;
#line 1358 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_tmp71_ = g_file_get_path (_tmp70_);
#line 1358 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_tmp72_ = _tmp71_;
#line 1358 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			g_warning ("FlickrPublishing.vala:1358: couldn't write metadata to file '%s' for u" \
"pload preprocessing.", _tmp72_);
#line 1358 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_g_free0 (_tmp72_);
#line 1358 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_g_object_unref0 (_tmp70_);
#line 1355 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_g_error_free0 (err);
#line 10090 "FlickrPublishing.c"
		}
		__finally26:
#line 1355 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1355 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			no_keywords = (_vala_array_free (no_keywords, no_keywords_length1, (GDestroyNotify) g_free), NULL);
#line 1355 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			all_keywords = (_vala_array_free (all_keywords, all_keywords_length1, (GDestroyNotify) g_free), NULL);
#line 1355 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			xmp_keywords = (_vala_array_free (xmp_keywords, xmp_keywords_length1, (GDestroyNotify) g_free), NULL);
#line 1355 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			iptc_keywords = (_vala_array_free (iptc_keywords, iptc_keywords_length1, (GDestroyNotify) g_free), NULL);
#line 1355 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_g_object_unref0 (keyword_set);
#line 1355 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_gexiv2_metadata_free0 (publishable_metadata);
#line 1355 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1355 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			g_clear_error (&_inner_error_);
#line 1355 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			return;
#line 10113 "FlickrPublishing.c"
		}
#line 1326 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		no_keywords = (_vala_array_free (no_keywords, no_keywords_length1, (GDestroyNotify) g_free), NULL);
#line 1326 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		all_keywords = (_vala_array_free (all_keywords, all_keywords_length1, (GDestroyNotify) g_free), NULL);
#line 1326 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		xmp_keywords = (_vala_array_free (xmp_keywords, xmp_keywords_length1, (GDestroyNotify) g_free), NULL);
#line 1326 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		iptc_keywords = (_vala_array_free (iptc_keywords, iptc_keywords_length1, (GDestroyNotify) g_free), NULL);
#line 1326 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_object_unref0 (keyword_set);
#line 10125 "FlickrPublishing.c"
	}
#line 1297 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_gexiv2_metadata_free0 (publishable_metadata);
#line 10129 "FlickrPublishing.c"
}


static PublishingRESTSupportTransaction* publishing_flickr_uploader_real_create_transaction (PublishingRESTSupportBatchUploader* base, SpitPublishingPublishable* publishable) {
	PublishingFlickrUploader * self;
	PublishingRESTSupportTransaction* result = NULL;
	SpitPublishingPublishable* _tmp0_ = NULL;
	SpitPublishingPublishable* _tmp1_ = NULL;
	PublishingRESTSupportSession* _tmp2_ = NULL;
	PublishingFlickrSession* _tmp3_ = NULL;
	PublishingFlickrPublishingParameters* _tmp4_ = NULL;
	SpitPublishingPublishable* _tmp5_ = NULL;
	SpitPublishingPublishable* _tmp6_ = NULL;
	PublishingFlickrUploadTransaction* _tmp7_ = NULL;
	PublishingRESTSupportTransaction* _tmp8_ = NULL;
#line 1364 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_FLICKR_TYPE_UPLOADER, PublishingFlickrUploader);
#line 1364 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (SPIT_PUBLISHING_IS_PUBLISHABLE (publishable), NULL);
#line 1366 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = publishing_rest_support_batch_uploader_get_current_publishable (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, PublishingRESTSupportBatchUploader));
#line 1366 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = _tmp0_;
#line 1366 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_uploader_preprocess_publishable (self, _tmp1_);
#line 1366 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (_tmp1_);
#line 1367 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp2_ = publishing_rest_support_batch_uploader_get_session (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, PublishingRESTSupportBatchUploader));
#line 1367 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp3_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, PUBLISHING_FLICKR_TYPE_SESSION, PublishingFlickrSession);
#line 1367 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp4_ = self->priv->parameters;
#line 1367 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp5_ = publishing_rest_support_batch_uploader_get_current_publishable (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, PublishingRESTSupportBatchUploader));
#line 1367 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp6_ = _tmp5_;
#line 1367 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp7_ = publishing_flickr_upload_transaction_new (_tmp3_, _tmp4_, _tmp6_);
#line 1367 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp8_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction);
#line 1367 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (_tmp6_);
#line 1367 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_publishing_rest_support_session_unref0 (_tmp3_);
#line 1367 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	result = _tmp8_;
#line 1367 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return result;
#line 10179 "FlickrPublishing.c"
}


static void publishing_flickr_uploader_class_init (PublishingFlickrUploaderClass * klass) {
#line 1285 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_uploader_parent_class = g_type_class_peek_parent (klass);
#line 1285 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	((PublishingRESTSupportBatchUploaderClass *) klass)->finalize = publishing_flickr_uploader_finalize;
#line 1285 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_type_class_add_private (klass, sizeof (PublishingFlickrUploaderPrivate));
#line 1285 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	((PublishingRESTSupportBatchUploaderClass *) klass)->create_transaction = publishing_flickr_uploader_real_create_transaction;
#line 10192 "FlickrPublishing.c"
}


static void publishing_flickr_uploader_instance_init (PublishingFlickrUploader * self) {
#line 1285 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv = PUBLISHING_FLICKR_UPLOADER_GET_PRIVATE (self);
#line 10199 "FlickrPublishing.c"
}


static void publishing_flickr_uploader_finalize (PublishingRESTSupportBatchUploader* obj) {
	PublishingFlickrUploader * self;
#line 1285 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_FLICKR_TYPE_UPLOADER, PublishingFlickrUploader);
#line 1286 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_publishing_flickr_publishing_parameters_unref0 (self->priv->parameters);
#line 1285 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	PUBLISHING_REST_SUPPORT_BATCH_UPLOADER_CLASS (publishing_flickr_uploader_parent_class)->finalize (obj);
#line 10211 "FlickrPublishing.c"
}


GType publishing_flickr_uploader_get_type (void) {
	static volatile gsize publishing_flickr_uploader_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_flickr_uploader_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingFlickrUploaderClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_flickr_uploader_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingFlickrUploader), 0, (GInstanceInitFunc) publishing_flickr_uploader_instance_init, NULL };
		GType publishing_flickr_uploader_type_id;
		publishing_flickr_uploader_type_id = g_type_register_static (PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, "PublishingFlickrUploader", &g_define_type_info, 0);
		g_once_init_leave (&publishing_flickr_uploader_type_id__volatile, publishing_flickr_uploader_type_id);
	}
	return publishing_flickr_uploader_type_id__volatile;
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}


static gint _vala_array_length (gpointer array) {
	int length;
	length = 0;
	if (array) {
		while (((gpointer*) array)[length]) {
			length++;
		}
	}
	return length;
}



